import type { SimulationStore, ExtendSimulationActions, ExtendSimulationSelectors, ExtendSimulationSchema, TableOutput, AnyState } from "@simulacrum/foundation-simulator";
import { type GitHubStore, type GitHubBlob, type GitHubOrganization, type GitHubRepository, type GitHubUser } from "./entities";
import type { ExtendSimulationSchemaInput } from "@simulacrum/foundation-simulator/src/store/schema";
import type { ExtendSimulationActionsInput, ExtendSimulationSelectorsInput } from "@simulacrum/foundation-simulator/src/store";
export type ExtendedSchema = ({ slice }: ExtendSimulationSchema) => {
    users: (n: string) => TableOutput<GitHubUser, AnyState, GitHubUser | undefined>;
    repositories: (n: string) => TableOutput<GitHubRepository, AnyState, GitHubRepository | undefined>;
    organizations: (n: string) => TableOutput<GitHubOrganization, AnyState, GitHubOrganization | undefined>;
    blobs: (n: string) => TableOutput<GitHubBlob, AnyState, GitHubBlob | undefined>;
};
type ExtendActions = typeof inputActions;
type ExtendSelectors = typeof inputSelectors;
export type ExtendedSimulationStore = SimulationStore<ReturnType<ExtendedSchema>, ReturnType<ExtendActions>, ReturnType<ExtendSelectors>>;
declare const inputActions: (args: ExtendSimulationActions<ExtendedSchema>) => {};
declare const inputSelectors: (args: ExtendSimulationSelectors<ExtendedSchema>) => {
    allGithubOrganizations: ((state: AnyState) => {
        login: string;
        id: string | number;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        created_at?: string | undefined;
    }[]) & import("reselect").OutputSelectorFields<(args_0: {
        login: string;
        id: string | number;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        created_at?: string | undefined;
    }[]) => {
        login: string;
        id: string | number;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        created_at?: string | undefined;
    }[], {
        clearCache: () => void;
    }> & {
        clearCache: () => void;
    };
    getBlob: ((state: AnyState, owner: string, repo: string, sha_or_path: string) => {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        encoding: "string" | "base64";
        repo: string;
        sha: string;
    } | undefined) & import("reselect").OutputSelectorFields<(args_0: {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        encoding: "string" | "base64";
        repo: string;
        sha: string;
    }[], args_1: {
        owner: string;
        repo: string;
        sha_or_path: string;
    }) => {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        encoding: "string" | "base64";
        repo: string;
        sha: string;
    } | undefined, {
        clearCache: () => void;
    }> & {
        clearCache: () => void;
    };
    getBlobAtOwnerRepo: ((state: AnyState, owner: string, repo: string) => {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        encoding: "string" | "base64";
        repo: string;
        sha: string;
    }[]) & import("reselect").OutputSelectorFields<(args_0: {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        encoding: "string" | "base64";
        repo: string;
        sha: string;
    }[], args_1: {
        owner: string;
        repo: string;
    }) => {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        encoding: "string" | "base64";
        repo: string;
        sha: string;
    }[], {
        clearCache: () => void;
    }> & {
        clearCache: () => void;
    };
};
export declare const extendStore: <T>(initialState: GitHubStore | undefined, extended: {
    actions: ExtendSimulationActionsInput<any, ExtendSimulationSchemaInput<T>>;
    selectors: ExtendSimulationSelectorsInput<any, ExtendSimulationSchemaInput<T>>;
    schema?: ExtendSimulationSchemaInput<T>;
} | undefined) => {
    actions: (args: ExtendSimulationActions<ExtendedSchema>) => any;
    selectors: (args: ExtendSimulationSelectors<ExtendedSchema>) => any;
    schema: ({ slice }: ExtendSimulationSchema) => {
        users: (n: string) => TableOutput<{
            login: string;
            id: string | number;
            organizations: string[];
            email?: string | undefined;
            name?: string | undefined;
        }, AnyState, {
            login: string;
            id: string | number;
            organizations: string[];
            email?: string | undefined;
            name?: string | undefined;
        } | undefined>;
        repositories: (n: string) => TableOutput<{
            id: string | number;
            name: string;
            owner: string;
            full_name: string;
            packages?: string[] | undefined;
        }, AnyState, {
            id: string | number;
            name: string;
            owner: string;
            full_name: string;
            packages?: string[] | undefined;
        } | undefined>;
        organizations: (n: string) => TableOutput<{
            login: string;
            id: string | number;
            email?: string | undefined;
            name?: string | undefined;
            description?: string | undefined;
            teams?: string[] | undefined;
            created_at?: string | undefined;
        }, AnyState, {
            login: string;
            id: string | number;
            email?: string | undefined;
            name?: string | undefined;
            description?: string | undefined;
            teams?: string[] | undefined;
            created_at?: string | undefined;
        } | undefined>;
        blobs: (n: string) => TableOutput<{
            id: string | number;
            owner: string;
            path: string;
            content: string;
            encoding: "string" | "base64";
            repo: string;
            sha: string;
        }, AnyState, {
            id: string | number;
            owner: string;
            path: string;
            content: string;
            encoding: "string" | "base64";
            repo: string;
            sha: string;
        } | undefined>;
    };
};
export {};
//# sourceMappingURL=index.d.ts.map