"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extendStore = void 0;
const entities_1 = require("./entities");
const inputSchema = (initialState, extendedSchema) => ({ slice }) => {
    const storeInitialState = !initialState
        ? undefined
        : (0, entities_1.convertInitialStateToStoreState)(initialState);
    const extended = extendedSchema ? extendedSchema({ slice }) : {};
    let slices = {
        users: slice.table(!storeInitialState ? {} : { initialState: storeInitialState.users }),
        repositories: slice.table(!storeInitialState
            ? {}
            : { initialState: storeInitialState.repositories }),
        organizations: slice.table(!storeInitialState
            ? {}
            : { initialState: storeInitialState.organizations }),
        blobs: slice.table(!storeInitialState ? {} : { initialState: storeInitialState.blobs }),
        ...extended,
    };
    return slices;
};
const inputActions = (args) => {
    return {};
};
const extendActions = (extendedActions) => (args) => {
    return extendedActions
        ? // @ts-expect-error schema is cyclical, ignore extension for now
            { ...inputActions(args), ...extendedActions(args) }
        : inputActions(args);
};
const inputSelectors = (args) => {
    const { createSelector, schema } = args;
    const allGithubOrganizations = createSelector(schema.organizations.selectTableAsList, (ghOrgs) => {
        return ghOrgs;
    });
    const getBlob = createSelector(schema.blobs.selectTableAsList, (_state, owner, repo, sha_or_path) => ({
        owner,
        repo,
        sha_or_path,
    }), (blobs, { owner, repo, sha_or_path }) => {
        const blob = blobs.find((blob) => blob.owner === owner &&
            blob.repo === repo &&
            (blob.path === sha_or_path || blob.sha === sha_or_path));
        return blob;
    });
    const getBlobAtOwnerRepo = createSelector(schema.blobs.selectTableAsList, (_state, owner, repo) => ({
        owner,
        repo,
    }), (blobs, { owner, repo }) => {
        const blob = blobs.filter((blob) => blob.owner === owner && blob.repo === repo);
        return blob;
    });
    return { allGithubOrganizations, getBlob, getBlobAtOwnerRepo };
};
const extendSelectors = (extendedSelectors) => (args) => {
    return extendedSelectors
        ? // @ts-expect-error schema is cyclical, ignore extension for now
            { ...inputSelectors(args), ...extendedSelectors(args) }
        : inputSelectors(args);
};
const extendStore = (initialState, extended) => ({
    actions: extendActions(extended === null || extended === void 0 ? void 0 : extended.actions),
    selectors: extendSelectors(extended === null || extended === void 0 ? void 0 : extended.selectors),
    schema: inputSchema(initialState, extended === null || extended === void 0 ? void 0 : extended.schema),
});
exports.extendStore = extendStore;
//# sourceMappingURL=index.js.map