import { z } from "zod";
import { IdProp } from "@simulacrum/foundation-simulator";
export declare const githubUserSchema: z.ZodEffects<z.ZodObject<{
    id: z.ZodDefault<z.ZodUnion<[z.ZodString, z.ZodNumber]>>;
    login: z.ZodString;
    name: z.ZodOptional<z.ZodString>;
    email: z.ZodOptional<z.ZodString>;
    organizations: z.ZodArray<z.ZodString, "many">;
}, "strip", z.ZodTypeAny, {
    login: string;
    id: string | number;
    organizations: string[];
    email?: string | undefined;
    name?: string | undefined;
}, {
    login: string;
    organizations: string[];
    id?: string | number | undefined;
    email?: string | undefined;
    name?: string | undefined;
}>, {
    login: string;
    id: string | number;
    organizations: string[];
    email?: string | undefined;
    name?: string | undefined;
}, {
    login: string;
    organizations: string[];
    id?: string | number | undefined;
    email?: string | undefined;
    name?: string | undefined;
}>;
export type GitHubUser = z.infer<typeof githubUserSchema>;
export declare const githubRepositorySchema: z.ZodEffects<z.ZodObject<{
    id: z.ZodDefault<z.ZodUnion<[z.ZodString, z.ZodNumber]>>;
    name: z.ZodString;
    owner: z.ZodString;
    full_name: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    packages: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
}, "strip", z.ZodTypeAny, {
    id: string | number;
    name: string;
    owner: string;
    full_name: string;
    packages?: string[] | undefined;
}, {
    name: string;
    owner: string;
    id?: string | number | undefined;
    packages?: string[] | undefined;
    full_name?: string | undefined;
}>, {
    id: string | number;
    name: string;
    owner: string;
    full_name: string;
    packages?: string[] | undefined;
}, {
    name: string;
    owner: string;
    id?: string | number | undefined;
    packages?: string[] | undefined;
    full_name?: string | undefined;
}>;
export type GitHubRepository = z.infer<typeof githubRepositorySchema>;
export declare const githubOrganizationSchema: z.ZodEffects<z.ZodObject<{
    id: z.ZodDefault<z.ZodUnion<[z.ZodString, z.ZodNumber]>>;
    login: z.ZodString;
    name: z.ZodOptional<z.ZodString>;
    email: z.ZodOptional<z.ZodString>;
    description: z.ZodOptional<z.ZodString>;
    created_at: z.ZodOptional<z.ZodDefault<z.ZodString>>;
    teams: z.ZodUnion<[z.ZodArray<z.ZodString, "many">, z.ZodUndefined]>;
}, "strip", z.ZodTypeAny, {
    login: string;
    id: string | number;
    email?: string | undefined;
    name?: string | undefined;
    description?: string | undefined;
    teams?: string[] | undefined;
    created_at?: string | undefined;
}, {
    login: string;
    id?: string | number | undefined;
    email?: string | undefined;
    name?: string | undefined;
    description?: string | undefined;
    teams?: string[] | undefined;
    created_at?: string | undefined;
}>, {
    login: string;
    id: string | number;
    email?: string | undefined;
    name?: string | undefined;
    description?: string | undefined;
    teams?: string[] | undefined;
    created_at?: string | undefined;
}, {
    login: string;
    id?: string | number | undefined;
    email?: string | undefined;
    name?: string | undefined;
    description?: string | undefined;
    teams?: string[] | undefined;
    created_at?: string | undefined;
}>;
export type GitHubOrganization = z.infer<typeof githubOrganizationSchema>;
export declare const githubBlobSchema: z.ZodEffects<z.ZodObject<{
    id: z.ZodDefault<z.ZodUnion<[z.ZodString, z.ZodNumber]>>;
    content: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    encoding: z.ZodDefault<z.ZodUnion<[z.ZodLiteral<"string">, z.ZodLiteral<"base64">]>>;
    owner: z.ZodString;
    repo: z.ZodString;
    path: z.ZodString;
    sha: z.ZodString;
}, "strip", z.ZodTypeAny, {
    id: string | number;
    owner: string;
    path: string;
    content: string;
    encoding: "string" | "base64";
    repo: string;
    sha: string;
}, {
    owner: string;
    path: string;
    repo: string;
    sha: string;
    id?: string | number | undefined;
    content?: string | undefined;
    encoding?: "string" | "base64" | undefined;
}>, {
    id: string | number;
    owner: string;
    path: string;
    content: string;
    encoding: "string" | "base64";
    repo: string;
    sha: string;
}, {
    owner: string;
    path: string;
    repo: string;
    sha: string;
    id?: string | number | undefined;
    content?: string | undefined;
    encoding?: "string" | "base64" | undefined;
}>;
export type GitHubBlob = z.infer<typeof githubBlobSchema>;
export declare const gitubInitialStoreSchema: z.ZodObject<{
    users: z.ZodArray<z.ZodEffects<z.ZodObject<{
        id: z.ZodDefault<z.ZodUnion<[z.ZodString, z.ZodNumber]>>;
        login: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
        email: z.ZodOptional<z.ZodString>;
        organizations: z.ZodArray<z.ZodString, "many">;
    }, "strip", z.ZodTypeAny, {
        login: string;
        id: string | number;
        organizations: string[];
        email?: string | undefined;
        name?: string | undefined;
    }, {
        login: string;
        organizations: string[];
        id?: string | number | undefined;
        email?: string | undefined;
        name?: string | undefined;
    }>, {
        login: string;
        id: string | number;
        organizations: string[];
        email?: string | undefined;
        name?: string | undefined;
    }, {
        login: string;
        organizations: string[];
        id?: string | number | undefined;
        email?: string | undefined;
        name?: string | undefined;
    }>, "many">;
    repositories: z.ZodArray<z.ZodEffects<z.ZodObject<{
        id: z.ZodDefault<z.ZodUnion<[z.ZodString, z.ZodNumber]>>;
        name: z.ZodString;
        owner: z.ZodString;
        full_name: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        packages: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        id: string | number;
        name: string;
        owner: string;
        full_name: string;
        packages?: string[] | undefined;
    }, {
        name: string;
        owner: string;
        id?: string | number | undefined;
        packages?: string[] | undefined;
        full_name?: string | undefined;
    }>, {
        id: string | number;
        name: string;
        owner: string;
        full_name: string;
        packages?: string[] | undefined;
    }, {
        name: string;
        owner: string;
        id?: string | number | undefined;
        packages?: string[] | undefined;
        full_name?: string | undefined;
    }>, "many">;
    organizations: z.ZodArray<z.ZodEffects<z.ZodObject<{
        id: z.ZodDefault<z.ZodUnion<[z.ZodString, z.ZodNumber]>>;
        login: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
        email: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodString>;
        created_at: z.ZodOptional<z.ZodDefault<z.ZodString>>;
        teams: z.ZodUnion<[z.ZodArray<z.ZodString, "many">, z.ZodUndefined]>;
    }, "strip", z.ZodTypeAny, {
        login: string;
        id: string | number;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        created_at?: string | undefined;
    }, {
        login: string;
        id?: string | number | undefined;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        created_at?: string | undefined;
    }>, {
        login: string;
        id: string | number;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        created_at?: string | undefined;
    }, {
        login: string;
        id?: string | number | undefined;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        created_at?: string | undefined;
    }>, "many">;
    blobs: z.ZodArray<z.ZodEffects<z.ZodObject<{
        id: z.ZodDefault<z.ZodUnion<[z.ZodString, z.ZodNumber]>>;
        content: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        encoding: z.ZodDefault<z.ZodUnion<[z.ZodLiteral<"string">, z.ZodLiteral<"base64">]>>;
        owner: z.ZodString;
        repo: z.ZodString;
        path: z.ZodString;
        sha: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        encoding: "string" | "base64";
        repo: string;
        sha: string;
    }, {
        owner: string;
        path: string;
        repo: string;
        sha: string;
        id?: string | number | undefined;
        content?: string | undefined;
        encoding?: "string" | "base64" | undefined;
    }>, {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        encoding: "string" | "base64";
        repo: string;
        sha: string;
    }, {
        owner: string;
        path: string;
        repo: string;
        sha: string;
        id?: string | number | undefined;
        content?: string | undefined;
        encoding?: "string" | "base64" | undefined;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    repositories: {
        id: string | number;
        name: string;
        owner: string;
        full_name: string;
        packages?: string[] | undefined;
    }[];
    organizations: {
        login: string;
        id: string | number;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        created_at?: string | undefined;
    }[];
    users: {
        login: string;
        id: string | number;
        organizations: string[];
        email?: string | undefined;
        name?: string | undefined;
    }[];
    blobs: {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        encoding: "string" | "base64";
        repo: string;
        sha: string;
    }[];
}, {
    repositories: {
        name: string;
        owner: string;
        id?: string | number | undefined;
        packages?: string[] | undefined;
        full_name?: string | undefined;
    }[];
    organizations: {
        login: string;
        id?: string | number | undefined;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        created_at?: string | undefined;
    }[];
    users: {
        login: string;
        organizations: string[];
        id?: string | number | undefined;
        email?: string | undefined;
        name?: string | undefined;
    }[];
    blobs: {
        owner: string;
        path: string;
        repo: string;
        sha: string;
        id?: string | number | undefined;
        content?: string | undefined;
        encoding?: "string" | "base64" | undefined;
    }[];
}>;
export type GitHubStore = z.output<typeof gitubInitialStoreSchema>;
export type GitHubInitialStore = z.input<typeof gitubInitialStoreSchema>;
export declare const convertToObj: <T extends {
    id: IdProp;
    [k: string]: any;
}>(arrayOfObjects: T[]) => Record<IdProp, T>;
export declare const convertInitialStateToStoreState: (initialState: GitHubStore | undefined) => {
    users: Record<IdProp, {
        login: string;
        id: string | number;
        organizations: string[];
        email?: string | undefined;
        name?: string | undefined;
    }>;
    repositories: Record<IdProp, {
        id: string | number;
        name: string;
        owner: string;
        full_name: string;
        packages?: string[] | undefined;
    }>;
    organizations: Record<IdProp, {
        login: string;
        id: string | number;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        created_at?: string | undefined;
    }>;
    blobs: Record<IdProp, {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        encoding: "string" | "base64";
        repo: string;
        sha: string;
    }>;
} | undefined;
//# sourceMappingURL=entities.d.ts.map