import { GraphQLResolveInfo, GraphQLScalarType, GraphQLScalarTypeConfig } from 'graphql';
export type Maybe<T> = T | null;
export type InputMaybe<T> = Maybe<T>;
export type Exact<T extends {
    [key: string]: unknown;
}> = {
    [K in keyof T]: T[K];
};
export type MakeOptional<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]?: Maybe<T[SubKey]>;
};
export type MakeMaybe<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]: Maybe<T[SubKey]>;
};
export type MakeEmpty<T extends {
    [key: string]: unknown;
}, K extends keyof T> = {
    [_ in K]?: never;
};
export type Incremental<T> = T | {
    [P in keyof T]?: P extends ' $fragmentName' | '__typename' ? T[P] : never;
};
export type Omit<T, K extends keyof T> = Pick<T, Exclude<keyof T, K>>;
export type RequireFields<T, K extends keyof T> = Omit<T, K> & {
    [P in K]-?: NonNullable<T[P]>;
};
/** All built-in and custom scalars, mapped to their actual values */
export type Scalars = {
    ID: {
        input: string;
        output: string;
    };
    String: {
        input: string;
        output: string;
    };
    Boolean: {
        input: boolean;
        output: boolean;
    };
    Int: {
        input: number;
        output: number;
    };
    Float: {
        input: number;
        output: number;
    };
    /** An ISO-8601 encoded date string. */
    Date: {
        input: any;
        output: any;
    };
    /** An ISO-8601 encoded UTC date string. */
    DateTime: {
        input: any;
        output: any;
    };
    /** A Git object ID. */
    GitObjectID: {
        input: any;
        output: any;
    };
    /** A fully qualified reference name (e.g. `refs/heads/master`). */
    GitRefname: {
        input: any;
        output: any;
    };
    /** Git SSH string */
    GitSSHRemote: {
        input: any;
        output: any;
    };
    /** An ISO-8601 encoded date string. Unlike the DateTime type, GitTimestamp is not converted in UTC. */
    GitTimestamp: {
        input: any;
        output: any;
    };
    /** A string containing HTML code. */
    HTML: {
        input: any;
        output: any;
    };
    /** An ISO-8601 encoded UTC date string with millisecond precision. */
    PreciseDateTime: {
        input: any;
        output: any;
    };
    /** An RFC 3986, RFC 3987, and RFC 6570 (level 4) compliant URI string. */
    URI: {
        input: any;
        output: any;
    };
    /** A valid x509 certificate string */
    X509Certificate: {
        input: any;
        output: any;
    };
};
/** Represents an object which can take actions on GitHub. Typically a User or Bot. */
export type Actor = {
    /** A URL pointing to the actor's public avatar. */
    avatarUrl: Scalars['URI']['output'];
    /** The username of the actor. */
    login: Scalars['String']['output'];
    /** The HTTP path for this actor. */
    resourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this actor. */
    url: Scalars['URI']['output'];
};
/** Represents an object which can take actions on GitHub. Typically a User or Bot. */
export type ActorAvatarUrlArgs = {
    size?: InputMaybe<Scalars['Int']['input']>;
};
/** Location information for an actor */
export type ActorLocation = {
    __typename?: 'ActorLocation';
    /** City */
    city?: Maybe<Scalars['String']['output']>;
    /** Country name */
    country?: Maybe<Scalars['String']['output']>;
    /** Country code */
    countryCode?: Maybe<Scalars['String']['output']>;
    /** Region name */
    region?: Maybe<Scalars['String']['output']>;
    /** Region or state code */
    regionCode?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of AddAssigneesToAssignable */
export type AddAssigneesToAssignableInput = {
    /** The id of the assignable object to add assignees to. */
    assignableId: Scalars['ID']['input'];
    /** The id of users to add as assignees. */
    assigneeIds: Array<Scalars['ID']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
};
/** Autogenerated return type of AddAssigneesToAssignable */
export type AddAssigneesToAssignablePayload = {
    __typename?: 'AddAssigneesToAssignablePayload';
    /** The item that was assigned. */
    assignable?: Maybe<Assignable>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of AddComment */
export type AddCommentInput = {
    /** The contents of the comment. */
    body: Scalars['String']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the subject to modify. */
    subjectId: Scalars['ID']['input'];
};
/** Autogenerated return type of AddComment */
export type AddCommentPayload = {
    __typename?: 'AddCommentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The edge from the subject's comment connection. */
    commentEdge?: Maybe<IssueCommentEdge>;
    /** The subject */
    subject?: Maybe<Node>;
    /** The edge from the subject's timeline connection. */
    timelineEdge?: Maybe<IssueTimelineItemEdge>;
};
/** Autogenerated input type of AddDiscussionComment */
export type AddDiscussionCommentInput = {
    /** The contents of the comment. */
    body: Scalars['String']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the discussion to comment on. */
    discussionId: Scalars['ID']['input'];
    /** The Node ID of the discussion comment within this discussion to reply to. */
    replyToId?: InputMaybe<Scalars['ID']['input']>;
};
/** Autogenerated return type of AddDiscussionComment */
export type AddDiscussionCommentPayload = {
    __typename?: 'AddDiscussionCommentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The newly created discussion comment. */
    comment?: Maybe<DiscussionComment>;
};
/** Autogenerated input type of AddEnterpriseAdmin */
export type AddEnterpriseAdminInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the enterprise account to which the administrator should be added. */
    enterpriseId: Scalars['ID']['input'];
    /** The login of the user to add as an administrator. */
    login: Scalars['String']['input'];
};
/** Autogenerated return type of AddEnterpriseAdmin */
export type AddEnterpriseAdminPayload = {
    __typename?: 'AddEnterpriseAdminPayload';
    /** The user who was added as an administrator. */
    admin?: Maybe<User>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated enterprise. */
    enterprise?: Maybe<Enterprise>;
    /** The role of the administrator. */
    role?: Maybe<EnterpriseAdministratorRole>;
    /** The viewer performing the mutation. */
    viewer?: Maybe<User>;
};
/** Autogenerated input type of AddLabelsToLabelable */
export type AddLabelsToLabelableInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ids of the labels to add. */
    labelIds: Array<Scalars['ID']['input']>;
    /** The id of the labelable object to add labels to. */
    labelableId: Scalars['ID']['input'];
};
/** Autogenerated return type of AddLabelsToLabelable */
export type AddLabelsToLabelablePayload = {
    __typename?: 'AddLabelsToLabelablePayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The item that was labeled. */
    labelable?: Maybe<Labelable>;
};
/** Autogenerated input type of AddProjectCard */
export type AddProjectCardInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The content of the card. Must be a member of the ProjectCardItem union */
    contentId?: InputMaybe<Scalars['ID']['input']>;
    /** The note on the card. */
    note?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the ProjectColumn. */
    projectColumnId: Scalars['ID']['input'];
};
/** Autogenerated return type of AddProjectCard */
export type AddProjectCardPayload = {
    __typename?: 'AddProjectCardPayload';
    /** The edge from the ProjectColumn's card connection. */
    cardEdge?: Maybe<ProjectCardEdge>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The ProjectColumn */
    projectColumn?: Maybe<ProjectColumn>;
};
/** Autogenerated input type of AddProjectColumn */
export type AddProjectColumnInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The name of the column. */
    name: Scalars['String']['input'];
    /** The Node ID of the project. */
    projectId: Scalars['ID']['input'];
};
/** Autogenerated return type of AddProjectColumn */
export type AddProjectColumnPayload = {
    __typename?: 'AddProjectColumnPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The edge from the project's column connection. */
    columnEdge?: Maybe<ProjectColumnEdge>;
    /** The project */
    project?: Maybe<Project>;
};
/** Autogenerated input type of AddPullRequestReviewComment */
export type AddPullRequestReviewCommentInput = {
    /** The text of the comment. */
    body: Scalars['String']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The SHA of the commit to comment on. */
    commitOID?: InputMaybe<Scalars['GitObjectID']['input']>;
    /** The comment id to reply to. */
    inReplyTo?: InputMaybe<Scalars['ID']['input']>;
    /** The relative path of the file to comment on. */
    path?: InputMaybe<Scalars['String']['input']>;
    /** The line index in the diff to comment on. */
    position?: InputMaybe<Scalars['Int']['input']>;
    /** The node ID of the pull request reviewing */
    pullRequestId?: InputMaybe<Scalars['ID']['input']>;
    /** The Node ID of the review to modify. */
    pullRequestReviewId?: InputMaybe<Scalars['ID']['input']>;
};
/** Autogenerated return type of AddPullRequestReviewComment */
export type AddPullRequestReviewCommentPayload = {
    __typename?: 'AddPullRequestReviewCommentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The newly created comment. */
    comment?: Maybe<PullRequestReviewComment>;
    /** The edge from the review's comment connection. */
    commentEdge?: Maybe<PullRequestReviewCommentEdge>;
};
/** Autogenerated input type of AddPullRequestReview */
export type AddPullRequestReviewInput = {
    /** The contents of the review body comment. */
    body?: InputMaybe<Scalars['String']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The review line comments. */
    comments?: InputMaybe<Array<InputMaybe<DraftPullRequestReviewComment>>>;
    /** The commit OID the review pertains to. */
    commitOID?: InputMaybe<Scalars['GitObjectID']['input']>;
    /** The event to perform on the pull request review. */
    event?: InputMaybe<PullRequestReviewEvent>;
    /** The Node ID of the pull request to modify. */
    pullRequestId: Scalars['ID']['input'];
    /** The review line comment threads. */
    threads?: InputMaybe<Array<InputMaybe<DraftPullRequestReviewThread>>>;
};
/** Autogenerated return type of AddPullRequestReview */
export type AddPullRequestReviewPayload = {
    __typename?: 'AddPullRequestReviewPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The newly created pull request review. */
    pullRequestReview?: Maybe<PullRequestReview>;
    /** The edge from the pull request's review connection. */
    reviewEdge?: Maybe<PullRequestReviewEdge>;
};
/** Autogenerated input type of AddPullRequestReviewThread */
export type AddPullRequestReviewThreadInput = {
    /** Body of the thread's first comment. */
    body: Scalars['String']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The line of the blob to which the thread refers. The end of the line range for multi-line comments. */
    line: Scalars['Int']['input'];
    /** Path to the file being commented on. */
    path: Scalars['String']['input'];
    /** The node ID of the pull request reviewing */
    pullRequestId?: InputMaybe<Scalars['ID']['input']>;
    /** The Node ID of the review to modify. */
    pullRequestReviewId?: InputMaybe<Scalars['ID']['input']>;
    /** The side of the diff on which the line resides. For multi-line comments, this is the side for the end of the line range. */
    side?: InputMaybe<DiffSide>;
    /** The first line of the range to which the comment refers. */
    startLine?: InputMaybe<Scalars['Int']['input']>;
    /** The side of the diff on which the start line resides. */
    startSide?: InputMaybe<DiffSide>;
};
/** Autogenerated return type of AddPullRequestReviewThread */
export type AddPullRequestReviewThreadPayload = {
    __typename?: 'AddPullRequestReviewThreadPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The newly created thread. */
    thread?: Maybe<PullRequestReviewThread>;
};
/** Autogenerated input type of AddReaction */
export type AddReactionInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The name of the emoji to react with. */
    content: ReactionContent;
    /** The Node ID of the subject to modify. */
    subjectId: Scalars['ID']['input'];
};
/** Autogenerated return type of AddReaction */
export type AddReactionPayload = {
    __typename?: 'AddReactionPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The reaction object. */
    reaction?: Maybe<Reaction>;
    /** The reactable subject. */
    subject?: Maybe<Reactable>;
};
/** Autogenerated input type of AddStar */
export type AddStarInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Starrable ID to star. */
    starrableId: Scalars['ID']['input'];
};
/** Autogenerated return type of AddStar */
export type AddStarPayload = {
    __typename?: 'AddStarPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The starrable. */
    starrable?: Maybe<Starrable>;
};
/** Autogenerated input type of AddUpvote */
export type AddUpvoteInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the discussion or comment to upvote. */
    subjectId: Scalars['ID']['input'];
};
/** Autogenerated return type of AddUpvote */
export type AddUpvotePayload = {
    __typename?: 'AddUpvotePayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The votable subject. */
    subject?: Maybe<Votable>;
};
/** Autogenerated input type of AddVerifiableDomain */
export type AddVerifiableDomainInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The URL of the domain */
    domain: Scalars['URI']['input'];
    /** The ID of the owner to add the domain to */
    ownerId: Scalars['ID']['input'];
};
/** Autogenerated return type of AddVerifiableDomain */
export type AddVerifiableDomainPayload = {
    __typename?: 'AddVerifiableDomainPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The verifiable domain that was added. */
    domain?: Maybe<VerifiableDomain>;
};
/** Represents a 'added_to_project' event on a given issue or pull request. */
export type AddedToProjectEvent = Node & {
    __typename?: 'AddedToProjectEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** Project referenced by event. */
    project?: Maybe<Project>;
    /** Project card referenced by this project event. */
    projectCard?: Maybe<ProjectCard>;
    /** Column name referenced by this project event. */
    projectColumnName: Scalars['String']['output'];
};
/** A GitHub App. */
export type App = Node & {
    __typename?: 'App';
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The description of the app. */
    description?: Maybe<Scalars['String']['output']>;
    id: Scalars['ID']['output'];
    /** The IP addresses of the app. */
    ipAllowListEntries: IpAllowListEntryConnection;
    /** The hex color code, without the leading '#', for the logo background. */
    logoBackgroundColor: Scalars['String']['output'];
    /** A URL pointing to the app's logo. */
    logoUrl: Scalars['URI']['output'];
    /** The name of the app. */
    name: Scalars['String']['output'];
    /** A slug based on the name of the app for use in URLs. */
    slug: Scalars['String']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The URL to the app's homepage. */
    url: Scalars['URI']['output'];
};
/** A GitHub App. */
export type AppIpAllowListEntriesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<IpAllowListEntryOrder>;
};
/** A GitHub App. */
export type AppLogoUrlArgs = {
    size?: InputMaybe<Scalars['Int']['input']>;
};
/** Autogenerated input type of ApproveDeployments */
export type ApproveDeploymentsInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** Optional comment for approving deployments */
    comment?: InputMaybe<Scalars['String']['input']>;
    /** The ids of environments to reject deployments */
    environmentIds: Array<Scalars['ID']['input']>;
    /** The node ID of the workflow run containing the pending deployments. */
    workflowRunId: Scalars['ID']['input'];
};
/** Autogenerated return type of ApproveDeployments */
export type ApproveDeploymentsPayload = {
    __typename?: 'ApproveDeploymentsPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The affected deployments. */
    deployments?: Maybe<Array<Deployment>>;
};
/** Autogenerated input type of ApproveVerifiableDomain */
export type ApproveVerifiableDomainInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the verifiable domain to approve. */
    id: Scalars['ID']['input'];
};
/** Autogenerated return type of ApproveVerifiableDomain */
export type ApproveVerifiableDomainPayload = {
    __typename?: 'ApproveVerifiableDomainPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The verifiable domain that was approved. */
    domain?: Maybe<VerifiableDomain>;
};
/** Autogenerated input type of ArchiveRepository */
export type ArchiveRepositoryInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the repository to mark as archived. */
    repositoryId: Scalars['ID']['input'];
};
/** Autogenerated return type of ArchiveRepository */
export type ArchiveRepositoryPayload = {
    __typename?: 'ArchiveRepositoryPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The repository that was marked as archived. */
    repository?: Maybe<Repository>;
};
/** An object that can have users assigned to it. */
export type Assignable = {
    /** A list of Users assigned to this object. */
    assignees: UserConnection;
};
/** An object that can have users assigned to it. */
export type AssignableAssigneesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** Represents an 'assigned' event on any assignable object. */
export type AssignedEvent = Node & {
    __typename?: 'AssignedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the assignable associated with the event. */
    assignable: Assignable;
    /** Identifies the user or mannequin that was assigned. */
    assignee?: Maybe<Assignee>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /**
     * Identifies the user who was assigned.
     * @deprecated Assignees can now be mannequins. Use the `assignee` field instead. Removal on 2020-01-01 UTC.
     */
    user?: Maybe<User>;
};
/** Types that can be assigned to issues. */
export type Assignee = Bot | Mannequin | Organization | User;
/** An entry in the audit log. */
export type AuditEntry = {
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Types that can initiate an audit log event. */
export type AuditEntryActor = Bot | Organization | User;
/** Ordering options for Audit Log connections. */
export type AuditLogOrder = {
    /** The ordering direction. */
    direction?: InputMaybe<OrderDirection>;
    /** The field to order Audit Logs by. */
    field?: InputMaybe<AuditLogOrderField>;
};
/** Properties by which Audit Log connections can be ordered. */
export declare enum AuditLogOrderField {
    /** Order audit log entries by timestamp */
    CreatedAt = "CREATED_AT"
}
/** Represents a 'auto_merge_disabled' event on a given pull request. */
export type AutoMergeDisabledEvent = Node & {
    __typename?: 'AutoMergeDisabledEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The user who disabled auto-merge for this Pull Request */
    disabler?: Maybe<User>;
    id: Scalars['ID']['output'];
    /** PullRequest referenced by event */
    pullRequest?: Maybe<PullRequest>;
    /** The reason auto-merge was disabled */
    reason?: Maybe<Scalars['String']['output']>;
    /** The reason_code relating to why auto-merge was disabled */
    reasonCode?: Maybe<Scalars['String']['output']>;
};
/** Represents a 'auto_merge_enabled' event on a given pull request. */
export type AutoMergeEnabledEvent = Node & {
    __typename?: 'AutoMergeEnabledEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The user who enabled auto-merge for this Pull Request */
    enabler?: Maybe<User>;
    id: Scalars['ID']['output'];
    /** PullRequest referenced by event. */
    pullRequest?: Maybe<PullRequest>;
};
/** Represents an auto-merge request for a pull request */
export type AutoMergeRequest = {
    __typename?: 'AutoMergeRequest';
    /** The email address of the author of this auto-merge request. */
    authorEmail?: Maybe<Scalars['String']['output']>;
    /** The commit message of the auto-merge request. */
    commitBody?: Maybe<Scalars['String']['output']>;
    /** The commit title of the auto-merge request. */
    commitHeadline?: Maybe<Scalars['String']['output']>;
    /** When was this auto-merge request was enabled. */
    enabledAt?: Maybe<Scalars['DateTime']['output']>;
    /** The actor who created the auto-merge request. */
    enabledBy?: Maybe<Actor>;
    /** The merge method of the auto-merge request. */
    mergeMethod: PullRequestMergeMethod;
    /** The pull request that this auto-merge request is set against. */
    pullRequest: PullRequest;
};
/** Represents a 'auto_rebase_enabled' event on a given pull request. */
export type AutoRebaseEnabledEvent = Node & {
    __typename?: 'AutoRebaseEnabledEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The user who enabled auto-merge (rebase) for this Pull Request */
    enabler?: Maybe<User>;
    id: Scalars['ID']['output'];
    /** PullRequest referenced by event. */
    pullRequest?: Maybe<PullRequest>;
};
/** Represents a 'auto_squash_enabled' event on a given pull request. */
export type AutoSquashEnabledEvent = Node & {
    __typename?: 'AutoSquashEnabledEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The user who enabled auto-merge (squash) for this Pull Request */
    enabler?: Maybe<User>;
    id: Scalars['ID']['output'];
    /** PullRequest referenced by event. */
    pullRequest?: Maybe<PullRequest>;
};
/** Represents a 'automatic_base_change_failed' event on a given pull request. */
export type AutomaticBaseChangeFailedEvent = Node & {
    __typename?: 'AutomaticBaseChangeFailedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** The new base for this PR */
    newBase: Scalars['String']['output'];
    /** The old base for this PR */
    oldBase: Scalars['String']['output'];
    /** PullRequest referenced by event. */
    pullRequest: PullRequest;
};
/** Represents a 'automatic_base_change_succeeded' event on a given pull request. */
export type AutomaticBaseChangeSucceededEvent = Node & {
    __typename?: 'AutomaticBaseChangeSucceededEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** The new base for this PR */
    newBase: Scalars['String']['output'];
    /** The old base for this PR */
    oldBase: Scalars['String']['output'];
    /** PullRequest referenced by event. */
    pullRequest: PullRequest;
};
/** Represents a 'base_ref_changed' event on a given issue or pull request. */
export type BaseRefChangedEvent = Node & {
    __typename?: 'BaseRefChangedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the name of the base ref for the pull request after it was changed. */
    currentRefName: Scalars['String']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** Identifies the name of the base ref for the pull request before it was changed. */
    previousRefName: Scalars['String']['output'];
    /** PullRequest referenced by event. */
    pullRequest: PullRequest;
};
/** Represents a 'base_ref_deleted' event on a given pull request. */
export type BaseRefDeletedEvent = Node & {
    __typename?: 'BaseRefDeletedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the name of the Ref associated with the `base_ref_deleted` event. */
    baseRefName?: Maybe<Scalars['String']['output']>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** PullRequest referenced by event. */
    pullRequest?: Maybe<PullRequest>;
};
/** Represents a 'base_ref_force_pushed' event on a given pull request. */
export type BaseRefForcePushedEvent = Node & {
    __typename?: 'BaseRefForcePushedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the after commit SHA for the 'base_ref_force_pushed' event. */
    afterCommit?: Maybe<Commit>;
    /** Identifies the before commit SHA for the 'base_ref_force_pushed' event. */
    beforeCommit?: Maybe<Commit>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** PullRequest referenced by event. */
    pullRequest: PullRequest;
    /** Identifies the fully qualified ref name for the 'base_ref_force_pushed' event. */
    ref?: Maybe<Ref>;
};
/** Represents a Git blame. */
export type Blame = {
    __typename?: 'Blame';
    /** The list of ranges from a Git blame. */
    ranges: Array<BlameRange>;
};
/** Represents a range of information from a Git blame. */
export type BlameRange = {
    __typename?: 'BlameRange';
    /**
     * Identifies the recency of the change, from 1 (new) to 10 (old). This is
     * calculated as a 2-quantile and determines the length of distance between the
     * median age of all the changes in the file and the recency of the current
     * range's change.
     */
    age: Scalars['Int']['output'];
    /** Identifies the line author */
    commit: Commit;
    /** The ending line for the range */
    endingLine: Scalars['Int']['output'];
    /** The starting line for the range */
    startingLine: Scalars['Int']['output'];
};
/** Represents a Git blob. */
export type Blob = GitObject & Node & {
    __typename?: 'Blob';
    /** An abbreviated version of the Git object ID */
    abbreviatedOid: Scalars['String']['output'];
    /** Byte size of Blob object */
    byteSize: Scalars['Int']['output'];
    /** The HTTP path for this Git object */
    commitResourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this Git object */
    commitUrl: Scalars['URI']['output'];
    id: Scalars['ID']['output'];
    /** Indicates whether the Blob is binary or text. Returns null if unable to determine the encoding. */
    isBinary?: Maybe<Scalars['Boolean']['output']>;
    /** Indicates whether the contents is truncated */
    isTruncated: Scalars['Boolean']['output'];
    /** The Git object ID */
    oid: Scalars['GitObjectID']['output'];
    /** The Repository the Git object belongs to */
    repository: Repository;
    /** UTF8 text data or null if the Blob is binary */
    text?: Maybe<Scalars['String']['output']>;
};
/** A special type of user which takes actions on behalf of GitHub Apps. */
export type Bot = Actor & Node & UniformResourceLocatable & {
    __typename?: 'Bot';
    /** A URL pointing to the GitHub App's public avatar. */
    avatarUrl: Scalars['URI']['output'];
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** The username of the actor. */
    login: Scalars['String']['output'];
    /** The HTTP path for this bot */
    resourcePath: Scalars['URI']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this bot */
    url: Scalars['URI']['output'];
};
/** A special type of user which takes actions on behalf of GitHub Apps. */
export type BotAvatarUrlArgs = {
    size?: InputMaybe<Scalars['Int']['input']>;
};
/** A branch protection rule. */
export type BranchProtectionRule = Node & {
    __typename?: 'BranchProtectionRule';
    /** Can this branch be deleted. */
    allowsDeletions: Scalars['Boolean']['output'];
    /** Are force pushes allowed on this branch. */
    allowsForcePushes: Scalars['Boolean']['output'];
    /** A list of conflicts matching branches protection rule and other branch protection rules */
    branchProtectionRuleConflicts: BranchProtectionRuleConflictConnection;
    /** The actor who created this branch protection rule. */
    creator?: Maybe<Actor>;
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** Will new commits pushed to matching branches dismiss pull request review approvals. */
    dismissesStaleReviews: Scalars['Boolean']['output'];
    id: Scalars['ID']['output'];
    /** Can admins overwrite branch protection. */
    isAdminEnforced: Scalars['Boolean']['output'];
    /** Repository refs that are protected by this rule */
    matchingRefs: RefConnection;
    /** Identifies the protection rule pattern. */
    pattern: Scalars['String']['output'];
    /** A list push allowances for this branch protection rule. */
    pushAllowances: PushAllowanceConnection;
    /** The repository associated with this branch protection rule. */
    repository?: Maybe<Repository>;
    /** Number of approving reviews required to update matching branches. */
    requiredApprovingReviewCount?: Maybe<Scalars['Int']['output']>;
    /** List of required status check contexts that must pass for commits to be accepted to matching branches. */
    requiredStatusCheckContexts?: Maybe<Array<Maybe<Scalars['String']['output']>>>;
    /** Are approving reviews required to update matching branches. */
    requiresApprovingReviews: Scalars['Boolean']['output'];
    /** Are reviews from code owners required to update matching branches. */
    requiresCodeOwnerReviews: Scalars['Boolean']['output'];
    /** Are commits required to be signed. */
    requiresCommitSignatures: Scalars['Boolean']['output'];
    /** Are conversations required to be resolved before merging. */
    requiresConversationResolution: Scalars['Boolean']['output'];
    /** Are merge commits prohibited from being pushed to this branch. */
    requiresLinearHistory: Scalars['Boolean']['output'];
    /** Are status checks required to update matching branches. */
    requiresStatusChecks: Scalars['Boolean']['output'];
    /** Are branches required to be up to date before merging. */
    requiresStrictStatusChecks: Scalars['Boolean']['output'];
    /** Is pushing to matching branches restricted. */
    restrictsPushes: Scalars['Boolean']['output'];
    /** Is dismissal of pull request reviews restricted. */
    restrictsReviewDismissals: Scalars['Boolean']['output'];
    /** A list review dismissal allowances for this branch protection rule. */
    reviewDismissalAllowances: ReviewDismissalAllowanceConnection;
};
/** A branch protection rule. */
export type BranchProtectionRuleBranchProtectionRuleConflictsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A branch protection rule. */
export type BranchProtectionRuleMatchingRefsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    query?: InputMaybe<Scalars['String']['input']>;
};
/** A branch protection rule. */
export type BranchProtectionRulePushAllowancesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A branch protection rule. */
export type BranchProtectionRuleReviewDismissalAllowancesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A conflict between two branch protection rules. */
export type BranchProtectionRuleConflict = {
    __typename?: 'BranchProtectionRuleConflict';
    /** Identifies the branch protection rule. */
    branchProtectionRule?: Maybe<BranchProtectionRule>;
    /** Identifies the conflicting branch protection rule. */
    conflictingBranchProtectionRule?: Maybe<BranchProtectionRule>;
    /** Identifies the branch ref that has conflicting rules */
    ref?: Maybe<Ref>;
};
/** The connection type for BranchProtectionRuleConflict. */
export type BranchProtectionRuleConflictConnection = {
    __typename?: 'BranchProtectionRuleConflictConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<BranchProtectionRuleConflictEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<BranchProtectionRuleConflict>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type BranchProtectionRuleConflictEdge = {
    __typename?: 'BranchProtectionRuleConflictEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<BranchProtectionRuleConflict>;
};
/** The connection type for BranchProtectionRule. */
export type BranchProtectionRuleConnection = {
    __typename?: 'BranchProtectionRuleConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<BranchProtectionRuleEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<BranchProtectionRule>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type BranchProtectionRuleEdge = {
    __typename?: 'BranchProtectionRuleEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<BranchProtectionRule>;
};
/** The Common Vulnerability Scoring System */
export type Cvss = {
    __typename?: 'CVSS';
    /** The CVSS score associated with this advisory */
    score: Scalars['Float']['output'];
    /** The CVSS vector string associated with this advisory */
    vectorString?: Maybe<Scalars['String']['output']>;
};
/** A common weakness enumeration */
export type Cwe = Node & {
    __typename?: 'CWE';
    /** The id of the CWE */
    cweId: Scalars['String']['output'];
    /** A detailed description of this CWE */
    description: Scalars['String']['output'];
    /** ID of the object. */
    id: Scalars['ID']['output'];
    /** The name of this CWE */
    name: Scalars['String']['output'];
};
/** The connection type for CWE. */
export type CweConnection = {
    __typename?: 'CWEConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<CweEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Cwe>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type CweEdge = {
    __typename?: 'CWEEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Cwe>;
};
/** Autogenerated input type of ChangeUserStatus */
export type ChangeUserStatusInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The emoji to represent your status. Can either be a native Unicode emoji or an emoji name with colons, e.g., :grinning:. */
    emoji?: InputMaybe<Scalars['String']['input']>;
    /** If set, the user status will not be shown after this date. */
    expiresAt?: InputMaybe<Scalars['DateTime']['input']>;
    /** Whether this status should indicate you are not fully available on GitHub, e.g., you are away. */
    limitedAvailability?: InputMaybe<Scalars['Boolean']['input']>;
    /** A short description of your current status. */
    message?: InputMaybe<Scalars['String']['input']>;
    /**
     * The ID of the organization whose members will be allowed to see the status. If
     * omitted, the status will be publicly visible.
     */
    organizationId?: InputMaybe<Scalars['ID']['input']>;
};
/** Autogenerated return type of ChangeUserStatus */
export type ChangeUserStatusPayload = {
    __typename?: 'ChangeUserStatusPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** Your updated status. */
    status?: Maybe<UserStatus>;
};
/** A single check annotation. */
export type CheckAnnotation = {
    __typename?: 'CheckAnnotation';
    /** The annotation's severity level. */
    annotationLevel?: Maybe<CheckAnnotationLevel>;
    /** The path to the file that this annotation was made on. */
    blobUrl: Scalars['URI']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The position of this annotation. */
    location: CheckAnnotationSpan;
    /** The annotation's message. */
    message: Scalars['String']['output'];
    /** The path that this annotation was made on. */
    path: Scalars['String']['output'];
    /** Additional information about the annotation. */
    rawDetails?: Maybe<Scalars['String']['output']>;
    /** The annotation's title */
    title?: Maybe<Scalars['String']['output']>;
};
/** The connection type for CheckAnnotation. */
export type CheckAnnotationConnection = {
    __typename?: 'CheckAnnotationConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<CheckAnnotationEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<CheckAnnotation>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** Information from a check run analysis to specific lines of code. */
export type CheckAnnotationData = {
    /** Represents an annotation's information level */
    annotationLevel: CheckAnnotationLevel;
    /** The location of the annotation */
    location: CheckAnnotationRange;
    /** A short description of the feedback for these lines of code. */
    message: Scalars['String']['input'];
    /** The path of the file to add an annotation to. */
    path: Scalars['String']['input'];
    /** Details about this annotation. */
    rawDetails?: InputMaybe<Scalars['String']['input']>;
    /** The title that represents the annotation. */
    title?: InputMaybe<Scalars['String']['input']>;
};
/** An edge in a connection. */
export type CheckAnnotationEdge = {
    __typename?: 'CheckAnnotationEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<CheckAnnotation>;
};
/** Represents an annotation's information level. */
export declare enum CheckAnnotationLevel {
    /** An annotation indicating an inescapable error. */
    Failure = "FAILURE",
    /** An annotation indicating some information. */
    Notice = "NOTICE",
    /** An annotation indicating an ignorable error. */
    Warning = "WARNING"
}
/** A character position in a check annotation. */
export type CheckAnnotationPosition = {
    __typename?: 'CheckAnnotationPosition';
    /** Column number (1 indexed). */
    column?: Maybe<Scalars['Int']['output']>;
    /** Line number (1 indexed). */
    line: Scalars['Int']['output'];
};
/** Information from a check run analysis to specific lines of code. */
export type CheckAnnotationRange = {
    /** The ending column of the range. */
    endColumn?: InputMaybe<Scalars['Int']['input']>;
    /** The ending line of the range. */
    endLine: Scalars['Int']['input'];
    /** The starting column of the range. */
    startColumn?: InputMaybe<Scalars['Int']['input']>;
    /** The starting line of the range. */
    startLine: Scalars['Int']['input'];
};
/** An inclusive pair of positions for a check annotation. */
export type CheckAnnotationSpan = {
    __typename?: 'CheckAnnotationSpan';
    /** End position (inclusive). */
    end: CheckAnnotationPosition;
    /** Start position (inclusive). */
    start: CheckAnnotationPosition;
};
/** The possible states for a check suite or run conclusion. */
export declare enum CheckConclusionState {
    /** The check suite or run requires action. */
    ActionRequired = "ACTION_REQUIRED",
    /** The check suite or run has been cancelled. */
    Cancelled = "CANCELLED",
    /** The check suite or run has failed. */
    Failure = "FAILURE",
    /** The check suite or run was neutral. */
    Neutral = "NEUTRAL",
    /** The check suite or run was skipped. */
    Skipped = "SKIPPED",
    /** The check suite or run was marked stale by GitHub. Only GitHub can use this conclusion. */
    Stale = "STALE",
    /** The check suite or run has failed at startup. */
    StartupFailure = "STARTUP_FAILURE",
    /** The check suite or run has succeeded. */
    Success = "SUCCESS",
    /** The check suite or run has timed out. */
    TimedOut = "TIMED_OUT"
}
/** A check run. */
export type CheckRun = Node & RequirableByPullRequest & UniformResourceLocatable & {
    __typename?: 'CheckRun';
    /** The check run's annotations */
    annotations?: Maybe<CheckAnnotationConnection>;
    /** The check suite that this run is a part of. */
    checkSuite: CheckSuite;
    /** Identifies the date and time when the check run was completed. */
    completedAt?: Maybe<Scalars['DateTime']['output']>;
    /** The conclusion of the check run. */
    conclusion?: Maybe<CheckConclusionState>;
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The corresponding deployment for this job, if any */
    deployment?: Maybe<Deployment>;
    /** The URL from which to find full details of the check run on the integrator's site. */
    detailsUrl?: Maybe<Scalars['URI']['output']>;
    /** A reference for the check run on the integrator's system. */
    externalId?: Maybe<Scalars['String']['output']>;
    id: Scalars['ID']['output'];
    /** Whether this is required to pass before merging for a specific pull request. */
    isRequired: Scalars['Boolean']['output'];
    /** The name of the check for this check run. */
    name: Scalars['String']['output'];
    /** Information about a pending deployment, if any, in this check run */
    pendingDeploymentRequest?: Maybe<DeploymentRequest>;
    /** The permalink to the check run summary. */
    permalink: Scalars['URI']['output'];
    /** The repository associated with this check run. */
    repository: Repository;
    /** The HTTP path for this check run. */
    resourcePath: Scalars['URI']['output'];
    /** Identifies the date and time when the check run was started. */
    startedAt?: Maybe<Scalars['DateTime']['output']>;
    /** The current status of the check run. */
    status: CheckStatusState;
    /** The check run's steps */
    steps?: Maybe<CheckStepConnection>;
    /** A string representing the check run's summary */
    summary?: Maybe<Scalars['String']['output']>;
    /** A string representing the check run's text */
    text?: Maybe<Scalars['String']['output']>;
    /** A string representing the check run */
    title?: Maybe<Scalars['String']['output']>;
    /** The HTTP URL for this check run. */
    url: Scalars['URI']['output'];
};
/** A check run. */
export type CheckRunAnnotationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A check run. */
export type CheckRunIsRequiredArgs = {
    pullRequestId?: InputMaybe<Scalars['ID']['input']>;
    pullRequestNumber?: InputMaybe<Scalars['Int']['input']>;
};
/** A check run. */
export type CheckRunStepsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    number?: InputMaybe<Scalars['Int']['input']>;
};
/** Possible further actions the integrator can perform. */
export type CheckRunAction = {
    /** A short explanation of what this action would do. */
    description: Scalars['String']['input'];
    /** A reference for the action on the integrator's system. */
    identifier: Scalars['String']['input'];
    /** The text to be displayed on a button in the web UI. */
    label: Scalars['String']['input'];
};
/** The connection type for CheckRun. */
export type CheckRunConnection = {
    __typename?: 'CheckRunConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<CheckRunEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<CheckRun>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type CheckRunEdge = {
    __typename?: 'CheckRunEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<CheckRun>;
};
/** The filters that are available when fetching check runs. */
export type CheckRunFilter = {
    /** Filters the check runs created by this application ID. */
    appId?: InputMaybe<Scalars['Int']['input']>;
    /** Filters the check runs by this name. */
    checkName?: InputMaybe<Scalars['String']['input']>;
    /** Filters the check runs by this type. */
    checkType?: InputMaybe<CheckRunType>;
    /** Filters the check runs by this status. */
    status?: InputMaybe<CheckStatusState>;
};
/** Descriptive details about the check run. */
export type CheckRunOutput = {
    /** The annotations that are made as part of the check run. */
    annotations?: InputMaybe<Array<CheckAnnotationData>>;
    /** Images attached to the check run output displayed in the GitHub pull request UI. */
    images?: InputMaybe<Array<CheckRunOutputImage>>;
    /** The summary of the check run (supports Commonmark). */
    summary: Scalars['String']['input'];
    /** The details of the check run (supports Commonmark). */
    text?: InputMaybe<Scalars['String']['input']>;
    /** A title to provide for this check run. */
    title: Scalars['String']['input'];
};
/** Images attached to the check run output displayed in the GitHub pull request UI. */
export type CheckRunOutputImage = {
    /** The alternative text for the image. */
    alt: Scalars['String']['input'];
    /** A short image description. */
    caption?: InputMaybe<Scalars['String']['input']>;
    /** The full URL of the image. */
    imageUrl: Scalars['URI']['input'];
};
/** The possible types of check runs. */
export declare enum CheckRunType {
    /** Every check run available. */
    All = "ALL",
    /** The latest check run. */
    Latest = "LATEST"
}
/** The possible states for a check suite or run status. */
export declare enum CheckStatusState {
    /** The check suite or run has been completed. */
    Completed = "COMPLETED",
    /** The check suite or run is in progress. */
    InProgress = "IN_PROGRESS",
    /** The check suite or run is in pending state. */
    Pending = "PENDING",
    /** The check suite or run has been queued. */
    Queued = "QUEUED",
    /** The check suite or run has been requested. */
    Requested = "REQUESTED",
    /** The check suite or run is in waiting state. */
    Waiting = "WAITING"
}
/** A single check step. */
export type CheckStep = {
    __typename?: 'CheckStep';
    /** Identifies the date and time when the check step was completed. */
    completedAt?: Maybe<Scalars['DateTime']['output']>;
    /** The conclusion of the check step. */
    conclusion?: Maybe<CheckConclusionState>;
    /** A reference for the check step on the integrator's system. */
    externalId?: Maybe<Scalars['String']['output']>;
    /** The step's name. */
    name: Scalars['String']['output'];
    /** The index of the step in the list of steps of the parent check run. */
    number: Scalars['Int']['output'];
    /** Number of seconds to completion. */
    secondsToCompletion?: Maybe<Scalars['Int']['output']>;
    /** Identifies the date and time when the check step was started. */
    startedAt?: Maybe<Scalars['DateTime']['output']>;
    /** The current status of the check step. */
    status: CheckStatusState;
};
/** The connection type for CheckStep. */
export type CheckStepConnection = {
    __typename?: 'CheckStepConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<CheckStepEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<CheckStep>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type CheckStepEdge = {
    __typename?: 'CheckStepEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<CheckStep>;
};
/** A check suite. */
export type CheckSuite = Node & {
    __typename?: 'CheckSuite';
    /** The GitHub App which created this check suite. */
    app?: Maybe<App>;
    /** The name of the branch for this check suite. */
    branch?: Maybe<Ref>;
    /** The check runs associated with a check suite. */
    checkRuns?: Maybe<CheckRunConnection>;
    /** The commit for this check suite */
    commit: Commit;
    /** The conclusion of this check suite. */
    conclusion?: Maybe<CheckConclusionState>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The user who triggered the check suite. */
    creator?: Maybe<User>;
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** A list of open pull requests matching the check suite. */
    matchingPullRequests?: Maybe<PullRequestConnection>;
    /** The push that triggered this check suite. */
    push?: Maybe<Push>;
    /** The repository associated with this check suite. */
    repository: Repository;
    /** The HTTP path for this check suite */
    resourcePath: Scalars['URI']['output'];
    /** The status of this check suite. */
    status: CheckStatusState;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this check suite */
    url: Scalars['URI']['output'];
    /** The workflow run associated with this check suite. */
    workflowRun?: Maybe<WorkflowRun>;
};
/** A check suite. */
export type CheckSuiteCheckRunsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    filterBy?: InputMaybe<CheckRunFilter>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A check suite. */
export type CheckSuiteMatchingPullRequestsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    baseRefName?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    headRefName?: InputMaybe<Scalars['String']['input']>;
    labels?: InputMaybe<Array<Scalars['String']['input']>>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<IssueOrder>;
    states?: InputMaybe<Array<PullRequestState>>;
};
/** The auto-trigger preferences that are available for check suites. */
export type CheckSuiteAutoTriggerPreference = {
    /** The node ID of the application that owns the check suite. */
    appId: Scalars['ID']['input'];
    /** Set to `true` to enable automatic creation of CheckSuite events upon pushes to the repository. */
    setting: Scalars['Boolean']['input'];
};
/** The connection type for CheckSuite. */
export type CheckSuiteConnection = {
    __typename?: 'CheckSuiteConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<CheckSuiteEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<CheckSuite>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type CheckSuiteEdge = {
    __typename?: 'CheckSuiteEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<CheckSuite>;
};
/** The filters that are available when fetching check suites. */
export type CheckSuiteFilter = {
    /** Filters the check suites created by this application ID. */
    appId?: InputMaybe<Scalars['Int']['input']>;
    /** Filters the check suites by this name. */
    checkName?: InputMaybe<Scalars['String']['input']>;
};
/** Autogenerated input type of ClearLabelsFromLabelable */
export type ClearLabelsFromLabelableInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The id of the labelable object to clear the labels from. */
    labelableId: Scalars['ID']['input'];
};
/** Autogenerated return type of ClearLabelsFromLabelable */
export type ClearLabelsFromLabelablePayload = {
    __typename?: 'ClearLabelsFromLabelablePayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The item that was unlabeled. */
    labelable?: Maybe<Labelable>;
};
/** Autogenerated input type of CloneProject */
export type CloneProjectInput = {
    /** The description of the project. */
    body?: InputMaybe<Scalars['String']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** Whether or not to clone the source project's workflows. */
    includeWorkflows: Scalars['Boolean']['input'];
    /** The name of the project. */
    name: Scalars['String']['input'];
    /** The visibility of the project, defaults to false (private). */
    public?: InputMaybe<Scalars['Boolean']['input']>;
    /** The source project to clone. */
    sourceId: Scalars['ID']['input'];
    /** The owner ID to create the project under. */
    targetOwnerId: Scalars['ID']['input'];
};
/** Autogenerated return type of CloneProject */
export type CloneProjectPayload = {
    __typename?: 'CloneProjectPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The id of the JobStatus for populating cloned fields. */
    jobStatusId?: Maybe<Scalars['String']['output']>;
    /** The new cloned project. */
    project?: Maybe<Project>;
};
/** Autogenerated input type of CloneTemplateRepository */
export type CloneTemplateRepositoryInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** A short description of the new repository. */
    description?: InputMaybe<Scalars['String']['input']>;
    /**
     * Whether to copy all branches from the template to the new repository. Defaults
     * to copying only the default branch of the template.
     */
    includeAllBranches?: InputMaybe<Scalars['Boolean']['input']>;
    /** The name of the new repository. */
    name: Scalars['String']['input'];
    /** The ID of the owner for the new repository. */
    ownerId: Scalars['ID']['input'];
    /** The Node ID of the template repository. */
    repositoryId: Scalars['ID']['input'];
    /** Indicates the repository's visibility level. */
    visibility: RepositoryVisibility;
};
/** Autogenerated return type of CloneTemplateRepository */
export type CloneTemplateRepositoryPayload = {
    __typename?: 'CloneTemplateRepositoryPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The new repository. */
    repository?: Maybe<Repository>;
};
/** An object that can be closed */
export type Closable = {
    /** `true` if the object is closed (definition of closed may depend on type) */
    closed: Scalars['Boolean']['output'];
    /** Identifies the date and time when the object was closed. */
    closedAt?: Maybe<Scalars['DateTime']['output']>;
};
/** Autogenerated input type of CloseIssue */
export type CloseIssueInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** ID of the issue to be closed. */
    issueId: Scalars['ID']['input'];
};
/** Autogenerated return type of CloseIssue */
export type CloseIssuePayload = {
    __typename?: 'CloseIssuePayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The issue that was closed. */
    issue?: Maybe<Issue>;
};
/** Autogenerated input type of ClosePullRequest */
export type ClosePullRequestInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** ID of the pull request to be closed. */
    pullRequestId: Scalars['ID']['input'];
};
/** Autogenerated return type of ClosePullRequest */
export type ClosePullRequestPayload = {
    __typename?: 'ClosePullRequestPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The pull request that was closed. */
    pullRequest?: Maybe<PullRequest>;
};
/** Represents a 'closed' event on any `Closable`. */
export type ClosedEvent = Node & UniformResourceLocatable & {
    __typename?: 'ClosedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Object that was closed. */
    closable: Closable;
    /** Object which triggered the creation of this event. */
    closer?: Maybe<Closer>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** The HTTP path for this closed event. */
    resourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this closed event. */
    url: Scalars['URI']['output'];
};
/** The object which triggered a `ClosedEvent`. */
export type Closer = Commit | PullRequest;
/** The Code of Conduct for a repository */
export type CodeOfConduct = Node & {
    __typename?: 'CodeOfConduct';
    /** The body of the Code of Conduct */
    body?: Maybe<Scalars['String']['output']>;
    id: Scalars['ID']['output'];
    /** The key for the Code of Conduct */
    key: Scalars['String']['output'];
    /** The formal name of the Code of Conduct */
    name: Scalars['String']['output'];
    /** The HTTP path for this Code of Conduct */
    resourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for this Code of Conduct */
    url?: Maybe<Scalars['URI']['output']>;
};
/** Collaborators affiliation level with a subject. */
export declare enum CollaboratorAffiliation {
    /** All collaborators the authenticated user can see. */
    All = "ALL",
    /** All collaborators with permissions to an organization-owned subject, regardless of organization membership status. */
    Direct = "DIRECT",
    /** All outside collaborators of an organization-owned subject. */
    Outside = "OUTSIDE"
}
/** Represents a comment. */
export type Comment = {
    /** The actor who authored the comment. */
    author?: Maybe<Actor>;
    /** Author's association with the subject of the comment. */
    authorAssociation: CommentAuthorAssociation;
    /** The body as Markdown. */
    body: Scalars['String']['output'];
    /** The body rendered to HTML. */
    bodyHTML: Scalars['HTML']['output'];
    /** The body rendered to text. */
    bodyText: Scalars['String']['output'];
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Check if this comment was created via an email reply. */
    createdViaEmail: Scalars['Boolean']['output'];
    /** The actor who edited the comment. */
    editor?: Maybe<Actor>;
    id: Scalars['ID']['output'];
    /** Check if this comment was edited and includes an edit with the creation data */
    includesCreatedEdit: Scalars['Boolean']['output'];
    /** The moment the editor made the last edit */
    lastEditedAt?: Maybe<Scalars['DateTime']['output']>;
    /** Identifies when the comment was published at. */
    publishedAt?: Maybe<Scalars['DateTime']['output']>;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** A list of edits to this content. */
    userContentEdits?: Maybe<UserContentEditConnection>;
    /** Did the viewer author this comment. */
    viewerDidAuthor: Scalars['Boolean']['output'];
};
/** Represents a comment. */
export type CommentUserContentEditsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A comment author association with repository. */
export declare enum CommentAuthorAssociation {
    /** Author has been invited to collaborate on the repository. */
    Collaborator = "COLLABORATOR",
    /** Author has previously committed to the repository. */
    Contributor = "CONTRIBUTOR",
    /** Author has not previously committed to GitHub. */
    FirstTimer = "FIRST_TIMER",
    /** Author has not previously committed to the repository. */
    FirstTimeContributor = "FIRST_TIME_CONTRIBUTOR",
    /** Author is a placeholder for an unclaimed user. */
    Mannequin = "MANNEQUIN",
    /** Author is a member of the organization that owns the repository. */
    Member = "MEMBER",
    /** Author has no association with the repository. */
    None = "NONE",
    /** Author is the owner of the repository. */
    Owner = "OWNER"
}
/** The possible errors that will prevent a user from updating a comment. */
export declare enum CommentCannotUpdateReason {
    /** Unable to create comment because repository is archived. */
    Archived = "ARCHIVED",
    /** You cannot update this comment */
    Denied = "DENIED",
    /** You must be the author or have write access to this repository to update this comment. */
    InsufficientAccess = "INSUFFICIENT_ACCESS",
    /** Unable to create comment because issue is locked. */
    Locked = "LOCKED",
    /** You must be logged in to update this comment. */
    LoginRequired = "LOGIN_REQUIRED",
    /** Repository is under maintenance. */
    Maintenance = "MAINTENANCE",
    /** At least one email address must be verified to update this comment. */
    VerifiedEmailRequired = "VERIFIED_EMAIL_REQUIRED"
}
/** Represents a 'comment_deleted' event on a given issue or pull request. */
export type CommentDeletedEvent = Node & {
    __typename?: 'CommentDeletedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The user who authored the deleted comment. */
    deletedCommentAuthor?: Maybe<Actor>;
    id: Scalars['ID']['output'];
};
/** Represents a Git commit. */
export type Commit = GitObject & Node & Subscribable & UniformResourceLocatable & {
    __typename?: 'Commit';
    /** An abbreviated version of the Git object ID */
    abbreviatedOid: Scalars['String']['output'];
    /** The number of additions in this commit. */
    additions: Scalars['Int']['output'];
    /**
     * The merged Pull Request that introduced the commit to the repository. If the
     * commit is not present in the default branch, additionally returns open Pull
     * Requests associated with the commit
     */
    associatedPullRequests?: Maybe<PullRequestConnection>;
    /** Authorship details of the commit. */
    author?: Maybe<GitActor>;
    /** Check if the committer and the author match. */
    authoredByCommitter: Scalars['Boolean']['output'];
    /** The datetime when this commit was authored. */
    authoredDate: Scalars['DateTime']['output'];
    /**
     * The list of authors for this commit based on the git author and the Co-authored-by
     * message trailer. The git author will always be first.
     */
    authors: GitActorConnection;
    /** Fetches `git blame` information. */
    blame: Blame;
    /** The number of changed files in this commit. */
    changedFiles: Scalars['Int']['output'];
    /** The check suites associated with a commit. */
    checkSuites?: Maybe<CheckSuiteConnection>;
    /** Comments made on the commit. */
    comments: CommitCommentConnection;
    /** The HTTP path for this Git object */
    commitResourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this Git object */
    commitUrl: Scalars['URI']['output'];
    /** The datetime when this commit was committed. */
    committedDate: Scalars['DateTime']['output'];
    /** Check if committed via GitHub web UI. */
    committedViaWeb: Scalars['Boolean']['output'];
    /** Committer details of the commit. */
    committer?: Maybe<GitActor>;
    /** The number of deletions in this commit. */
    deletions: Scalars['Int']['output'];
    /** The deployments associated with a commit. */
    deployments?: Maybe<DeploymentConnection>;
    /** The tree entry representing the file located at the given path. */
    file?: Maybe<TreeEntry>;
    /** The linear commit history starting from (and including) this commit, in the same order as `git log`. */
    history: CommitHistoryConnection;
    id: Scalars['ID']['output'];
    /** The Git commit message */
    message: Scalars['String']['output'];
    /** The Git commit message body */
    messageBody: Scalars['String']['output'];
    /** The commit message body rendered to HTML. */
    messageBodyHTML: Scalars['HTML']['output'];
    /** The Git commit message headline */
    messageHeadline: Scalars['String']['output'];
    /** The commit message headline rendered to HTML. */
    messageHeadlineHTML: Scalars['HTML']['output'];
    /** The Git object ID */
    oid: Scalars['GitObjectID']['output'];
    /** The organization this commit was made on behalf of. */
    onBehalfOf?: Maybe<Organization>;
    /** The parents of a commit. */
    parents: CommitConnection;
    /** The datetime when this commit was pushed. */
    pushedDate?: Maybe<Scalars['DateTime']['output']>;
    /** The Repository this commit belongs to */
    repository: Repository;
    /** The HTTP path for this commit */
    resourcePath: Scalars['URI']['output'];
    /** Commit signing information, if present. */
    signature?: Maybe<GitSignature>;
    /** Status information for this commit */
    status?: Maybe<Status>;
    /** Check and Status rollup information for this commit. */
    statusCheckRollup?: Maybe<StatusCheckRollup>;
    /** Returns a list of all submodules in this repository as of this Commit parsed from the .gitmodules file. */
    submodules: SubmoduleConnection;
    /**
     * Returns a URL to download a tarball archive for a repository.
     * Note: For private repositories, these links are temporary and expire after five minutes.
     */
    tarballUrl: Scalars['URI']['output'];
    /** Commit's root Tree */
    tree: Tree;
    /** The HTTP path for the tree of this commit */
    treeResourcePath: Scalars['URI']['output'];
    /** The HTTP URL for the tree of this commit */
    treeUrl: Scalars['URI']['output'];
    /** The HTTP URL for this commit */
    url: Scalars['URI']['output'];
    /** Check if the viewer is able to change their subscription status for the repository. */
    viewerCanSubscribe: Scalars['Boolean']['output'];
    /** Identifies if the viewer is watching, not watching, or ignoring the subscribable entity. */
    viewerSubscription?: Maybe<SubscriptionState>;
    /**
     * Returns a URL to download a zipball archive for a repository.
     * Note: For private repositories, these links are temporary and expire after five minutes.
     */
    zipballUrl: Scalars['URI']['output'];
};
/** Represents a Git commit. */
export type CommitAssociatedPullRequestsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<PullRequestOrder>;
};
/** Represents a Git commit. */
export type CommitAuthorsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** Represents a Git commit. */
export type CommitBlameArgs = {
    path: Scalars['String']['input'];
};
/** Represents a Git commit. */
export type CommitCheckSuitesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    filterBy?: InputMaybe<CheckSuiteFilter>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** Represents a Git commit. */
export type CommitCommentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** Represents a Git commit. */
export type CommitDeploymentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    environments?: InputMaybe<Array<Scalars['String']['input']>>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<DeploymentOrder>;
};
/** Represents a Git commit. */
export type CommitFileArgs = {
    path: Scalars['String']['input'];
};
/** Represents a Git commit. */
export type CommitHistoryArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    author?: InputMaybe<CommitAuthor>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    path?: InputMaybe<Scalars['String']['input']>;
    since?: InputMaybe<Scalars['GitTimestamp']['input']>;
    until?: InputMaybe<Scalars['GitTimestamp']['input']>;
};
/** Represents a Git commit. */
export type CommitParentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** Represents a Git commit. */
export type CommitSubmodulesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** Specifies an author for filtering Git commits. */
export type CommitAuthor = {
    /** Email addresses to filter by. Commits authored by any of the specified email addresses will be returned. */
    emails?: InputMaybe<Array<Scalars['String']['input']>>;
    /**
     * ID of a User to filter by. If non-null, only commits authored by this user
     * will be returned. This field takes precedence over emails.
     */
    id?: InputMaybe<Scalars['ID']['input']>;
};
/** Represents a comment on a given Commit. */
export type CommitComment = Comment & Deletable & Minimizable & Node & Reactable & RepositoryNode & Updatable & UpdatableComment & {
    __typename?: 'CommitComment';
    /** The actor who authored the comment. */
    author?: Maybe<Actor>;
    /** Author's association with the subject of the comment. */
    authorAssociation: CommentAuthorAssociation;
    /** Identifies the comment body. */
    body: Scalars['String']['output'];
    /** The body rendered to HTML. */
    bodyHTML: Scalars['HTML']['output'];
    /** The body rendered to text. */
    bodyText: Scalars['String']['output'];
    /** Identifies the commit associated with the comment, if the commit exists. */
    commit?: Maybe<Commit>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Check if this comment was created via an email reply. */
    createdViaEmail: Scalars['Boolean']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The actor who edited the comment. */
    editor?: Maybe<Actor>;
    id: Scalars['ID']['output'];
    /** Check if this comment was edited and includes an edit with the creation data */
    includesCreatedEdit: Scalars['Boolean']['output'];
    /** Returns whether or not a comment has been minimized. */
    isMinimized: Scalars['Boolean']['output'];
    /** The moment the editor made the last edit */
    lastEditedAt?: Maybe<Scalars['DateTime']['output']>;
    /** Returns why the comment was minimized. */
    minimizedReason?: Maybe<Scalars['String']['output']>;
    /** Identifies the file path associated with the comment. */
    path?: Maybe<Scalars['String']['output']>;
    /** Identifies the line position associated with the comment. */
    position?: Maybe<Scalars['Int']['output']>;
    /** Identifies when the comment was published at. */
    publishedAt?: Maybe<Scalars['DateTime']['output']>;
    /** A list of reactions grouped by content left on the subject. */
    reactionGroups?: Maybe<Array<ReactionGroup>>;
    /** A list of Reactions left on the Issue. */
    reactions: ReactionConnection;
    /** The repository associated with this node. */
    repository: Repository;
    /** The HTTP path permalink for this commit comment. */
    resourcePath: Scalars['URI']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL permalink for this commit comment. */
    url: Scalars['URI']['output'];
    /** A list of edits to this content. */
    userContentEdits?: Maybe<UserContentEditConnection>;
    /** Check if the current viewer can delete this object. */
    viewerCanDelete: Scalars['Boolean']['output'];
    /** Check if the current viewer can minimize this object. */
    viewerCanMinimize: Scalars['Boolean']['output'];
    /** Can user react to this subject */
    viewerCanReact: Scalars['Boolean']['output'];
    /** Check if the current viewer can update this object. */
    viewerCanUpdate: Scalars['Boolean']['output'];
    /** Reasons why the current viewer can not update this comment. */
    viewerCannotUpdateReasons: Array<CommentCannotUpdateReason>;
    /** Did the viewer author this comment. */
    viewerDidAuthor: Scalars['Boolean']['output'];
};
/** Represents a comment on a given Commit. */
export type CommitCommentReactionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    content?: InputMaybe<ReactionContent>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ReactionOrder>;
};
/** Represents a comment on a given Commit. */
export type CommitCommentUserContentEditsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** The connection type for CommitComment. */
export type CommitCommentConnection = {
    __typename?: 'CommitCommentConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<CommitCommentEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<CommitComment>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type CommitCommentEdge = {
    __typename?: 'CommitCommentEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<CommitComment>;
};
/** A thread of comments on a commit. */
export type CommitCommentThread = Node & RepositoryNode & {
    __typename?: 'CommitCommentThread';
    /** The comments that exist in this thread. */
    comments: CommitCommentConnection;
    /** The commit the comments were made on. */
    commit?: Maybe<Commit>;
    id: Scalars['ID']['output'];
    /** The file the comments were made on. */
    path?: Maybe<Scalars['String']['output']>;
    /** The position in the diff for the commit that the comment was made on. */
    position?: Maybe<Scalars['Int']['output']>;
    /** The repository associated with this node. */
    repository: Repository;
};
/** A thread of comments on a commit. */
export type CommitCommentThreadCommentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** The connection type for Commit. */
export type CommitConnection = {
    __typename?: 'CommitConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<CommitEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Commit>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** Ordering options for commit contribution connections. */
export type CommitContributionOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field by which to order commit contributions. */
    field: CommitContributionOrderField;
};
/** Properties by which commit contribution connections can be ordered. */
export declare enum CommitContributionOrderField {
    /** Order commit contributions by how many commits they represent. */
    CommitCount = "COMMIT_COUNT",
    /** Order commit contributions by when they were made. */
    OccurredAt = "OCCURRED_AT"
}
/** This aggregates commits made by a user within one repository. */
export type CommitContributionsByRepository = {
    __typename?: 'CommitContributionsByRepository';
    /** The commit contributions, each representing a day. */
    contributions: CreatedCommitContributionConnection;
    /** The repository in which the commits were made. */
    repository: Repository;
    /** The HTTP path for the user's commits to the repository in this time range. */
    resourcePath: Scalars['URI']['output'];
    /** The HTTP URL for the user's commits to the repository in this time range. */
    url: Scalars['URI']['output'];
};
/** This aggregates commits made by a user within one repository. */
export type CommitContributionsByRepositoryContributionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<CommitContributionOrder>;
};
/** An edge in a connection. */
export type CommitEdge = {
    __typename?: 'CommitEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Commit>;
};
/** The connection type for Commit. */
export type CommitHistoryConnection = {
    __typename?: 'CommitHistoryConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<CommitEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Commit>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** Represents a 'connected' event on a given issue or pull request. */
export type ConnectedEvent = Node & {
    __typename?: 'ConnectedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** Reference originated in a different repository. */
    isCrossRepository: Scalars['Boolean']['output'];
    /** Issue or pull request that made the reference. */
    source: ReferencedSubject;
    /** Issue or pull request which was connected. */
    subject: ReferencedSubject;
};
/** A content attachment */
export type ContentAttachment = {
    __typename?: 'ContentAttachment';
    /** The body text of the content attachment. This parameter supports markdown. */
    body: Scalars['String']['output'];
    /** The content reference that the content attachment is attached to. */
    contentReference: ContentReference;
    /** Identifies the primary key from the database. */
    databaseId: Scalars['Int']['output'];
    id: Scalars['ID']['output'];
    /** The title of the content attachment. */
    title: Scalars['String']['output'];
};
/** A content reference */
export type ContentReference = {
    __typename?: 'ContentReference';
    /** Identifies the primary key from the database. */
    databaseId: Scalars['Int']['output'];
    id: Scalars['ID']['output'];
    /** The reference of the content reference. */
    reference: Scalars['String']['output'];
};
/** Represents a contribution a user made on GitHub, such as opening an issue. */
export type Contribution = {
    /**
     * Whether this contribution is associated with a record you do not have access to. For
     * example, your own 'first issue' contribution may have been made on a repository you can no
     * longer access.
     */
    isRestricted: Scalars['Boolean']['output'];
    /** When this contribution was made. */
    occurredAt: Scalars['DateTime']['output'];
    /** The HTTP path for this contribution. */
    resourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this contribution. */
    url: Scalars['URI']['output'];
    /** The user who made this contribution. */
    user: User;
};
/** A calendar of contributions made on GitHub by a user. */
export type ContributionCalendar = {
    __typename?: 'ContributionCalendar';
    /** A list of hex color codes used in this calendar. The darker the color, the more contributions it represents. */
    colors: Array<Scalars['String']['output']>;
    /** Determine if the color set was chosen because it's currently Halloween. */
    isHalloween: Scalars['Boolean']['output'];
    /** A list of the months of contributions in this calendar. */
    months: Array<ContributionCalendarMonth>;
    /** The count of total contributions in the calendar. */
    totalContributions: Scalars['Int']['output'];
    /** A list of the weeks of contributions in this calendar. */
    weeks: Array<ContributionCalendarWeek>;
};
/** Represents a single day of contributions on GitHub by a user. */
export type ContributionCalendarDay = {
    __typename?: 'ContributionCalendarDay';
    /** The hex color code that represents how many contributions were made on this day compared to others in the calendar. */
    color: Scalars['String']['output'];
    /** How many contributions were made by the user on this day. */
    contributionCount: Scalars['Int']['output'];
    /**
     * Indication of contributions, relative to other days. Can be used to indicate
     * which color to represent this day on a calendar.
     */
    contributionLevel: ContributionLevel;
    /** The day this square represents. */
    date: Scalars['Date']['output'];
    /** A number representing which day of the week this square represents, e.g., 1 is Monday. */
    weekday: Scalars['Int']['output'];
};
/** A month of contributions in a user's contribution graph. */
export type ContributionCalendarMonth = {
    __typename?: 'ContributionCalendarMonth';
    /** The date of the first day of this month. */
    firstDay: Scalars['Date']['output'];
    /** The name of the month. */
    name: Scalars['String']['output'];
    /** How many weeks started in this month. */
    totalWeeks: Scalars['Int']['output'];
    /** The year the month occurred in. */
    year: Scalars['Int']['output'];
};
/** A week of contributions in a user's contribution graph. */
export type ContributionCalendarWeek = {
    __typename?: 'ContributionCalendarWeek';
    /** The days of contributions in this week. */
    contributionDays: Array<ContributionCalendarDay>;
    /** The date of the earliest square in this week. */
    firstDay: Scalars['Date']['output'];
};
/** Varying levels of contributions from none to many. */
export declare enum ContributionLevel {
    /** Lowest 25% of days of contributions. */
    FirstQuartile = "FIRST_QUARTILE",
    /** Highest 25% of days of contributions. More contributions than the third quartile. */
    FourthQuartile = "FOURTH_QUARTILE",
    /** No contributions occurred. */
    None = "NONE",
    /** Second lowest 25% of days of contributions. More contributions than the first quartile. */
    SecondQuartile = "SECOND_QUARTILE",
    /** Second highest 25% of days of contributions. More contributions than second quartile, less than the fourth quartile. */
    ThirdQuartile = "THIRD_QUARTILE"
}
/** Ordering options for contribution connections. */
export type ContributionOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
};
/** A contributions collection aggregates contributions such as opened issues and commits created by a user. */
export type ContributionsCollection = {
    __typename?: 'ContributionsCollection';
    /** Commit contributions made by the user, grouped by repository. */
    commitContributionsByRepository: Array<CommitContributionsByRepository>;
    /** A calendar of this user's contributions on GitHub. */
    contributionCalendar: ContributionCalendar;
    /** The years the user has been making contributions with the most recent year first. */
    contributionYears: Array<Scalars['Int']['output']>;
    /** Determine if this collection's time span ends in the current month. */
    doesEndInCurrentMonth: Scalars['Boolean']['output'];
    /**
     * The date of the first restricted contribution the user made in this time
     * period. Can only be non-null when the user has enabled private contribution counts.
     */
    earliestRestrictedContributionDate?: Maybe<Scalars['Date']['output']>;
    /** The ending date and time of this collection. */
    endedAt: Scalars['DateTime']['output'];
    /**
     * The first issue the user opened on GitHub. This will be null if that issue was
     * opened outside the collection's time range and ignoreTimeRange is false. If
     * the issue is not visible but the user has opted to show private contributions,
     * a RestrictedContribution will be returned.
     */
    firstIssueContribution?: Maybe<CreatedIssueOrRestrictedContribution>;
    /**
     * The first pull request the user opened on GitHub. This will be null if that
     * pull request was opened outside the collection's time range and
     * ignoreTimeRange is not true. If the pull request is not visible but the user
     * has opted to show private contributions, a RestrictedContribution will be returned.
     */
    firstPullRequestContribution?: Maybe<CreatedPullRequestOrRestrictedContribution>;
    /**
     * The first repository the user created on GitHub. This will be null if that
     * first repository was created outside the collection's time range and
     * ignoreTimeRange is false. If the repository is not visible, then a
     * RestrictedContribution is returned.
     */
    firstRepositoryContribution?: Maybe<CreatedRepositoryOrRestrictedContribution>;
    /** Does the user have any more activity in the timeline that occurred prior to the collection's time range? */
    hasActivityInThePast: Scalars['Boolean']['output'];
    /** Determine if there are any contributions in this collection. */
    hasAnyContributions: Scalars['Boolean']['output'];
    /**
     * Determine if the user made any contributions in this time frame whose details
     * are not visible because they were made in a private repository. Can only be
     * true if the user enabled private contribution counts.
     */
    hasAnyRestrictedContributions: Scalars['Boolean']['output'];
    /** Whether or not the collector's time span is all within the same day. */
    isSingleDay: Scalars['Boolean']['output'];
    /** A list of issues the user opened. */
    issueContributions: CreatedIssueContributionConnection;
    /** Issue contributions made by the user, grouped by repository. */
    issueContributionsByRepository: Array<IssueContributionsByRepository>;
    /**
     * When the user signed up for GitHub. This will be null if that sign up date
     * falls outside the collection's time range and ignoreTimeRange is false.
     */
    joinedGitHubContribution?: Maybe<JoinedGitHubContribution>;
    /**
     * The date of the most recent restricted contribution the user made in this time
     * period. Can only be non-null when the user has enabled private contribution counts.
     */
    latestRestrictedContributionDate?: Maybe<Scalars['Date']['output']>;
    /**
     * When this collection's time range does not include any activity from the user, use this
     * to get a different collection from an earlier time range that does have activity.
     */
    mostRecentCollectionWithActivity?: Maybe<ContributionsCollection>;
    /**
     * Returns a different contributions collection from an earlier time range than this one
     * that does not have any contributions.
     */
    mostRecentCollectionWithoutActivity?: Maybe<ContributionsCollection>;
    /**
     * The issue the user opened on GitHub that received the most comments in the specified
     * time frame.
     */
    popularIssueContribution?: Maybe<CreatedIssueContribution>;
    /**
     * The pull request the user opened on GitHub that received the most comments in the
     * specified time frame.
     */
    popularPullRequestContribution?: Maybe<CreatedPullRequestContribution>;
    /** Pull request contributions made by the user. */
    pullRequestContributions: CreatedPullRequestContributionConnection;
    /** Pull request contributions made by the user, grouped by repository. */
    pullRequestContributionsByRepository: Array<PullRequestContributionsByRepository>;
    /** Pull request review contributions made by the user. */
    pullRequestReviewContributions: CreatedPullRequestReviewContributionConnection;
    /** Pull request review contributions made by the user, grouped by repository. */
    pullRequestReviewContributionsByRepository: Array<PullRequestReviewContributionsByRepository>;
    /** A list of repositories owned by the user that the user created in this time range. */
    repositoryContributions: CreatedRepositoryContributionConnection;
    /**
     * A count of contributions made by the user that the viewer cannot access. Only
     * non-zero when the user has chosen to share their private contribution counts.
     */
    restrictedContributionsCount: Scalars['Int']['output'];
    /** The beginning date and time of this collection. */
    startedAt: Scalars['DateTime']['output'];
    /** How many commits were made by the user in this time span. */
    totalCommitContributions: Scalars['Int']['output'];
    /** How many issues the user opened. */
    totalIssueContributions: Scalars['Int']['output'];
    /** How many pull requests the user opened. */
    totalPullRequestContributions: Scalars['Int']['output'];
    /** How many pull request reviews the user left. */
    totalPullRequestReviewContributions: Scalars['Int']['output'];
    /** How many different repositories the user committed to. */
    totalRepositoriesWithContributedCommits: Scalars['Int']['output'];
    /** How many different repositories the user opened issues in. */
    totalRepositoriesWithContributedIssues: Scalars['Int']['output'];
    /** How many different repositories the user left pull request reviews in. */
    totalRepositoriesWithContributedPullRequestReviews: Scalars['Int']['output'];
    /** How many different repositories the user opened pull requests in. */
    totalRepositoriesWithContributedPullRequests: Scalars['Int']['output'];
    /** How many repositories the user created. */
    totalRepositoryContributions: Scalars['Int']['output'];
    /** The user who made the contributions in this collection. */
    user: User;
};
/** A contributions collection aggregates contributions such as opened issues and commits created by a user. */
export type ContributionsCollectionCommitContributionsByRepositoryArgs = {
    maxRepositories?: InputMaybe<Scalars['Int']['input']>;
};
/** A contributions collection aggregates contributions such as opened issues and commits created by a user. */
export type ContributionsCollectionIssueContributionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    excludeFirst?: InputMaybe<Scalars['Boolean']['input']>;
    excludePopular?: InputMaybe<Scalars['Boolean']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ContributionOrder>;
};
/** A contributions collection aggregates contributions such as opened issues and commits created by a user. */
export type ContributionsCollectionIssueContributionsByRepositoryArgs = {
    excludeFirst?: InputMaybe<Scalars['Boolean']['input']>;
    excludePopular?: InputMaybe<Scalars['Boolean']['input']>;
    maxRepositories?: InputMaybe<Scalars['Int']['input']>;
};
/** A contributions collection aggregates contributions such as opened issues and commits created by a user. */
export type ContributionsCollectionPullRequestContributionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    excludeFirst?: InputMaybe<Scalars['Boolean']['input']>;
    excludePopular?: InputMaybe<Scalars['Boolean']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ContributionOrder>;
};
/** A contributions collection aggregates contributions such as opened issues and commits created by a user. */
export type ContributionsCollectionPullRequestContributionsByRepositoryArgs = {
    excludeFirst?: InputMaybe<Scalars['Boolean']['input']>;
    excludePopular?: InputMaybe<Scalars['Boolean']['input']>;
    maxRepositories?: InputMaybe<Scalars['Int']['input']>;
};
/** A contributions collection aggregates contributions such as opened issues and commits created by a user. */
export type ContributionsCollectionPullRequestReviewContributionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ContributionOrder>;
};
/** A contributions collection aggregates contributions such as opened issues and commits created by a user. */
export type ContributionsCollectionPullRequestReviewContributionsByRepositoryArgs = {
    maxRepositories?: InputMaybe<Scalars['Int']['input']>;
};
/** A contributions collection aggregates contributions such as opened issues and commits created by a user. */
export type ContributionsCollectionRepositoryContributionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    excludeFirst?: InputMaybe<Scalars['Boolean']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ContributionOrder>;
};
/** A contributions collection aggregates contributions such as opened issues and commits created by a user. */
export type ContributionsCollectionTotalIssueContributionsArgs = {
    excludeFirst?: InputMaybe<Scalars['Boolean']['input']>;
    excludePopular?: InputMaybe<Scalars['Boolean']['input']>;
};
/** A contributions collection aggregates contributions such as opened issues and commits created by a user. */
export type ContributionsCollectionTotalPullRequestContributionsArgs = {
    excludeFirst?: InputMaybe<Scalars['Boolean']['input']>;
    excludePopular?: InputMaybe<Scalars['Boolean']['input']>;
};
/** A contributions collection aggregates contributions such as opened issues and commits created by a user. */
export type ContributionsCollectionTotalRepositoriesWithContributedIssuesArgs = {
    excludeFirst?: InputMaybe<Scalars['Boolean']['input']>;
    excludePopular?: InputMaybe<Scalars['Boolean']['input']>;
};
/** A contributions collection aggregates contributions such as opened issues and commits created by a user. */
export type ContributionsCollectionTotalRepositoriesWithContributedPullRequestsArgs = {
    excludeFirst?: InputMaybe<Scalars['Boolean']['input']>;
    excludePopular?: InputMaybe<Scalars['Boolean']['input']>;
};
/** A contributions collection aggregates contributions such as opened issues and commits created by a user. */
export type ContributionsCollectionTotalRepositoryContributionsArgs = {
    excludeFirst?: InputMaybe<Scalars['Boolean']['input']>;
};
/** Autogenerated input type of ConvertProjectCardNoteToIssue */
export type ConvertProjectCardNoteToIssueInput = {
    /** The body of the newly created issue. */
    body?: InputMaybe<Scalars['String']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ProjectCard ID to convert. */
    projectCardId: Scalars['ID']['input'];
    /** The ID of the repository to create the issue in. */
    repositoryId: Scalars['ID']['input'];
    /** The title of the newly created issue. Defaults to the card's note text. */
    title?: InputMaybe<Scalars['String']['input']>;
};
/** Autogenerated return type of ConvertProjectCardNoteToIssue */
export type ConvertProjectCardNoteToIssuePayload = {
    __typename?: 'ConvertProjectCardNoteToIssuePayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated ProjectCard. */
    projectCard?: Maybe<ProjectCard>;
};
/** Autogenerated input type of ConvertPullRequestToDraft */
export type ConvertPullRequestToDraftInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** ID of the pull request to convert to draft */
    pullRequestId: Scalars['ID']['input'];
};
/** Autogenerated return type of ConvertPullRequestToDraft */
export type ConvertPullRequestToDraftPayload = {
    __typename?: 'ConvertPullRequestToDraftPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The pull request that is now a draft. */
    pullRequest?: Maybe<PullRequest>;
};
/** Represents a 'convert_to_draft' event on a given pull request. */
export type ConvertToDraftEvent = Node & UniformResourceLocatable & {
    __typename?: 'ConvertToDraftEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** PullRequest referenced by event. */
    pullRequest: PullRequest;
    /** The HTTP path for this convert to draft event. */
    resourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this convert to draft event. */
    url: Scalars['URI']['output'];
};
/** Represents a 'converted_note_to_issue' event on a given issue or pull request. */
export type ConvertedNoteToIssueEvent = Node & {
    __typename?: 'ConvertedNoteToIssueEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** Project referenced by event. */
    project?: Maybe<Project>;
    /** Project card referenced by this project event. */
    projectCard?: Maybe<ProjectCard>;
    /** Column name referenced by this project event. */
    projectColumnName: Scalars['String']['output'];
};
/** Autogenerated input type of CreateBranchProtectionRule */
export type CreateBranchProtectionRuleInput = {
    /** Can this branch be deleted. */
    allowsDeletions?: InputMaybe<Scalars['Boolean']['input']>;
    /** Are force pushes allowed on this branch. */
    allowsForcePushes?: InputMaybe<Scalars['Boolean']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** Will new commits pushed to matching branches dismiss pull request review approvals. */
    dismissesStaleReviews?: InputMaybe<Scalars['Boolean']['input']>;
    /** Can admins overwrite branch protection. */
    isAdminEnforced?: InputMaybe<Scalars['Boolean']['input']>;
    /** The glob-like pattern used to determine matching branches. */
    pattern: Scalars['String']['input'];
    /** A list of User, Team or App IDs allowed to push to matching branches. */
    pushActorIds?: InputMaybe<Array<Scalars['ID']['input']>>;
    /** The global relay id of the repository in which a new branch protection rule should be created in. */
    repositoryId: Scalars['ID']['input'];
    /** Number of approving reviews required to update matching branches. */
    requiredApprovingReviewCount?: InputMaybe<Scalars['Int']['input']>;
    /** List of required status check contexts that must pass for commits to be accepted to matching branches. */
    requiredStatusCheckContexts?: InputMaybe<Array<Scalars['String']['input']>>;
    /** Are approving reviews required to update matching branches. */
    requiresApprovingReviews?: InputMaybe<Scalars['Boolean']['input']>;
    /** Are reviews from code owners required to update matching branches. */
    requiresCodeOwnerReviews?: InputMaybe<Scalars['Boolean']['input']>;
    /** Are commits required to be signed. */
    requiresCommitSignatures?: InputMaybe<Scalars['Boolean']['input']>;
    /** Are conversations required to be resolved before merging. */
    requiresConversationResolution?: InputMaybe<Scalars['Boolean']['input']>;
    /** Are merge commits prohibited from being pushed to this branch. */
    requiresLinearHistory?: InputMaybe<Scalars['Boolean']['input']>;
    /** Are status checks required to update matching branches. */
    requiresStatusChecks?: InputMaybe<Scalars['Boolean']['input']>;
    /** Are branches required to be up to date before merging. */
    requiresStrictStatusChecks?: InputMaybe<Scalars['Boolean']['input']>;
    /** Is pushing to matching branches restricted. */
    restrictsPushes?: InputMaybe<Scalars['Boolean']['input']>;
    /** Is dismissal of pull request reviews restricted. */
    restrictsReviewDismissals?: InputMaybe<Scalars['Boolean']['input']>;
    /** A list of User or Team IDs allowed to dismiss reviews on pull requests targeting matching branches. */
    reviewDismissalActorIds?: InputMaybe<Array<Scalars['ID']['input']>>;
};
/** Autogenerated return type of CreateBranchProtectionRule */
export type CreateBranchProtectionRulePayload = {
    __typename?: 'CreateBranchProtectionRulePayload';
    /** The newly created BranchProtectionRule. */
    branchProtectionRule?: Maybe<BranchProtectionRule>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of CreateCheckRun */
export type CreateCheckRunInput = {
    /** Possible further actions the integrator can perform, which a user may trigger. */
    actions?: InputMaybe<Array<CheckRunAction>>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The time that the check run finished. */
    completedAt?: InputMaybe<Scalars['DateTime']['input']>;
    /** The final conclusion of the check. */
    conclusion?: InputMaybe<CheckConclusionState>;
    /** The URL of the integrator's site that has the full details of the check. */
    detailsUrl?: InputMaybe<Scalars['URI']['input']>;
    /** A reference for the run on the integrator's system. */
    externalId?: InputMaybe<Scalars['String']['input']>;
    /** The SHA of the head commit. */
    headSha: Scalars['GitObjectID']['input'];
    /** The name of the check. */
    name: Scalars['String']['input'];
    /** Descriptive details about the run. */
    output?: InputMaybe<CheckRunOutput>;
    /** The node ID of the repository. */
    repositoryId: Scalars['ID']['input'];
    /** The time that the check run began. */
    startedAt?: InputMaybe<Scalars['DateTime']['input']>;
    /** The current status. */
    status?: InputMaybe<RequestableCheckStatusState>;
};
/** Autogenerated return type of CreateCheckRun */
export type CreateCheckRunPayload = {
    __typename?: 'CreateCheckRunPayload';
    /** The newly created check run. */
    checkRun?: Maybe<CheckRun>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of CreateCheckSuite */
export type CreateCheckSuiteInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The SHA of the head commit. */
    headSha: Scalars['GitObjectID']['input'];
    /** The Node ID of the repository. */
    repositoryId: Scalars['ID']['input'];
};
/** Autogenerated return type of CreateCheckSuite */
export type CreateCheckSuitePayload = {
    __typename?: 'CreateCheckSuitePayload';
    /** The newly created check suite. */
    checkSuite?: Maybe<CheckSuite>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of CreateContentAttachment */
export type CreateContentAttachmentInput = {
    /** The body of the content attachment, which may contain markdown. */
    body: Scalars['String']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The node ID of the content_reference. */
    contentReferenceId: Scalars['ID']['input'];
    /** The title of the content attachment. */
    title: Scalars['String']['input'];
};
/** Autogenerated return type of CreateContentAttachment */
export type CreateContentAttachmentPayload = {
    __typename?: 'CreateContentAttachmentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The newly created content attachment. */
    contentAttachment?: Maybe<ContentAttachment>;
};
/** Autogenerated input type of CreateDeployment */
export type CreateDeploymentInput = {
    /** Attempt to automatically merge the default branch into the requested ref, defaults to true. */
    autoMerge?: InputMaybe<Scalars['Boolean']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** Short description of the deployment. */
    description?: InputMaybe<Scalars['String']['input']>;
    /** Name for the target deployment environment. */
    environment?: InputMaybe<Scalars['String']['input']>;
    /** JSON payload with extra information about the deployment. */
    payload?: InputMaybe<Scalars['String']['input']>;
    /** The node ID of the ref to be deployed. */
    refId: Scalars['ID']['input'];
    /** The node ID of the repository. */
    repositoryId: Scalars['ID']['input'];
    /**
     * The status contexts to verify against commit status checks. To bypass required
     * contexts, pass an empty array. Defaults to all unique contexts.
     */
    requiredContexts?: InputMaybe<Array<Scalars['String']['input']>>;
    /** Specifies a task to execute. */
    task?: InputMaybe<Scalars['String']['input']>;
};
/** Autogenerated return type of CreateDeployment */
export type CreateDeploymentPayload = {
    __typename?: 'CreateDeploymentPayload';
    /** True if the default branch has been auto-merged into the deployment ref. */
    autoMerged?: Maybe<Scalars['Boolean']['output']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The new deployment. */
    deployment?: Maybe<Deployment>;
};
/** Autogenerated input type of CreateDeploymentStatus */
export type CreateDeploymentStatusInput = {
    /**
     * Adds a new inactive status to all non-transient, non-production environment
     * deployments with the same repository and environment name as the created
     * status's deployment.
     */
    autoInactive?: InputMaybe<Scalars['Boolean']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The node ID of the deployment. */
    deploymentId: Scalars['ID']['input'];
    /** A short description of the status. Maximum length of 140 characters. */
    description?: InputMaybe<Scalars['String']['input']>;
    /** If provided, updates the environment of the deploy. Otherwise, does not modify the environment. */
    environment?: InputMaybe<Scalars['String']['input']>;
    /** Sets the URL for accessing your environment. */
    environmentUrl?: InputMaybe<Scalars['String']['input']>;
    /**
     * The log URL to associate with this status.       This URL should contain
     * output to keep the user updated while the task is running       or serve as
     * historical information for what happened in the deployment.
     */
    logUrl?: InputMaybe<Scalars['String']['input']>;
    /** The state of the deployment. */
    state: DeploymentStatusState;
};
/** Autogenerated return type of CreateDeploymentStatus */
export type CreateDeploymentStatusPayload = {
    __typename?: 'CreateDeploymentStatusPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The new deployment status. */
    deploymentStatus?: Maybe<DeploymentStatus>;
};
/** Autogenerated input type of CreateDiscussion */
export type CreateDiscussionInput = {
    /** The body of the discussion. */
    body: Scalars['String']['input'];
    /** The id of the discussion category to associate with this discussion. */
    categoryId: Scalars['ID']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The id of the repository on which to create the discussion. */
    repositoryId: Scalars['ID']['input'];
    /** The title of the discussion. */
    title: Scalars['String']['input'];
};
/** Autogenerated return type of CreateDiscussion */
export type CreateDiscussionPayload = {
    __typename?: 'CreateDiscussionPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The discussion that was just created. */
    discussion?: Maybe<Discussion>;
};
/** Autogenerated input type of CreateEnterpriseOrganization */
export type CreateEnterpriseOrganizationInput = {
    /** The logins for the administrators of the new organization. */
    adminLogins: Array<Scalars['String']['input']>;
    /** The email used for sending billing receipts. */
    billingEmail: Scalars['String']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the enterprise owning the new organization. */
    enterpriseId: Scalars['ID']['input'];
    /** The login of the new organization. */
    login: Scalars['String']['input'];
    /** The profile name of the new organization. */
    profileName: Scalars['String']['input'];
};
/** Autogenerated return type of CreateEnterpriseOrganization */
export type CreateEnterpriseOrganizationPayload = {
    __typename?: 'CreateEnterpriseOrganizationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The enterprise that owns the created organization. */
    enterprise?: Maybe<Enterprise>;
    /** The organization that was created. */
    organization?: Maybe<Organization>;
};
/** Autogenerated input type of CreateEnvironment */
export type CreateEnvironmentInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The name of the environment. */
    name: Scalars['String']['input'];
    /** The node ID of the repository. */
    repositoryId: Scalars['ID']['input'];
};
/** Autogenerated return type of CreateEnvironment */
export type CreateEnvironmentPayload = {
    __typename?: 'CreateEnvironmentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The new or existing environment. */
    environment?: Maybe<Environment>;
};
/** Autogenerated input type of CreateIpAllowListEntry */
export type CreateIpAllowListEntryInput = {
    /** An IP address or range of addresses in CIDR notation. */
    allowListValue: Scalars['String']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** Whether the IP allow list entry is active when an IP allow list is enabled. */
    isActive: Scalars['Boolean']['input'];
    /** An optional name for the IP allow list entry. */
    name?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the owner for which to create the new IP allow list entry. */
    ownerId: Scalars['ID']['input'];
};
/** Autogenerated return type of CreateIpAllowListEntry */
export type CreateIpAllowListEntryPayload = {
    __typename?: 'CreateIpAllowListEntryPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The IP allow list entry that was created. */
    ipAllowListEntry?: Maybe<IpAllowListEntry>;
};
/** Autogenerated input type of CreateIssue */
export type CreateIssueInput = {
    /** The Node ID for the user assignee for this issue. */
    assigneeIds?: InputMaybe<Array<Scalars['ID']['input']>>;
    /** The body for the issue description. */
    body?: InputMaybe<Scalars['String']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The name of an issue template in the repository, assigns labels and assignees from the template to the issue */
    issueTemplate?: InputMaybe<Scalars['String']['input']>;
    /** An array of Node IDs of labels for this issue. */
    labelIds?: InputMaybe<Array<Scalars['ID']['input']>>;
    /** The Node ID of the milestone for this issue. */
    milestoneId?: InputMaybe<Scalars['ID']['input']>;
    /** An array of Node IDs for projects associated with this issue. */
    projectIds?: InputMaybe<Array<Scalars['ID']['input']>>;
    /** The Node ID of the repository. */
    repositoryId: Scalars['ID']['input'];
    /** The title for the issue. */
    title: Scalars['String']['input'];
};
/** Autogenerated return type of CreateIssue */
export type CreateIssuePayload = {
    __typename?: 'CreateIssuePayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The new issue. */
    issue?: Maybe<Issue>;
};
/** Autogenerated input type of CreateLabel */
export type CreateLabelInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** A 6 character hex code, without the leading #, identifying the color of the label. */
    color: Scalars['String']['input'];
    /** A brief description of the label, such as its purpose. */
    description?: InputMaybe<Scalars['String']['input']>;
    /** The name of the label. */
    name: Scalars['String']['input'];
    /** The Node ID of the repository. */
    repositoryId: Scalars['ID']['input'];
};
/** Autogenerated return type of CreateLabel */
export type CreateLabelPayload = {
    __typename?: 'CreateLabelPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The new label. */
    label?: Maybe<Label>;
};
/** Autogenerated input type of CreateProject */
export type CreateProjectInput = {
    /** The description of project. */
    body?: InputMaybe<Scalars['String']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The name of project. */
    name: Scalars['String']['input'];
    /** The owner ID to create the project under. */
    ownerId: Scalars['ID']['input'];
    /** A list of repository IDs to create as linked repositories for the project */
    repositoryIds?: InputMaybe<Array<Scalars['ID']['input']>>;
    /** The name of the GitHub-provided template. */
    template?: InputMaybe<ProjectTemplate>;
};
/** Autogenerated return type of CreateProject */
export type CreateProjectPayload = {
    __typename?: 'CreateProjectPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The new project. */
    project?: Maybe<Project>;
};
/** Autogenerated input type of CreatePullRequest */
export type CreatePullRequestInput = {
    /**
     * The name of the branch you want your changes pulled into. This should be an existing branch
     * on the current repository. You cannot update the base branch on a pull request to point
     * to another repository.
     */
    baseRefName: Scalars['String']['input'];
    /** The contents of the pull request. */
    body?: InputMaybe<Scalars['String']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** Indicates whether this pull request should be a draft. */
    draft?: InputMaybe<Scalars['Boolean']['input']>;
    /**
     * The name of the branch where your changes are implemented. For cross-repository pull requests
     * in the same network, namespace `head_ref_name` with a user like this: `username:branch`.
     */
    headRefName: Scalars['String']['input'];
    /** Indicates whether maintainers can modify the pull request. */
    maintainerCanModify?: InputMaybe<Scalars['Boolean']['input']>;
    /** The Node ID of the repository. */
    repositoryId: Scalars['ID']['input'];
    /** The title of the pull request. */
    title: Scalars['String']['input'];
};
/** Autogenerated return type of CreatePullRequest */
export type CreatePullRequestPayload = {
    __typename?: 'CreatePullRequestPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The new pull request. */
    pullRequest?: Maybe<PullRequest>;
};
/** Autogenerated input type of CreateRef */
export type CreateRefInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The fully qualified name of the new Ref (ie: `refs/heads/my_new_branch`). */
    name: Scalars['String']['input'];
    /** The GitObjectID that the new Ref shall target. Must point to a commit. */
    oid: Scalars['GitObjectID']['input'];
    /** The Node ID of the Repository to create the Ref in. */
    repositoryId: Scalars['ID']['input'];
};
/** Autogenerated return type of CreateRef */
export type CreateRefPayload = {
    __typename?: 'CreateRefPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The newly created ref. */
    ref?: Maybe<Ref>;
};
/** Autogenerated input type of CreateRepository */
export type CreateRepositoryInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** A short description of the new repository. */
    description?: InputMaybe<Scalars['String']['input']>;
    /** Indicates if the repository should have the issues feature enabled. */
    hasIssuesEnabled?: InputMaybe<Scalars['Boolean']['input']>;
    /** Indicates if the repository should have the wiki feature enabled. */
    hasWikiEnabled?: InputMaybe<Scalars['Boolean']['input']>;
    /** The URL for a web page about this repository. */
    homepageUrl?: InputMaybe<Scalars['URI']['input']>;
    /** The name of the new repository. */
    name: Scalars['String']['input'];
    /** The ID of the owner for the new repository. */
    ownerId?: InputMaybe<Scalars['ID']['input']>;
    /**
     * When an organization is specified as the owner, this ID identifies the team
     * that should be granted access to the new repository.
     */
    teamId?: InputMaybe<Scalars['ID']['input']>;
    /**
     * Whether this repository should be marked as a template such that anyone who
     * can access it can create new repositories with the same files and directory structure.
     */
    template?: InputMaybe<Scalars['Boolean']['input']>;
    /** Indicates the repository's visibility level. */
    visibility: RepositoryVisibility;
};
/** Autogenerated return type of CreateRepository */
export type CreateRepositoryPayload = {
    __typename?: 'CreateRepositoryPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The new repository. */
    repository?: Maybe<Repository>;
};
/** Autogenerated input type of CreateTeamDiscussionComment */
export type CreateTeamDiscussionCommentInput = {
    /** The content of the comment. */
    body: Scalars['String']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the discussion to which the comment belongs. */
    discussionId: Scalars['ID']['input'];
};
/** Autogenerated return type of CreateTeamDiscussionComment */
export type CreateTeamDiscussionCommentPayload = {
    __typename?: 'CreateTeamDiscussionCommentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The new comment. */
    teamDiscussionComment?: Maybe<TeamDiscussionComment>;
};
/** Autogenerated input type of CreateTeamDiscussion */
export type CreateTeamDiscussionInput = {
    /** The content of the discussion. */
    body: Scalars['String']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /**
     * If true, restricts the visibility of this discussion to team members and
     * organization admins. If false or not specified, allows any organization member
     * to view this discussion.
     */
    private?: InputMaybe<Scalars['Boolean']['input']>;
    /** The ID of the team to which the discussion belongs. */
    teamId: Scalars['ID']['input'];
    /** The title of the discussion. */
    title: Scalars['String']['input'];
};
/** Autogenerated return type of CreateTeamDiscussion */
export type CreateTeamDiscussionPayload = {
    __typename?: 'CreateTeamDiscussionPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The new discussion. */
    teamDiscussion?: Maybe<TeamDiscussion>;
};
/** Represents the contribution a user made by committing to a repository. */
export type CreatedCommitContribution = Contribution & {
    __typename?: 'CreatedCommitContribution';
    /** How many commits were made on this day to this repository by the user. */
    commitCount: Scalars['Int']['output'];
    /**
     * Whether this contribution is associated with a record you do not have access to. For
     * example, your own 'first issue' contribution may have been made on a repository you can no
     * longer access.
     */
    isRestricted: Scalars['Boolean']['output'];
    /** When this contribution was made. */
    occurredAt: Scalars['DateTime']['output'];
    /** The repository the user made a commit in. */
    repository: Repository;
    /** The HTTP path for this contribution. */
    resourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this contribution. */
    url: Scalars['URI']['output'];
    /** The user who made this contribution. */
    user: User;
};
/** The connection type for CreatedCommitContribution. */
export type CreatedCommitContributionConnection = {
    __typename?: 'CreatedCommitContributionConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<CreatedCommitContributionEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<CreatedCommitContribution>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of commits across days and repositories in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type CreatedCommitContributionEdge = {
    __typename?: 'CreatedCommitContributionEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<CreatedCommitContribution>;
};
/** Represents the contribution a user made on GitHub by opening an issue. */
export type CreatedIssueContribution = Contribution & {
    __typename?: 'CreatedIssueContribution';
    /**
     * Whether this contribution is associated with a record you do not have access to. For
     * example, your own 'first issue' contribution may have been made on a repository you can no
     * longer access.
     */
    isRestricted: Scalars['Boolean']['output'];
    /** The issue that was opened. */
    issue: Issue;
    /** When this contribution was made. */
    occurredAt: Scalars['DateTime']['output'];
    /** The HTTP path for this contribution. */
    resourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this contribution. */
    url: Scalars['URI']['output'];
    /** The user who made this contribution. */
    user: User;
};
/** The connection type for CreatedIssueContribution. */
export type CreatedIssueContributionConnection = {
    __typename?: 'CreatedIssueContributionConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<CreatedIssueContributionEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<CreatedIssueContribution>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type CreatedIssueContributionEdge = {
    __typename?: 'CreatedIssueContributionEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<CreatedIssueContribution>;
};
/** Represents either a issue the viewer can access or a restricted contribution. */
export type CreatedIssueOrRestrictedContribution = CreatedIssueContribution | RestrictedContribution;
/** Represents the contribution a user made on GitHub by opening a pull request. */
export type CreatedPullRequestContribution = Contribution & {
    __typename?: 'CreatedPullRequestContribution';
    /**
     * Whether this contribution is associated with a record you do not have access to. For
     * example, your own 'first issue' contribution may have been made on a repository you can no
     * longer access.
     */
    isRestricted: Scalars['Boolean']['output'];
    /** When this contribution was made. */
    occurredAt: Scalars['DateTime']['output'];
    /** The pull request that was opened. */
    pullRequest: PullRequest;
    /** The HTTP path for this contribution. */
    resourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this contribution. */
    url: Scalars['URI']['output'];
    /** The user who made this contribution. */
    user: User;
};
/** The connection type for CreatedPullRequestContribution. */
export type CreatedPullRequestContributionConnection = {
    __typename?: 'CreatedPullRequestContributionConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<CreatedPullRequestContributionEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<CreatedPullRequestContribution>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type CreatedPullRequestContributionEdge = {
    __typename?: 'CreatedPullRequestContributionEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<CreatedPullRequestContribution>;
};
/** Represents either a pull request the viewer can access or a restricted contribution. */
export type CreatedPullRequestOrRestrictedContribution = CreatedPullRequestContribution | RestrictedContribution;
/** Represents the contribution a user made by leaving a review on a pull request. */
export type CreatedPullRequestReviewContribution = Contribution & {
    __typename?: 'CreatedPullRequestReviewContribution';
    /**
     * Whether this contribution is associated with a record you do not have access to. For
     * example, your own 'first issue' contribution may have been made on a repository you can no
     * longer access.
     */
    isRestricted: Scalars['Boolean']['output'];
    /** When this contribution was made. */
    occurredAt: Scalars['DateTime']['output'];
    /** The pull request the user reviewed. */
    pullRequest: PullRequest;
    /** The review the user left on the pull request. */
    pullRequestReview: PullRequestReview;
    /** The repository containing the pull request that the user reviewed. */
    repository: Repository;
    /** The HTTP path for this contribution. */
    resourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this contribution. */
    url: Scalars['URI']['output'];
    /** The user who made this contribution. */
    user: User;
};
/** The connection type for CreatedPullRequestReviewContribution. */
export type CreatedPullRequestReviewContributionConnection = {
    __typename?: 'CreatedPullRequestReviewContributionConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<CreatedPullRequestReviewContributionEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<CreatedPullRequestReviewContribution>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type CreatedPullRequestReviewContributionEdge = {
    __typename?: 'CreatedPullRequestReviewContributionEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<CreatedPullRequestReviewContribution>;
};
/** Represents the contribution a user made on GitHub by creating a repository. */
export type CreatedRepositoryContribution = Contribution & {
    __typename?: 'CreatedRepositoryContribution';
    /**
     * Whether this contribution is associated with a record you do not have access to. For
     * example, your own 'first issue' contribution may have been made on a repository you can no
     * longer access.
     */
    isRestricted: Scalars['Boolean']['output'];
    /** When this contribution was made. */
    occurredAt: Scalars['DateTime']['output'];
    /** The repository that was created. */
    repository: Repository;
    /** The HTTP path for this contribution. */
    resourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this contribution. */
    url: Scalars['URI']['output'];
    /** The user who made this contribution. */
    user: User;
};
/** The connection type for CreatedRepositoryContribution. */
export type CreatedRepositoryContributionConnection = {
    __typename?: 'CreatedRepositoryContributionConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<CreatedRepositoryContributionEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<CreatedRepositoryContribution>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type CreatedRepositoryContributionEdge = {
    __typename?: 'CreatedRepositoryContributionEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<CreatedRepositoryContribution>;
};
/** Represents either a repository the viewer can access or a restricted contribution. */
export type CreatedRepositoryOrRestrictedContribution = CreatedRepositoryContribution | RestrictedContribution;
/** Represents a mention made by one issue or pull request to another. */
export type CrossReferencedEvent = Node & UniformResourceLocatable & {
    __typename?: 'CrossReferencedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** Reference originated in a different repository. */
    isCrossRepository: Scalars['Boolean']['output'];
    /** Identifies when the reference was made. */
    referencedAt: Scalars['DateTime']['output'];
    /** The HTTP path for this pull request. */
    resourcePath: Scalars['URI']['output'];
    /** Issue or pull request that made the reference. */
    source: ReferencedSubject;
    /** Issue or pull request to which the reference was made. */
    target: ReferencedSubject;
    /** The HTTP URL for this pull request. */
    url: Scalars['URI']['output'];
    /** Checks if the target will be closed when the source is merged. */
    willCloseTarget: Scalars['Boolean']['output'];
};
/** The possible default permissions for repositories. */
export declare enum DefaultRepositoryPermissionField {
    /** Can read, write, and administrate repos by default */
    Admin = "ADMIN",
    /** No access */
    None = "NONE",
    /** Can read repos by default */
    Read = "READ",
    /** Can read and write repos by default */
    Write = "WRITE"
}
/** Entities that can be deleted. */
export type Deletable = {
    /** Check if the current viewer can delete this object. */
    viewerCanDelete: Scalars['Boolean']['output'];
};
/** Autogenerated input type of DeleteBranchProtectionRule */
export type DeleteBranchProtectionRuleInput = {
    /** The global relay id of the branch protection rule to be deleted. */
    branchProtectionRuleId: Scalars['ID']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
};
/** Autogenerated return type of DeleteBranchProtectionRule */
export type DeleteBranchProtectionRulePayload = {
    __typename?: 'DeleteBranchProtectionRulePayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of DeleteDeployment */
export type DeleteDeploymentInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the deployment to be deleted. */
    id: Scalars['ID']['input'];
};
/** Autogenerated return type of DeleteDeployment */
export type DeleteDeploymentPayload = {
    __typename?: 'DeleteDeploymentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of DeleteDiscussionComment */
export type DeleteDiscussionCommentInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node id of the discussion comment to delete. */
    id: Scalars['ID']['input'];
};
/** Autogenerated return type of DeleteDiscussionComment */
export type DeleteDiscussionCommentPayload = {
    __typename?: 'DeleteDiscussionCommentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The discussion comment that was just deleted. */
    comment?: Maybe<DiscussionComment>;
};
/** Autogenerated input type of DeleteDiscussion */
export type DeleteDiscussionInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The id of the discussion to delete. */
    id: Scalars['ID']['input'];
};
/** Autogenerated return type of DeleteDiscussion */
export type DeleteDiscussionPayload = {
    __typename?: 'DeleteDiscussionPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The discussion that was just deleted. */
    discussion?: Maybe<Discussion>;
};
/** Autogenerated input type of DeleteEnvironment */
export type DeleteEnvironmentInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the environment to be deleted. */
    id: Scalars['ID']['input'];
};
/** Autogenerated return type of DeleteEnvironment */
export type DeleteEnvironmentPayload = {
    __typename?: 'DeleteEnvironmentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of DeleteIpAllowListEntry */
export type DeleteIpAllowListEntryInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the IP allow list entry to delete. */
    ipAllowListEntryId: Scalars['ID']['input'];
};
/** Autogenerated return type of DeleteIpAllowListEntry */
export type DeleteIpAllowListEntryPayload = {
    __typename?: 'DeleteIpAllowListEntryPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The IP allow list entry that was deleted. */
    ipAllowListEntry?: Maybe<IpAllowListEntry>;
};
/** Autogenerated input type of DeleteIssueComment */
export type DeleteIssueCommentInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the comment to delete. */
    id: Scalars['ID']['input'];
};
/** Autogenerated return type of DeleteIssueComment */
export type DeleteIssueCommentPayload = {
    __typename?: 'DeleteIssueCommentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of DeleteIssue */
export type DeleteIssueInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the issue to delete. */
    issueId: Scalars['ID']['input'];
};
/** Autogenerated return type of DeleteIssue */
export type DeleteIssuePayload = {
    __typename?: 'DeleteIssuePayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The repository the issue belonged to */
    repository?: Maybe<Repository>;
};
/** Autogenerated input type of DeleteLabel */
export type DeleteLabelInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the label to be deleted. */
    id: Scalars['ID']['input'];
};
/** Autogenerated return type of DeleteLabel */
export type DeleteLabelPayload = {
    __typename?: 'DeleteLabelPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of DeletePackageVersion */
export type DeletePackageVersionInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the package version to be deleted. */
    packageVersionId: Scalars['ID']['input'];
};
/** Autogenerated return type of DeletePackageVersion */
export type DeletePackageVersionPayload = {
    __typename?: 'DeletePackageVersionPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** Whether or not the operation succeeded. */
    success?: Maybe<Scalars['Boolean']['output']>;
};
/** Autogenerated input type of DeleteProjectCard */
export type DeleteProjectCardInput = {
    /** The id of the card to delete. */
    cardId: Scalars['ID']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
};
/** Autogenerated return type of DeleteProjectCard */
export type DeleteProjectCardPayload = {
    __typename?: 'DeleteProjectCardPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The column the deleted card was in. */
    column?: Maybe<ProjectColumn>;
    /** The deleted card ID. */
    deletedCardId?: Maybe<Scalars['ID']['output']>;
};
/** Autogenerated input type of DeleteProjectColumn */
export type DeleteProjectColumnInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The id of the column to delete. */
    columnId: Scalars['ID']['input'];
};
/** Autogenerated return type of DeleteProjectColumn */
export type DeleteProjectColumnPayload = {
    __typename?: 'DeleteProjectColumnPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The deleted column ID. */
    deletedColumnId?: Maybe<Scalars['ID']['output']>;
    /** The project the deleted column was in. */
    project?: Maybe<Project>;
};
/** Autogenerated input type of DeleteProject */
export type DeleteProjectInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Project ID to update. */
    projectId: Scalars['ID']['input'];
};
/** Autogenerated return type of DeleteProject */
export type DeleteProjectPayload = {
    __typename?: 'DeleteProjectPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The repository or organization the project was removed from. */
    owner?: Maybe<ProjectOwner>;
};
/** Autogenerated input type of DeletePullRequestReviewComment */
export type DeletePullRequestReviewCommentInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the comment to delete. */
    id: Scalars['ID']['input'];
};
/** Autogenerated return type of DeletePullRequestReviewComment */
export type DeletePullRequestReviewCommentPayload = {
    __typename?: 'DeletePullRequestReviewCommentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The pull request review the deleted comment belonged to. */
    pullRequestReview?: Maybe<PullRequestReview>;
};
/** Autogenerated input type of DeletePullRequestReview */
export type DeletePullRequestReviewInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the pull request review to delete. */
    pullRequestReviewId: Scalars['ID']['input'];
};
/** Autogenerated return type of DeletePullRequestReview */
export type DeletePullRequestReviewPayload = {
    __typename?: 'DeletePullRequestReviewPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The deleted pull request review. */
    pullRequestReview?: Maybe<PullRequestReview>;
};
/** Autogenerated input type of DeleteRef */
export type DeleteRefInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the Ref to be deleted. */
    refId: Scalars['ID']['input'];
};
/** Autogenerated return type of DeleteRef */
export type DeleteRefPayload = {
    __typename?: 'DeleteRefPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of DeleteTeamDiscussionComment */
export type DeleteTeamDiscussionCommentInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the comment to delete. */
    id: Scalars['ID']['input'];
};
/** Autogenerated return type of DeleteTeamDiscussionComment */
export type DeleteTeamDiscussionCommentPayload = {
    __typename?: 'DeleteTeamDiscussionCommentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of DeleteTeamDiscussion */
export type DeleteTeamDiscussionInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The discussion ID to delete. */
    id: Scalars['ID']['input'];
};
/** Autogenerated return type of DeleteTeamDiscussion */
export type DeleteTeamDiscussionPayload = {
    __typename?: 'DeleteTeamDiscussionPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of DeleteVerifiableDomain */
export type DeleteVerifiableDomainInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the verifiable domain to delete. */
    id: Scalars['ID']['input'];
};
/** Autogenerated return type of DeleteVerifiableDomain */
export type DeleteVerifiableDomainPayload = {
    __typename?: 'DeleteVerifiableDomainPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The owning account from which the domain was deleted. */
    owner?: Maybe<VerifiableDomainOwner>;
};
/** Represents a 'demilestoned' event on a given issue or pull request. */
export type DemilestonedEvent = Node & {
    __typename?: 'DemilestonedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** Identifies the milestone title associated with the 'demilestoned' event. */
    milestoneTitle: Scalars['String']['output'];
    /** Object referenced by event. */
    subject: MilestoneItem;
};
/** A repository deploy key. */
export type DeployKey = Node & {
    __typename?: 'DeployKey';
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** The deploy key. */
    key: Scalars['String']['output'];
    /** Whether or not the deploy key is read only. */
    readOnly: Scalars['Boolean']['output'];
    /** The deploy key title. */
    title: Scalars['String']['output'];
    /** Whether or not the deploy key has been verified. */
    verified: Scalars['Boolean']['output'];
};
/** The connection type for DeployKey. */
export type DeployKeyConnection = {
    __typename?: 'DeployKeyConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<DeployKeyEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<DeployKey>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type DeployKeyEdge = {
    __typename?: 'DeployKeyEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<DeployKey>;
};
/** Represents a 'deployed' event on a given pull request. */
export type DeployedEvent = Node & {
    __typename?: 'DeployedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The deployment associated with the 'deployed' event. */
    deployment: Deployment;
    id: Scalars['ID']['output'];
    /** PullRequest referenced by event. */
    pullRequest: PullRequest;
    /** The ref associated with the 'deployed' event. */
    ref?: Maybe<Ref>;
};
/** Represents triggered deployment instance. */
export type Deployment = Node & {
    __typename?: 'Deployment';
    /** Identifies the commit sha of the deployment. */
    commit?: Maybe<Commit>;
    /** Identifies the oid of the deployment commit, even if the commit has been deleted. */
    commitOid: Scalars['String']['output'];
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the actor who triggered the deployment. */
    creator: Actor;
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The deployment description. */
    description?: Maybe<Scalars['String']['output']>;
    /** The latest environment to which this deployment was made. */
    environment?: Maybe<Scalars['String']['output']>;
    id: Scalars['ID']['output'];
    /** The latest environment to which this deployment was made. */
    latestEnvironment?: Maybe<Scalars['String']['output']>;
    /** The latest status of this deployment. */
    latestStatus?: Maybe<DeploymentStatus>;
    /** The original environment to which this deployment was made. */
    originalEnvironment?: Maybe<Scalars['String']['output']>;
    /** Extra information that a deployment system might need. */
    payload?: Maybe<Scalars['String']['output']>;
    /** Identifies the Ref of the deployment, if the deployment was created by ref. */
    ref?: Maybe<Ref>;
    /** Identifies the repository associated with the deployment. */
    repository: Repository;
    /** The current state of the deployment. */
    state?: Maybe<DeploymentState>;
    /** A list of statuses associated with the deployment. */
    statuses?: Maybe<DeploymentStatusConnection>;
    /** The deployment task. */
    task?: Maybe<Scalars['String']['output']>;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
};
/** Represents triggered deployment instance. */
export type DeploymentStatusesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** The connection type for Deployment. */
export type DeploymentConnection = {
    __typename?: 'DeploymentConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<DeploymentEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Deployment>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type DeploymentEdge = {
    __typename?: 'DeploymentEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Deployment>;
};
/** Represents a 'deployment_environment_changed' event on a given pull request. */
export type DeploymentEnvironmentChangedEvent = Node & {
    __typename?: 'DeploymentEnvironmentChangedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The deployment status that updated the deployment environment. */
    deploymentStatus: DeploymentStatus;
    id: Scalars['ID']['output'];
    /** PullRequest referenced by event. */
    pullRequest: PullRequest;
};
/** Ordering options for deployment connections */
export type DeploymentOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order deployments by. */
    field: DeploymentOrderField;
};
/** Properties by which deployment connections can be ordered. */
export declare enum DeploymentOrderField {
    /** Order collection by creation time */
    CreatedAt = "CREATED_AT"
}
/** A protection rule. */
export type DeploymentProtectionRule = Node & {
    __typename?: 'DeploymentProtectionRule';
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** The teams or users that can review the deployment */
    reviewers: DeploymentReviewerConnection;
    /** The timeout in minutes for this protection rule. */
    timeout: Scalars['Int']['output'];
    /** The type of protection rule. */
    type: DeploymentProtectionRuleType;
};
/** A protection rule. */
export type DeploymentProtectionRuleReviewersArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** The connection type for DeploymentProtectionRule. */
export type DeploymentProtectionRuleConnection = {
    __typename?: 'DeploymentProtectionRuleConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<DeploymentProtectionRuleEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<DeploymentProtectionRule>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type DeploymentProtectionRuleEdge = {
    __typename?: 'DeploymentProtectionRuleEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<DeploymentProtectionRule>;
};
/** The possible protection rule types. */
export declare enum DeploymentProtectionRuleType {
    /** Required reviewers */
    RequiredReviewers = "REQUIRED_REVIEWERS",
    /** Wait timer */
    WaitTimer = "WAIT_TIMER"
}
/** A request to deploy a workflow run to an environment. */
export type DeploymentRequest = {
    __typename?: 'DeploymentRequest';
    /** Whether or not the current user can approve the deployment */
    currentUserCanApprove: Scalars['Boolean']['output'];
    /** The target environment of the deployment */
    environment: Environment;
    /** The teams or users that can review the deployment */
    reviewers: DeploymentReviewerConnection;
    /** The wait timer in minutes configured in the environment */
    waitTimer: Scalars['Int']['output'];
    /** The wait timer in minutes configured in the environment */
    waitTimerStartedAt?: Maybe<Scalars['DateTime']['output']>;
};
/** A request to deploy a workflow run to an environment. */
export type DeploymentRequestReviewersArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** The connection type for DeploymentRequest. */
export type DeploymentRequestConnection = {
    __typename?: 'DeploymentRequestConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<DeploymentRequestEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<DeploymentRequest>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type DeploymentRequestEdge = {
    __typename?: 'DeploymentRequestEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<DeploymentRequest>;
};
/** A deployment review. */
export type DeploymentReview = Node & {
    __typename?: 'DeploymentReview';
    /** The comment the user left. */
    comment: Scalars['String']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The environments approved or rejected */
    environments: EnvironmentConnection;
    id: Scalars['ID']['output'];
    /** The decision of the user. */
    state: DeploymentReviewState;
    /** The user that reviewed the deployment. */
    user: User;
};
/** A deployment review. */
export type DeploymentReviewEnvironmentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** The connection type for DeploymentReview. */
export type DeploymentReviewConnection = {
    __typename?: 'DeploymentReviewConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<DeploymentReviewEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<DeploymentReview>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type DeploymentReviewEdge = {
    __typename?: 'DeploymentReviewEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<DeploymentReview>;
};
/** The possible states for a deployment review. */
export declare enum DeploymentReviewState {
    /** The deployment was approved. */
    Approved = "APPROVED",
    /** The deployment was rejected. */
    Rejected = "REJECTED"
}
/** Users and teams. */
export type DeploymentReviewer = Team | User;
/** The connection type for DeploymentReviewer. */
export type DeploymentReviewerConnection = {
    __typename?: 'DeploymentReviewerConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<DeploymentReviewerEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<DeploymentReviewer>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type DeploymentReviewerEdge = {
    __typename?: 'DeploymentReviewerEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<DeploymentReviewer>;
};
/** The possible states in which a deployment can be. */
export declare enum DeploymentState {
    /** The pending deployment was not updated after 30 minutes. */
    Abandoned = "ABANDONED",
    /** The deployment is currently active. */
    Active = "ACTIVE",
    /** An inactive transient deployment. */
    Destroyed = "DESTROYED",
    /** The deployment experienced an error. */
    Error = "ERROR",
    /** The deployment has failed. */
    Failure = "FAILURE",
    /** The deployment is inactive. */
    Inactive = "INACTIVE",
    /** The deployment is in progress. */
    InProgress = "IN_PROGRESS",
    /** The deployment is pending. */
    Pending = "PENDING",
    /** The deployment has queued */
    Queued = "QUEUED",
    /** The deployment is waiting. */
    Waiting = "WAITING"
}
/** Describes the status of a given deployment attempt. */
export type DeploymentStatus = Node & {
    __typename?: 'DeploymentStatus';
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the actor who triggered the deployment. */
    creator: Actor;
    /** Identifies the deployment associated with status. */
    deployment: Deployment;
    /** Identifies the description of the deployment. */
    description?: Maybe<Scalars['String']['output']>;
    /** Identifies the environment of the deployment at the time of this deployment status */
    environment?: Maybe<Scalars['String']['output']>;
    /** Identifies the environment URL of the deployment. */
    environmentUrl?: Maybe<Scalars['URI']['output']>;
    id: Scalars['ID']['output'];
    /** Identifies the log URL of the deployment. */
    logUrl?: Maybe<Scalars['URI']['output']>;
    /** Identifies the current state of the deployment. */
    state: DeploymentStatusState;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
};
/** The connection type for DeploymentStatus. */
export type DeploymentStatusConnection = {
    __typename?: 'DeploymentStatusConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<DeploymentStatusEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<DeploymentStatus>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type DeploymentStatusEdge = {
    __typename?: 'DeploymentStatusEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<DeploymentStatus>;
};
/** The possible states for a deployment status. */
export declare enum DeploymentStatusState {
    /** The deployment experienced an error. */
    Error = "ERROR",
    /** The deployment has failed. */
    Failure = "FAILURE",
    /** The deployment is inactive. */
    Inactive = "INACTIVE",
    /** The deployment is in progress. */
    InProgress = "IN_PROGRESS",
    /** The deployment is pending. */
    Pending = "PENDING",
    /** The deployment is queued */
    Queued = "QUEUED",
    /** The deployment was successful. */
    Success = "SUCCESS",
    /** The deployment is waiting. */
    Waiting = "WAITING"
}
/** The possible sides of a diff. */
export declare enum DiffSide {
    /** The left side of the diff. */
    Left = "LEFT",
    /** The right side of the diff. */
    Right = "RIGHT"
}
/** Autogenerated input type of DisablePullRequestAutoMerge */
export type DisablePullRequestAutoMergeInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** ID of the pull request to disable auto merge on. */
    pullRequestId: Scalars['ID']['input'];
};
/** Autogenerated return type of DisablePullRequestAutoMerge */
export type DisablePullRequestAutoMergePayload = {
    __typename?: 'DisablePullRequestAutoMergePayload';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The pull request auto merge was disabled on. */
    pullRequest?: Maybe<PullRequest>;
};
/** Represents a 'disconnected' event on a given issue or pull request. */
export type DisconnectedEvent = Node & {
    __typename?: 'DisconnectedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** Reference originated in a different repository. */
    isCrossRepository: Scalars['Boolean']['output'];
    /** Issue or pull request from which the issue was disconnected. */
    source: ReferencedSubject;
    /** Issue or pull request which was disconnected. */
    subject: ReferencedSubject;
};
/** A discussion in a repository. */
export type Discussion = Comment & Deletable & Labelable & Lockable & Node & Reactable & RepositoryNode & Subscribable & Updatable & Votable & {
    __typename?: 'Discussion';
    /** Reason that the conversation was locked. */
    activeLockReason?: Maybe<LockReason>;
    /** The comment chosen as this discussion's answer, if any. */
    answer?: Maybe<DiscussionComment>;
    /** The time when a user chose this discussion's answer, if answered. */
    answerChosenAt?: Maybe<Scalars['DateTime']['output']>;
    /** The user who chose this discussion's answer, if answered. */
    answerChosenBy?: Maybe<Actor>;
    /** The actor who authored the comment. */
    author?: Maybe<Actor>;
    /** Author's association with the subject of the comment. */
    authorAssociation: CommentAuthorAssociation;
    /** The main text of the discussion post. */
    body: Scalars['String']['output'];
    /** The body rendered to HTML. */
    bodyHTML: Scalars['HTML']['output'];
    /** The body rendered to text. */
    bodyText: Scalars['String']['output'];
    /** The category for this discussion. */
    category: DiscussionCategory;
    /** The replies to the discussion. */
    comments: DiscussionCommentConnection;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Check if this comment was created via an email reply. */
    createdViaEmail: Scalars['Boolean']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The actor who edited the comment. */
    editor?: Maybe<Actor>;
    id: Scalars['ID']['output'];
    /** Check if this comment was edited and includes an edit with the creation data */
    includesCreatedEdit: Scalars['Boolean']['output'];
    /** A list of labels associated with the object. */
    labels?: Maybe<LabelConnection>;
    /** The moment the editor made the last edit */
    lastEditedAt?: Maybe<Scalars['DateTime']['output']>;
    /** `true` if the object is locked */
    locked: Scalars['Boolean']['output'];
    /** The number identifying this discussion within the repository. */
    number: Scalars['Int']['output'];
    /** Identifies when the comment was published at. */
    publishedAt?: Maybe<Scalars['DateTime']['output']>;
    /** A list of reactions grouped by content left on the subject. */
    reactionGroups?: Maybe<Array<ReactionGroup>>;
    /** A list of Reactions left on the Issue. */
    reactions: ReactionConnection;
    /** The repository associated with this node. */
    repository: Repository;
    /** The path for this discussion. */
    resourcePath: Scalars['URI']['output'];
    /** The title of this discussion. */
    title: Scalars['String']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** Number of upvotes that this subject has received. */
    upvoteCount: Scalars['Int']['output'];
    /** The URL for this discussion. */
    url: Scalars['URI']['output'];
    /** A list of edits to this content. */
    userContentEdits?: Maybe<UserContentEditConnection>;
    /** Check if the current viewer can delete this object. */
    viewerCanDelete: Scalars['Boolean']['output'];
    /** Can user react to this subject */
    viewerCanReact: Scalars['Boolean']['output'];
    /** Check if the viewer is able to change their subscription status for the repository. */
    viewerCanSubscribe: Scalars['Boolean']['output'];
    /** Check if the current viewer can update this object. */
    viewerCanUpdate: Scalars['Boolean']['output'];
    /** Whether or not the current user can add or remove an upvote on this subject. */
    viewerCanUpvote: Scalars['Boolean']['output'];
    /** Did the viewer author this comment. */
    viewerDidAuthor: Scalars['Boolean']['output'];
    /** Whether or not the current user has already upvoted this subject. */
    viewerHasUpvoted: Scalars['Boolean']['output'];
    /** Identifies if the viewer is watching, not watching, or ignoring the subscribable entity. */
    viewerSubscription?: Maybe<SubscriptionState>;
};
/** A discussion in a repository. */
export type DiscussionCommentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A discussion in a repository. */
export type DiscussionLabelsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<LabelOrder>;
};
/** A discussion in a repository. */
export type DiscussionReactionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    content?: InputMaybe<ReactionContent>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ReactionOrder>;
};
/** A discussion in a repository. */
export type DiscussionUserContentEditsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A category for discussions in a repository. */
export type DiscussionCategory = Node & RepositoryNode & {
    __typename?: 'DiscussionCategory';
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** A description of this category. */
    description?: Maybe<Scalars['String']['output']>;
    /** An emoji representing this category. */
    emoji: Scalars['String']['output'];
    /** This category's emoji rendered as HTML. */
    emojiHTML: Scalars['HTML']['output'];
    id: Scalars['ID']['output'];
    /** Whether or not discussions in this category support choosing an answer with the markDiscussionCommentAsAnswer mutation. */
    isAnswerable: Scalars['Boolean']['output'];
    /** The name of this category. */
    name: Scalars['String']['output'];
    /** The repository associated with this node. */
    repository: Repository;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
};
/** The connection type for DiscussionCategory. */
export type DiscussionCategoryConnection = {
    __typename?: 'DiscussionCategoryConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<DiscussionCategoryEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<DiscussionCategory>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type DiscussionCategoryEdge = {
    __typename?: 'DiscussionCategoryEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<DiscussionCategory>;
};
/** A comment on a discussion. */
export type DiscussionComment = Comment & Deletable & Minimizable & Node & Reactable & Updatable & UpdatableComment & Votable & {
    __typename?: 'DiscussionComment';
    /** The actor who authored the comment. */
    author?: Maybe<Actor>;
    /** Author's association with the subject of the comment. */
    authorAssociation: CommentAuthorAssociation;
    /** The body as Markdown. */
    body: Scalars['String']['output'];
    /** The body rendered to HTML. */
    bodyHTML: Scalars['HTML']['output'];
    /** The body rendered to text. */
    bodyText: Scalars['String']['output'];
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Check if this comment was created via an email reply. */
    createdViaEmail: Scalars['Boolean']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The time when this replied-to comment was deleted */
    deletedAt?: Maybe<Scalars['DateTime']['output']>;
    /** The discussion this comment was created in */
    discussion?: Maybe<Discussion>;
    /** The actor who edited the comment. */
    editor?: Maybe<Actor>;
    id: Scalars['ID']['output'];
    /** Check if this comment was edited and includes an edit with the creation data */
    includesCreatedEdit: Scalars['Boolean']['output'];
    /** Has this comment been chosen as the answer of its discussion? */
    isAnswer: Scalars['Boolean']['output'];
    /** Returns whether or not a comment has been minimized. */
    isMinimized: Scalars['Boolean']['output'];
    /** The moment the editor made the last edit */
    lastEditedAt?: Maybe<Scalars['DateTime']['output']>;
    /** Returns why the comment was minimized. */
    minimizedReason?: Maybe<Scalars['String']['output']>;
    /** Identifies when the comment was published at. */
    publishedAt?: Maybe<Scalars['DateTime']['output']>;
    /** A list of reactions grouped by content left on the subject. */
    reactionGroups?: Maybe<Array<ReactionGroup>>;
    /** A list of Reactions left on the Issue. */
    reactions: ReactionConnection;
    /** The threaded replies to this comment. */
    replies: DiscussionCommentConnection;
    /** The discussion comment this comment is a reply to */
    replyTo?: Maybe<DiscussionComment>;
    /** The path for this discussion comment. */
    resourcePath: Scalars['URI']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** Number of upvotes that this subject has received. */
    upvoteCount: Scalars['Int']['output'];
    /** The URL for this discussion comment. */
    url: Scalars['URI']['output'];
    /** A list of edits to this content. */
    userContentEdits?: Maybe<UserContentEditConnection>;
    /** Check if the current viewer can delete this object. */
    viewerCanDelete: Scalars['Boolean']['output'];
    /** Can the current user mark this comment as an answer? */
    viewerCanMarkAsAnswer: Scalars['Boolean']['output'];
    /** Check if the current viewer can minimize this object. */
    viewerCanMinimize: Scalars['Boolean']['output'];
    /** Can user react to this subject */
    viewerCanReact: Scalars['Boolean']['output'];
    /** Can the current user unmark this comment as an answer? */
    viewerCanUnmarkAsAnswer: Scalars['Boolean']['output'];
    /** Check if the current viewer can update this object. */
    viewerCanUpdate: Scalars['Boolean']['output'];
    /** Whether or not the current user can add or remove an upvote on this subject. */
    viewerCanUpvote: Scalars['Boolean']['output'];
    /** Reasons why the current viewer can not update this comment. */
    viewerCannotUpdateReasons: Array<CommentCannotUpdateReason>;
    /** Did the viewer author this comment. */
    viewerDidAuthor: Scalars['Boolean']['output'];
    /** Whether or not the current user has already upvoted this subject. */
    viewerHasUpvoted: Scalars['Boolean']['output'];
};
/** A comment on a discussion. */
export type DiscussionCommentReactionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    content?: InputMaybe<ReactionContent>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ReactionOrder>;
};
/** A comment on a discussion. */
export type DiscussionCommentRepliesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A comment on a discussion. */
export type DiscussionCommentUserContentEditsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** The connection type for DiscussionComment. */
export type DiscussionCommentConnection = {
    __typename?: 'DiscussionCommentConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<DiscussionCommentEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<DiscussionComment>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type DiscussionCommentEdge = {
    __typename?: 'DiscussionCommentEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<DiscussionComment>;
};
/** The connection type for Discussion. */
export type DiscussionConnection = {
    __typename?: 'DiscussionConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<DiscussionEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Discussion>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type DiscussionEdge = {
    __typename?: 'DiscussionEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Discussion>;
};
/** Ways in which lists of discussions can be ordered upon return. */
export type DiscussionOrder = {
    /** The direction in which to order discussions by the specified field. */
    direction: OrderDirection;
    /** The field by which to order discussions. */
    field: DiscussionOrderField;
};
/** Properties by which discussion connections can be ordered. */
export declare enum DiscussionOrderField {
    /** Order discussions by creation time. */
    CreatedAt = "CREATED_AT",
    /** Order discussions by most recent modification time. */
    UpdatedAt = "UPDATED_AT"
}
/** Autogenerated input type of DismissPullRequestReview */
export type DismissPullRequestReviewInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The contents of the pull request review dismissal message. */
    message: Scalars['String']['input'];
    /** The Node ID of the pull request review to modify. */
    pullRequestReviewId: Scalars['ID']['input'];
};
/** Autogenerated return type of DismissPullRequestReview */
export type DismissPullRequestReviewPayload = {
    __typename?: 'DismissPullRequestReviewPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The dismissed pull request review. */
    pullRequestReview?: Maybe<PullRequestReview>;
};
/** Specifies a review comment to be left with a Pull Request Review. */
export type DraftPullRequestReviewComment = {
    /** Body of the comment to leave. */
    body: Scalars['String']['input'];
    /** Path to the file being commented on. */
    path: Scalars['String']['input'];
    /** Position in the file to leave a comment on. */
    position: Scalars['Int']['input'];
};
/** Specifies a review comment thread to be left with a Pull Request Review. */
export type DraftPullRequestReviewThread = {
    /** Body of the comment to leave. */
    body: Scalars['String']['input'];
    /** The line of the blob to which the thread refers. The end of the line range for multi-line comments. */
    line: Scalars['Int']['input'];
    /** Path to the file being commented on. */
    path: Scalars['String']['input'];
    /** The side of the diff on which the line resides. For multi-line comments, this is the side for the end of the line range. */
    side?: InputMaybe<DiffSide>;
    /** The first line of the range to which the comment refers. */
    startLine?: InputMaybe<Scalars['Int']['input']>;
    /** The side of the diff on which the start line resides. */
    startSide?: InputMaybe<DiffSide>;
};
/** Autogenerated input type of EnablePullRequestAutoMerge */
export type EnablePullRequestAutoMergeInput = {
    /** The email address to associate with this merge. */
    authorEmail?: InputMaybe<Scalars['String']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** Commit body to use for the commit when the PR is mergable; if omitted, a default message will be used. */
    commitBody?: InputMaybe<Scalars['String']['input']>;
    /** Commit headline to use for the commit when the PR is mergable; if omitted, a default message will be used. */
    commitHeadline?: InputMaybe<Scalars['String']['input']>;
    /** The merge method to use. If omitted, defaults to 'MERGE' */
    mergeMethod?: InputMaybe<PullRequestMergeMethod>;
    /** ID of the pull request to enable auto-merge on. */
    pullRequestId: Scalars['ID']['input'];
};
/** Autogenerated return type of EnablePullRequestAutoMerge */
export type EnablePullRequestAutoMergePayload = {
    __typename?: 'EnablePullRequestAutoMergePayload';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The pull request auto-merge was enabled on. */
    pullRequest?: Maybe<PullRequest>;
};
/** An account to manage multiple organizations with consolidated policy and billing. */
export type Enterprise = Node & {
    __typename?: 'Enterprise';
    /** A URL pointing to the enterprise's public avatar. */
    avatarUrl: Scalars['URI']['output'];
    /** Enterprise billing information visible to enterprise billing managers. */
    billingInfo?: Maybe<EnterpriseBillingInfo>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The description of the enterprise. */
    description?: Maybe<Scalars['String']['output']>;
    /** The description of the enterprise as HTML. */
    descriptionHTML: Scalars['HTML']['output'];
    id: Scalars['ID']['output'];
    /** The location of the enterprise. */
    location?: Maybe<Scalars['String']['output']>;
    /** A list of users who are members of this enterprise. */
    members: EnterpriseMemberConnection;
    /** The name of the enterprise. */
    name: Scalars['String']['output'];
    /** A list of organizations that belong to this enterprise. */
    organizations: OrganizationConnection;
    /** Enterprise information only visible to enterprise owners. */
    ownerInfo?: Maybe<EnterpriseOwnerInfo>;
    /** The HTTP path for this enterprise. */
    resourcePath: Scalars['URI']['output'];
    /** The URL-friendly identifier for the enterprise. */
    slug: Scalars['String']['output'];
    /** The HTTP URL for this enterprise. */
    url: Scalars['URI']['output'];
    /** A list of user accounts on this enterprise. */
    userAccounts: EnterpriseUserAccountConnection;
    /** Is the current viewer an admin of this enterprise? */
    viewerIsAdmin: Scalars['Boolean']['output'];
    /** The URL of the enterprise website. */
    websiteUrl?: Maybe<Scalars['URI']['output']>;
};
/** An account to manage multiple organizations with consolidated policy and billing. */
export type EnterpriseAvatarUrlArgs = {
    size?: InputMaybe<Scalars['Int']['input']>;
};
/** An account to manage multiple organizations with consolidated policy and billing. */
export type EnterpriseMembersArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    deployment?: InputMaybe<EnterpriseUserDeployment>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<EnterpriseMemberOrder>;
    organizationLogins?: InputMaybe<Array<Scalars['String']['input']>>;
    query?: InputMaybe<Scalars['String']['input']>;
    role?: InputMaybe<EnterpriseUserAccountMembershipRole>;
};
/** An account to manage multiple organizations with consolidated policy and billing. */
export type EnterpriseOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<OrganizationOrder>;
    query?: InputMaybe<Scalars['String']['input']>;
};
/** An account to manage multiple organizations with consolidated policy and billing. */
export type EnterpriseUserAccountsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** The connection type for User. */
export type EnterpriseAdministratorConnection = {
    __typename?: 'EnterpriseAdministratorConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<EnterpriseAdministratorEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<User>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** A User who is an administrator of an enterprise. */
export type EnterpriseAdministratorEdge = {
    __typename?: 'EnterpriseAdministratorEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<User>;
    /** The role of the administrator. */
    role: EnterpriseAdministratorRole;
};
/** An invitation for a user to become an owner or billing manager of an enterprise. */
export type EnterpriseAdministratorInvitation = Node & {
    __typename?: 'EnterpriseAdministratorInvitation';
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The email of the person who was invited to the enterprise. */
    email?: Maybe<Scalars['String']['output']>;
    /** The enterprise the invitation is for. */
    enterprise: Enterprise;
    id: Scalars['ID']['output'];
    /** The user who was invited to the enterprise. */
    invitee?: Maybe<User>;
    /** The user who created the invitation. */
    inviter?: Maybe<User>;
    /** The invitee's pending role in the enterprise (owner or billing_manager). */
    role: EnterpriseAdministratorRole;
};
/** The connection type for EnterpriseAdministratorInvitation. */
export type EnterpriseAdministratorInvitationConnection = {
    __typename?: 'EnterpriseAdministratorInvitationConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<EnterpriseAdministratorInvitationEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<EnterpriseAdministratorInvitation>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type EnterpriseAdministratorInvitationEdge = {
    __typename?: 'EnterpriseAdministratorInvitationEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<EnterpriseAdministratorInvitation>;
};
/** Ordering options for enterprise administrator invitation connections */
export type EnterpriseAdministratorInvitationOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order enterprise administrator invitations by. */
    field: EnterpriseAdministratorInvitationOrderField;
};
/** Properties by which enterprise administrator invitation connections can be ordered. */
export declare enum EnterpriseAdministratorInvitationOrderField {
    /** Order enterprise administrator member invitations by creation time */
    CreatedAt = "CREATED_AT"
}
/** The possible administrator roles in an enterprise account. */
export declare enum EnterpriseAdministratorRole {
    /** Represents a billing manager of the enterprise account. */
    BillingManager = "BILLING_MANAGER",
    /** Represents an owner of the enterprise account. */
    Owner = "OWNER"
}
/** Metadata for an audit entry containing enterprise account information. */
export type EnterpriseAuditEntryData = {
    /** The HTTP path for this enterprise. */
    enterpriseResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The slug of the enterprise. */
    enterpriseSlug?: Maybe<Scalars['String']['output']>;
    /** The HTTP URL for this enterprise. */
    enterpriseUrl?: Maybe<Scalars['URI']['output']>;
};
/** Enterprise billing information visible to enterprise billing managers and owners. */
export type EnterpriseBillingInfo = {
    __typename?: 'EnterpriseBillingInfo';
    /** The number of licenseable users/emails across the enterprise. */
    allLicensableUsersCount: Scalars['Int']['output'];
    /** The number of data packs used by all organizations owned by the enterprise. */
    assetPacks: Scalars['Int']['output'];
    /**
     * The number of available seats across all owned organizations based on the unique number of billable users.
     * @deprecated `availableSeats` will be replaced with `totalAvailableLicenses` to provide more clarity on the value being returned Use EnterpriseBillingInfo.totalAvailableLicenses instead. Removal on 2020-01-01 UTC.
     */
    availableSeats: Scalars['Int']['output'];
    /** The bandwidth quota in GB for all organizations owned by the enterprise. */
    bandwidthQuota: Scalars['Float']['output'];
    /** The bandwidth usage in GB for all organizations owned by the enterprise. */
    bandwidthUsage: Scalars['Float']['output'];
    /** The bandwidth usage as a percentage of the bandwidth quota. */
    bandwidthUsagePercentage: Scalars['Int']['output'];
    /**
     * The total seats across all organizations owned by the enterprise.
     * @deprecated `seats` will be replaced with `totalLicenses` to provide more clarity on the value being returned Use EnterpriseBillingInfo.totalLicenses instead. Removal on 2020-01-01 UTC.
     */
    seats: Scalars['Int']['output'];
    /** The storage quota in GB for all organizations owned by the enterprise. */
    storageQuota: Scalars['Float']['output'];
    /** The storage usage in GB for all organizations owned by the enterprise. */
    storageUsage: Scalars['Float']['output'];
    /** The storage usage as a percentage of the storage quota. */
    storageUsagePercentage: Scalars['Int']['output'];
    /** The number of available licenses across all owned organizations based on the unique number of billable users. */
    totalAvailableLicenses: Scalars['Int']['output'];
    /** The total number of licenses allocated. */
    totalLicenses: Scalars['Int']['output'];
};
/** The possible values for the enterprise default repository permission setting. */
export declare enum EnterpriseDefaultRepositoryPermissionSettingValue {
    /** Organization members will be able to clone, pull, push, and add new collaborators to all organization repositories. */
    Admin = "ADMIN",
    /** Organization members will only be able to clone and pull public repositories. */
    None = "NONE",
    /** Organizations in the enterprise choose default repository permissions for their members. */
    NoPolicy = "NO_POLICY",
    /** Organization members will be able to clone and pull all organization repositories. */
    Read = "READ",
    /** Organization members will be able to clone, pull, and push all organization repositories. */
    Write = "WRITE"
}
/** The possible values for an enabled/disabled enterprise setting. */
export declare enum EnterpriseEnabledDisabledSettingValue {
    /** The setting is disabled for organizations in the enterprise. */
    Disabled = "DISABLED",
    /** The setting is enabled for organizations in the enterprise. */
    Enabled = "ENABLED",
    /** There is no policy set for organizations in the enterprise. */
    NoPolicy = "NO_POLICY"
}
/** The possible values for an enabled/no policy enterprise setting. */
export declare enum EnterpriseEnabledSettingValue {
    /** The setting is enabled for organizations in the enterprise. */
    Enabled = "ENABLED",
    /** There is no policy set for organizations in the enterprise. */
    NoPolicy = "NO_POLICY"
}
/** An identity provider configured to provision identities for an enterprise. */
export type EnterpriseIdentityProvider = Node & {
    __typename?: 'EnterpriseIdentityProvider';
    /** The digest algorithm used to sign SAML requests for the identity provider. */
    digestMethod?: Maybe<SamlDigestAlgorithm>;
    /** The enterprise this identity provider belongs to. */
    enterprise?: Maybe<Enterprise>;
    /** ExternalIdentities provisioned by this identity provider. */
    externalIdentities: ExternalIdentityConnection;
    id: Scalars['ID']['output'];
    /** The x509 certificate used by the identity provider to sign assertions and responses. */
    idpCertificate?: Maybe<Scalars['X509Certificate']['output']>;
    /** The Issuer Entity ID for the SAML identity provider. */
    issuer?: Maybe<Scalars['String']['output']>;
    /** Recovery codes that can be used by admins to access the enterprise if the identity provider is unavailable. */
    recoveryCodes?: Maybe<Array<Scalars['String']['output']>>;
    /** The signature algorithm used to sign SAML requests for the identity provider. */
    signatureMethod?: Maybe<SamlSignatureAlgorithm>;
    /** The URL endpoint for the identity provider's SAML SSO. */
    ssoUrl?: Maybe<Scalars['URI']['output']>;
};
/** An identity provider configured to provision identities for an enterprise. */
export type EnterpriseIdentityProviderExternalIdentitiesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    membersOnly?: InputMaybe<Scalars['Boolean']['input']>;
};
/** An object that is a member of an enterprise. */
export type EnterpriseMember = EnterpriseUserAccount | User;
/** The connection type for EnterpriseMember. */
export type EnterpriseMemberConnection = {
    __typename?: 'EnterpriseMemberConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<EnterpriseMemberEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<EnterpriseMember>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** A User who is a member of an enterprise through one or more organizations. */
export type EnterpriseMemberEdge = {
    __typename?: 'EnterpriseMemberEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /**
     * Whether the user does not have a license for the enterprise.
     * @deprecated All members consume a license Removal on 2021-01-01 UTC.
     */
    isUnlicensed: Scalars['Boolean']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<EnterpriseMember>;
};
/** Ordering options for enterprise member connections. */
export type EnterpriseMemberOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order enterprise members by. */
    field: EnterpriseMemberOrderField;
};
/** Properties by which enterprise member connections can be ordered. */
export declare enum EnterpriseMemberOrderField {
    /** Order enterprise members by creation time */
    CreatedAt = "CREATED_AT",
    /** Order enterprise members by login */
    Login = "LOGIN"
}
/** The possible values for the enterprise members can create repositories setting. */
export declare enum EnterpriseMembersCanCreateRepositoriesSettingValue {
    /** Members will be able to create public and private repositories. */
    All = "ALL",
    /** Members will not be able to create public or private repositories. */
    Disabled = "DISABLED",
    /** Organization administrators choose whether to allow members to create repositories. */
    NoPolicy = "NO_POLICY",
    /** Members will be able to create only private repositories. */
    Private = "PRIVATE",
    /** Members will be able to create only public repositories. */
    Public = "PUBLIC"
}
/** The possible values for the members can make purchases setting. */
export declare enum EnterpriseMembersCanMakePurchasesSettingValue {
    /** The setting is disabled for organizations in the enterprise. */
    Disabled = "DISABLED",
    /** The setting is enabled for organizations in the enterprise. */
    Enabled = "ENABLED"
}
/** The connection type for Organization. */
export type EnterpriseOrganizationMembershipConnection = {
    __typename?: 'EnterpriseOrganizationMembershipConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<EnterpriseOrganizationMembershipEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Organization>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An enterprise organization that a user is a member of. */
export type EnterpriseOrganizationMembershipEdge = {
    __typename?: 'EnterpriseOrganizationMembershipEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Organization>;
    /** The role of the user in the enterprise membership. */
    role: EnterpriseUserAccountMembershipRole;
};
/** The connection type for User. */
export type EnterpriseOutsideCollaboratorConnection = {
    __typename?: 'EnterpriseOutsideCollaboratorConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<EnterpriseOutsideCollaboratorEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<User>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** A User who is an outside collaborator of an enterprise through one or more organizations. */
export type EnterpriseOutsideCollaboratorEdge = {
    __typename?: 'EnterpriseOutsideCollaboratorEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /**
     * Whether the outside collaborator does not have a license for the enterprise.
     * @deprecated All outside collaborators consume a license Removal on 2021-01-01 UTC.
     */
    isUnlicensed: Scalars['Boolean']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<User>;
    /** The enterprise organization repositories this user is a member of. */
    repositories: EnterpriseRepositoryInfoConnection;
};
/** A User who is an outside collaborator of an enterprise through one or more organizations. */
export type EnterpriseOutsideCollaboratorEdgeRepositoriesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<RepositoryOrder>;
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfo = {
    __typename?: 'EnterpriseOwnerInfo';
    /** A list of all of the administrators for this enterprise. */
    admins: EnterpriseAdministratorConnection;
    /** A list of users in the enterprise who currently have two-factor authentication disabled. */
    affiliatedUsersWithTwoFactorDisabled: UserConnection;
    /** Whether or not affiliated users with two-factor authentication disabled exist in the enterprise. */
    affiliatedUsersWithTwoFactorDisabledExist: Scalars['Boolean']['output'];
    /** The setting value for whether private repository forking is enabled for repositories in organizations in this enterprise. */
    allowPrivateRepositoryForkingSetting: EnterpriseEnabledDisabledSettingValue;
    /** A list of enterprise organizations configured with the provided private repository forking setting value. */
    allowPrivateRepositoryForkingSettingOrganizations: OrganizationConnection;
    /** The setting value for base repository permissions for organizations in this enterprise. */
    defaultRepositoryPermissionSetting: EnterpriseDefaultRepositoryPermissionSettingValue;
    /** A list of enterprise organizations configured with the provided default repository permission. */
    defaultRepositoryPermissionSettingOrganizations: OrganizationConnection;
    /** A list of domains owned by the enterprise. */
    domains: VerifiableDomainConnection;
    /** The setting value for whether the enterprise has an IP allow list enabled. */
    ipAllowListEnabledSetting: IpAllowListEnabledSettingValue;
    /** The IP addresses that are allowed to access resources owned by the enterprise. */
    ipAllowListEntries: IpAllowListEntryConnection;
    /** The setting value for whether the enterprise has IP allow list configuration for installed GitHub Apps enabled. */
    ipAllowListForInstalledAppsEnabledSetting: IpAllowListForInstalledAppsEnabledSettingValue;
    /** Whether or not the default repository permission is currently being updated. */
    isUpdatingDefaultRepositoryPermission: Scalars['Boolean']['output'];
    /** Whether the two-factor authentication requirement is currently being enforced. */
    isUpdatingTwoFactorRequirement: Scalars['Boolean']['output'];
    /**
     * The setting value for whether organization members with admin permissions on a
     * repository can change repository visibility.
     */
    membersCanChangeRepositoryVisibilitySetting: EnterpriseEnabledDisabledSettingValue;
    /** A list of enterprise organizations configured with the provided can change repository visibility setting value. */
    membersCanChangeRepositoryVisibilitySettingOrganizations: OrganizationConnection;
    /** The setting value for whether members of organizations in the enterprise can create internal repositories. */
    membersCanCreateInternalRepositoriesSetting?: Maybe<Scalars['Boolean']['output']>;
    /** The setting value for whether members of organizations in the enterprise can create private repositories. */
    membersCanCreatePrivateRepositoriesSetting?: Maybe<Scalars['Boolean']['output']>;
    /** The setting value for whether members of organizations in the enterprise can create public repositories. */
    membersCanCreatePublicRepositoriesSetting?: Maybe<Scalars['Boolean']['output']>;
    /** The setting value for whether members of organizations in the enterprise can create repositories. */
    membersCanCreateRepositoriesSetting?: Maybe<EnterpriseMembersCanCreateRepositoriesSettingValue>;
    /** A list of enterprise organizations configured with the provided repository creation setting value. */
    membersCanCreateRepositoriesSettingOrganizations: OrganizationConnection;
    /** The setting value for whether members with admin permissions for repositories can delete issues. */
    membersCanDeleteIssuesSetting: EnterpriseEnabledDisabledSettingValue;
    /** A list of enterprise organizations configured with the provided members can delete issues setting value. */
    membersCanDeleteIssuesSettingOrganizations: OrganizationConnection;
    /** The setting value for whether members with admin permissions for repositories can delete or transfer repositories. */
    membersCanDeleteRepositoriesSetting: EnterpriseEnabledDisabledSettingValue;
    /** A list of enterprise organizations configured with the provided members can delete repositories setting value. */
    membersCanDeleteRepositoriesSettingOrganizations: OrganizationConnection;
    /** The setting value for whether members of organizations in the enterprise can invite outside collaborators. */
    membersCanInviteCollaboratorsSetting: EnterpriseEnabledDisabledSettingValue;
    /** A list of enterprise organizations configured with the provided members can invite collaborators setting value. */
    membersCanInviteCollaboratorsSettingOrganizations: OrganizationConnection;
    /** Indicates whether members of this enterprise's organizations can purchase additional services for those organizations. */
    membersCanMakePurchasesSetting: EnterpriseMembersCanMakePurchasesSettingValue;
    /** The setting value for whether members with admin permissions for repositories can update protected branches. */
    membersCanUpdateProtectedBranchesSetting: EnterpriseEnabledDisabledSettingValue;
    /** A list of enterprise organizations configured with the provided members can update protected branches setting value. */
    membersCanUpdateProtectedBranchesSettingOrganizations: OrganizationConnection;
    /** The setting value for whether members can view dependency insights. */
    membersCanViewDependencyInsightsSetting: EnterpriseEnabledDisabledSettingValue;
    /** A list of enterprise organizations configured with the provided members can view dependency insights setting value. */
    membersCanViewDependencyInsightsSettingOrganizations: OrganizationConnection;
    /** Indicates if email notification delivery for this enterprise is restricted to verified or approved domains. */
    notificationDeliveryRestrictionEnabledSetting: NotificationRestrictionSettingValue;
    /** The setting value for whether organization projects are enabled for organizations in this enterprise. */
    organizationProjectsSetting: EnterpriseEnabledDisabledSettingValue;
    /** A list of enterprise organizations configured with the provided organization projects setting value. */
    organizationProjectsSettingOrganizations: OrganizationConnection;
    /** A list of outside collaborators across the repositories in the enterprise. */
    outsideCollaborators: EnterpriseOutsideCollaboratorConnection;
    /** A list of pending administrator invitations for the enterprise. */
    pendingAdminInvitations: EnterpriseAdministratorInvitationConnection;
    /** A list of pending collaborator invitations across the repositories in the enterprise. */
    pendingCollaboratorInvitations: RepositoryInvitationConnection;
    /**
     * A list of pending collaborators across the repositories in the enterprise.
     * @deprecated Repository invitations can now be associated with an email, not only an invitee. Use the `pendingCollaboratorInvitations` field instead. Removal on 2020-10-01 UTC.
     */
    pendingCollaborators: EnterprisePendingCollaboratorConnection;
    /** A list of pending member invitations for organizations in the enterprise. */
    pendingMemberInvitations: EnterprisePendingMemberInvitationConnection;
    /** The setting value for whether repository projects are enabled in this enterprise. */
    repositoryProjectsSetting: EnterpriseEnabledDisabledSettingValue;
    /** A list of enterprise organizations configured with the provided repository projects setting value. */
    repositoryProjectsSettingOrganizations: OrganizationConnection;
    /** The SAML Identity Provider for the enterprise. */
    samlIdentityProvider?: Maybe<EnterpriseIdentityProvider>;
    /** A list of enterprise organizations configured with the SAML single sign-on setting value. */
    samlIdentityProviderSettingOrganizations: OrganizationConnection;
    /** The setting value for whether team discussions are enabled for organizations in this enterprise. */
    teamDiscussionsSetting: EnterpriseEnabledDisabledSettingValue;
    /** A list of enterprise organizations configured with the provided team discussions setting value. */
    teamDiscussionsSettingOrganizations: OrganizationConnection;
    /** The setting value for whether the enterprise requires two-factor authentication for its organizations and users. */
    twoFactorRequiredSetting: EnterpriseEnabledSettingValue;
    /** A list of enterprise organizations configured with the two-factor authentication setting value. */
    twoFactorRequiredSettingOrganizations: OrganizationConnection;
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoAdminsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<EnterpriseMemberOrder>;
    query?: InputMaybe<Scalars['String']['input']>;
    role?: InputMaybe<EnterpriseAdministratorRole>;
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoAffiliatedUsersWithTwoFactorDisabledArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoAllowPrivateRepositoryForkingSettingOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<OrganizationOrder>;
    value: Scalars['Boolean']['input'];
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoDefaultRepositoryPermissionSettingOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<OrganizationOrder>;
    value: DefaultRepositoryPermissionField;
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoDomainsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    isApproved?: InputMaybe<Scalars['Boolean']['input']>;
    isVerified?: InputMaybe<Scalars['Boolean']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<VerifiableDomainOrder>;
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoIpAllowListEntriesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<IpAllowListEntryOrder>;
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoMembersCanChangeRepositoryVisibilitySettingOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<OrganizationOrder>;
    value: Scalars['Boolean']['input'];
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoMembersCanCreateRepositoriesSettingOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<OrganizationOrder>;
    value: OrganizationMembersCanCreateRepositoriesSettingValue;
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoMembersCanDeleteIssuesSettingOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<OrganizationOrder>;
    value: Scalars['Boolean']['input'];
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoMembersCanDeleteRepositoriesSettingOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<OrganizationOrder>;
    value: Scalars['Boolean']['input'];
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoMembersCanInviteCollaboratorsSettingOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<OrganizationOrder>;
    value: Scalars['Boolean']['input'];
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoMembersCanUpdateProtectedBranchesSettingOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<OrganizationOrder>;
    value: Scalars['Boolean']['input'];
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoMembersCanViewDependencyInsightsSettingOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<OrganizationOrder>;
    value: Scalars['Boolean']['input'];
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoOrganizationProjectsSettingOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<OrganizationOrder>;
    value: Scalars['Boolean']['input'];
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoOutsideCollaboratorsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    login?: InputMaybe<Scalars['String']['input']>;
    orderBy?: InputMaybe<EnterpriseMemberOrder>;
    query?: InputMaybe<Scalars['String']['input']>;
    visibility?: InputMaybe<RepositoryVisibility>;
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoPendingAdminInvitationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<EnterpriseAdministratorInvitationOrder>;
    query?: InputMaybe<Scalars['String']['input']>;
    role?: InputMaybe<EnterpriseAdministratorRole>;
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoPendingCollaboratorInvitationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<RepositoryInvitationOrder>;
    query?: InputMaybe<Scalars['String']['input']>;
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoPendingCollaboratorsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<RepositoryInvitationOrder>;
    query?: InputMaybe<Scalars['String']['input']>;
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoPendingMemberInvitationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    query?: InputMaybe<Scalars['String']['input']>;
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoRepositoryProjectsSettingOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<OrganizationOrder>;
    value: Scalars['Boolean']['input'];
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoSamlIdentityProviderSettingOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<OrganizationOrder>;
    value: IdentityProviderConfigurationState;
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoTeamDiscussionsSettingOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<OrganizationOrder>;
    value: Scalars['Boolean']['input'];
};
/** Enterprise information only visible to enterprise owners. */
export type EnterpriseOwnerInfoTwoFactorRequiredSettingOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<OrganizationOrder>;
    value: Scalars['Boolean']['input'];
};
/** The connection type for User. */
export type EnterprisePendingCollaboratorConnection = {
    __typename?: 'EnterprisePendingCollaboratorConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<EnterprisePendingCollaboratorEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<User>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** A user with an invitation to be a collaborator on a repository owned by an organization in an enterprise. */
export type EnterprisePendingCollaboratorEdge = {
    __typename?: 'EnterprisePendingCollaboratorEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /**
     * Whether the invited collaborator does not have a license for the enterprise.
     * @deprecated All pending collaborators consume a license Removal on 2021-01-01 UTC.
     */
    isUnlicensed: Scalars['Boolean']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<User>;
    /** The enterprise organization repositories this user is a member of. */
    repositories: EnterpriseRepositoryInfoConnection;
};
/** A user with an invitation to be a collaborator on a repository owned by an organization in an enterprise. */
export type EnterprisePendingCollaboratorEdgeRepositoriesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<RepositoryOrder>;
};
/** The connection type for OrganizationInvitation. */
export type EnterprisePendingMemberInvitationConnection = {
    __typename?: 'EnterprisePendingMemberInvitationConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<EnterprisePendingMemberInvitationEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<OrganizationInvitation>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
    /** Identifies the total count of unique users in the connection. */
    totalUniqueUserCount: Scalars['Int']['output'];
};
/** An invitation to be a member in an enterprise organization. */
export type EnterprisePendingMemberInvitationEdge = {
    __typename?: 'EnterprisePendingMemberInvitationEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /**
     * Whether the invitation has a license for the enterprise.
     * @deprecated All pending members consume a license Removal on 2020-07-01 UTC.
     */
    isUnlicensed: Scalars['Boolean']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<OrganizationInvitation>;
};
/** A subset of repository information queryable from an enterprise. */
export type EnterpriseRepositoryInfo = Node & {
    __typename?: 'EnterpriseRepositoryInfo';
    id: Scalars['ID']['output'];
    /** Identifies if the repository is private or internal. */
    isPrivate: Scalars['Boolean']['output'];
    /** The repository's name. */
    name: Scalars['String']['output'];
    /** The repository's name with owner. */
    nameWithOwner: Scalars['String']['output'];
};
/** The connection type for EnterpriseRepositoryInfo. */
export type EnterpriseRepositoryInfoConnection = {
    __typename?: 'EnterpriseRepositoryInfoConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<EnterpriseRepositoryInfoEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<EnterpriseRepositoryInfo>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type EnterpriseRepositoryInfoEdge = {
    __typename?: 'EnterpriseRepositoryInfoEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<EnterpriseRepositoryInfo>;
};
/** An Enterprise Server installation. */
export type EnterpriseServerInstallation = Node & {
    __typename?: 'EnterpriseServerInstallation';
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The customer name to which the Enterprise Server installation belongs. */
    customerName: Scalars['String']['output'];
    /** The host name of the Enterprise Server installation. */
    hostName: Scalars['String']['output'];
    id: Scalars['ID']['output'];
    /** Whether or not the installation is connected to an Enterprise Server installation via GitHub Connect. */
    isConnected: Scalars['Boolean']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** User accounts on this Enterprise Server installation. */
    userAccounts: EnterpriseServerUserAccountConnection;
    /** User accounts uploads for the Enterprise Server installation. */
    userAccountsUploads: EnterpriseServerUserAccountsUploadConnection;
};
/** An Enterprise Server installation. */
export type EnterpriseServerInstallationUserAccountsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<EnterpriseServerUserAccountOrder>;
};
/** An Enterprise Server installation. */
export type EnterpriseServerInstallationUserAccountsUploadsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<EnterpriseServerUserAccountsUploadOrder>;
};
/** A user account on an Enterprise Server installation. */
export type EnterpriseServerUserAccount = Node & {
    __typename?: 'EnterpriseServerUserAccount';
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** User emails belonging to this user account. */
    emails: EnterpriseServerUserAccountEmailConnection;
    /** The Enterprise Server installation on which this user account exists. */
    enterpriseServerInstallation: EnterpriseServerInstallation;
    id: Scalars['ID']['output'];
    /** Whether the user account is a site administrator on the Enterprise Server installation. */
    isSiteAdmin: Scalars['Boolean']['output'];
    /** The login of the user account on the Enterprise Server installation. */
    login: Scalars['String']['output'];
    /** The profile name of the user account on the Enterprise Server installation. */
    profileName?: Maybe<Scalars['String']['output']>;
    /** The date and time when the user account was created on the Enterprise Server installation. */
    remoteCreatedAt: Scalars['DateTime']['output'];
    /** The ID of the user account on the Enterprise Server installation. */
    remoteUserId: Scalars['Int']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
};
/** A user account on an Enterprise Server installation. */
export type EnterpriseServerUserAccountEmailsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<EnterpriseServerUserAccountEmailOrder>;
};
/** The connection type for EnterpriseServerUserAccount. */
export type EnterpriseServerUserAccountConnection = {
    __typename?: 'EnterpriseServerUserAccountConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<EnterpriseServerUserAccountEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<EnterpriseServerUserAccount>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type EnterpriseServerUserAccountEdge = {
    __typename?: 'EnterpriseServerUserAccountEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<EnterpriseServerUserAccount>;
};
/** An email belonging to a user account on an Enterprise Server installation. */
export type EnterpriseServerUserAccountEmail = Node & {
    __typename?: 'EnterpriseServerUserAccountEmail';
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The email address. */
    email: Scalars['String']['output'];
    id: Scalars['ID']['output'];
    /** Indicates whether this is the primary email of the associated user account. */
    isPrimary: Scalars['Boolean']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The user account to which the email belongs. */
    userAccount: EnterpriseServerUserAccount;
};
/** The connection type for EnterpriseServerUserAccountEmail. */
export type EnterpriseServerUserAccountEmailConnection = {
    __typename?: 'EnterpriseServerUserAccountEmailConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<EnterpriseServerUserAccountEmailEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<EnterpriseServerUserAccountEmail>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type EnterpriseServerUserAccountEmailEdge = {
    __typename?: 'EnterpriseServerUserAccountEmailEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<EnterpriseServerUserAccountEmail>;
};
/** Ordering options for Enterprise Server user account email connections. */
export type EnterpriseServerUserAccountEmailOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order emails by. */
    field: EnterpriseServerUserAccountEmailOrderField;
};
/** Properties by which Enterprise Server user account email connections can be ordered. */
export declare enum EnterpriseServerUserAccountEmailOrderField {
    /** Order emails by email */
    Email = "EMAIL"
}
/** Ordering options for Enterprise Server user account connections. */
export type EnterpriseServerUserAccountOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order user accounts by. */
    field: EnterpriseServerUserAccountOrderField;
};
/** Properties by which Enterprise Server user account connections can be ordered. */
export declare enum EnterpriseServerUserAccountOrderField {
    /** Order user accounts by login */
    Login = "LOGIN",
    /** Order user accounts by creation time on the Enterprise Server installation */
    RemoteCreatedAt = "REMOTE_CREATED_AT"
}
/** A user accounts upload from an Enterprise Server installation. */
export type EnterpriseServerUserAccountsUpload = Node & {
    __typename?: 'EnterpriseServerUserAccountsUpload';
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The enterprise to which this upload belongs. */
    enterprise: Enterprise;
    /** The Enterprise Server installation for which this upload was generated. */
    enterpriseServerInstallation: EnterpriseServerInstallation;
    id: Scalars['ID']['output'];
    /** The name of the file uploaded. */
    name: Scalars['String']['output'];
    /** The synchronization state of the upload */
    syncState: EnterpriseServerUserAccountsUploadSyncState;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
};
/** The connection type for EnterpriseServerUserAccountsUpload. */
export type EnterpriseServerUserAccountsUploadConnection = {
    __typename?: 'EnterpriseServerUserAccountsUploadConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<EnterpriseServerUserAccountsUploadEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<EnterpriseServerUserAccountsUpload>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type EnterpriseServerUserAccountsUploadEdge = {
    __typename?: 'EnterpriseServerUserAccountsUploadEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<EnterpriseServerUserAccountsUpload>;
};
/** Ordering options for Enterprise Server user accounts upload connections. */
export type EnterpriseServerUserAccountsUploadOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order user accounts uploads by. */
    field: EnterpriseServerUserAccountsUploadOrderField;
};
/** Properties by which Enterprise Server user accounts upload connections can be ordered. */
export declare enum EnterpriseServerUserAccountsUploadOrderField {
    /** Order user accounts uploads by creation time */
    CreatedAt = "CREATED_AT"
}
/** Synchronization state of the Enterprise Server user accounts upload */
export declare enum EnterpriseServerUserAccountsUploadSyncState {
    /** The synchronization of the upload failed. */
    Failure = "FAILURE",
    /** The synchronization of the upload is pending. */
    Pending = "PENDING",
    /** The synchronization of the upload succeeded. */
    Success = "SUCCESS"
}
/** An account for a user who is an admin of an enterprise or a member of an enterprise through one or more organizations. */
export type EnterpriseUserAccount = Actor & Node & {
    __typename?: 'EnterpriseUserAccount';
    /** A URL pointing to the enterprise user account's public avatar. */
    avatarUrl: Scalars['URI']['output'];
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The enterprise in which this user account exists. */
    enterprise: Enterprise;
    id: Scalars['ID']['output'];
    /** An identifier for the enterprise user account, a login or email address */
    login: Scalars['String']['output'];
    /** The name of the enterprise user account */
    name?: Maybe<Scalars['String']['output']>;
    /** A list of enterprise organizations this user is a member of. */
    organizations: EnterpriseOrganizationMembershipConnection;
    /** The HTTP path for this user. */
    resourcePath: Scalars['URI']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this user. */
    url: Scalars['URI']['output'];
    /** The user within the enterprise. */
    user?: Maybe<User>;
};
/** An account for a user who is an admin of an enterprise or a member of an enterprise through one or more organizations. */
export type EnterpriseUserAccountAvatarUrlArgs = {
    size?: InputMaybe<Scalars['Int']['input']>;
};
/** An account for a user who is an admin of an enterprise or a member of an enterprise through one or more organizations. */
export type EnterpriseUserAccountOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<OrganizationOrder>;
    query?: InputMaybe<Scalars['String']['input']>;
    role?: InputMaybe<EnterpriseUserAccountMembershipRole>;
};
/** The connection type for EnterpriseUserAccount. */
export type EnterpriseUserAccountConnection = {
    __typename?: 'EnterpriseUserAccountConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<EnterpriseUserAccountEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<EnterpriseUserAccount>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type EnterpriseUserAccountEdge = {
    __typename?: 'EnterpriseUserAccountEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<EnterpriseUserAccount>;
};
/** The possible roles for enterprise membership. */
export declare enum EnterpriseUserAccountMembershipRole {
    /** The user is a member of the enterprise membership. */
    Member = "MEMBER",
    /** The user is an owner of the enterprise membership. */
    Owner = "OWNER"
}
/** The possible GitHub Enterprise deployments where this user can exist. */
export declare enum EnterpriseUserDeployment {
    /** The user is part of a GitHub Enterprise Cloud deployment. */
    Cloud = "CLOUD",
    /** The user is part of a GitHub Enterprise Server deployment. */
    Server = "SERVER"
}
/** An environment. */
export type Environment = Node & {
    __typename?: 'Environment';
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** The name of the environment */
    name: Scalars['String']['output'];
    /** The protection rules defined for this environment */
    protectionRules: DeploymentProtectionRuleConnection;
};
/** An environment. */
export type EnvironmentProtectionRulesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** The connection type for Environment. */
export type EnvironmentConnection = {
    __typename?: 'EnvironmentConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<EnvironmentEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Environment>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type EnvironmentEdge = {
    __typename?: 'EnvironmentEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Environment>;
};
/** An external identity provisioned by SAML SSO or SCIM. */
export type ExternalIdentity = Node & {
    __typename?: 'ExternalIdentity';
    /** The GUID for this identity */
    guid: Scalars['String']['output'];
    id: Scalars['ID']['output'];
    /** Organization invitation for this SCIM-provisioned external identity */
    organizationInvitation?: Maybe<OrganizationInvitation>;
    /** SAML Identity attributes */
    samlIdentity?: Maybe<ExternalIdentitySamlAttributes>;
    /** SCIM Identity attributes */
    scimIdentity?: Maybe<ExternalIdentityScimAttributes>;
    /** User linked to this external identity. Will be NULL if this identity has not been claimed by an organization member. */
    user?: Maybe<User>;
};
/** The connection type for ExternalIdentity. */
export type ExternalIdentityConnection = {
    __typename?: 'ExternalIdentityConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<ExternalIdentityEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<ExternalIdentity>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type ExternalIdentityEdge = {
    __typename?: 'ExternalIdentityEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<ExternalIdentity>;
};
/** SAML attributes for the External Identity */
export type ExternalIdentitySamlAttributes = {
    __typename?: 'ExternalIdentitySamlAttributes';
    /** The emails associated with the SAML identity */
    emails?: Maybe<Array<UserEmailMetadata>>;
    /** Family name of the SAML identity */
    familyName?: Maybe<Scalars['String']['output']>;
    /** Given name of the SAML identity */
    givenName?: Maybe<Scalars['String']['output']>;
    /** The groups linked to this identity in IDP */
    groups?: Maybe<Array<Scalars['String']['output']>>;
    /** The NameID of the SAML identity */
    nameId?: Maybe<Scalars['String']['output']>;
    /** The userName of the SAML identity */
    username?: Maybe<Scalars['String']['output']>;
};
/** SCIM attributes for the External Identity */
export type ExternalIdentityScimAttributes = {
    __typename?: 'ExternalIdentityScimAttributes';
    /** The emails associated with the SCIM identity */
    emails?: Maybe<Array<UserEmailMetadata>>;
    /** Family name of the SCIM identity */
    familyName?: Maybe<Scalars['String']['output']>;
    /** Given name of the SCIM identity */
    givenName?: Maybe<Scalars['String']['output']>;
    /** The groups linked to this identity in IDP */
    groups?: Maybe<Array<Scalars['String']['output']>>;
    /** The userName of the SCIM identity */
    username?: Maybe<Scalars['String']['output']>;
};
/** The possible viewed states of a file . */
export declare enum FileViewedState {
    /** The file has new changes since last viewed. */
    Dismissed = "DISMISSED",
    /** The file has not been marked as viewed. */
    Unviewed = "UNVIEWED",
    /** The file has been marked as viewed. */
    Viewed = "VIEWED"
}
/** Autogenerated input type of FollowUser */
export type FollowUserInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** ID of the user to follow. */
    userId: Scalars['ID']['input'];
};
/** Autogenerated return type of FollowUser */
export type FollowUserPayload = {
    __typename?: 'FollowUserPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The user that was followed. */
    user?: Maybe<User>;
};
/** The connection type for User. */
export type FollowerConnection = {
    __typename?: 'FollowerConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<UserEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<User>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** The connection type for User. */
export type FollowingConnection = {
    __typename?: 'FollowingConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<UserEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<User>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** A generic hovercard context with a message and icon */
export type GenericHovercardContext = HovercardContext & {
    __typename?: 'GenericHovercardContext';
    /** A string describing this context */
    message: Scalars['String']['output'];
    /** An octicon to accompany this context */
    octicon: Scalars['String']['output'];
};
/** A Gist. */
export type Gist = Node & Starrable & UniformResourceLocatable & {
    __typename?: 'Gist';
    /** A list of comments associated with the gist */
    comments: GistCommentConnection;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The gist description. */
    description?: Maybe<Scalars['String']['output']>;
    /** The files in this gist. */
    files?: Maybe<Array<Maybe<GistFile>>>;
    /** A list of forks associated with the gist */
    forks: GistConnection;
    id: Scalars['ID']['output'];
    /** Identifies if the gist is a fork. */
    isFork: Scalars['Boolean']['output'];
    /** Whether the gist is public or not. */
    isPublic: Scalars['Boolean']['output'];
    /** The gist name. */
    name: Scalars['String']['output'];
    /** The gist owner. */
    owner?: Maybe<RepositoryOwner>;
    /** Identifies when the gist was last pushed to. */
    pushedAt?: Maybe<Scalars['DateTime']['output']>;
    /** The HTML path to this resource. */
    resourcePath: Scalars['URI']['output'];
    /** Returns a count of how many stargazers there are on this object */
    stargazerCount: Scalars['Int']['output'];
    /** A list of users who have starred this starrable. */
    stargazers: StargazerConnection;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this Gist. */
    url: Scalars['URI']['output'];
    /** Returns a boolean indicating whether the viewing user has starred this starrable. */
    viewerHasStarred: Scalars['Boolean']['output'];
};
/** A Gist. */
export type GistCommentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A Gist. */
export type GistFilesArgs = {
    limit?: InputMaybe<Scalars['Int']['input']>;
    oid?: InputMaybe<Scalars['GitObjectID']['input']>;
};
/** A Gist. */
export type GistForksArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<GistOrder>;
};
/** A Gist. */
export type GistStargazersArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<StarOrder>;
};
/** Represents a comment on an Gist. */
export type GistComment = Comment & Deletable & Minimizable & Node & Updatable & UpdatableComment & {
    __typename?: 'GistComment';
    /** The actor who authored the comment. */
    author?: Maybe<Actor>;
    /** Author's association with the gist. */
    authorAssociation: CommentAuthorAssociation;
    /** Identifies the comment body. */
    body: Scalars['String']['output'];
    /** The body rendered to HTML. */
    bodyHTML: Scalars['HTML']['output'];
    /** The body rendered to text. */
    bodyText: Scalars['String']['output'];
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Check if this comment was created via an email reply. */
    createdViaEmail: Scalars['Boolean']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The actor who edited the comment. */
    editor?: Maybe<Actor>;
    /** The associated gist. */
    gist: Gist;
    id: Scalars['ID']['output'];
    /** Check if this comment was edited and includes an edit with the creation data */
    includesCreatedEdit: Scalars['Boolean']['output'];
    /** Returns whether or not a comment has been minimized. */
    isMinimized: Scalars['Boolean']['output'];
    /** The moment the editor made the last edit */
    lastEditedAt?: Maybe<Scalars['DateTime']['output']>;
    /** Returns why the comment was minimized. */
    minimizedReason?: Maybe<Scalars['String']['output']>;
    /** Identifies when the comment was published at. */
    publishedAt?: Maybe<Scalars['DateTime']['output']>;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** A list of edits to this content. */
    userContentEdits?: Maybe<UserContentEditConnection>;
    /** Check if the current viewer can delete this object. */
    viewerCanDelete: Scalars['Boolean']['output'];
    /** Check if the current viewer can minimize this object. */
    viewerCanMinimize: Scalars['Boolean']['output'];
    /** Check if the current viewer can update this object. */
    viewerCanUpdate: Scalars['Boolean']['output'];
    /** Reasons why the current viewer can not update this comment. */
    viewerCannotUpdateReasons: Array<CommentCannotUpdateReason>;
    /** Did the viewer author this comment. */
    viewerDidAuthor: Scalars['Boolean']['output'];
};
/** Represents a comment on an Gist. */
export type GistCommentUserContentEditsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** The connection type for GistComment. */
export type GistCommentConnection = {
    __typename?: 'GistCommentConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<GistCommentEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<GistComment>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type GistCommentEdge = {
    __typename?: 'GistCommentEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<GistComment>;
};
/** The connection type for Gist. */
export type GistConnection = {
    __typename?: 'GistConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<GistEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Gist>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type GistEdge = {
    __typename?: 'GistEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Gist>;
};
/** A file in a gist. */
export type GistFile = {
    __typename?: 'GistFile';
    /** The file name encoded to remove characters that are invalid in URL paths. */
    encodedName?: Maybe<Scalars['String']['output']>;
    /** The gist file encoding. */
    encoding?: Maybe<Scalars['String']['output']>;
    /** The file extension from the file name. */
    extension?: Maybe<Scalars['String']['output']>;
    /** Indicates if this file is an image. */
    isImage: Scalars['Boolean']['output'];
    /** Whether the file's contents were truncated. */
    isTruncated: Scalars['Boolean']['output'];
    /** The programming language this file is written in. */
    language?: Maybe<Language>;
    /** The gist file name. */
    name?: Maybe<Scalars['String']['output']>;
    /** The gist file size in bytes. */
    size?: Maybe<Scalars['Int']['output']>;
    /** UTF8 text data or null if the file is binary */
    text?: Maybe<Scalars['String']['output']>;
};
/** A file in a gist. */
export type GistFileTextArgs = {
    truncate?: InputMaybe<Scalars['Int']['input']>;
};
/** Ordering options for gist connections */
export type GistOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order repositories by. */
    field: GistOrderField;
};
/** Properties by which gist connections can be ordered. */
export declare enum GistOrderField {
    /** Order gists by creation time */
    CreatedAt = "CREATED_AT",
    /** Order gists by push time */
    PushedAt = "PUSHED_AT",
    /** Order gists by update time */
    UpdatedAt = "UPDATED_AT"
}
/** The privacy of a Gist */
export declare enum GistPrivacy {
    /** Gists that are public and secret */
    All = "ALL",
    /** Public */
    Public = "PUBLIC",
    /** Secret */
    Secret = "SECRET"
}
/** Represents an actor in a Git commit (ie. an author or committer). */
export type GitActor = {
    __typename?: 'GitActor';
    /** A URL pointing to the author's public avatar. */
    avatarUrl: Scalars['URI']['output'];
    /** The timestamp of the Git action (authoring or committing). */
    date?: Maybe<Scalars['GitTimestamp']['output']>;
    /** The email in the Git commit. */
    email?: Maybe<Scalars['String']['output']>;
    /** The name in the Git commit. */
    name?: Maybe<Scalars['String']['output']>;
    /** The GitHub user corresponding to the email field. Null if no such user exists. */
    user?: Maybe<User>;
};
/** Represents an actor in a Git commit (ie. an author or committer). */
export type GitActorAvatarUrlArgs = {
    size?: InputMaybe<Scalars['Int']['input']>;
};
/** The connection type for GitActor. */
export type GitActorConnection = {
    __typename?: 'GitActorConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<GitActorEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<GitActor>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type GitActorEdge = {
    __typename?: 'GitActorEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<GitActor>;
};
/** Represents information about the GitHub instance. */
export type GitHubMetadata = {
    __typename?: 'GitHubMetadata';
    /** Returns a String that's a SHA of `github-services` */
    gitHubServicesSha: Scalars['GitObjectID']['output'];
    /** Whether or not users are verified */
    isPasswordAuthenticationVerifiable: Scalars['Boolean']['output'];
};
/** Represents a Git object. */
export type GitObject = {
    /** An abbreviated version of the Git object ID */
    abbreviatedOid: Scalars['String']['output'];
    /** The HTTP path for this Git object */
    commitResourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this Git object */
    commitUrl: Scalars['URI']['output'];
    id: Scalars['ID']['output'];
    /** The Git object ID */
    oid: Scalars['GitObjectID']['output'];
    /** The Repository the Git object belongs to */
    repository: Repository;
};
/** Information about a signature (GPG or S/MIME) on a Commit or Tag. */
export type GitSignature = {
    /** Email used to sign this object. */
    email: Scalars['String']['output'];
    /** True if the signature is valid and verified by GitHub. */
    isValid: Scalars['Boolean']['output'];
    /** Payload for GPG signing object. Raw ODB object without the signature header. */
    payload: Scalars['String']['output'];
    /** ASCII-armored signature header from object. */
    signature: Scalars['String']['output'];
    /** GitHub user corresponding to the email signing this commit. */
    signer?: Maybe<User>;
    /**
     * The state of this signature. `VALID` if signature is valid and verified by
     * GitHub, otherwise represents reason why signature is considered invalid.
     */
    state: GitSignatureState;
    /** True if the signature was made with GitHub's signing key. */
    wasSignedByGitHub: Scalars['Boolean']['output'];
};
/** The state of a Git signature. */
export declare enum GitSignatureState {
    /** The signing certificate or its chain could not be verified */
    BadCert = "BAD_CERT",
    /** Invalid email used for signing */
    BadEmail = "BAD_EMAIL",
    /** Signing key expired */
    ExpiredKey = "EXPIRED_KEY",
    /** Internal error - the GPG verification service misbehaved */
    GpgverifyError = "GPGVERIFY_ERROR",
    /** Internal error - the GPG verification service is unavailable at the moment */
    GpgverifyUnavailable = "GPGVERIFY_UNAVAILABLE",
    /** Invalid signature */
    Invalid = "INVALID",
    /** Malformed signature */
    MalformedSig = "MALFORMED_SIG",
    /** The usage flags for the key that signed this don't allow signing */
    NotSigningKey = "NOT_SIGNING_KEY",
    /** Email used for signing not known to GitHub */
    NoUser = "NO_USER",
    /** Valid signature, though certificate revocation check failed */
    OcspError = "OCSP_ERROR",
    /** Valid signature, pending certificate revocation checking */
    OcspPending = "OCSP_PENDING",
    /** One or more certificates in chain has been revoked */
    OcspRevoked = "OCSP_REVOKED",
    /** Key used for signing not known to GitHub */
    UnknownKey = "UNKNOWN_KEY",
    /** Unknown signature type */
    UnknownSigType = "UNKNOWN_SIG_TYPE",
    /** Unsigned */
    Unsigned = "UNSIGNED",
    /** Email used for signing unverified on GitHub */
    UnverifiedEmail = "UNVERIFIED_EMAIL",
    /** Valid signature and verified by GitHub */
    Valid = "VALID"
}
/** Represents a GPG signature on a Commit or Tag. */
export type GpgSignature = GitSignature & {
    __typename?: 'GpgSignature';
    /** Email used to sign this object. */
    email: Scalars['String']['output'];
    /** True if the signature is valid and verified by GitHub. */
    isValid: Scalars['Boolean']['output'];
    /** Hex-encoded ID of the key that signed this object. */
    keyId?: Maybe<Scalars['String']['output']>;
    /** Payload for GPG signing object. Raw ODB object without the signature header. */
    payload: Scalars['String']['output'];
    /** ASCII-armored signature header from object. */
    signature: Scalars['String']['output'];
    /** GitHub user corresponding to the email signing this commit. */
    signer?: Maybe<User>;
    /**
     * The state of this signature. `VALID` if signature is valid and verified by
     * GitHub, otherwise represents reason why signature is considered invalid.
     */
    state: GitSignatureState;
    /** True if the signature was made with GitHub's signing key. */
    wasSignedByGitHub: Scalars['Boolean']['output'];
};
/** Represents a 'head_ref_deleted' event on a given pull request. */
export type HeadRefDeletedEvent = Node & {
    __typename?: 'HeadRefDeletedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the Ref associated with the `head_ref_deleted` event. */
    headRef?: Maybe<Ref>;
    /** Identifies the name of the Ref associated with the `head_ref_deleted` event. */
    headRefName: Scalars['String']['output'];
    id: Scalars['ID']['output'];
    /** PullRequest referenced by event. */
    pullRequest: PullRequest;
};
/** Represents a 'head_ref_force_pushed' event on a given pull request. */
export type HeadRefForcePushedEvent = Node & {
    __typename?: 'HeadRefForcePushedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the after commit SHA for the 'head_ref_force_pushed' event. */
    afterCommit?: Maybe<Commit>;
    /** Identifies the before commit SHA for the 'head_ref_force_pushed' event. */
    beforeCommit?: Maybe<Commit>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** PullRequest referenced by event. */
    pullRequest: PullRequest;
    /** Identifies the fully qualified ref name for the 'head_ref_force_pushed' event. */
    ref?: Maybe<Ref>;
};
/** Represents a 'head_ref_restored' event on a given pull request. */
export type HeadRefRestoredEvent = Node & {
    __typename?: 'HeadRefRestoredEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** PullRequest referenced by event. */
    pullRequest: PullRequest;
};
/** Detail needed to display a hovercard for a user */
export type Hovercard = {
    __typename?: 'Hovercard';
    /** Each of the contexts for this hovercard */
    contexts: Array<HovercardContext>;
};
/** An individual line of a hovercard */
export type HovercardContext = {
    /** A string describing this context */
    message: Scalars['String']['output'];
    /** An octicon to accompany this context */
    octicon: Scalars['String']['output'];
};
/** The possible states in which authentication can be configured with an identity provider. */
export declare enum IdentityProviderConfigurationState {
    /** Authentication with an identity provider is configured but not enforced. */
    Configured = "CONFIGURED",
    /** Authentication with an identity provider is configured and enforced. */
    Enforced = "ENFORCED",
    /** Authentication with an identity provider is not configured. */
    Unconfigured = "UNCONFIGURED"
}
/** Autogenerated input type of ImportProject */
export type ImportProjectInput = {
    /** The description of Project. */
    body?: InputMaybe<Scalars['String']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** A list of columns containing issues and pull requests. */
    columnImports: Array<ProjectColumnImport>;
    /** The name of Project. */
    name: Scalars['String']['input'];
    /** The name of the Organization or User to create the Project under. */
    ownerName: Scalars['String']['input'];
    /** Whether the Project is public or not. */
    public?: InputMaybe<Scalars['Boolean']['input']>;
};
/** Autogenerated return type of ImportProject */
export type ImportProjectPayload = {
    __typename?: 'ImportProjectPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The new Project! */
    project?: Maybe<Project>;
};
/** The possible values for the IP allow list enabled setting. */
export declare enum IpAllowListEnabledSettingValue {
    /** The setting is disabled for the owner. */
    Disabled = "DISABLED",
    /** The setting is enabled for the owner. */
    Enabled = "ENABLED"
}
/** An IP address or range of addresses that is allowed to access an owner's resources. */
export type IpAllowListEntry = Node & {
    __typename?: 'IpAllowListEntry';
    /** A single IP address or range of IP addresses in CIDR notation. */
    allowListValue: Scalars['String']['output'];
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** Whether the entry is currently active. */
    isActive: Scalars['Boolean']['output'];
    /** The name of the IP allow list entry. */
    name?: Maybe<Scalars['String']['output']>;
    /** The owner of the IP allow list entry. */
    owner: IpAllowListOwner;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
};
/** The connection type for IpAllowListEntry. */
export type IpAllowListEntryConnection = {
    __typename?: 'IpAllowListEntryConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<IpAllowListEntryEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<IpAllowListEntry>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type IpAllowListEntryEdge = {
    __typename?: 'IpAllowListEntryEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<IpAllowListEntry>;
};
/** Ordering options for IP allow list entry connections. */
export type IpAllowListEntryOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order IP allow list entries by. */
    field: IpAllowListEntryOrderField;
};
/** Properties by which IP allow list entry connections can be ordered. */
export declare enum IpAllowListEntryOrderField {
    /** Order IP allow list entries by the allow list value. */
    AllowListValue = "ALLOW_LIST_VALUE",
    /** Order IP allow list entries by creation time. */
    CreatedAt = "CREATED_AT"
}
/** The possible values for the IP allow list configuration for installed GitHub Apps setting. */
export declare enum IpAllowListForInstalledAppsEnabledSettingValue {
    /** The setting is disabled for the owner. */
    Disabled = "DISABLED",
    /** The setting is enabled for the owner. */
    Enabled = "ENABLED"
}
/** Types that can own an IP allow list. */
export type IpAllowListOwner = App | Enterprise | Organization;
/** An Issue is a place to discuss ideas, enhancements, tasks, and bugs for a project. */
export type Issue = Assignable & Closable & Comment & Labelable & Lockable & Node & Reactable & RepositoryNode & Subscribable & UniformResourceLocatable & Updatable & UpdatableComment & {
    __typename?: 'Issue';
    /** Reason that the conversation was locked. */
    activeLockReason?: Maybe<LockReason>;
    /** A list of Users assigned to this object. */
    assignees: UserConnection;
    /** The actor who authored the comment. */
    author?: Maybe<Actor>;
    /** Author's association with the subject of the comment. */
    authorAssociation: CommentAuthorAssociation;
    /** Identifies the body of the issue. */
    body: Scalars['String']['output'];
    /** The body rendered to HTML. */
    bodyHTML: Scalars['HTML']['output'];
    /** The http path for this issue body */
    bodyResourcePath: Scalars['URI']['output'];
    /** Identifies the body of the issue rendered to text. */
    bodyText: Scalars['String']['output'];
    /** The http URL for this issue body */
    bodyUrl: Scalars['URI']['output'];
    /** `true` if the object is closed (definition of closed may depend on type) */
    closed: Scalars['Boolean']['output'];
    /** Identifies the date and time when the object was closed. */
    closedAt?: Maybe<Scalars['DateTime']['output']>;
    /** A list of comments associated with the Issue. */
    comments: IssueCommentConnection;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Check if this comment was created via an email reply. */
    createdViaEmail: Scalars['Boolean']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The actor who edited the comment. */
    editor?: Maybe<Actor>;
    /** The hovercard information for this issue */
    hovercard: Hovercard;
    id: Scalars['ID']['output'];
    /** Check if this comment was edited and includes an edit with the creation data */
    includesCreatedEdit: Scalars['Boolean']['output'];
    /** Indicates whether or not this issue is currently pinned to the repository issues list */
    isPinned?: Maybe<Scalars['Boolean']['output']>;
    /** Is this issue read by the viewer */
    isReadByViewer?: Maybe<Scalars['Boolean']['output']>;
    /** A list of labels associated with the object. */
    labels?: Maybe<LabelConnection>;
    /** The moment the editor made the last edit */
    lastEditedAt?: Maybe<Scalars['DateTime']['output']>;
    /** `true` if the object is locked */
    locked: Scalars['Boolean']['output'];
    /** Identifies the milestone associated with the issue. */
    milestone?: Maybe<Milestone>;
    /** Identifies the issue number. */
    number: Scalars['Int']['output'];
    /** A list of Users that are participating in the Issue conversation. */
    participants: UserConnection;
    /** List of project cards associated with this issue. */
    projectCards: ProjectCardConnection;
    /** Identifies when the comment was published at. */
    publishedAt?: Maybe<Scalars['DateTime']['output']>;
    /** A list of reactions grouped by content left on the subject. */
    reactionGroups?: Maybe<Array<ReactionGroup>>;
    /** A list of Reactions left on the Issue. */
    reactions: ReactionConnection;
    /** The repository associated with this node. */
    repository: Repository;
    /** The HTTP path for this issue */
    resourcePath: Scalars['URI']['output'];
    /** Identifies the state of the issue. */
    state: IssueState;
    /**
     * A list of events, comments, commits, etc. associated with the issue.
     * @deprecated `timeline` will be removed Use Issue.timelineItems instead. Removal on 2020-10-01 UTC.
     */
    timeline: IssueTimelineConnection;
    /** A list of events, comments, commits, etc. associated with the issue. */
    timelineItems: IssueTimelineItemsConnection;
    /** Identifies the issue title. */
    title: Scalars['String']['output'];
    /** Identifies the issue title rendered to HTML. */
    titleHTML: Scalars['String']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this issue */
    url: Scalars['URI']['output'];
    /** A list of edits to this content. */
    userContentEdits?: Maybe<UserContentEditConnection>;
    /** Can user react to this subject */
    viewerCanReact: Scalars['Boolean']['output'];
    /** Check if the viewer is able to change their subscription status for the repository. */
    viewerCanSubscribe: Scalars['Boolean']['output'];
    /** Check if the current viewer can update this object. */
    viewerCanUpdate: Scalars['Boolean']['output'];
    /** Reasons why the current viewer can not update this comment. */
    viewerCannotUpdateReasons: Array<CommentCannotUpdateReason>;
    /** Did the viewer author this comment. */
    viewerDidAuthor: Scalars['Boolean']['output'];
    /** Identifies if the viewer is watching, not watching, or ignoring the subscribable entity. */
    viewerSubscription?: Maybe<SubscriptionState>;
};
/** An Issue is a place to discuss ideas, enhancements, tasks, and bugs for a project. */
export type IssueAssigneesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** An Issue is a place to discuss ideas, enhancements, tasks, and bugs for a project. */
export type IssueCommentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<IssueCommentOrder>;
};
/** An Issue is a place to discuss ideas, enhancements, tasks, and bugs for a project. */
export type IssueHovercardArgs = {
    includeNotificationContexts?: InputMaybe<Scalars['Boolean']['input']>;
};
/** An Issue is a place to discuss ideas, enhancements, tasks, and bugs for a project. */
export type IssueLabelsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<LabelOrder>;
};
/** An Issue is a place to discuss ideas, enhancements, tasks, and bugs for a project. */
export type IssueParticipantsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** An Issue is a place to discuss ideas, enhancements, tasks, and bugs for a project. */
export type IssueProjectCardsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    archivedStates?: InputMaybe<Array<InputMaybe<ProjectCardArchivedState>>>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** An Issue is a place to discuss ideas, enhancements, tasks, and bugs for a project. */
export type IssueReactionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    content?: InputMaybe<ReactionContent>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ReactionOrder>;
};
/** An Issue is a place to discuss ideas, enhancements, tasks, and bugs for a project. */
export type IssueTimelineArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    since?: InputMaybe<Scalars['DateTime']['input']>;
};
/** An Issue is a place to discuss ideas, enhancements, tasks, and bugs for a project. */
export type IssueTimelineItemsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    itemTypes?: InputMaybe<Array<IssueTimelineItemsItemType>>;
    last?: InputMaybe<Scalars['Int']['input']>;
    since?: InputMaybe<Scalars['DateTime']['input']>;
    skip?: InputMaybe<Scalars['Int']['input']>;
};
/** An Issue is a place to discuss ideas, enhancements, tasks, and bugs for a project. */
export type IssueUserContentEditsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** Represents a comment on an Issue. */
export type IssueComment = Comment & Deletable & Minimizable & Node & Reactable & RepositoryNode & Updatable & UpdatableComment & {
    __typename?: 'IssueComment';
    /** The actor who authored the comment. */
    author?: Maybe<Actor>;
    /** Author's association with the subject of the comment. */
    authorAssociation: CommentAuthorAssociation;
    /** The body as Markdown. */
    body: Scalars['String']['output'];
    /** The body rendered to HTML. */
    bodyHTML: Scalars['HTML']['output'];
    /** The body rendered to text. */
    bodyText: Scalars['String']['output'];
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Check if this comment was created via an email reply. */
    createdViaEmail: Scalars['Boolean']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The actor who edited the comment. */
    editor?: Maybe<Actor>;
    id: Scalars['ID']['output'];
    /** Check if this comment was edited and includes an edit with the creation data */
    includesCreatedEdit: Scalars['Boolean']['output'];
    /** Returns whether or not a comment has been minimized. */
    isMinimized: Scalars['Boolean']['output'];
    /** Identifies the issue associated with the comment. */
    issue: Issue;
    /** The moment the editor made the last edit */
    lastEditedAt?: Maybe<Scalars['DateTime']['output']>;
    /** Returns why the comment was minimized. */
    minimizedReason?: Maybe<Scalars['String']['output']>;
    /** Identifies when the comment was published at. */
    publishedAt?: Maybe<Scalars['DateTime']['output']>;
    /**
     * Returns the pull request associated with the comment, if this comment was made on a
     * pull request.
     */
    pullRequest?: Maybe<PullRequest>;
    /** A list of reactions grouped by content left on the subject. */
    reactionGroups?: Maybe<Array<ReactionGroup>>;
    /** A list of Reactions left on the Issue. */
    reactions: ReactionConnection;
    /** The repository associated with this node. */
    repository: Repository;
    /** The HTTP path for this issue comment */
    resourcePath: Scalars['URI']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this issue comment */
    url: Scalars['URI']['output'];
    /** A list of edits to this content. */
    userContentEdits?: Maybe<UserContentEditConnection>;
    /** Check if the current viewer can delete this object. */
    viewerCanDelete: Scalars['Boolean']['output'];
    /** Check if the current viewer can minimize this object. */
    viewerCanMinimize: Scalars['Boolean']['output'];
    /** Can user react to this subject */
    viewerCanReact: Scalars['Boolean']['output'];
    /** Check if the current viewer can update this object. */
    viewerCanUpdate: Scalars['Boolean']['output'];
    /** Reasons why the current viewer can not update this comment. */
    viewerCannotUpdateReasons: Array<CommentCannotUpdateReason>;
    /** Did the viewer author this comment. */
    viewerDidAuthor: Scalars['Boolean']['output'];
};
/** Represents a comment on an Issue. */
export type IssueCommentReactionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    content?: InputMaybe<ReactionContent>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ReactionOrder>;
};
/** Represents a comment on an Issue. */
export type IssueCommentUserContentEditsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** The connection type for IssueComment. */
export type IssueCommentConnection = {
    __typename?: 'IssueCommentConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<IssueCommentEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<IssueComment>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type IssueCommentEdge = {
    __typename?: 'IssueCommentEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<IssueComment>;
};
/** Ways in which lists of issue comments can be ordered upon return. */
export type IssueCommentOrder = {
    /** The direction in which to order issue comments by the specified field. */
    direction: OrderDirection;
    /** The field in which to order issue comments by. */
    field: IssueCommentOrderField;
};
/** Properties by which issue comment connections can be ordered. */
export declare enum IssueCommentOrderField {
    /** Order issue comments by update time */
    UpdatedAt = "UPDATED_AT"
}
/** The connection type for Issue. */
export type IssueConnection = {
    __typename?: 'IssueConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<IssueEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Issue>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** This aggregates issues opened by a user within one repository. */
export type IssueContributionsByRepository = {
    __typename?: 'IssueContributionsByRepository';
    /** The issue contributions. */
    contributions: CreatedIssueContributionConnection;
    /** The repository in which the issues were opened. */
    repository: Repository;
};
/** This aggregates issues opened by a user within one repository. */
export type IssueContributionsByRepositoryContributionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ContributionOrder>;
};
/** An edge in a connection. */
export type IssueEdge = {
    __typename?: 'IssueEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Issue>;
};
/** Ways in which to filter lists of issues. */
export type IssueFilters = {
    /**
     * List issues assigned to given name. Pass in `null` for issues with no assigned
     * user, and `*` for issues assigned to any user.
     */
    assignee?: InputMaybe<Scalars['String']['input']>;
    /** List issues created by given name. */
    createdBy?: InputMaybe<Scalars['String']['input']>;
    /** List issues where the list of label names exist on the issue. */
    labels?: InputMaybe<Array<Scalars['String']['input']>>;
    /** List issues where the given name is mentioned in the issue. */
    mentioned?: InputMaybe<Scalars['String']['input']>;
    /**
     * List issues by given milestone argument. If an string representation of an
     * integer is passed, it should refer to a milestone by its number field. Pass in
     * `null` for issues with no milestone, and `*` for issues that are assigned to any milestone.
     */
    milestone?: InputMaybe<Scalars['String']['input']>;
    /** List issues that have been updated at or after the given date. */
    since?: InputMaybe<Scalars['DateTime']['input']>;
    /** List issues filtered by the list of states given. */
    states?: InputMaybe<Array<IssueState>>;
    /** List issues subscribed to by viewer. */
    viewerSubscribed?: InputMaybe<Scalars['Boolean']['input']>;
};
/** Used for return value of Repository.issueOrPullRequest. */
export type IssueOrPullRequest = Issue | PullRequest;
/** Ways in which lists of issues can be ordered upon return. */
export type IssueOrder = {
    /** The direction in which to order issues by the specified field. */
    direction: OrderDirection;
    /** The field in which to order issues by. */
    field: IssueOrderField;
};
/** Properties by which issue connections can be ordered. */
export declare enum IssueOrderField {
    /** Order issues by comment count */
    Comments = "COMMENTS",
    /** Order issues by creation time */
    CreatedAt = "CREATED_AT",
    /** Order issues by update time */
    UpdatedAt = "UPDATED_AT"
}
/** The possible states of an issue. */
export declare enum IssueState {
    /** An issue that has been closed */
    Closed = "CLOSED",
    /** An issue that is still open */
    Open = "OPEN"
}
/** A repository issue template. */
export type IssueTemplate = {
    __typename?: 'IssueTemplate';
    /** The template purpose. */
    about?: Maybe<Scalars['String']['output']>;
    /** The suggested issue body. */
    body?: Maybe<Scalars['String']['output']>;
    /** The template name. */
    name: Scalars['String']['output'];
    /** The suggested issue title. */
    title?: Maybe<Scalars['String']['output']>;
};
/** The connection type for IssueTimelineItem. */
export type IssueTimelineConnection = {
    __typename?: 'IssueTimelineConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<IssueTimelineItemEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<IssueTimelineItem>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An item in an issue timeline */
export type IssueTimelineItem = AssignedEvent | ClosedEvent | Commit | CrossReferencedEvent | DemilestonedEvent | IssueComment | LabeledEvent | LockedEvent | MilestonedEvent | ReferencedEvent | RenamedTitleEvent | ReopenedEvent | SubscribedEvent | TransferredEvent | UnassignedEvent | UnlabeledEvent | UnlockedEvent | UnsubscribedEvent | UserBlockedEvent;
/** An edge in a connection. */
export type IssueTimelineItemEdge = {
    __typename?: 'IssueTimelineItemEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<IssueTimelineItem>;
};
/** An item in an issue timeline */
export type IssueTimelineItems = AddedToProjectEvent | AssignedEvent | ClosedEvent | CommentDeletedEvent | ConnectedEvent | ConvertedNoteToIssueEvent | CrossReferencedEvent | DemilestonedEvent | DisconnectedEvent | IssueComment | LabeledEvent | LockedEvent | MarkedAsDuplicateEvent | MentionedEvent | MilestonedEvent | MovedColumnsInProjectEvent | PinnedEvent | ReferencedEvent | RemovedFromProjectEvent | RenamedTitleEvent | ReopenedEvent | SubscribedEvent | TransferredEvent | UnassignedEvent | UnlabeledEvent | UnlockedEvent | UnmarkedAsDuplicateEvent | UnpinnedEvent | UnsubscribedEvent | UserBlockedEvent;
/** The connection type for IssueTimelineItems. */
export type IssueTimelineItemsConnection = {
    __typename?: 'IssueTimelineItemsConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<IssueTimelineItemsEdge>>>;
    /** Identifies the count of items after applying `before` and `after` filters. */
    filteredCount: Scalars['Int']['output'];
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<IssueTimelineItems>>>;
    /** Identifies the count of items after applying `before`/`after` filters and `first`/`last`/`skip` slicing. */
    pageCount: Scalars['Int']['output'];
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
    /** Identifies the date and time when the timeline was last updated. */
    updatedAt: Scalars['DateTime']['output'];
};
/** An edge in a connection. */
export type IssueTimelineItemsEdge = {
    __typename?: 'IssueTimelineItemsEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<IssueTimelineItems>;
};
/** The possible item types found in a timeline. */
export declare enum IssueTimelineItemsItemType {
    /** Represents a 'added_to_project' event on a given issue or pull request. */
    AddedToProjectEvent = "ADDED_TO_PROJECT_EVENT",
    /** Represents an 'assigned' event on any assignable object. */
    AssignedEvent = "ASSIGNED_EVENT",
    /** Represents a 'closed' event on any `Closable`. */
    ClosedEvent = "CLOSED_EVENT",
    /** Represents a 'comment_deleted' event on a given issue or pull request. */
    CommentDeletedEvent = "COMMENT_DELETED_EVENT",
    /** Represents a 'connected' event on a given issue or pull request. */
    ConnectedEvent = "CONNECTED_EVENT",
    /** Represents a 'converted_note_to_issue' event on a given issue or pull request. */
    ConvertedNoteToIssueEvent = "CONVERTED_NOTE_TO_ISSUE_EVENT",
    /** Represents a mention made by one issue or pull request to another. */
    CrossReferencedEvent = "CROSS_REFERENCED_EVENT",
    /** Represents a 'demilestoned' event on a given issue or pull request. */
    DemilestonedEvent = "DEMILESTONED_EVENT",
    /** Represents a 'disconnected' event on a given issue or pull request. */
    DisconnectedEvent = "DISCONNECTED_EVENT",
    /** Represents a comment on an Issue. */
    IssueComment = "ISSUE_COMMENT",
    /** Represents a 'labeled' event on a given issue or pull request. */
    LabeledEvent = "LABELED_EVENT",
    /** Represents a 'locked' event on a given issue or pull request. */
    LockedEvent = "LOCKED_EVENT",
    /** Represents a 'marked_as_duplicate' event on a given issue or pull request. */
    MarkedAsDuplicateEvent = "MARKED_AS_DUPLICATE_EVENT",
    /** Represents a 'mentioned' event on a given issue or pull request. */
    MentionedEvent = "MENTIONED_EVENT",
    /** Represents a 'milestoned' event on a given issue or pull request. */
    MilestonedEvent = "MILESTONED_EVENT",
    /** Represents a 'moved_columns_in_project' event on a given issue or pull request. */
    MovedColumnsInProjectEvent = "MOVED_COLUMNS_IN_PROJECT_EVENT",
    /** Represents a 'pinned' event on a given issue or pull request. */
    PinnedEvent = "PINNED_EVENT",
    /** Represents a 'referenced' event on a given `ReferencedSubject`. */
    ReferencedEvent = "REFERENCED_EVENT",
    /** Represents a 'removed_from_project' event on a given issue or pull request. */
    RemovedFromProjectEvent = "REMOVED_FROM_PROJECT_EVENT",
    /** Represents a 'renamed' event on a given issue or pull request */
    RenamedTitleEvent = "RENAMED_TITLE_EVENT",
    /** Represents a 'reopened' event on any `Closable`. */
    ReopenedEvent = "REOPENED_EVENT",
    /** Represents a 'subscribed' event on a given `Subscribable`. */
    SubscribedEvent = "SUBSCRIBED_EVENT",
    /** Represents a 'transferred' event on a given issue or pull request. */
    TransferredEvent = "TRANSFERRED_EVENT",
    /** Represents an 'unassigned' event on any assignable object. */
    UnassignedEvent = "UNASSIGNED_EVENT",
    /** Represents an 'unlabeled' event on a given issue or pull request. */
    UnlabeledEvent = "UNLABELED_EVENT",
    /** Represents an 'unlocked' event on a given issue or pull request. */
    UnlockedEvent = "UNLOCKED_EVENT",
    /** Represents an 'unmarked_as_duplicate' event on a given issue or pull request. */
    UnmarkedAsDuplicateEvent = "UNMARKED_AS_DUPLICATE_EVENT",
    /** Represents an 'unpinned' event on a given issue or pull request. */
    UnpinnedEvent = "UNPINNED_EVENT",
    /** Represents an 'unsubscribed' event on a given `Subscribable`. */
    UnsubscribedEvent = "UNSUBSCRIBED_EVENT",
    /** Represents a 'user_blocked' event on a given user. */
    UserBlockedEvent = "USER_BLOCKED_EVENT"
}
/** Represents a user signing up for a GitHub account. */
export type JoinedGitHubContribution = Contribution & {
    __typename?: 'JoinedGitHubContribution';
    /**
     * Whether this contribution is associated with a record you do not have access to. For
     * example, your own 'first issue' contribution may have been made on a repository you can no
     * longer access.
     */
    isRestricted: Scalars['Boolean']['output'];
    /** When this contribution was made. */
    occurredAt: Scalars['DateTime']['output'];
    /** The HTTP path for this contribution. */
    resourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this contribution. */
    url: Scalars['URI']['output'];
    /** The user who made this contribution. */
    user: User;
};
/** A label for categorizing Issues, Pull Requests, Milestones, or Discussions with a given Repository. */
export type Label = Node & {
    __typename?: 'Label';
    /** Identifies the label color. */
    color: Scalars['String']['output'];
    /** Identifies the date and time when the label was created. */
    createdAt?: Maybe<Scalars['DateTime']['output']>;
    /** A brief description of this label. */
    description?: Maybe<Scalars['String']['output']>;
    id: Scalars['ID']['output'];
    /** Indicates whether or not this is a default label. */
    isDefault: Scalars['Boolean']['output'];
    /** A list of issues associated with this label. */
    issues: IssueConnection;
    /** Identifies the label name. */
    name: Scalars['String']['output'];
    /** A list of pull requests associated with this label. */
    pullRequests: PullRequestConnection;
    /** The repository associated with this label. */
    repository: Repository;
    /** The HTTP path for this label. */
    resourcePath: Scalars['URI']['output'];
    /** Identifies the date and time when the label was last updated. */
    updatedAt?: Maybe<Scalars['DateTime']['output']>;
    /** The HTTP URL for this label. */
    url: Scalars['URI']['output'];
};
/** A label for categorizing Issues, Pull Requests, Milestones, or Discussions with a given Repository. */
export type LabelIssuesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    filterBy?: InputMaybe<IssueFilters>;
    first?: InputMaybe<Scalars['Int']['input']>;
    labels?: InputMaybe<Array<Scalars['String']['input']>>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<IssueOrder>;
    states?: InputMaybe<Array<IssueState>>;
};
/** A label for categorizing Issues, Pull Requests, Milestones, or Discussions with a given Repository. */
export type LabelPullRequestsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    baseRefName?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    headRefName?: InputMaybe<Scalars['String']['input']>;
    labels?: InputMaybe<Array<Scalars['String']['input']>>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<IssueOrder>;
    states?: InputMaybe<Array<PullRequestState>>;
};
/** The connection type for Label. */
export type LabelConnection = {
    __typename?: 'LabelConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<LabelEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Label>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type LabelEdge = {
    __typename?: 'LabelEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Label>;
};
/** Ways in which lists of labels can be ordered upon return. */
export type LabelOrder = {
    /** The direction in which to order labels by the specified field. */
    direction: OrderDirection;
    /** The field in which to order labels by. */
    field: LabelOrderField;
};
/** Properties by which label connections can be ordered. */
export declare enum LabelOrderField {
    /** Order labels by creation time */
    CreatedAt = "CREATED_AT",
    /** Order labels by name */
    Name = "NAME"
}
/** An object that can have labels assigned to it. */
export type Labelable = {
    /** A list of labels associated with the object. */
    labels?: Maybe<LabelConnection>;
};
/** An object that can have labels assigned to it. */
export type LabelableLabelsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<LabelOrder>;
};
/** Represents a 'labeled' event on a given issue or pull request. */
export type LabeledEvent = Node & {
    __typename?: 'LabeledEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** Identifies the label associated with the 'labeled' event. */
    label: Label;
    /** Identifies the `Labelable` associated with the event. */
    labelable: Labelable;
};
/** Represents a given language found in repositories. */
export type Language = Node & {
    __typename?: 'Language';
    /** The color defined for the current language. */
    color?: Maybe<Scalars['String']['output']>;
    id: Scalars['ID']['output'];
    /** The name of the current language. */
    name: Scalars['String']['output'];
};
/** A list of languages associated with the parent. */
export type LanguageConnection = {
    __typename?: 'LanguageConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<LanguageEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Language>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
    /** The total size in bytes of files written in that language. */
    totalSize: Scalars['Int']['output'];
};
/** Represents the language of a repository. */
export type LanguageEdge = {
    __typename?: 'LanguageEdge';
    cursor: Scalars['String']['output'];
    node: Language;
    /** The number of bytes of code written in the language. */
    size: Scalars['Int']['output'];
};
/** Ordering options for language connections. */
export type LanguageOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order languages by. */
    field: LanguageOrderField;
};
/** Properties by which language connections can be ordered. */
export declare enum LanguageOrderField {
    /** Order languages by the size of all files containing the language */
    Size = "SIZE"
}
/** A repository's open source license */
export type License = Node & {
    __typename?: 'License';
    /** The full text of the license */
    body: Scalars['String']['output'];
    /** The conditions set by the license */
    conditions: Array<Maybe<LicenseRule>>;
    /** A human-readable description of the license */
    description?: Maybe<Scalars['String']['output']>;
    /** Whether the license should be featured */
    featured: Scalars['Boolean']['output'];
    /** Whether the license should be displayed in license pickers */
    hidden: Scalars['Boolean']['output'];
    id: Scalars['ID']['output'];
    /** Instructions on how to implement the license */
    implementation?: Maybe<Scalars['String']['output']>;
    /** The lowercased SPDX ID of the license */
    key: Scalars['String']['output'];
    /** The limitations set by the license */
    limitations: Array<Maybe<LicenseRule>>;
    /** The license full name specified by <https://spdx.org/licenses> */
    name: Scalars['String']['output'];
    /** Customary short name if applicable (e.g, GPLv3) */
    nickname?: Maybe<Scalars['String']['output']>;
    /** The permissions set by the license */
    permissions: Array<Maybe<LicenseRule>>;
    /** Whether the license is a pseudo-license placeholder (e.g., other, no-license) */
    pseudoLicense: Scalars['Boolean']['output'];
    /** Short identifier specified by <https://spdx.org/licenses> */
    spdxId?: Maybe<Scalars['String']['output']>;
    /** URL to the license on <https://choosealicense.com> */
    url?: Maybe<Scalars['URI']['output']>;
};
/** Describes a License's conditions, permissions, and limitations */
export type LicenseRule = {
    __typename?: 'LicenseRule';
    /** A description of the rule */
    description: Scalars['String']['output'];
    /** The machine-readable rule key */
    key: Scalars['String']['output'];
    /** The human-readable rule label */
    label: Scalars['String']['output'];
};
/** Autogenerated input type of LinkRepositoryToProject */
export type LinkRepositoryToProjectInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the Project to link to a Repository */
    projectId: Scalars['ID']['input'];
    /** The ID of the Repository to link to a Project. */
    repositoryId: Scalars['ID']['input'];
};
/** Autogenerated return type of LinkRepositoryToProject */
export type LinkRepositoryToProjectPayload = {
    __typename?: 'LinkRepositoryToProjectPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The linked Project. */
    project?: Maybe<Project>;
    /** The linked Repository. */
    repository?: Maybe<Repository>;
};
/** Autogenerated input type of LockLockable */
export type LockLockableInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** A reason for why the item will be locked. */
    lockReason?: InputMaybe<LockReason>;
    /** ID of the item to be locked. */
    lockableId: Scalars['ID']['input'];
};
/** Autogenerated return type of LockLockable */
export type LockLockablePayload = {
    __typename?: 'LockLockablePayload';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The item that was locked. */
    lockedRecord?: Maybe<Lockable>;
};
/** The possible reasons that an issue or pull request was locked. */
export declare enum LockReason {
    /** The issue or pull request was locked because the conversation was off-topic. */
    OffTopic = "OFF_TOPIC",
    /** The issue or pull request was locked because the conversation was resolved. */
    Resolved = "RESOLVED",
    /** The issue or pull request was locked because the conversation was spam. */
    Spam = "SPAM",
    /** The issue or pull request was locked because the conversation was too heated. */
    TooHeated = "TOO_HEATED"
}
/** An object that can be locked. */
export type Lockable = {
    /** Reason that the conversation was locked. */
    activeLockReason?: Maybe<LockReason>;
    /** `true` if the object is locked */
    locked: Scalars['Boolean']['output'];
};
/** Represents a 'locked' event on a given issue or pull request. */
export type LockedEvent = Node & {
    __typename?: 'LockedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** Reason that the conversation was locked (optional). */
    lockReason?: Maybe<LockReason>;
    /** Object that was locked. */
    lockable: Lockable;
};
/** A placeholder user for attribution of imported data on GitHub. */
export type Mannequin = Actor & Node & UniformResourceLocatable & {
    __typename?: 'Mannequin';
    /** A URL pointing to the GitHub App's public avatar. */
    avatarUrl: Scalars['URI']['output'];
    /** The user that has claimed the data attributed to this mannequin. */
    claimant?: Maybe<User>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The mannequin's email on the source instance. */
    email?: Maybe<Scalars['String']['output']>;
    id: Scalars['ID']['output'];
    /** The username of the actor. */
    login: Scalars['String']['output'];
    /** The HTML path to this resource. */
    resourcePath: Scalars['URI']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The URL to this resource. */
    url: Scalars['URI']['output'];
};
/** A placeholder user for attribution of imported data on GitHub. */
export type MannequinAvatarUrlArgs = {
    size?: InputMaybe<Scalars['Int']['input']>;
};
/** Autogenerated input type of MarkDiscussionCommentAsAnswer */
export type MarkDiscussionCommentAsAnswerInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the discussion comment to mark as an answer. */
    id: Scalars['ID']['input'];
};
/** Autogenerated return type of MarkDiscussionCommentAsAnswer */
export type MarkDiscussionCommentAsAnswerPayload = {
    __typename?: 'MarkDiscussionCommentAsAnswerPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The discussion that includes the chosen comment. */
    discussion?: Maybe<Discussion>;
};
/** Autogenerated input type of MarkFileAsViewed */
export type MarkFileAsViewedInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The path of the file to mark as viewed */
    path: Scalars['String']['input'];
    /** The Node ID of the pull request. */
    pullRequestId: Scalars['ID']['input'];
};
/** Autogenerated return type of MarkFileAsViewed */
export type MarkFileAsViewedPayload = {
    __typename?: 'MarkFileAsViewedPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated pull request. */
    pullRequest?: Maybe<PullRequest>;
};
/** Autogenerated input type of MarkPullRequestReadyForReview */
export type MarkPullRequestReadyForReviewInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** ID of the pull request to be marked as ready for review. */
    pullRequestId: Scalars['ID']['input'];
};
/** Autogenerated return type of MarkPullRequestReadyForReview */
export type MarkPullRequestReadyForReviewPayload = {
    __typename?: 'MarkPullRequestReadyForReviewPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The pull request that is ready for review. */
    pullRequest?: Maybe<PullRequest>;
};
/** Represents a 'marked_as_duplicate' event on a given issue or pull request. */
export type MarkedAsDuplicateEvent = Node & {
    __typename?: 'MarkedAsDuplicateEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** The authoritative issue or pull request which has been duplicated by another. */
    canonical?: Maybe<IssueOrPullRequest>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The issue or pull request which has been marked as a duplicate of another. */
    duplicate?: Maybe<IssueOrPullRequest>;
    id: Scalars['ID']['output'];
    /** Canonical and duplicate belong to different repositories. */
    isCrossRepository: Scalars['Boolean']['output'];
};
/** Entities that have members who can set status messages. */
export type MemberStatusable = {
    /** Get the status messages members of this entity have set that are either public or visible only to the organization. */
    memberStatuses: UserStatusConnection;
};
/** Entities that have members who can set status messages. */
export type MemberStatusableMemberStatusesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<UserStatusOrder>;
};
/** Audit log entry for a members_can_delete_repos.clear event. */
export type MembersCanDeleteReposClearAuditEntry = AuditEntry & EnterpriseAuditEntryData & Node & OrganizationAuditEntryData & {
    __typename?: 'MembersCanDeleteReposClearAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    /** The HTTP path for this enterprise. */
    enterpriseResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The slug of the enterprise. */
    enterpriseSlug?: Maybe<Scalars['String']['output']>;
    /** The HTTP URL for this enterprise. */
    enterpriseUrl?: Maybe<Scalars['URI']['output']>;
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a members_can_delete_repos.disable event. */
export type MembersCanDeleteReposDisableAuditEntry = AuditEntry & EnterpriseAuditEntryData & Node & OrganizationAuditEntryData & {
    __typename?: 'MembersCanDeleteReposDisableAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    /** The HTTP path for this enterprise. */
    enterpriseResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The slug of the enterprise. */
    enterpriseSlug?: Maybe<Scalars['String']['output']>;
    /** The HTTP URL for this enterprise. */
    enterpriseUrl?: Maybe<Scalars['URI']['output']>;
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a members_can_delete_repos.enable event. */
export type MembersCanDeleteReposEnableAuditEntry = AuditEntry & EnterpriseAuditEntryData & Node & OrganizationAuditEntryData & {
    __typename?: 'MembersCanDeleteReposEnableAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    /** The HTTP path for this enterprise. */
    enterpriseResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The slug of the enterprise. */
    enterpriseSlug?: Maybe<Scalars['String']['output']>;
    /** The HTTP URL for this enterprise. */
    enterpriseUrl?: Maybe<Scalars['URI']['output']>;
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Represents a 'mentioned' event on a given issue or pull request. */
export type MentionedEvent = Node & {
    __typename?: 'MentionedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
};
/** Autogenerated input type of MergeBranch */
export type MergeBranchInput = {
    /** The name of the base branch that the provided head will be merged into. */
    base: Scalars['String']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** Message to use for the merge commit. If omitted, a default will be used. */
    commitMessage?: InputMaybe<Scalars['String']['input']>;
    /** The head to merge into the base branch. This can be a branch name or a commit GitObjectID. */
    head: Scalars['String']['input'];
    /** The Node ID of the Repository containing the base branch that will be modified. */
    repositoryId: Scalars['ID']['input'];
};
/** Autogenerated return type of MergeBranch */
export type MergeBranchPayload = {
    __typename?: 'MergeBranchPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The resulting merge Commit. */
    mergeCommit?: Maybe<Commit>;
};
/** Autogenerated input type of MergePullRequest */
export type MergePullRequestInput = {
    /** The email address to associate with this merge. */
    authorEmail?: InputMaybe<Scalars['String']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** Commit body to use for the merge commit; if omitted, a default message will be used */
    commitBody?: InputMaybe<Scalars['String']['input']>;
    /** Commit headline to use for the merge commit; if omitted, a default message will be used. */
    commitHeadline?: InputMaybe<Scalars['String']['input']>;
    /** OID that the pull request head ref must match to allow merge; if omitted, no check is performed. */
    expectedHeadOid?: InputMaybe<Scalars['GitObjectID']['input']>;
    /** The merge method to use. If omitted, defaults to 'MERGE' */
    mergeMethod?: InputMaybe<PullRequestMergeMethod>;
    /** ID of the pull request to be merged. */
    pullRequestId: Scalars['ID']['input'];
};
/** Autogenerated return type of MergePullRequest */
export type MergePullRequestPayload = {
    __typename?: 'MergePullRequestPayload';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The pull request that was merged. */
    pullRequest?: Maybe<PullRequest>;
};
/** Detailed status information about a pull request merge. */
export declare enum MergeStateStatus {
    /** The head ref is out of date. */
    Behind = "BEHIND",
    /** The merge is blocked. */
    Blocked = "BLOCKED",
    /** Mergeable and passing commit status. */
    Clean = "CLEAN",
    /** The merge commit cannot be cleanly created. */
    Dirty = "DIRTY",
    /**
     * The merge is blocked due to the pull request being a draft.
     * @deprecated DRAFT state will be removed from this enum and `isDraft` should be used instead Use PullRequest.isDraft instead. Removal on 2021-01-01 UTC.
     */
    Draft = "DRAFT",
    /** Mergeable with passing commit status and pre-receive hooks. */
    HasHooks = "HAS_HOOKS",
    /** The state cannot currently be determined. */
    Unknown = "UNKNOWN",
    /** Mergeable with non-passing commit status. */
    Unstable = "UNSTABLE"
}
/** Whether or not a PullRequest can be merged. */
export declare enum MergeableState {
    /** The pull request cannot be merged due to merge conflicts. */
    Conflicting = "CONFLICTING",
    /** The pull request can be merged. */
    Mergeable = "MERGEABLE",
    /** The mergeability of the pull request is still being calculated. */
    Unknown = "UNKNOWN"
}
/** Represents a 'merged' event on a given pull request. */
export type MergedEvent = Node & UniformResourceLocatable & {
    __typename?: 'MergedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the commit associated with the `merge` event. */
    commit?: Maybe<Commit>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** Identifies the Ref associated with the `merge` event. */
    mergeRef?: Maybe<Ref>;
    /** Identifies the name of the Ref associated with the `merge` event. */
    mergeRefName: Scalars['String']['output'];
    /** PullRequest referenced by event. */
    pullRequest: PullRequest;
    /** The HTTP path for this merged event. */
    resourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this merged event. */
    url: Scalars['URI']['output'];
};
/** Represents a Milestone object on a given repository. */
export type Milestone = Closable & Node & UniformResourceLocatable & {
    __typename?: 'Milestone';
    /** `true` if the object is closed (definition of closed may depend on type) */
    closed: Scalars['Boolean']['output'];
    /** Identifies the date and time when the object was closed. */
    closedAt?: Maybe<Scalars['DateTime']['output']>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the actor who created the milestone. */
    creator?: Maybe<Actor>;
    /** Identifies the description of the milestone. */
    description?: Maybe<Scalars['String']['output']>;
    /** Identifies the due date of the milestone. */
    dueOn?: Maybe<Scalars['DateTime']['output']>;
    id: Scalars['ID']['output'];
    /** A list of issues associated with the milestone. */
    issues: IssueConnection;
    /** Identifies the number of the milestone. */
    number: Scalars['Int']['output'];
    /** Identifies the percentage complete for the milestone */
    progressPercentage: Scalars['Float']['output'];
    /** A list of pull requests associated with the milestone. */
    pullRequests: PullRequestConnection;
    /** The repository associated with this milestone. */
    repository: Repository;
    /** The HTTP path for this milestone */
    resourcePath: Scalars['URI']['output'];
    /** Identifies the state of the milestone. */
    state: MilestoneState;
    /** Identifies the title of the milestone. */
    title: Scalars['String']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this milestone */
    url: Scalars['URI']['output'];
};
/** Represents a Milestone object on a given repository. */
export type MilestoneIssuesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    filterBy?: InputMaybe<IssueFilters>;
    first?: InputMaybe<Scalars['Int']['input']>;
    labels?: InputMaybe<Array<Scalars['String']['input']>>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<IssueOrder>;
    states?: InputMaybe<Array<IssueState>>;
};
/** Represents a Milestone object on a given repository. */
export type MilestonePullRequestsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    baseRefName?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    headRefName?: InputMaybe<Scalars['String']['input']>;
    labels?: InputMaybe<Array<Scalars['String']['input']>>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<IssueOrder>;
    states?: InputMaybe<Array<PullRequestState>>;
};
/** The connection type for Milestone. */
export type MilestoneConnection = {
    __typename?: 'MilestoneConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<MilestoneEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Milestone>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type MilestoneEdge = {
    __typename?: 'MilestoneEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Milestone>;
};
/** Types that can be inside a Milestone. */
export type MilestoneItem = Issue | PullRequest;
/** Ordering options for milestone connections. */
export type MilestoneOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order milestones by. */
    field: MilestoneOrderField;
};
/** Properties by which milestone connections can be ordered. */
export declare enum MilestoneOrderField {
    /** Order milestones by when they were created. */
    CreatedAt = "CREATED_AT",
    /** Order milestones by when they are due. */
    DueDate = "DUE_DATE",
    /** Order milestones by their number. */
    Number = "NUMBER",
    /** Order milestones by when they were last updated. */
    UpdatedAt = "UPDATED_AT"
}
/** The possible states of a milestone. */
export declare enum MilestoneState {
    /** A milestone that has been closed. */
    Closed = "CLOSED",
    /** A milestone that is still open. */
    Open = "OPEN"
}
/** Represents a 'milestoned' event on a given issue or pull request. */
export type MilestonedEvent = Node & {
    __typename?: 'MilestonedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** Identifies the milestone title associated with the 'milestoned' event. */
    milestoneTitle: Scalars['String']['output'];
    /** Object referenced by event. */
    subject: MilestoneItem;
};
/** Entities that can be minimized. */
export type Minimizable = {
    /** Returns whether or not a comment has been minimized. */
    isMinimized: Scalars['Boolean']['output'];
    /** Returns why the comment was minimized. */
    minimizedReason?: Maybe<Scalars['String']['output']>;
    /** Check if the current viewer can minimize this object. */
    viewerCanMinimize: Scalars['Boolean']['output'];
};
/** Autogenerated input type of MinimizeComment */
export type MinimizeCommentInput = {
    /** The classification of comment */
    classifier: ReportedContentClassifiers;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the subject to modify. */
    subjectId: Scalars['ID']['input'];
};
/** Autogenerated return type of MinimizeComment */
export type MinimizeCommentPayload = {
    __typename?: 'MinimizeCommentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The comment that was minimized. */
    minimizedComment?: Maybe<Minimizable>;
};
/** Autogenerated input type of MoveProjectCard */
export type MoveProjectCardInput = {
    /** Place the new card after the card with this id. Pass null to place it at the top. */
    afterCardId?: InputMaybe<Scalars['ID']['input']>;
    /** The id of the card to move. */
    cardId: Scalars['ID']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The id of the column to move it into. */
    columnId: Scalars['ID']['input'];
};
/** Autogenerated return type of MoveProjectCard */
export type MoveProjectCardPayload = {
    __typename?: 'MoveProjectCardPayload';
    /** The new edge of the moved card. */
    cardEdge?: Maybe<ProjectCardEdge>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of MoveProjectColumn */
export type MoveProjectColumnInput = {
    /** Place the new column after the column with this id. Pass null to place it at the front. */
    afterColumnId?: InputMaybe<Scalars['ID']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The id of the column to move. */
    columnId: Scalars['ID']['input'];
};
/** Autogenerated return type of MoveProjectColumn */
export type MoveProjectColumnPayload = {
    __typename?: 'MoveProjectColumnPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The new edge of the moved column. */
    columnEdge?: Maybe<ProjectColumnEdge>;
};
/** Represents a 'moved_columns_in_project' event on a given issue or pull request. */
export type MovedColumnsInProjectEvent = Node & {
    __typename?: 'MovedColumnsInProjectEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** Column name the issue or pull request was moved from. */
    previousProjectColumnName: Scalars['String']['output'];
    /** Project referenced by event. */
    project?: Maybe<Project>;
    /** Project card referenced by this project event. */
    projectCard?: Maybe<ProjectCard>;
    /** Column name the issue or pull request was moved to. */
    projectColumnName: Scalars['String']['output'];
};
/** The root query for implementing GraphQL mutations. */
export type Mutation = {
    __typename?: 'Mutation';
    /** Adds assignees to an assignable object. */
    addAssigneesToAssignable?: Maybe<AddAssigneesToAssignablePayload>;
    /** Adds a comment to an Issue or Pull Request. */
    addComment?: Maybe<AddCommentPayload>;
    /** Adds a comment to a Discussion, possibly as a reply to another comment. */
    addDiscussionComment?: Maybe<AddDiscussionCommentPayload>;
    /** Adds an administrator to the global enterprise account. */
    addEnterpriseAdmin?: Maybe<AddEnterpriseAdminPayload>;
    /** Adds labels to a labelable object. */
    addLabelsToLabelable?: Maybe<AddLabelsToLabelablePayload>;
    /** Adds a card to a ProjectColumn. Either `contentId` or `note` must be provided but **not** both. */
    addProjectCard?: Maybe<AddProjectCardPayload>;
    /** Adds a column to a Project. */
    addProjectColumn?: Maybe<AddProjectColumnPayload>;
    /** Adds a review to a Pull Request. */
    addPullRequestReview?: Maybe<AddPullRequestReviewPayload>;
    /** Adds a comment to a review. */
    addPullRequestReviewComment?: Maybe<AddPullRequestReviewCommentPayload>;
    /** Adds a new thread to a pending Pull Request Review. */
    addPullRequestReviewThread?: Maybe<AddPullRequestReviewThreadPayload>;
    /** Adds a reaction to a subject. */
    addReaction?: Maybe<AddReactionPayload>;
    /** Adds a star to a Starrable. */
    addStar?: Maybe<AddStarPayload>;
    /** Add an upvote to a discussion or discussion comment. */
    addUpvote?: Maybe<AddUpvotePayload>;
    /** Adds a verifiable domain to an owning account. */
    addVerifiableDomain?: Maybe<AddVerifiableDomainPayload>;
    /** Approve all pending deployments under one or more environments */
    approveDeployments?: Maybe<ApproveDeploymentsPayload>;
    /** Approve a verifiable domain for notification delivery. */
    approveVerifiableDomain?: Maybe<ApproveVerifiableDomainPayload>;
    /** Marks a repository as archived. */
    archiveRepository?: Maybe<ArchiveRepositoryPayload>;
    /** Update your status on GitHub. */
    changeUserStatus?: Maybe<ChangeUserStatusPayload>;
    /** Clears all labels from a labelable object. */
    clearLabelsFromLabelable?: Maybe<ClearLabelsFromLabelablePayload>;
    /** Creates a new project by cloning configuration from an existing project. */
    cloneProject?: Maybe<CloneProjectPayload>;
    /** Create a new repository with the same files and directory structure as a template repository. */
    cloneTemplateRepository?: Maybe<CloneTemplateRepositoryPayload>;
    /** Close an issue. */
    closeIssue?: Maybe<CloseIssuePayload>;
    /** Close a pull request. */
    closePullRequest?: Maybe<ClosePullRequestPayload>;
    /** Convert a project note card to one associated with a newly created issue. */
    convertProjectCardNoteToIssue?: Maybe<ConvertProjectCardNoteToIssuePayload>;
    /** Converts a pull request to draft */
    convertPullRequestToDraft?: Maybe<ConvertPullRequestToDraftPayload>;
    /** Create a new branch protection rule */
    createBranchProtectionRule?: Maybe<CreateBranchProtectionRulePayload>;
    /** Create a check run. */
    createCheckRun?: Maybe<CreateCheckRunPayload>;
    /** Create a check suite */
    createCheckSuite?: Maybe<CreateCheckSuitePayload>;
    /** Create a content attachment. */
    createContentAttachment?: Maybe<CreateContentAttachmentPayload>;
    /** Creates a new deployment event. */
    createDeployment?: Maybe<CreateDeploymentPayload>;
    /** Create a deployment status. */
    createDeploymentStatus?: Maybe<CreateDeploymentStatusPayload>;
    /** Create a discussion. */
    createDiscussion?: Maybe<CreateDiscussionPayload>;
    /** Creates an organization as part of an enterprise account. */
    createEnterpriseOrganization?: Maybe<CreateEnterpriseOrganizationPayload>;
    /** Creates an environment or simply returns it if already exists. */
    createEnvironment?: Maybe<CreateEnvironmentPayload>;
    /** Creates a new IP allow list entry. */
    createIpAllowListEntry?: Maybe<CreateIpAllowListEntryPayload>;
    /** Creates a new issue. */
    createIssue?: Maybe<CreateIssuePayload>;
    /** Creates a new label. */
    createLabel?: Maybe<CreateLabelPayload>;
    /** Creates a new project. */
    createProject?: Maybe<CreateProjectPayload>;
    /** Create a new pull request */
    createPullRequest?: Maybe<CreatePullRequestPayload>;
    /** Create a new Git Ref. */
    createRef?: Maybe<CreateRefPayload>;
    /** Create a new repository. */
    createRepository?: Maybe<CreateRepositoryPayload>;
    /** Creates a new team discussion. */
    createTeamDiscussion?: Maybe<CreateTeamDiscussionPayload>;
    /** Creates a new team discussion comment. */
    createTeamDiscussionComment?: Maybe<CreateTeamDiscussionCommentPayload>;
    /** Delete a branch protection rule */
    deleteBranchProtectionRule?: Maybe<DeleteBranchProtectionRulePayload>;
    /** Deletes a deployment. */
    deleteDeployment?: Maybe<DeleteDeploymentPayload>;
    /** Delete a discussion and all of its replies. */
    deleteDiscussion?: Maybe<DeleteDiscussionPayload>;
    /** Delete a discussion comment. If it has replies, wipe it instead. */
    deleteDiscussionComment?: Maybe<DeleteDiscussionCommentPayload>;
    /** Deletes an environment */
    deleteEnvironment?: Maybe<DeleteEnvironmentPayload>;
    /** Deletes an IP allow list entry. */
    deleteIpAllowListEntry?: Maybe<DeleteIpAllowListEntryPayload>;
    /** Deletes an Issue object. */
    deleteIssue?: Maybe<DeleteIssuePayload>;
    /** Deletes an IssueComment object. */
    deleteIssueComment?: Maybe<DeleteIssueCommentPayload>;
    /** Deletes a label. */
    deleteLabel?: Maybe<DeleteLabelPayload>;
    /** Delete a package version. */
    deletePackageVersion?: Maybe<DeletePackageVersionPayload>;
    /** Deletes a project. */
    deleteProject?: Maybe<DeleteProjectPayload>;
    /** Deletes a project card. */
    deleteProjectCard?: Maybe<DeleteProjectCardPayload>;
    /** Deletes a project column. */
    deleteProjectColumn?: Maybe<DeleteProjectColumnPayload>;
    /** Deletes a pull request review. */
    deletePullRequestReview?: Maybe<DeletePullRequestReviewPayload>;
    /** Deletes a pull request review comment. */
    deletePullRequestReviewComment?: Maybe<DeletePullRequestReviewCommentPayload>;
    /** Delete a Git Ref. */
    deleteRef?: Maybe<DeleteRefPayload>;
    /** Deletes a team discussion. */
    deleteTeamDiscussion?: Maybe<DeleteTeamDiscussionPayload>;
    /** Deletes a team discussion comment. */
    deleteTeamDiscussionComment?: Maybe<DeleteTeamDiscussionCommentPayload>;
    /** Deletes a verifiable domain. */
    deleteVerifiableDomain?: Maybe<DeleteVerifiableDomainPayload>;
    /** Disable auto merge on the given pull request */
    disablePullRequestAutoMerge?: Maybe<DisablePullRequestAutoMergePayload>;
    /** Dismisses an approved or rejected pull request review. */
    dismissPullRequestReview?: Maybe<DismissPullRequestReviewPayload>;
    /** Enable the default auto-merge on a pull request. */
    enablePullRequestAutoMerge?: Maybe<EnablePullRequestAutoMergePayload>;
    /** Follow a user. */
    followUser?: Maybe<FollowUserPayload>;
    /** Creates a new project by importing columns and a list of issues/PRs. */
    importProject?: Maybe<ImportProjectPayload>;
    /** Creates a repository link for a project. */
    linkRepositoryToProject?: Maybe<LinkRepositoryToProjectPayload>;
    /** Lock a lockable object */
    lockLockable?: Maybe<LockLockablePayload>;
    /** Mark a discussion comment as the chosen answer for discussions in an answerable category. */
    markDiscussionCommentAsAnswer?: Maybe<MarkDiscussionCommentAsAnswerPayload>;
    /** Mark a pull request file as viewed */
    markFileAsViewed?: Maybe<MarkFileAsViewedPayload>;
    /** Marks a pull request ready for review. */
    markPullRequestReadyForReview?: Maybe<MarkPullRequestReadyForReviewPayload>;
    /** Merge a head into a branch. */
    mergeBranch?: Maybe<MergeBranchPayload>;
    /** Merge a pull request. */
    mergePullRequest?: Maybe<MergePullRequestPayload>;
    /** Minimizes a comment on an Issue, Commit, Pull Request, or Gist */
    minimizeComment?: Maybe<MinimizeCommentPayload>;
    /** Moves a project card to another place. */
    moveProjectCard?: Maybe<MoveProjectCardPayload>;
    /** Moves a project column to another place. */
    moveProjectColumn?: Maybe<MoveProjectColumnPayload>;
    /** Pin an issue to a repository */
    pinIssue?: Maybe<PinIssuePayload>;
    /** Regenerates a verifiable domain's verification token. */
    regenerateVerifiableDomainToken?: Maybe<RegenerateVerifiableDomainTokenPayload>;
    /** Reject all pending deployments under one or more environments */
    rejectDeployments?: Maybe<RejectDeploymentsPayload>;
    /** Removes assignees from an assignable object. */
    removeAssigneesFromAssignable?: Maybe<RemoveAssigneesFromAssignablePayload>;
    /** Removes an administrator from the enterprise. */
    removeEnterpriseAdmin?: Maybe<RemoveEnterpriseAdminPayload>;
    /** Removes labels from a Labelable object. */
    removeLabelsFromLabelable?: Maybe<RemoveLabelsFromLabelablePayload>;
    /** Removes outside collaborator from all repositories in an organization. */
    removeOutsideCollaborator?: Maybe<RemoveOutsideCollaboratorPayload>;
    /** Removes a reaction from a subject. */
    removeReaction?: Maybe<RemoveReactionPayload>;
    /** Removes a star from a Starrable. */
    removeStar?: Maybe<RemoveStarPayload>;
    /** Remove an upvote to a discussion or discussion comment. */
    removeUpvote?: Maybe<RemoveUpvotePayload>;
    /** Reopen a issue. */
    reopenIssue?: Maybe<ReopenIssuePayload>;
    /** Reopen a pull request. */
    reopenPullRequest?: Maybe<ReopenPullRequestPayload>;
    /** Set review requests on a pull request. */
    requestReviews?: Maybe<RequestReviewsPayload>;
    /** Rerequests an existing check suite. */
    rerequestCheckSuite?: Maybe<RerequestCheckSuitePayload>;
    /** Marks a review thread as resolved. */
    resolveReviewThread?: Maybe<ResolveReviewThreadPayload>;
    /** Submits a pending pull request review. */
    submitPullRequestReview?: Maybe<SubmitPullRequestReviewPayload>;
    /** Transfer an issue to a different repository */
    transferIssue?: Maybe<TransferIssuePayload>;
    /** Unarchives a repository. */
    unarchiveRepository?: Maybe<UnarchiveRepositoryPayload>;
    /** Unfollow a user. */
    unfollowUser?: Maybe<UnfollowUserPayload>;
    /** Deletes a repository link from a project. */
    unlinkRepositoryFromProject?: Maybe<UnlinkRepositoryFromProjectPayload>;
    /** Unlock a lockable object */
    unlockLockable?: Maybe<UnlockLockablePayload>;
    /** Unmark a discussion comment as the chosen answer for discussions in an answerable category. */
    unmarkDiscussionCommentAsAnswer?: Maybe<UnmarkDiscussionCommentAsAnswerPayload>;
    /** Unmark a pull request file as viewed */
    unmarkFileAsViewed?: Maybe<UnmarkFileAsViewedPayload>;
    /** Unmark an issue as a duplicate of another issue. */
    unmarkIssueAsDuplicate?: Maybe<UnmarkIssueAsDuplicatePayload>;
    /** Unminimizes a comment on an Issue, Commit, Pull Request, or Gist */
    unminimizeComment?: Maybe<UnminimizeCommentPayload>;
    /** Unpin a pinned issue from a repository */
    unpinIssue?: Maybe<UnpinIssuePayload>;
    /** Marks a review thread as unresolved. */
    unresolveReviewThread?: Maybe<UnresolveReviewThreadPayload>;
    /** Create a new branch protection rule */
    updateBranchProtectionRule?: Maybe<UpdateBranchProtectionRulePayload>;
    /** Update a check run */
    updateCheckRun?: Maybe<UpdateCheckRunPayload>;
    /** Modifies the settings of an existing check suite */
    updateCheckSuitePreferences?: Maybe<UpdateCheckSuitePreferencesPayload>;
    /** Update a discussion */
    updateDiscussion?: Maybe<UpdateDiscussionPayload>;
    /** Update the contents of a comment on a Discussion */
    updateDiscussionComment?: Maybe<UpdateDiscussionCommentPayload>;
    /** Sets whether private repository forks are enabled for an enterprise. */
    updateEnterpriseAllowPrivateRepositoryForkingSetting?: Maybe<UpdateEnterpriseAllowPrivateRepositoryForkingSettingPayload>;
    /** Sets the base repository permission for organizations in an enterprise. */
    updateEnterpriseDefaultRepositoryPermissionSetting?: Maybe<UpdateEnterpriseDefaultRepositoryPermissionSettingPayload>;
    /** Sets whether organization members with admin permissions on a repository can change repository visibility. */
    updateEnterpriseMembersCanChangeRepositoryVisibilitySetting?: Maybe<UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingPayload>;
    /** Sets the members can create repositories setting for an enterprise. */
    updateEnterpriseMembersCanCreateRepositoriesSetting?: Maybe<UpdateEnterpriseMembersCanCreateRepositoriesSettingPayload>;
    /** Sets the members can delete issues setting for an enterprise. */
    updateEnterpriseMembersCanDeleteIssuesSetting?: Maybe<UpdateEnterpriseMembersCanDeleteIssuesSettingPayload>;
    /** Sets the members can delete repositories setting for an enterprise. */
    updateEnterpriseMembersCanDeleteRepositoriesSetting?: Maybe<UpdateEnterpriseMembersCanDeleteRepositoriesSettingPayload>;
    /** Sets whether members can invite collaborators are enabled for an enterprise. */
    updateEnterpriseMembersCanInviteCollaboratorsSetting?: Maybe<UpdateEnterpriseMembersCanInviteCollaboratorsSettingPayload>;
    /** Sets whether or not an organization admin can make purchases. */
    updateEnterpriseMembersCanMakePurchasesSetting?: Maybe<UpdateEnterpriseMembersCanMakePurchasesSettingPayload>;
    /** Sets the members can update protected branches setting for an enterprise. */
    updateEnterpriseMembersCanUpdateProtectedBranchesSetting?: Maybe<UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingPayload>;
    /** Sets the members can view dependency insights for an enterprise. */
    updateEnterpriseMembersCanViewDependencyInsightsSetting?: Maybe<UpdateEnterpriseMembersCanViewDependencyInsightsSettingPayload>;
    /** Sets whether organization projects are enabled for an enterprise. */
    updateEnterpriseOrganizationProjectsSetting?: Maybe<UpdateEnterpriseOrganizationProjectsSettingPayload>;
    /** Updates an enterprise's profile. */
    updateEnterpriseProfile?: Maybe<UpdateEnterpriseProfilePayload>;
    /** Sets whether repository projects are enabled for a enterprise. */
    updateEnterpriseRepositoryProjectsSetting?: Maybe<UpdateEnterpriseRepositoryProjectsSettingPayload>;
    /** Sets whether team discussions are enabled for an enterprise. */
    updateEnterpriseTeamDiscussionsSetting?: Maybe<UpdateEnterpriseTeamDiscussionsSettingPayload>;
    /** Sets whether two factor authentication is required for all users in an enterprise. */
    updateEnterpriseTwoFactorAuthenticationRequiredSetting?: Maybe<UpdateEnterpriseTwoFactorAuthenticationRequiredSettingPayload>;
    /** Updates an environment. */
    updateEnvironment?: Maybe<UpdateEnvironmentPayload>;
    /** Sets whether an IP allow list is enabled on an owner. */
    updateIpAllowListEnabledSetting?: Maybe<UpdateIpAllowListEnabledSettingPayload>;
    /** Updates an IP allow list entry. */
    updateIpAllowListEntry?: Maybe<UpdateIpAllowListEntryPayload>;
    /** Sets whether IP allow list configuration for installed GitHub Apps is enabled on an owner. */
    updateIpAllowListForInstalledAppsEnabledSetting?: Maybe<UpdateIpAllowListForInstalledAppsEnabledSettingPayload>;
    /** Updates an Issue. */
    updateIssue?: Maybe<UpdateIssuePayload>;
    /** Updates an IssueComment object. */
    updateIssueComment?: Maybe<UpdateIssueCommentPayload>;
    /** Updates an existing label. */
    updateLabel?: Maybe<UpdateLabelPayload>;
    /** Update the setting to restrict notifications to only verified or approved domains available to an owner. */
    updateNotificationRestrictionSetting?: Maybe<UpdateNotificationRestrictionSettingPayload>;
    /** Updates an existing project. */
    updateProject?: Maybe<UpdateProjectPayload>;
    /** Updates an existing project card. */
    updateProjectCard?: Maybe<UpdateProjectCardPayload>;
    /** Updates an existing project column. */
    updateProjectColumn?: Maybe<UpdateProjectColumnPayload>;
    /** Update a pull request */
    updatePullRequest?: Maybe<UpdatePullRequestPayload>;
    /** Updates the body of a pull request review. */
    updatePullRequestReview?: Maybe<UpdatePullRequestReviewPayload>;
    /** Updates a pull request review comment. */
    updatePullRequestReviewComment?: Maybe<UpdatePullRequestReviewCommentPayload>;
    /** Update a Git Ref. */
    updateRef?: Maybe<UpdateRefPayload>;
    /**
     * Creates, updates and/or deletes multiple refs in a repository.
     *
     * This mutation takes a list of `RefUpdate`s and performs these updates
     * on the repository. All updates are performed atomically, meaning that
     * if one of them is rejected, no other ref will be modified.
     *
     * `RefUpdate.beforeOid` specifies that the given reference needs to point
     * to the given value before performing any updates. A value of
     * `0000000000000000000000000000000000000000` can be used to verify that
     * the references should not exist.
     *
     * `RefUpdate.afterOid` specifies the value that the given reference
     * will point to after performing all updates. A value of
     * `0000000000000000000000000000000000000000` can be used to delete a
     * reference.
     *
     * If `RefUpdate.force` is set to `true`, a non-fast-forward updates
     * for the given reference will be allowed.
     */
    updateRefs?: Maybe<UpdateRefsPayload>;
    /** Update information about a repository. */
    updateRepository?: Maybe<UpdateRepositoryPayload>;
    /** Updates the state for subscribable subjects. */
    updateSubscription?: Maybe<UpdateSubscriptionPayload>;
    /** Updates a team discussion. */
    updateTeamDiscussion?: Maybe<UpdateTeamDiscussionPayload>;
    /** Updates a discussion comment. */
    updateTeamDiscussionComment?: Maybe<UpdateTeamDiscussionCommentPayload>;
    /** Updates team review assignment. */
    updateTeamReviewAssignment?: Maybe<UpdateTeamReviewAssignmentPayload>;
    /** Replaces the repository's topics with the given topics. */
    updateTopics?: Maybe<UpdateTopicsPayload>;
    /** Verify that a verifiable domain has the expected DNS record. */
    verifyVerifiableDomain?: Maybe<VerifyVerifiableDomainPayload>;
};
/** The root query for implementing GraphQL mutations. */
export type MutationAddAssigneesToAssignableArgs = {
    input: AddAssigneesToAssignableInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationAddCommentArgs = {
    input: AddCommentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationAddDiscussionCommentArgs = {
    input: AddDiscussionCommentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationAddEnterpriseAdminArgs = {
    input: AddEnterpriseAdminInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationAddLabelsToLabelableArgs = {
    input: AddLabelsToLabelableInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationAddProjectCardArgs = {
    input: AddProjectCardInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationAddProjectColumnArgs = {
    input: AddProjectColumnInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationAddPullRequestReviewArgs = {
    input: AddPullRequestReviewInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationAddPullRequestReviewCommentArgs = {
    input: AddPullRequestReviewCommentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationAddPullRequestReviewThreadArgs = {
    input: AddPullRequestReviewThreadInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationAddReactionArgs = {
    input: AddReactionInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationAddStarArgs = {
    input: AddStarInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationAddUpvoteArgs = {
    input: AddUpvoteInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationAddVerifiableDomainArgs = {
    input: AddVerifiableDomainInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationApproveDeploymentsArgs = {
    input: ApproveDeploymentsInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationApproveVerifiableDomainArgs = {
    input: ApproveVerifiableDomainInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationArchiveRepositoryArgs = {
    input: ArchiveRepositoryInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationChangeUserStatusArgs = {
    input: ChangeUserStatusInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationClearLabelsFromLabelableArgs = {
    input: ClearLabelsFromLabelableInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCloneProjectArgs = {
    input: CloneProjectInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCloneTemplateRepositoryArgs = {
    input: CloneTemplateRepositoryInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCloseIssueArgs = {
    input: CloseIssueInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationClosePullRequestArgs = {
    input: ClosePullRequestInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationConvertProjectCardNoteToIssueArgs = {
    input: ConvertProjectCardNoteToIssueInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationConvertPullRequestToDraftArgs = {
    input: ConvertPullRequestToDraftInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreateBranchProtectionRuleArgs = {
    input: CreateBranchProtectionRuleInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreateCheckRunArgs = {
    input: CreateCheckRunInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreateCheckSuiteArgs = {
    input: CreateCheckSuiteInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreateContentAttachmentArgs = {
    input: CreateContentAttachmentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreateDeploymentArgs = {
    input: CreateDeploymentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreateDeploymentStatusArgs = {
    input: CreateDeploymentStatusInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreateDiscussionArgs = {
    input: CreateDiscussionInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreateEnterpriseOrganizationArgs = {
    input: CreateEnterpriseOrganizationInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreateEnvironmentArgs = {
    input: CreateEnvironmentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreateIpAllowListEntryArgs = {
    input: CreateIpAllowListEntryInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreateIssueArgs = {
    input: CreateIssueInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreateLabelArgs = {
    input: CreateLabelInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreateProjectArgs = {
    input: CreateProjectInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreatePullRequestArgs = {
    input: CreatePullRequestInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreateRefArgs = {
    input: CreateRefInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreateRepositoryArgs = {
    input: CreateRepositoryInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreateTeamDiscussionArgs = {
    input: CreateTeamDiscussionInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationCreateTeamDiscussionCommentArgs = {
    input: CreateTeamDiscussionCommentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeleteBranchProtectionRuleArgs = {
    input: DeleteBranchProtectionRuleInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeleteDeploymentArgs = {
    input: DeleteDeploymentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeleteDiscussionArgs = {
    input: DeleteDiscussionInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeleteDiscussionCommentArgs = {
    input: DeleteDiscussionCommentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeleteEnvironmentArgs = {
    input: DeleteEnvironmentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeleteIpAllowListEntryArgs = {
    input: DeleteIpAllowListEntryInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeleteIssueArgs = {
    input: DeleteIssueInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeleteIssueCommentArgs = {
    input: DeleteIssueCommentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeleteLabelArgs = {
    input: DeleteLabelInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeletePackageVersionArgs = {
    input: DeletePackageVersionInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeleteProjectArgs = {
    input: DeleteProjectInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeleteProjectCardArgs = {
    input: DeleteProjectCardInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeleteProjectColumnArgs = {
    input: DeleteProjectColumnInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeletePullRequestReviewArgs = {
    input: DeletePullRequestReviewInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeletePullRequestReviewCommentArgs = {
    input: DeletePullRequestReviewCommentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeleteRefArgs = {
    input: DeleteRefInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeleteTeamDiscussionArgs = {
    input: DeleteTeamDiscussionInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeleteTeamDiscussionCommentArgs = {
    input: DeleteTeamDiscussionCommentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDeleteVerifiableDomainArgs = {
    input: DeleteVerifiableDomainInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDisablePullRequestAutoMergeArgs = {
    input: DisablePullRequestAutoMergeInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationDismissPullRequestReviewArgs = {
    input: DismissPullRequestReviewInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationEnablePullRequestAutoMergeArgs = {
    input: EnablePullRequestAutoMergeInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationFollowUserArgs = {
    input: FollowUserInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationImportProjectArgs = {
    input: ImportProjectInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationLinkRepositoryToProjectArgs = {
    input: LinkRepositoryToProjectInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationLockLockableArgs = {
    input: LockLockableInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationMarkDiscussionCommentAsAnswerArgs = {
    input: MarkDiscussionCommentAsAnswerInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationMarkFileAsViewedArgs = {
    input: MarkFileAsViewedInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationMarkPullRequestReadyForReviewArgs = {
    input: MarkPullRequestReadyForReviewInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationMergeBranchArgs = {
    input: MergeBranchInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationMergePullRequestArgs = {
    input: MergePullRequestInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationMinimizeCommentArgs = {
    input: MinimizeCommentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationMoveProjectCardArgs = {
    input: MoveProjectCardInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationMoveProjectColumnArgs = {
    input: MoveProjectColumnInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationPinIssueArgs = {
    input: PinIssueInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationRegenerateVerifiableDomainTokenArgs = {
    input: RegenerateVerifiableDomainTokenInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationRejectDeploymentsArgs = {
    input: RejectDeploymentsInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationRemoveAssigneesFromAssignableArgs = {
    input: RemoveAssigneesFromAssignableInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationRemoveEnterpriseAdminArgs = {
    input: RemoveEnterpriseAdminInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationRemoveLabelsFromLabelableArgs = {
    input: RemoveLabelsFromLabelableInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationRemoveOutsideCollaboratorArgs = {
    input: RemoveOutsideCollaboratorInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationRemoveReactionArgs = {
    input: RemoveReactionInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationRemoveStarArgs = {
    input: RemoveStarInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationRemoveUpvoteArgs = {
    input: RemoveUpvoteInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationReopenIssueArgs = {
    input: ReopenIssueInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationReopenPullRequestArgs = {
    input: ReopenPullRequestInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationRequestReviewsArgs = {
    input: RequestReviewsInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationRerequestCheckSuiteArgs = {
    input: RerequestCheckSuiteInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationResolveReviewThreadArgs = {
    input: ResolveReviewThreadInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationSubmitPullRequestReviewArgs = {
    input: SubmitPullRequestReviewInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationTransferIssueArgs = {
    input: TransferIssueInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUnarchiveRepositoryArgs = {
    input: UnarchiveRepositoryInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUnfollowUserArgs = {
    input: UnfollowUserInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUnlinkRepositoryFromProjectArgs = {
    input: UnlinkRepositoryFromProjectInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUnlockLockableArgs = {
    input: UnlockLockableInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUnmarkDiscussionCommentAsAnswerArgs = {
    input: UnmarkDiscussionCommentAsAnswerInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUnmarkFileAsViewedArgs = {
    input: UnmarkFileAsViewedInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUnmarkIssueAsDuplicateArgs = {
    input: UnmarkIssueAsDuplicateInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUnminimizeCommentArgs = {
    input: UnminimizeCommentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUnpinIssueArgs = {
    input: UnpinIssueInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUnresolveReviewThreadArgs = {
    input: UnresolveReviewThreadInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateBranchProtectionRuleArgs = {
    input: UpdateBranchProtectionRuleInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateCheckRunArgs = {
    input: UpdateCheckRunInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateCheckSuitePreferencesArgs = {
    input: UpdateCheckSuitePreferencesInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateDiscussionArgs = {
    input: UpdateDiscussionInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateDiscussionCommentArgs = {
    input: UpdateDiscussionCommentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateEnterpriseAllowPrivateRepositoryForkingSettingArgs = {
    input: UpdateEnterpriseAllowPrivateRepositoryForkingSettingInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateEnterpriseDefaultRepositoryPermissionSettingArgs = {
    input: UpdateEnterpriseDefaultRepositoryPermissionSettingInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingArgs = {
    input: UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateEnterpriseMembersCanCreateRepositoriesSettingArgs = {
    input: UpdateEnterpriseMembersCanCreateRepositoriesSettingInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateEnterpriseMembersCanDeleteIssuesSettingArgs = {
    input: UpdateEnterpriseMembersCanDeleteIssuesSettingInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateEnterpriseMembersCanDeleteRepositoriesSettingArgs = {
    input: UpdateEnterpriseMembersCanDeleteRepositoriesSettingInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateEnterpriseMembersCanInviteCollaboratorsSettingArgs = {
    input: UpdateEnterpriseMembersCanInviteCollaboratorsSettingInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateEnterpriseMembersCanMakePurchasesSettingArgs = {
    input: UpdateEnterpriseMembersCanMakePurchasesSettingInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateEnterpriseMembersCanUpdateProtectedBranchesSettingArgs = {
    input: UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateEnterpriseMembersCanViewDependencyInsightsSettingArgs = {
    input: UpdateEnterpriseMembersCanViewDependencyInsightsSettingInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateEnterpriseOrganizationProjectsSettingArgs = {
    input: UpdateEnterpriseOrganizationProjectsSettingInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateEnterpriseProfileArgs = {
    input: UpdateEnterpriseProfileInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateEnterpriseRepositoryProjectsSettingArgs = {
    input: UpdateEnterpriseRepositoryProjectsSettingInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateEnterpriseTeamDiscussionsSettingArgs = {
    input: UpdateEnterpriseTeamDiscussionsSettingInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateEnterpriseTwoFactorAuthenticationRequiredSettingArgs = {
    input: UpdateEnterpriseTwoFactorAuthenticationRequiredSettingInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateEnvironmentArgs = {
    input: UpdateEnvironmentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateIpAllowListEnabledSettingArgs = {
    input: UpdateIpAllowListEnabledSettingInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateIpAllowListEntryArgs = {
    input: UpdateIpAllowListEntryInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateIpAllowListForInstalledAppsEnabledSettingArgs = {
    input: UpdateIpAllowListForInstalledAppsEnabledSettingInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateIssueArgs = {
    input: UpdateIssueInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateIssueCommentArgs = {
    input: UpdateIssueCommentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateLabelArgs = {
    input: UpdateLabelInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateNotificationRestrictionSettingArgs = {
    input: UpdateNotificationRestrictionSettingInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateProjectArgs = {
    input: UpdateProjectInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateProjectCardArgs = {
    input: UpdateProjectCardInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateProjectColumnArgs = {
    input: UpdateProjectColumnInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdatePullRequestArgs = {
    input: UpdatePullRequestInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdatePullRequestReviewArgs = {
    input: UpdatePullRequestReviewInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdatePullRequestReviewCommentArgs = {
    input: UpdatePullRequestReviewCommentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateRefArgs = {
    input: UpdateRefInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateRefsArgs = {
    input: UpdateRefsInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateRepositoryArgs = {
    input: UpdateRepositoryInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateSubscriptionArgs = {
    input: UpdateSubscriptionInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateTeamDiscussionArgs = {
    input: UpdateTeamDiscussionInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateTeamDiscussionCommentArgs = {
    input: UpdateTeamDiscussionCommentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateTeamReviewAssignmentArgs = {
    input: UpdateTeamReviewAssignmentInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationUpdateTopicsArgs = {
    input: UpdateTopicsInput;
};
/** The root query for implementing GraphQL mutations. */
export type MutationVerifyVerifiableDomainArgs = {
    input: VerifyVerifiableDomainInput;
};
/** An object with an ID. */
export type Node = {
    /** ID of the object. */
    id: Scalars['ID']['output'];
};
/** The possible values for the notification restriction setting. */
export declare enum NotificationRestrictionSettingValue {
    /** The setting is disabled for the owner. */
    Disabled = "DISABLED",
    /** The setting is enabled for the owner. */
    Enabled = "ENABLED"
}
/** Metadata for an audit entry with action oauth_application.* */
export type OauthApplicationAuditEntryData = {
    /** The name of the OAuth Application. */
    oauthApplicationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the OAuth Application */
    oauthApplicationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the OAuth Application */
    oauthApplicationUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a oauth_application.create event. */
export type OauthApplicationCreateAuditEntry = AuditEntry & Node & OauthApplicationAuditEntryData & OrganizationAuditEntryData & {
    __typename?: 'OauthApplicationCreateAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The application URL of the OAuth Application. */
    applicationUrl?: Maybe<Scalars['URI']['output']>;
    /** The callback URL of the OAuth Application. */
    callbackUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The name of the OAuth Application. */
    oauthApplicationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the OAuth Application */
    oauthApplicationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the OAuth Application */
    oauthApplicationUrl?: Maybe<Scalars['URI']['output']>;
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The rate limit of the OAuth Application. */
    rateLimit?: Maybe<Scalars['Int']['output']>;
    /** The state of the OAuth Application. */
    state?: Maybe<OauthApplicationCreateAuditEntryState>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** The state of an OAuth Application when it was created. */
export declare enum OauthApplicationCreateAuditEntryState {
    /** The OAuth Application was active and allowed to have OAuth Accesses. */
    Active = "ACTIVE",
    /** The OAuth Application was in the process of being deleted. */
    PendingDeletion = "PENDING_DELETION",
    /** The OAuth Application was suspended from generating OAuth Accesses due to abuse or security concerns. */
    Suspended = "SUSPENDED"
}
/** The corresponding operation type for the action */
export declare enum OperationType {
    /** An existing resource was accessed */
    Access = "ACCESS",
    /** A resource performed an authentication event */
    Authentication = "AUTHENTICATION",
    /** A new resource was created */
    Create = "CREATE",
    /** An existing resource was modified */
    Modify = "MODIFY",
    /** An existing resource was removed */
    Remove = "REMOVE",
    /** An existing resource was restored */
    Restore = "RESTORE",
    /** An existing resource was transferred between multiple resources */
    Transfer = "TRANSFER"
}
/** Possible directions in which to order a list of items when provided an `orderBy` argument. */
export declare enum OrderDirection {
    /** Specifies an ascending order for a given `orderBy` argument. */
    Asc = "ASC",
    /** Specifies a descending order for a given `orderBy` argument. */
    Desc = "DESC"
}
/** Audit log entry for a org.add_billing_manager */
export type OrgAddBillingManagerAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgAddBillingManagerAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The email address used to invite a billing manager for the organization. */
    invitationEmail?: Maybe<Scalars['String']['output']>;
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a org.add_member */
export type OrgAddMemberAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgAddMemberAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The permission level of the member added to the organization. */
    permission?: Maybe<OrgAddMemberAuditEntryPermission>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** The permissions available to members on an Organization. */
export declare enum OrgAddMemberAuditEntryPermission {
    /** Can read, clone, push, and add collaborators to repositories. */
    Admin = "ADMIN",
    /** Can read and clone repositories. */
    Read = "READ"
}
/** Audit log entry for a org.block_user */
export type OrgBlockUserAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgBlockUserAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The blocked user. */
    blockedUser?: Maybe<User>;
    /** The username of the blocked user. */
    blockedUserName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the blocked user. */
    blockedUserResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the blocked user. */
    blockedUserUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a org.config.disable_collaborators_only event. */
export type OrgConfigDisableCollaboratorsOnlyAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgConfigDisableCollaboratorsOnlyAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a org.config.enable_collaborators_only event. */
export type OrgConfigEnableCollaboratorsOnlyAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgConfigEnableCollaboratorsOnlyAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a org.create event. */
export type OrgCreateAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgCreateAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The billing plan for the Organization. */
    billingPlan?: Maybe<OrgCreateAuditEntryBillingPlan>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** The billing plans available for organizations. */
export declare enum OrgCreateAuditEntryBillingPlan {
    /** Team Plan */
    Business = "BUSINESS",
    /** Enterprise Cloud Plan */
    BusinessPlus = "BUSINESS_PLUS",
    /** Free Plan */
    Free = "FREE",
    /** Tiered Per Seat Plan */
    TieredPerSeat = "TIERED_PER_SEAT",
    /** Legacy Unlimited Plan */
    Unlimited = "UNLIMITED"
}
/** Audit log entry for a org.disable_oauth_app_restrictions event. */
export type OrgDisableOauthAppRestrictionsAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgDisableOauthAppRestrictionsAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a org.disable_saml event. */
export type OrgDisableSamlAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgDisableSamlAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    /** The SAML provider's digest algorithm URL. */
    digestMethodUrl?: Maybe<Scalars['URI']['output']>;
    id: Scalars['ID']['output'];
    /** The SAML provider's issuer URL. */
    issuerUrl?: Maybe<Scalars['URI']['output']>;
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The SAML provider's signature algorithm URL. */
    signatureMethodUrl?: Maybe<Scalars['URI']['output']>;
    /** The SAML provider's single sign-on URL. */
    singleSignOnUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a org.disable_two_factor_requirement event. */
export type OrgDisableTwoFactorRequirementAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgDisableTwoFactorRequirementAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a org.enable_oauth_app_restrictions event. */
export type OrgEnableOauthAppRestrictionsAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgEnableOauthAppRestrictionsAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a org.enable_saml event. */
export type OrgEnableSamlAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgEnableSamlAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    /** The SAML provider's digest algorithm URL. */
    digestMethodUrl?: Maybe<Scalars['URI']['output']>;
    id: Scalars['ID']['output'];
    /** The SAML provider's issuer URL. */
    issuerUrl?: Maybe<Scalars['URI']['output']>;
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The SAML provider's signature algorithm URL. */
    signatureMethodUrl?: Maybe<Scalars['URI']['output']>;
    /** The SAML provider's single sign-on URL. */
    singleSignOnUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a org.enable_two_factor_requirement event. */
export type OrgEnableTwoFactorRequirementAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgEnableTwoFactorRequirementAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a org.invite_member event. */
export type OrgInviteMemberAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgInviteMemberAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    /** The email address of the organization invitation. */
    email?: Maybe<Scalars['String']['output']>;
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The organization invitation. */
    organizationInvitation?: Maybe<OrganizationInvitation>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a org.invite_to_business event. */
export type OrgInviteToBusinessAuditEntry = AuditEntry & EnterpriseAuditEntryData & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgInviteToBusinessAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    /** The HTTP path for this enterprise. */
    enterpriseResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The slug of the enterprise. */
    enterpriseSlug?: Maybe<Scalars['String']['output']>;
    /** The HTTP URL for this enterprise. */
    enterpriseUrl?: Maybe<Scalars['URI']['output']>;
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a org.oauth_app_access_approved event. */
export type OrgOauthAppAccessApprovedAuditEntry = AuditEntry & Node & OauthApplicationAuditEntryData & OrganizationAuditEntryData & {
    __typename?: 'OrgOauthAppAccessApprovedAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The name of the OAuth Application. */
    oauthApplicationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the OAuth Application */
    oauthApplicationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the OAuth Application */
    oauthApplicationUrl?: Maybe<Scalars['URI']['output']>;
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a org.oauth_app_access_denied event. */
export type OrgOauthAppAccessDeniedAuditEntry = AuditEntry & Node & OauthApplicationAuditEntryData & OrganizationAuditEntryData & {
    __typename?: 'OrgOauthAppAccessDeniedAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The name of the OAuth Application. */
    oauthApplicationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the OAuth Application */
    oauthApplicationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the OAuth Application */
    oauthApplicationUrl?: Maybe<Scalars['URI']['output']>;
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a org.oauth_app_access_requested event. */
export type OrgOauthAppAccessRequestedAuditEntry = AuditEntry & Node & OauthApplicationAuditEntryData & OrganizationAuditEntryData & {
    __typename?: 'OrgOauthAppAccessRequestedAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The name of the OAuth Application. */
    oauthApplicationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the OAuth Application */
    oauthApplicationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the OAuth Application */
    oauthApplicationUrl?: Maybe<Scalars['URI']['output']>;
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a org.remove_billing_manager event. */
export type OrgRemoveBillingManagerAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgRemoveBillingManagerAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The reason for the billing manager being removed. */
    reason?: Maybe<OrgRemoveBillingManagerAuditEntryReason>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** The reason a billing manager was removed from an Organization. */
export declare enum OrgRemoveBillingManagerAuditEntryReason {
    /** SAML external identity missing */
    SamlExternalIdentityMissing = "SAML_EXTERNAL_IDENTITY_MISSING",
    /** SAML SSO enforcement requires an external identity */
    SamlSsoEnforcementRequiresExternalIdentity = "SAML_SSO_ENFORCEMENT_REQUIRES_EXTERNAL_IDENTITY",
    /** The organization required 2FA of its billing managers and this user did not have 2FA enabled. */
    TwoFactorRequirementNonCompliance = "TWO_FACTOR_REQUIREMENT_NON_COMPLIANCE"
}
/** Audit log entry for a org.remove_member event. */
export type OrgRemoveMemberAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgRemoveMemberAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The types of membership the member has with the organization. */
    membershipTypes?: Maybe<Array<OrgRemoveMemberAuditEntryMembershipType>>;
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The reason for the member being removed. */
    reason?: Maybe<OrgRemoveMemberAuditEntryReason>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** The type of membership a user has with an Organization. */
export declare enum OrgRemoveMemberAuditEntryMembershipType {
    /**
     * Organization administrators have full access and can change several settings,
     * including the names of repositories that belong to the Organization and Owners
     * team membership. In addition, organization admins can delete the organization
     * and all of its repositories.
     */
    Admin = "ADMIN",
    /** A billing manager is a user who manages the billing settings for the Organization, such as updating payment information. */
    BillingManager = "BILLING_MANAGER",
    /** A direct member is a user that is a member of the Organization. */
    DirectMember = "DIRECT_MEMBER",
    /**
     * An outside collaborator is a person who isn't explicitly a member of the
     * Organization, but who has Read, Write, or Admin permissions to one or more
     * repositories in the organization.
     */
    OutsideCollaborator = "OUTSIDE_COLLABORATOR",
    /**
     * An unaffiliated collaborator is a person who is not a member of the
     * Organization and does not have access to any repositories in the Organization.
     */
    Unaffiliated = "UNAFFILIATED"
}
/** The reason a member was removed from an Organization. */
export declare enum OrgRemoveMemberAuditEntryReason {
    /** SAML external identity missing */
    SamlExternalIdentityMissing = "SAML_EXTERNAL_IDENTITY_MISSING",
    /** SAML SSO enforcement requires an external identity */
    SamlSsoEnforcementRequiresExternalIdentity = "SAML_SSO_ENFORCEMENT_REQUIRES_EXTERNAL_IDENTITY",
    /** User was removed from organization during account recovery */
    TwoFactorAccountRecovery = "TWO_FACTOR_ACCOUNT_RECOVERY",
    /** The organization required 2FA of its billing managers and this user did not have 2FA enabled. */
    TwoFactorRequirementNonCompliance = "TWO_FACTOR_REQUIREMENT_NON_COMPLIANCE",
    /** User account has been deleted */
    UserAccountDeleted = "USER_ACCOUNT_DELETED"
}
/** Audit log entry for a org.remove_outside_collaborator event. */
export type OrgRemoveOutsideCollaboratorAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgRemoveOutsideCollaboratorAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The types of membership the outside collaborator has with the organization. */
    membershipTypes?: Maybe<Array<OrgRemoveOutsideCollaboratorAuditEntryMembershipType>>;
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The reason for the outside collaborator being removed from the Organization. */
    reason?: Maybe<OrgRemoveOutsideCollaboratorAuditEntryReason>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** The type of membership a user has with an Organization. */
export declare enum OrgRemoveOutsideCollaboratorAuditEntryMembershipType {
    /** A billing manager is a user who manages the billing settings for the Organization, such as updating payment information. */
    BillingManager = "BILLING_MANAGER",
    /**
     * An outside collaborator is a person who isn't explicitly a member of the
     * Organization, but who has Read, Write, or Admin permissions to one or more
     * repositories in the organization.
     */
    OutsideCollaborator = "OUTSIDE_COLLABORATOR",
    /**
     * An unaffiliated collaborator is a person who is not a member of the
     * Organization and does not have access to any repositories in the organization.
     */
    Unaffiliated = "UNAFFILIATED"
}
/** The reason an outside collaborator was removed from an Organization. */
export declare enum OrgRemoveOutsideCollaboratorAuditEntryReason {
    /** SAML external identity missing */
    SamlExternalIdentityMissing = "SAML_EXTERNAL_IDENTITY_MISSING",
    /** The organization required 2FA of its billing managers and this user did not have 2FA enabled. */
    TwoFactorRequirementNonCompliance = "TWO_FACTOR_REQUIREMENT_NON_COMPLIANCE"
}
/** Audit log entry for a org.restore_member event. */
export type OrgRestoreMemberAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgRestoreMemberAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The number of custom email routings for the restored member. */
    restoredCustomEmailRoutingsCount?: Maybe<Scalars['Int']['output']>;
    /** The number of issue assignments for the restored member. */
    restoredIssueAssignmentsCount?: Maybe<Scalars['Int']['output']>;
    /** Restored organization membership objects. */
    restoredMemberships?: Maybe<Array<OrgRestoreMemberAuditEntryMembership>>;
    /** The number of restored memberships. */
    restoredMembershipsCount?: Maybe<Scalars['Int']['output']>;
    /** The number of repositories of the restored member. */
    restoredRepositoriesCount?: Maybe<Scalars['Int']['output']>;
    /** The number of starred repositories for the restored member. */
    restoredRepositoryStarsCount?: Maybe<Scalars['Int']['output']>;
    /** The number of watched repositories for the restored member. */
    restoredRepositoryWatchesCount?: Maybe<Scalars['Int']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Types of memberships that can be restored for an Organization member. */
export type OrgRestoreMemberAuditEntryMembership = OrgRestoreMemberMembershipOrganizationAuditEntryData | OrgRestoreMemberMembershipRepositoryAuditEntryData | OrgRestoreMemberMembershipTeamAuditEntryData;
/** Metadata for an organization membership for org.restore_member actions */
export type OrgRestoreMemberMembershipOrganizationAuditEntryData = OrganizationAuditEntryData & {
    __typename?: 'OrgRestoreMemberMembershipOrganizationAuditEntryData';
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
};
/** Metadata for a repository membership for org.restore_member actions */
export type OrgRestoreMemberMembershipRepositoryAuditEntryData = RepositoryAuditEntryData & {
    __typename?: 'OrgRestoreMemberMembershipRepositoryAuditEntryData';
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
};
/** Metadata for a team membership for org.restore_member actions */
export type OrgRestoreMemberMembershipTeamAuditEntryData = TeamAuditEntryData & {
    __typename?: 'OrgRestoreMemberMembershipTeamAuditEntryData';
    /** The team associated with the action */
    team?: Maybe<Team>;
    /** The name of the team */
    teamName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for this team */
    teamResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for this team */
    teamUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a org.unblock_user */
export type OrgUnblockUserAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgUnblockUserAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The user being unblocked by the organization. */
    blockedUser?: Maybe<User>;
    /** The username of the blocked user. */
    blockedUserName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the blocked user. */
    blockedUserResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the blocked user. */
    blockedUserUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a org.update_default_repository_permission */
export type OrgUpdateDefaultRepositoryPermissionAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgUpdateDefaultRepositoryPermissionAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The new default repository permission level for the organization. */
    permission?: Maybe<OrgUpdateDefaultRepositoryPermissionAuditEntryPermission>;
    /** The former default repository permission level for the organization. */
    permissionWas?: Maybe<OrgUpdateDefaultRepositoryPermissionAuditEntryPermission>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** The default permission a repository can have in an Organization. */
export declare enum OrgUpdateDefaultRepositoryPermissionAuditEntryPermission {
    /** Can read, clone, push, and add collaborators to repositories. */
    Admin = "ADMIN",
    /** No default permission value. */
    None = "NONE",
    /** Can read and clone repositories. */
    Read = "READ",
    /** Can read, clone and push to repositories. */
    Write = "WRITE"
}
/** Audit log entry for a org.update_member event. */
export type OrgUpdateMemberAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgUpdateMemberAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The new member permission level for the organization. */
    permission?: Maybe<OrgUpdateMemberAuditEntryPermission>;
    /** The former member permission level for the organization. */
    permissionWas?: Maybe<OrgUpdateMemberAuditEntryPermission>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** The permissions available to members on an Organization. */
export declare enum OrgUpdateMemberAuditEntryPermission {
    /** Can read, clone, push, and add collaborators to repositories. */
    Admin = "ADMIN",
    /** Can read and clone repositories. */
    Read = "READ"
}
/** Audit log entry for a org.update_member_repository_creation_permission event. */
export type OrgUpdateMemberRepositoryCreationPermissionAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgUpdateMemberRepositoryCreationPermissionAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** Can members create repositories in the organization. */
    canCreateRepositories?: Maybe<Scalars['Boolean']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
    /** The permission for visibility level of repositories for this organization. */
    visibility?: Maybe<OrgUpdateMemberRepositoryCreationPermissionAuditEntryVisibility>;
};
/** The permissions available for repository creation on an Organization. */
export declare enum OrgUpdateMemberRepositoryCreationPermissionAuditEntryVisibility {
    /** All organization members are restricted from creating any repositories. */
    All = "ALL",
    /** All organization members are restricted from creating internal repositories. */
    Internal = "INTERNAL",
    /** All organization members are allowed to create any repositories. */
    None = "NONE",
    /** All organization members are restricted from creating private repositories. */
    Private = "PRIVATE",
    /** All organization members are restricted from creating private or internal repositories. */
    PrivateInternal = "PRIVATE_INTERNAL",
    /** All organization members are restricted from creating public repositories. */
    Public = "PUBLIC",
    /** All organization members are restricted from creating public or internal repositories. */
    PublicInternal = "PUBLIC_INTERNAL",
    /** All organization members are restricted from creating public or private repositories. */
    PublicPrivate = "PUBLIC_PRIVATE"
}
/** Audit log entry for a org.update_member_repository_invitation_permission event. */
export type OrgUpdateMemberRepositoryInvitationPermissionAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & {
    __typename?: 'OrgUpdateMemberRepositoryInvitationPermissionAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** Can outside collaborators be invited to repositories in the organization. */
    canInviteOutsideCollaboratorsToRepositories?: Maybe<Scalars['Boolean']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type Organization = Actor & MemberStatusable & Node & PackageOwner & ProfileOwner & ProjectOwner & RepositoryDiscussionAuthor & RepositoryDiscussionCommentAuthor & RepositoryOwner & Sponsorable & UniformResourceLocatable & {
    __typename?: 'Organization';
    /** Determine if this repository owner has any items that can be pinned to their profile. */
    anyPinnableItems: Scalars['Boolean']['output'];
    /** Audit log entries of the organization */
    auditLog: OrganizationAuditEntryConnection;
    /** A URL pointing to the organization's public avatar. */
    avatarUrl: Scalars['URI']['output'];
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The organization's public profile description. */
    description?: Maybe<Scalars['String']['output']>;
    /** The organization's public profile description rendered to HTML. */
    descriptionHTML?: Maybe<Scalars['String']['output']>;
    /** A list of domains owned by the organization. */
    domains?: Maybe<VerifiableDomainConnection>;
    /** The organization's public email. */
    email?: Maybe<Scalars['String']['output']>;
    id: Scalars['ID']['output'];
    /** The setting value for whether the organization has an IP allow list enabled. */
    ipAllowListEnabledSetting: IpAllowListEnabledSettingValue;
    /** The IP addresses that are allowed to access resources owned by the organization. */
    ipAllowListEntries: IpAllowListEntryConnection;
    /** The setting value for whether the organization has IP allow list configuration for installed GitHub Apps enabled. */
    ipAllowListForInstalledAppsEnabledSetting: IpAllowListForInstalledAppsEnabledSettingValue;
    /** Whether the organization has verified its profile email and website. */
    isVerified: Scalars['Boolean']['output'];
    /**
     * Showcases a selection of repositories and gists that the profile owner has
     * either curated or that have been selected automatically based on popularity.
     */
    itemShowcase: ProfileItemShowcase;
    /** The organization's public profile location. */
    location?: Maybe<Scalars['String']['output']>;
    /** The organization's login name. */
    login: Scalars['String']['output'];
    /** Get the status messages members of this entity have set that are either public or visible only to the organization. */
    memberStatuses: UserStatusConnection;
    /** A list of users who are members of this organization. */
    membersWithRole: OrganizationMemberConnection;
    /** The organization's public profile name. */
    name?: Maybe<Scalars['String']['output']>;
    /** The HTTP path creating a new team */
    newTeamResourcePath: Scalars['URI']['output'];
    /** The HTTP URL creating a new team */
    newTeamUrl: Scalars['URI']['output'];
    /** Indicates if email notification delivery for this organization is restricted to verified or approved domains. */
    notificationDeliveryRestrictionEnabledSetting: NotificationRestrictionSettingValue;
    /** The billing email for the organization. */
    organizationBillingEmail?: Maybe<Scalars['String']['output']>;
    /** A list of packages under the owner. */
    packages: PackageConnection;
    /** A list of users who have been invited to join this organization. */
    pendingMembers: UserConnection;
    /** A list of repositories and gists this profile owner can pin to their profile. */
    pinnableItems: PinnableItemConnection;
    /** A list of repositories and gists this profile owner has pinned to their profile */
    pinnedItems: PinnableItemConnection;
    /** Returns how many more items this profile owner can pin to their profile. */
    pinnedItemsRemaining: Scalars['Int']['output'];
    /** Find project by number. */
    project?: Maybe<Project>;
    /** A list of projects under the owner. */
    projects: ProjectConnection;
    /** The HTTP path listing organization's projects */
    projectsResourcePath: Scalars['URI']['output'];
    /** The HTTP URL listing organization's projects */
    projectsUrl: Scalars['URI']['output'];
    /** A list of repositories that the user owns. */
    repositories: RepositoryConnection;
    /** Find Repository. */
    repository?: Maybe<Repository>;
    /** Discussion comments this user has authored. */
    repositoryDiscussionComments: DiscussionCommentConnection;
    /** Discussions this user has started. */
    repositoryDiscussions: DiscussionConnection;
    /**
     * When true the organization requires all members, billing managers, and outside
     * collaborators to enable two-factor authentication.
     */
    requiresTwoFactorAuthentication?: Maybe<Scalars['Boolean']['output']>;
    /** The HTTP path for this organization. */
    resourcePath: Scalars['URI']['output'];
    /** The Organization's SAML identity providers */
    samlIdentityProvider?: Maybe<OrganizationIdentityProvider>;
    /** This object's sponsorships as the maintainer. */
    sponsorshipsAsMaintainer: SponsorshipConnection;
    /** This object's sponsorships as the sponsor. */
    sponsorshipsAsSponsor: SponsorshipConnection;
    /** Find an organization's team by its slug. */
    team?: Maybe<Team>;
    /** A list of teams in this organization. */
    teams: TeamConnection;
    /** The HTTP path listing organization's teams */
    teamsResourcePath: Scalars['URI']['output'];
    /** The HTTP URL listing organization's teams */
    teamsUrl: Scalars['URI']['output'];
    /** The organization's Twitter username. */
    twitterUsername?: Maybe<Scalars['String']['output']>;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this organization. */
    url: Scalars['URI']['output'];
    /** Organization is adminable by the viewer. */
    viewerCanAdminister: Scalars['Boolean']['output'];
    /** Can the viewer pin repositories and gists to the profile? */
    viewerCanChangePinnedItems: Scalars['Boolean']['output'];
    /** Can the current viewer create new projects on this owner. */
    viewerCanCreateProjects: Scalars['Boolean']['output'];
    /** Viewer can create repositories on this organization */
    viewerCanCreateRepositories: Scalars['Boolean']['output'];
    /** Viewer can create teams on this organization. */
    viewerCanCreateTeams: Scalars['Boolean']['output'];
    /** Viewer is an active member of this organization. */
    viewerIsAMember: Scalars['Boolean']['output'];
    /** The organization's public profile URL. */
    websiteUrl?: Maybe<Scalars['URI']['output']>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationAnyPinnableItemsArgs = {
    type?: InputMaybe<PinnableItemType>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationAuditLogArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<AuditLogOrder>;
    query?: InputMaybe<Scalars['String']['input']>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationAvatarUrlArgs = {
    size?: InputMaybe<Scalars['Int']['input']>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationDomainsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    isApproved?: InputMaybe<Scalars['Boolean']['input']>;
    isVerified?: InputMaybe<Scalars['Boolean']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<VerifiableDomainOrder>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationIpAllowListEntriesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<IpAllowListEntryOrder>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationMemberStatusesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<UserStatusOrder>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationMembersWithRoleArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationPackagesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    names?: InputMaybe<Array<InputMaybe<Scalars['String']['input']>>>;
    orderBy?: InputMaybe<PackageOrder>;
    packageType?: InputMaybe<PackageType>;
    repositoryId?: InputMaybe<Scalars['ID']['input']>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationPendingMembersArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationPinnableItemsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    types?: InputMaybe<Array<PinnableItemType>>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationPinnedItemsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    types?: InputMaybe<Array<PinnableItemType>>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationProjectArgs = {
    number: Scalars['Int']['input'];
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationProjectsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ProjectOrder>;
    search?: InputMaybe<Scalars['String']['input']>;
    states?: InputMaybe<Array<ProjectState>>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationRepositoriesArgs = {
    affiliations?: InputMaybe<Array<InputMaybe<RepositoryAffiliation>>>;
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    isFork?: InputMaybe<Scalars['Boolean']['input']>;
    isLocked?: InputMaybe<Scalars['Boolean']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<RepositoryOrder>;
    ownerAffiliations?: InputMaybe<Array<InputMaybe<RepositoryAffiliation>>>;
    privacy?: InputMaybe<RepositoryPrivacy>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationRepositoryArgs = {
    name: Scalars['String']['input'];
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationRepositoryDiscussionCommentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    onlyAnswers?: InputMaybe<Scalars['Boolean']['input']>;
    repositoryId?: InputMaybe<Scalars['ID']['input']>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationRepositoryDiscussionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    answered?: InputMaybe<Scalars['Boolean']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<DiscussionOrder>;
    repositoryId?: InputMaybe<Scalars['ID']['input']>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationSponsorshipsAsMaintainerArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    includePrivate?: InputMaybe<Scalars['Boolean']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<SponsorshipOrder>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationSponsorshipsAsSponsorArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<SponsorshipOrder>;
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationTeamArgs = {
    slug: Scalars['String']['input'];
};
/** An account on GitHub, with one or more owners, that has repositories, members and teams. */
export type OrganizationTeamsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    ldapMapped?: InputMaybe<Scalars['Boolean']['input']>;
    orderBy?: InputMaybe<TeamOrder>;
    privacy?: InputMaybe<TeamPrivacy>;
    query?: InputMaybe<Scalars['String']['input']>;
    role?: InputMaybe<TeamRole>;
    rootTeamsOnly?: InputMaybe<Scalars['Boolean']['input']>;
    userLogins?: InputMaybe<Array<Scalars['String']['input']>>;
};
/** An audit entry in an organization audit log. */
export type OrganizationAuditEntry = MembersCanDeleteReposClearAuditEntry | MembersCanDeleteReposDisableAuditEntry | MembersCanDeleteReposEnableAuditEntry | OauthApplicationCreateAuditEntry | OrgAddBillingManagerAuditEntry | OrgAddMemberAuditEntry | OrgBlockUserAuditEntry | OrgConfigDisableCollaboratorsOnlyAuditEntry | OrgConfigEnableCollaboratorsOnlyAuditEntry | OrgCreateAuditEntry | OrgDisableOauthAppRestrictionsAuditEntry | OrgDisableSamlAuditEntry | OrgDisableTwoFactorRequirementAuditEntry | OrgEnableOauthAppRestrictionsAuditEntry | OrgEnableSamlAuditEntry | OrgEnableTwoFactorRequirementAuditEntry | OrgInviteMemberAuditEntry | OrgInviteToBusinessAuditEntry | OrgOauthAppAccessApprovedAuditEntry | OrgOauthAppAccessDeniedAuditEntry | OrgOauthAppAccessRequestedAuditEntry | OrgRemoveBillingManagerAuditEntry | OrgRemoveMemberAuditEntry | OrgRemoveOutsideCollaboratorAuditEntry | OrgRestoreMemberAuditEntry | OrgUnblockUserAuditEntry | OrgUpdateDefaultRepositoryPermissionAuditEntry | OrgUpdateMemberAuditEntry | OrgUpdateMemberRepositoryCreationPermissionAuditEntry | OrgUpdateMemberRepositoryInvitationPermissionAuditEntry | PrivateRepositoryForkingDisableAuditEntry | PrivateRepositoryForkingEnableAuditEntry | RepoAccessAuditEntry | RepoAddMemberAuditEntry | RepoAddTopicAuditEntry | RepoArchivedAuditEntry | RepoChangeMergeSettingAuditEntry | RepoConfigDisableAnonymousGitAccessAuditEntry | RepoConfigDisableCollaboratorsOnlyAuditEntry | RepoConfigDisableContributorsOnlyAuditEntry | RepoConfigDisableSockpuppetDisallowedAuditEntry | RepoConfigEnableAnonymousGitAccessAuditEntry | RepoConfigEnableCollaboratorsOnlyAuditEntry | RepoConfigEnableContributorsOnlyAuditEntry | RepoConfigEnableSockpuppetDisallowedAuditEntry | RepoConfigLockAnonymousGitAccessAuditEntry | RepoConfigUnlockAnonymousGitAccessAuditEntry | RepoCreateAuditEntry | RepoDestroyAuditEntry | RepoRemoveMemberAuditEntry | RepoRemoveTopicAuditEntry | RepositoryVisibilityChangeDisableAuditEntry | RepositoryVisibilityChangeEnableAuditEntry | TeamAddMemberAuditEntry | TeamAddRepositoryAuditEntry | TeamChangeParentTeamAuditEntry | TeamRemoveMemberAuditEntry | TeamRemoveRepositoryAuditEntry;
/** The connection type for OrganizationAuditEntry. */
export type OrganizationAuditEntryConnection = {
    __typename?: 'OrganizationAuditEntryConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<OrganizationAuditEntryEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<OrganizationAuditEntry>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** Metadata for an audit entry with action org.* */
export type OrganizationAuditEntryData = {
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
};
/** An edge in a connection. */
export type OrganizationAuditEntryEdge = {
    __typename?: 'OrganizationAuditEntryEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<OrganizationAuditEntry>;
};
/** The connection type for Organization. */
export type OrganizationConnection = {
    __typename?: 'OrganizationConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<OrganizationEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Organization>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type OrganizationEdge = {
    __typename?: 'OrganizationEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Organization>;
};
/** An Identity Provider configured to provision SAML and SCIM identities for Organizations */
export type OrganizationIdentityProvider = Node & {
    __typename?: 'OrganizationIdentityProvider';
    /** The digest algorithm used to sign SAML requests for the Identity Provider. */
    digestMethod?: Maybe<Scalars['URI']['output']>;
    /** External Identities provisioned by this Identity Provider */
    externalIdentities: ExternalIdentityConnection;
    id: Scalars['ID']['output'];
    /** The x509 certificate used by the Identity Provider to sign assertions and responses. */
    idpCertificate?: Maybe<Scalars['X509Certificate']['output']>;
    /** The Issuer Entity ID for the SAML Identity Provider */
    issuer?: Maybe<Scalars['String']['output']>;
    /** Organization this Identity Provider belongs to */
    organization?: Maybe<Organization>;
    /** The signature algorithm used to sign SAML requests for the Identity Provider. */
    signatureMethod?: Maybe<Scalars['URI']['output']>;
    /** The URL endpoint for the Identity Provider's SAML SSO. */
    ssoUrl?: Maybe<Scalars['URI']['output']>;
};
/** An Identity Provider configured to provision SAML and SCIM identities for Organizations */
export type OrganizationIdentityProviderExternalIdentitiesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    membersOnly?: InputMaybe<Scalars['Boolean']['input']>;
};
/** An Invitation for a user to an organization. */
export type OrganizationInvitation = Node & {
    __typename?: 'OrganizationInvitation';
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The email address of the user invited to the organization. */
    email?: Maybe<Scalars['String']['output']>;
    id: Scalars['ID']['output'];
    /** The type of invitation that was sent (e.g. email, user). */
    invitationType: OrganizationInvitationType;
    /** The user who was invited to the organization. */
    invitee?: Maybe<User>;
    /** The user who created the invitation. */
    inviter: User;
    /** The organization the invite is for */
    organization: Organization;
    /** The user's pending role in the organization (e.g. member, owner). */
    role: OrganizationInvitationRole;
};
/** The connection type for OrganizationInvitation. */
export type OrganizationInvitationConnection = {
    __typename?: 'OrganizationInvitationConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<OrganizationInvitationEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<OrganizationInvitation>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type OrganizationInvitationEdge = {
    __typename?: 'OrganizationInvitationEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<OrganizationInvitation>;
};
/** The possible organization invitation roles. */
export declare enum OrganizationInvitationRole {
    /** The user is invited to be an admin of the organization. */
    Admin = "ADMIN",
    /** The user is invited to be a billing manager of the organization. */
    BillingManager = "BILLING_MANAGER",
    /** The user is invited to be a direct member of the organization. */
    DirectMember = "DIRECT_MEMBER",
    /** The user's previous role will be reinstated. */
    Reinstate = "REINSTATE"
}
/** The possible organization invitation types. */
export declare enum OrganizationInvitationType {
    /** The invitation was to an email address. */
    Email = "EMAIL",
    /** The invitation was to an existing user. */
    User = "USER"
}
/** The connection type for User. */
export type OrganizationMemberConnection = {
    __typename?: 'OrganizationMemberConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<OrganizationMemberEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<User>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** Represents a user within an organization. */
export type OrganizationMemberEdge = {
    __typename?: 'OrganizationMemberEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** Whether the organization member has two factor enabled or not. Returns null if information is not available to viewer. */
    hasTwoFactorEnabled?: Maybe<Scalars['Boolean']['output']>;
    /** The item at the end of the edge. */
    node?: Maybe<User>;
    /** The role this user has in the organization. */
    role?: Maybe<OrganizationMemberRole>;
};
/** The possible roles within an organization for its members. */
export declare enum OrganizationMemberRole {
    /** The user is an administrator of the organization. */
    Admin = "ADMIN",
    /** The user is a member of the organization. */
    Member = "MEMBER"
}
/** The possible values for the members can create repositories setting on an organization. */
export declare enum OrganizationMembersCanCreateRepositoriesSettingValue {
    /** Members will be able to create public and private repositories. */
    All = "ALL",
    /** Members will not be able to create public or private repositories. */
    Disabled = "DISABLED",
    /** Members will be able to create only private repositories. */
    Private = "PRIVATE"
}
/** Ordering options for organization connections. */
export type OrganizationOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order organizations by. */
    field: OrganizationOrderField;
};
/** Properties by which organization connections can be ordered. */
export declare enum OrganizationOrderField {
    /** Order organizations by creation time */
    CreatedAt = "CREATED_AT",
    /** Order organizations by login */
    Login = "LOGIN"
}
/** An organization teams hovercard context */
export type OrganizationTeamsHovercardContext = HovercardContext & {
    __typename?: 'OrganizationTeamsHovercardContext';
    /** A string describing this context */
    message: Scalars['String']['output'];
    /** An octicon to accompany this context */
    octicon: Scalars['String']['output'];
    /** Teams in this organization the user is a member of that are relevant */
    relevantTeams: TeamConnection;
    /** The path for the full team list for this user */
    teamsResourcePath: Scalars['URI']['output'];
    /** The URL for the full team list for this user */
    teamsUrl: Scalars['URI']['output'];
    /** The total number of teams the user is on in the organization */
    totalTeamCount: Scalars['Int']['output'];
};
/** An organization teams hovercard context */
export type OrganizationTeamsHovercardContextRelevantTeamsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** An organization list hovercard context */
export type OrganizationsHovercardContext = HovercardContext & {
    __typename?: 'OrganizationsHovercardContext';
    /** A string describing this context */
    message: Scalars['String']['output'];
    /** An octicon to accompany this context */
    octicon: Scalars['String']['output'];
    /** Organizations this user is a member of that are relevant */
    relevantOrganizations: OrganizationConnection;
    /** The total number of organizations this user is in */
    totalOrganizationCount: Scalars['Int']['output'];
};
/** An organization list hovercard context */
export type OrganizationsHovercardContextRelevantOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** Information for an uploaded package. */
export type Package = Node & {
    __typename?: 'Package';
    id: Scalars['ID']['output'];
    /** Find the latest version for the package. */
    latestVersion?: Maybe<PackageVersion>;
    /** Identifies the name of the package. */
    name: Scalars['String']['output'];
    /** Identifies the type of the package. */
    packageType: PackageType;
    /** The repository this package belongs to. */
    repository?: Maybe<Repository>;
    /** Statistics about package activity. */
    statistics?: Maybe<PackageStatistics>;
    /** Find package version by version string. */
    version?: Maybe<PackageVersion>;
    /** list of versions for this package */
    versions: PackageVersionConnection;
};
/** Information for an uploaded package. */
export type PackageVersionArgs = {
    version: Scalars['String']['input'];
};
/** Information for an uploaded package. */
export type PackageVersionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<PackageVersionOrder>;
};
/** The connection type for Package. */
export type PackageConnection = {
    __typename?: 'PackageConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<PackageEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Package>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type PackageEdge = {
    __typename?: 'PackageEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Package>;
};
/** A file in a package version. */
export type PackageFile = Node & {
    __typename?: 'PackageFile';
    id: Scalars['ID']['output'];
    /** MD5 hash of the file. */
    md5?: Maybe<Scalars['String']['output']>;
    /** Name of the file. */
    name: Scalars['String']['output'];
    /** The package version this file belongs to. */
    packageVersion?: Maybe<PackageVersion>;
    /** SHA1 hash of the file. */
    sha1?: Maybe<Scalars['String']['output']>;
    /** SHA256 hash of the file. */
    sha256?: Maybe<Scalars['String']['output']>;
    /** Size of the file in bytes. */
    size?: Maybe<Scalars['Int']['output']>;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** URL to download the asset. */
    url?: Maybe<Scalars['URI']['output']>;
};
/** The connection type for PackageFile. */
export type PackageFileConnection = {
    __typename?: 'PackageFileConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<PackageFileEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<PackageFile>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type PackageFileEdge = {
    __typename?: 'PackageFileEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<PackageFile>;
};
/** Ways in which lists of package files can be ordered upon return. */
export type PackageFileOrder = {
    /** The direction in which to order package files by the specified field. */
    direction?: InputMaybe<OrderDirection>;
    /** The field in which to order package files by. */
    field?: InputMaybe<PackageFileOrderField>;
};
/** Properties by which package file connections can be ordered. */
export declare enum PackageFileOrderField {
    /** Order package files by creation time */
    CreatedAt = "CREATED_AT"
}
/** Ways in which lists of packages can be ordered upon return. */
export type PackageOrder = {
    /** The direction in which to order packages by the specified field. */
    direction?: InputMaybe<OrderDirection>;
    /** The field in which to order packages by. */
    field?: InputMaybe<PackageOrderField>;
};
/** Properties by which package connections can be ordered. */
export declare enum PackageOrderField {
    /** Order packages by creation time */
    CreatedAt = "CREATED_AT"
}
/** Represents an owner of a package. */
export type PackageOwner = {
    id: Scalars['ID']['output'];
    /** A list of packages under the owner. */
    packages: PackageConnection;
};
/** Represents an owner of a package. */
export type PackageOwnerPackagesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    names?: InputMaybe<Array<InputMaybe<Scalars['String']['input']>>>;
    orderBy?: InputMaybe<PackageOrder>;
    packageType?: InputMaybe<PackageType>;
    repositoryId?: InputMaybe<Scalars['ID']['input']>;
};
/** Represents a object that contains package activity statistics such as downloads. */
export type PackageStatistics = {
    __typename?: 'PackageStatistics';
    /** Number of times the package was downloaded since it was created. */
    downloadsTotalCount: Scalars['Int']['output'];
};
/** A version tag contains the mapping between a tag name and a version. */
export type PackageTag = Node & {
    __typename?: 'PackageTag';
    id: Scalars['ID']['output'];
    /** Identifies the tag name of the version. */
    name: Scalars['String']['output'];
    /** Version that the tag is associated with. */
    version?: Maybe<PackageVersion>;
};
/** The possible types of a package. */
export declare enum PackageType {
    /** A debian package. */
    Debian = "DEBIAN",
    /**
     * A docker image.
     * @deprecated DOCKER will be removed from this enum as this type will be migrated to only be used by the Packages REST API. Removal on 2021-06-21 UTC.
     */
    Docker = "DOCKER",
    /** A maven package. */
    Maven = "MAVEN",
    /** An npm package. */
    Npm = "NPM",
    /** A nuget package. */
    Nuget = "NUGET",
    /** A python package. */
    Pypi = "PYPI",
    /** A rubygems package. */
    Rubygems = "RUBYGEMS"
}
/** Information about a specific package version. */
export type PackageVersion = Node & {
    __typename?: 'PackageVersion';
    /** List of files associated with this package version */
    files: PackageFileConnection;
    id: Scalars['ID']['output'];
    /** The package associated with this version. */
    package?: Maybe<Package>;
    /** The platform this version was built for. */
    platform?: Maybe<Scalars['String']['output']>;
    /** Whether or not this version is a pre-release. */
    preRelease: Scalars['Boolean']['output'];
    /** The README of this package version. */
    readme?: Maybe<Scalars['String']['output']>;
    /** The release associated with this package version. */
    release?: Maybe<Release>;
    /** Statistics about package activity. */
    statistics?: Maybe<PackageVersionStatistics>;
    /** The package version summary. */
    summary?: Maybe<Scalars['String']['output']>;
    /** The version string. */
    version: Scalars['String']['output'];
};
/** Information about a specific package version. */
export type PackageVersionFilesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<PackageFileOrder>;
};
/** The connection type for PackageVersion. */
export type PackageVersionConnection = {
    __typename?: 'PackageVersionConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<PackageVersionEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<PackageVersion>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type PackageVersionEdge = {
    __typename?: 'PackageVersionEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<PackageVersion>;
};
/** Ways in which lists of package versions can be ordered upon return. */
export type PackageVersionOrder = {
    /** The direction in which to order package versions by the specified field. */
    direction?: InputMaybe<OrderDirection>;
    /** The field in which to order package versions by. */
    field?: InputMaybe<PackageVersionOrderField>;
};
/** Properties by which package version connections can be ordered. */
export declare enum PackageVersionOrderField {
    /** Order package versions by creation time */
    CreatedAt = "CREATED_AT"
}
/** Represents a object that contains package version activity statistics such as downloads. */
export type PackageVersionStatistics = {
    __typename?: 'PackageVersionStatistics';
    /** Number of times the package was downloaded since it was created. */
    downloadsTotalCount: Scalars['Int']['output'];
};
/** Information about pagination in a connection. */
export type PageInfo = {
    __typename?: 'PageInfo';
    /** When paginating forwards, the cursor to continue. */
    endCursor?: Maybe<Scalars['String']['output']>;
    /** When paginating forwards, are there more items? */
    hasNextPage: Scalars['Boolean']['output'];
    /** When paginating backwards, are there more items? */
    hasPreviousPage: Scalars['Boolean']['output'];
    /** When paginating backwards, the cursor to continue. */
    startCursor?: Maybe<Scalars['String']['output']>;
};
/** Types that can grant permissions on a repository to a user */
export type PermissionGranter = Organization | Repository | Team;
/** A level of permission and source for a user's access to a repository. */
export type PermissionSource = {
    __typename?: 'PermissionSource';
    /** The organization the repository belongs to. */
    organization: Organization;
    /** The level of access this source has granted to the user. */
    permission: DefaultRepositoryPermissionField;
    /** The source of this permission. */
    source: PermissionGranter;
};
/** Autogenerated input type of PinIssue */
export type PinIssueInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the issue to be pinned */
    issueId: Scalars['ID']['input'];
};
/** Autogenerated return type of PinIssue */
export type PinIssuePayload = {
    __typename?: 'PinIssuePayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The issue that was pinned */
    issue?: Maybe<Issue>;
};
/** Types that can be pinned to a profile page. */
export type PinnableItem = Gist | Repository;
/** The connection type for PinnableItem. */
export type PinnableItemConnection = {
    __typename?: 'PinnableItemConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<PinnableItemEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<PinnableItem>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type PinnableItemEdge = {
    __typename?: 'PinnableItemEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<PinnableItem>;
};
/** Represents items that can be pinned to a profile page or dashboard. */
export declare enum PinnableItemType {
    /** A gist. */
    Gist = "GIST",
    /** An issue. */
    Issue = "ISSUE",
    /** An organization. */
    Organization = "ORGANIZATION",
    /** A project. */
    Project = "PROJECT",
    /** A pull request. */
    PullRequest = "PULL_REQUEST",
    /** A repository. */
    Repository = "REPOSITORY",
    /** A team. */
    Team = "TEAM",
    /** A user. */
    User = "USER"
}
/** A Pinned Discussion is a discussion pinned to a repository's index page. */
export type PinnedDiscussion = Node & RepositoryNode & {
    __typename?: 'PinnedDiscussion';
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The discussion that was pinned. */
    discussion: Discussion;
    /** Color stops of the chosen gradient */
    gradientStopColors: Array<Scalars['String']['output']>;
    id: Scalars['ID']['output'];
    /** Background texture pattern */
    pattern: PinnedDiscussionPattern;
    /** The actor that pinned this discussion. */
    pinnedBy: Actor;
    /** Preconfigured background gradient option */
    preconfiguredGradient?: Maybe<PinnedDiscussionGradient>;
    /** The repository associated with this node. */
    repository: Repository;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
};
/** The connection type for PinnedDiscussion. */
export type PinnedDiscussionConnection = {
    __typename?: 'PinnedDiscussionConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<PinnedDiscussionEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<PinnedDiscussion>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type PinnedDiscussionEdge = {
    __typename?: 'PinnedDiscussionEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<PinnedDiscussion>;
};
/** Preconfigured gradients that may be used to style discussions pinned within a repository. */
export declare enum PinnedDiscussionGradient {
    /** A gradient of blue to mint */
    BlueMint = "BLUE_MINT",
    /** A gradient of blue to purple */
    BluePurple = "BLUE_PURPLE",
    /** A gradient of pink to blue */
    PinkBlue = "PINK_BLUE",
    /** A gradient of purple to coral */
    PurpleCoral = "PURPLE_CORAL",
    /** A gradient of red to orange */
    RedOrange = "RED_ORANGE"
}
/** Preconfigured background patterns that may be used to style discussions pinned within a repository. */
export declare enum PinnedDiscussionPattern {
    /** An upward-facing chevron pattern */
    ChevronUp = "CHEVRON_UP",
    /** A hollow dot pattern */
    Dot = "DOT",
    /** A solid dot pattern */
    DotFill = "DOT_FILL",
    /** A heart pattern */
    HeartFill = "HEART_FILL",
    /** A plus sign pattern */
    Plus = "PLUS",
    /** A lightning bolt pattern */
    Zap = "ZAP"
}
/** Represents a 'pinned' event on a given issue or pull request. */
export type PinnedEvent = Node & {
    __typename?: 'PinnedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** Identifies the issue associated with the event. */
    issue: Issue;
};
/** A Pinned Issue is a issue pinned to a repository's index page. */
export type PinnedIssue = Node & {
    __typename?: 'PinnedIssue';
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** The issue that was pinned. */
    issue: Issue;
    /** The actor that pinned this issue. */
    pinnedBy: Actor;
    /** The repository that this issue was pinned to. */
    repository: Repository;
};
/** The connection type for PinnedIssue. */
export type PinnedIssueConnection = {
    __typename?: 'PinnedIssueConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<PinnedIssueEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<PinnedIssue>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type PinnedIssueEdge = {
    __typename?: 'PinnedIssueEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<PinnedIssue>;
};
/** Audit log entry for a private_repository_forking.disable event. */
export type PrivateRepositoryForkingDisableAuditEntry = AuditEntry & EnterpriseAuditEntryData & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'PrivateRepositoryForkingDisableAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    /** The HTTP path for this enterprise. */
    enterpriseResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The slug of the enterprise. */
    enterpriseSlug?: Maybe<Scalars['String']['output']>;
    /** The HTTP URL for this enterprise. */
    enterpriseUrl?: Maybe<Scalars['URI']['output']>;
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a private_repository_forking.enable event. */
export type PrivateRepositoryForkingEnableAuditEntry = AuditEntry & EnterpriseAuditEntryData & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'PrivateRepositoryForkingEnableAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    /** The HTTP path for this enterprise. */
    enterpriseResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The slug of the enterprise. */
    enterpriseSlug?: Maybe<Scalars['String']['output']>;
    /** The HTTP URL for this enterprise. */
    enterpriseUrl?: Maybe<Scalars['URI']['output']>;
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/**
 * A curatable list of repositories relating to a repository owner, which defaults
 * to showing the most popular repositories they own.
 */
export type ProfileItemShowcase = {
    __typename?: 'ProfileItemShowcase';
    /** Whether or not the owner has pinned any repositories or gists. */
    hasPinnedItems: Scalars['Boolean']['output'];
    /**
     * The repositories and gists in the showcase. If the profile owner has any
     * pinned items, those will be returned. Otherwise, the profile owner's popular
     * repositories will be returned.
     */
    items: PinnableItemConnection;
};
/**
 * A curatable list of repositories relating to a repository owner, which defaults
 * to showing the most popular repositories they own.
 */
export type ProfileItemShowcaseItemsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** Represents any entity on GitHub that has a profile page. */
export type ProfileOwner = {
    /** Determine if this repository owner has any items that can be pinned to their profile. */
    anyPinnableItems: Scalars['Boolean']['output'];
    /** The public profile email. */
    email?: Maybe<Scalars['String']['output']>;
    id: Scalars['ID']['output'];
    /**
     * Showcases a selection of repositories and gists that the profile owner has
     * either curated or that have been selected automatically based on popularity.
     */
    itemShowcase: ProfileItemShowcase;
    /** The public profile location. */
    location?: Maybe<Scalars['String']['output']>;
    /** The username used to login. */
    login: Scalars['String']['output'];
    /** The public profile name. */
    name?: Maybe<Scalars['String']['output']>;
    /** A list of repositories and gists this profile owner can pin to their profile. */
    pinnableItems: PinnableItemConnection;
    /** A list of repositories and gists this profile owner has pinned to their profile */
    pinnedItems: PinnableItemConnection;
    /** Returns how many more items this profile owner can pin to their profile. */
    pinnedItemsRemaining: Scalars['Int']['output'];
    /** Can the viewer pin repositories and gists to the profile? */
    viewerCanChangePinnedItems: Scalars['Boolean']['output'];
    /** The public profile website URL. */
    websiteUrl?: Maybe<Scalars['URI']['output']>;
};
/** Represents any entity on GitHub that has a profile page. */
export type ProfileOwnerAnyPinnableItemsArgs = {
    type?: InputMaybe<PinnableItemType>;
};
/** Represents any entity on GitHub that has a profile page. */
export type ProfileOwnerPinnableItemsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    types?: InputMaybe<Array<PinnableItemType>>;
};
/** Represents any entity on GitHub that has a profile page. */
export type ProfileOwnerPinnedItemsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    types?: InputMaybe<Array<PinnableItemType>>;
};
/** Projects manage issues, pull requests and notes within a project owner. */
export type Project = Closable & Node & Updatable & {
    __typename?: 'Project';
    /** The project's description body. */
    body?: Maybe<Scalars['String']['output']>;
    /** The projects description body rendered to HTML. */
    bodyHTML: Scalars['HTML']['output'];
    /** `true` if the object is closed (definition of closed may depend on type) */
    closed: Scalars['Boolean']['output'];
    /** Identifies the date and time when the object was closed. */
    closedAt?: Maybe<Scalars['DateTime']['output']>;
    /** List of columns in the project */
    columns: ProjectColumnConnection;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The actor who originally created the project. */
    creator?: Maybe<Actor>;
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** The project's name. */
    name: Scalars['String']['output'];
    /** The project's number. */
    number: Scalars['Int']['output'];
    /** The project's owner. Currently limited to repositories, organizations, and users. */
    owner: ProjectOwner;
    /** List of pending cards in this project */
    pendingCards: ProjectCardConnection;
    /** Project progress details. */
    progress: ProjectProgress;
    /** The HTTP path for this project */
    resourcePath: Scalars['URI']['output'];
    /** Whether the project is open or closed. */
    state: ProjectState;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this project */
    url: Scalars['URI']['output'];
    /** Check if the current viewer can update this object. */
    viewerCanUpdate: Scalars['Boolean']['output'];
};
/** Projects manage issues, pull requests and notes within a project owner. */
export type ProjectColumnsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** Projects manage issues, pull requests and notes within a project owner. */
export type ProjectPendingCardsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    archivedStates?: InputMaybe<Array<InputMaybe<ProjectCardArchivedState>>>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A card in a project. */
export type ProjectCard = Node & {
    __typename?: 'ProjectCard';
    /**
     * The project column this card is associated under. A card may only belong to one
     * project column at a time. The column field will be null if the card is created
     * in a pending state and has yet to be associated with a column. Once cards are
     * associated with a column, they will not become pending in the future.
     */
    column?: Maybe<ProjectColumn>;
    /** The card content item */
    content?: Maybe<ProjectCardItem>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The actor who created this card */
    creator?: Maybe<Actor>;
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** Whether the card is archived */
    isArchived: Scalars['Boolean']['output'];
    /** The card note */
    note?: Maybe<Scalars['String']['output']>;
    /** The project that contains this card. */
    project: Project;
    /** The HTTP path for this card */
    resourcePath: Scalars['URI']['output'];
    /** The state of ProjectCard */
    state?: Maybe<ProjectCardState>;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this card */
    url: Scalars['URI']['output'];
};
/** The possible archived states of a project card. */
export declare enum ProjectCardArchivedState {
    /** A project card that is archived */
    Archived = "ARCHIVED",
    /** A project card that is not archived */
    NotArchived = "NOT_ARCHIVED"
}
/** The connection type for ProjectCard. */
export type ProjectCardConnection = {
    __typename?: 'ProjectCardConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<ProjectCardEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<ProjectCard>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type ProjectCardEdge = {
    __typename?: 'ProjectCardEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<ProjectCard>;
};
/** An issue or PR and its owning repository to be used in a project card. */
export type ProjectCardImport = {
    /** The issue or pull request number. */
    number: Scalars['Int']['input'];
    /** Repository name with owner (owner/repository). */
    repository: Scalars['String']['input'];
};
/** Types that can be inside Project Cards. */
export type ProjectCardItem = Issue | PullRequest;
/** Various content states of a ProjectCard */
export declare enum ProjectCardState {
    /** The card has content only. */
    ContentOnly = "CONTENT_ONLY",
    /** The card has a note only. */
    NoteOnly = "NOTE_ONLY",
    /** The card is redacted. */
    Redacted = "REDACTED"
}
/** A column inside a project. */
export type ProjectColumn = Node & {
    __typename?: 'ProjectColumn';
    /** List of cards in the column */
    cards: ProjectCardConnection;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** The project column's name. */
    name: Scalars['String']['output'];
    /** The project that contains this column. */
    project: Project;
    /** The semantic purpose of the column */
    purpose?: Maybe<ProjectColumnPurpose>;
    /** The HTTP path for this project column */
    resourcePath: Scalars['URI']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this project column */
    url: Scalars['URI']['output'];
};
/** A column inside a project. */
export type ProjectColumnCardsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    archivedStates?: InputMaybe<Array<InputMaybe<ProjectCardArchivedState>>>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** The connection type for ProjectColumn. */
export type ProjectColumnConnection = {
    __typename?: 'ProjectColumnConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<ProjectColumnEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<ProjectColumn>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type ProjectColumnEdge = {
    __typename?: 'ProjectColumnEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<ProjectColumn>;
};
/** A project column and a list of its issues and PRs. */
export type ProjectColumnImport = {
    /** The name of the column. */
    columnName: Scalars['String']['input'];
    /** A list of issues and pull requests in the column. */
    issues?: InputMaybe<Array<ProjectCardImport>>;
    /** The position of the column, starting from 0. */
    position: Scalars['Int']['input'];
};
/** The semantic purpose of the column - todo, in progress, or done. */
export declare enum ProjectColumnPurpose {
    /** The column contains cards which are complete */
    Done = "DONE",
    /** The column contains cards which are currently being worked on */
    InProgress = "IN_PROGRESS",
    /** The column contains cards still to be worked on */
    Todo = "TODO"
}
/** A list of projects associated with the owner. */
export type ProjectConnection = {
    __typename?: 'ProjectConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<ProjectEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Project>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type ProjectEdge = {
    __typename?: 'ProjectEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Project>;
};
/** Ways in which lists of projects can be ordered upon return. */
export type ProjectOrder = {
    /** The direction in which to order projects by the specified field. */
    direction: OrderDirection;
    /** The field in which to order projects by. */
    field: ProjectOrderField;
};
/** Properties by which project connections can be ordered. */
export declare enum ProjectOrderField {
    /** Order projects by creation time */
    CreatedAt = "CREATED_AT",
    /** Order projects by name */
    Name = "NAME",
    /** Order projects by update time */
    UpdatedAt = "UPDATED_AT"
}
/** Represents an owner of a Project. */
export type ProjectOwner = {
    id: Scalars['ID']['output'];
    /** Find project by number. */
    project?: Maybe<Project>;
    /** A list of projects under the owner. */
    projects: ProjectConnection;
    /** The HTTP path listing owners projects */
    projectsResourcePath: Scalars['URI']['output'];
    /** The HTTP URL listing owners projects */
    projectsUrl: Scalars['URI']['output'];
    /** Can the current viewer create new projects on this owner. */
    viewerCanCreateProjects: Scalars['Boolean']['output'];
};
/** Represents an owner of a Project. */
export type ProjectOwnerProjectArgs = {
    number: Scalars['Int']['input'];
};
/** Represents an owner of a Project. */
export type ProjectOwnerProjectsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ProjectOrder>;
    search?: InputMaybe<Scalars['String']['input']>;
    states?: InputMaybe<Array<ProjectState>>;
};
/** Project progress stats. */
export type ProjectProgress = {
    __typename?: 'ProjectProgress';
    /** The number of done cards. */
    doneCount: Scalars['Int']['output'];
    /** The percentage of done cards. */
    donePercentage: Scalars['Float']['output'];
    /** Whether progress tracking is enabled and cards with purpose exist for this project */
    enabled: Scalars['Boolean']['output'];
    /** The number of in-progress cards. */
    inProgressCount: Scalars['Int']['output'];
    /** The percentage of in-progress cards. */
    inProgressPercentage: Scalars['Float']['output'];
    /** The number of to do cards. */
    todoCount: Scalars['Int']['output'];
    /** The percentage of to do cards. */
    todoPercentage: Scalars['Float']['output'];
};
/** State of the project; either 'open' or 'closed' */
export declare enum ProjectState {
    /** The project is closed. */
    Closed = "CLOSED",
    /** The project is open. */
    Open = "OPEN"
}
/** GitHub-provided templates for Projects */
export declare enum ProjectTemplate {
    /** Create a board with v2 triggers to automatically move cards across To do, In progress and Done columns. */
    AutomatedKanbanV2 = "AUTOMATED_KANBAN_V2",
    /** Create a board with triggers to automatically move cards across columns with review automation. */
    AutomatedReviewsKanban = "AUTOMATED_REVIEWS_KANBAN",
    /** Create a board with columns for To do, In progress and Done. */
    BasicKanban = "BASIC_KANBAN",
    /** Create a board to triage and prioritize bugs with To do, priority, and Done columns. */
    BugTriage = "BUG_TRIAGE"
}
/** A user's public key. */
export type PublicKey = Node & {
    __typename?: 'PublicKey';
    /** The last time this authorization was used to perform an action. Values will be null for keys not owned by the user. */
    accessedAt?: Maybe<Scalars['DateTime']['output']>;
    /**
     * Identifies the date and time when the key was created. Keys created before
     * March 5th, 2014 have inaccurate values. Values will be null for keys not owned by the user.
     */
    createdAt?: Maybe<Scalars['DateTime']['output']>;
    /** The fingerprint for this PublicKey. */
    fingerprint: Scalars['String']['output'];
    id: Scalars['ID']['output'];
    /** Whether this PublicKey is read-only or not. Values will be null for keys not owned by the user. */
    isReadOnly?: Maybe<Scalars['Boolean']['output']>;
    /** The public key string. */
    key: Scalars['String']['output'];
    /**
     * Identifies the date and time when the key was updated. Keys created before
     * March 5th, 2014 may have inaccurate values. Values will be null for keys not
     * owned by the user.
     */
    updatedAt?: Maybe<Scalars['DateTime']['output']>;
};
/** The connection type for PublicKey. */
export type PublicKeyConnection = {
    __typename?: 'PublicKeyConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<PublicKeyEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<PublicKey>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type PublicKeyEdge = {
    __typename?: 'PublicKeyEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<PublicKey>;
};
/** A repository pull request. */
export type PullRequest = Assignable & Closable & Comment & Labelable & Lockable & Node & Reactable & RepositoryNode & Subscribable & UniformResourceLocatable & Updatable & UpdatableComment & {
    __typename?: 'PullRequest';
    /** Reason that the conversation was locked. */
    activeLockReason?: Maybe<LockReason>;
    /** The number of additions in this pull request. */
    additions: Scalars['Int']['output'];
    /** A list of Users assigned to this object. */
    assignees: UserConnection;
    /** The actor who authored the comment. */
    author?: Maybe<Actor>;
    /** Author's association with the subject of the comment. */
    authorAssociation: CommentAuthorAssociation;
    /** Returns the auto-merge request object if one exists for this pull request. */
    autoMergeRequest?: Maybe<AutoMergeRequest>;
    /** Identifies the base Ref associated with the pull request. */
    baseRef?: Maybe<Ref>;
    /** Identifies the name of the base Ref associated with the pull request, even if the ref has been deleted. */
    baseRefName: Scalars['String']['output'];
    /** Identifies the oid of the base ref associated with the pull request, even if the ref has been deleted. */
    baseRefOid: Scalars['GitObjectID']['output'];
    /** The repository associated with this pull request's base Ref. */
    baseRepository?: Maybe<Repository>;
    /** The body as Markdown. */
    body: Scalars['String']['output'];
    /** The body rendered to HTML. */
    bodyHTML: Scalars['HTML']['output'];
    /** The body rendered to text. */
    bodyText: Scalars['String']['output'];
    /** Whether or not the pull request is rebaseable. */
    canBeRebased: Scalars['Boolean']['output'];
    /** The number of changed files in this pull request. */
    changedFiles: Scalars['Int']['output'];
    /** The HTTP path for the checks of this pull request. */
    checksResourcePath: Scalars['URI']['output'];
    /** The HTTP URL for the checks of this pull request. */
    checksUrl: Scalars['URI']['output'];
    /** `true` if the pull request is closed */
    closed: Scalars['Boolean']['output'];
    /** Identifies the date and time when the object was closed. */
    closedAt?: Maybe<Scalars['DateTime']['output']>;
    /** List of issues that were may be closed by this pull request */
    closingIssuesReferences?: Maybe<IssueConnection>;
    /** A list of comments associated with the pull request. */
    comments: IssueCommentConnection;
    /** A list of commits present in this pull request's head branch not present in the base branch. */
    commits: PullRequestCommitConnection;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Check if this comment was created via an email reply. */
    createdViaEmail: Scalars['Boolean']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The number of deletions in this pull request. */
    deletions: Scalars['Int']['output'];
    /** The actor who edited this pull request's body. */
    editor?: Maybe<Actor>;
    /** Lists the files changed within this pull request. */
    files?: Maybe<PullRequestChangedFileConnection>;
    /** Identifies the head Ref associated with the pull request. */
    headRef?: Maybe<Ref>;
    /** Identifies the name of the head Ref associated with the pull request, even if the ref has been deleted. */
    headRefName: Scalars['String']['output'];
    /** Identifies the oid of the head ref associated with the pull request, even if the ref has been deleted. */
    headRefOid: Scalars['GitObjectID']['output'];
    /** The repository associated with this pull request's head Ref. */
    headRepository?: Maybe<Repository>;
    /** The owner of the repository associated with this pull request's head Ref. */
    headRepositoryOwner?: Maybe<RepositoryOwner>;
    /** The hovercard information for this issue */
    hovercard: Hovercard;
    id: Scalars['ID']['output'];
    /** Check if this comment was edited and includes an edit with the creation data */
    includesCreatedEdit: Scalars['Boolean']['output'];
    /** The head and base repositories are different. */
    isCrossRepository: Scalars['Boolean']['output'];
    /** Identifies if the pull request is a draft. */
    isDraft: Scalars['Boolean']['output'];
    /** Is this pull request read by the viewer */
    isReadByViewer?: Maybe<Scalars['Boolean']['output']>;
    /** A list of labels associated with the object. */
    labels?: Maybe<LabelConnection>;
    /** The moment the editor made the last edit */
    lastEditedAt?: Maybe<Scalars['DateTime']['output']>;
    /** A list of latest reviews per user associated with the pull request. */
    latestOpinionatedReviews?: Maybe<PullRequestReviewConnection>;
    /** A list of latest reviews per user associated with the pull request that are not also pending review. */
    latestReviews?: Maybe<PullRequestReviewConnection>;
    /** `true` if the pull request is locked */
    locked: Scalars['Boolean']['output'];
    /** Indicates whether maintainers can modify the pull request. */
    maintainerCanModify: Scalars['Boolean']['output'];
    /** The commit that was created when this pull request was merged. */
    mergeCommit?: Maybe<Commit>;
    /** Detailed information about the current pull request merge state status. */
    mergeStateStatus: MergeStateStatus;
    /** Whether or not the pull request can be merged based on the existence of merge conflicts. */
    mergeable: MergeableState;
    /** Whether or not the pull request was merged. */
    merged: Scalars['Boolean']['output'];
    /** The date and time that the pull request was merged. */
    mergedAt?: Maybe<Scalars['DateTime']['output']>;
    /** The actor who merged the pull request. */
    mergedBy?: Maybe<Actor>;
    /** Identifies the milestone associated with the pull request. */
    milestone?: Maybe<Milestone>;
    /** Identifies the pull request number. */
    number: Scalars['Int']['output'];
    /** A list of Users that are participating in the Pull Request conversation. */
    participants: UserConnection;
    /** The permalink to the pull request. */
    permalink: Scalars['URI']['output'];
    /**
     * The commit that GitHub automatically generated to test if this pull request
     * could be merged. This field will not return a value if the pull request is
     * merged, or if the test merge commit is still being generated. See the
     * `mergeable` field for more details on the mergeability of the pull request.
     */
    potentialMergeCommit?: Maybe<Commit>;
    /** List of project cards associated with this pull request. */
    projectCards: ProjectCardConnection;
    /** Identifies when the comment was published at. */
    publishedAt?: Maybe<Scalars['DateTime']['output']>;
    /** A list of reactions grouped by content left on the subject. */
    reactionGroups?: Maybe<Array<ReactionGroup>>;
    /** A list of Reactions left on the Issue. */
    reactions: ReactionConnection;
    /** The repository associated with this node. */
    repository: Repository;
    /** The HTTP path for this pull request. */
    resourcePath: Scalars['URI']['output'];
    /** The HTTP path for reverting this pull request. */
    revertResourcePath: Scalars['URI']['output'];
    /** The HTTP URL for reverting this pull request. */
    revertUrl: Scalars['URI']['output'];
    /** The current status of this pull request with respect to code review. */
    reviewDecision?: Maybe<PullRequestReviewDecision>;
    /** A list of review requests associated with the pull request. */
    reviewRequests?: Maybe<ReviewRequestConnection>;
    /** The list of all review threads for this pull request. */
    reviewThreads: PullRequestReviewThreadConnection;
    /** A list of reviews associated with the pull request. */
    reviews?: Maybe<PullRequestReviewConnection>;
    /** Identifies the state of the pull request. */
    state: PullRequestState;
    /** A list of reviewer suggestions based on commit history and past review comments. */
    suggestedReviewers: Array<Maybe<SuggestedReviewer>>;
    /**
     * A list of events, comments, commits, etc. associated with the pull request.
     * @deprecated `timeline` will be removed Use PullRequest.timelineItems instead. Removal on 2020-10-01 UTC.
     */
    timeline: PullRequestTimelineConnection;
    /** A list of events, comments, commits, etc. associated with the pull request. */
    timelineItems: PullRequestTimelineItemsConnection;
    /** Identifies the pull request title. */
    title: Scalars['String']['output'];
    /** Identifies the pull request title rendered to HTML. */
    titleHTML: Scalars['HTML']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this pull request. */
    url: Scalars['URI']['output'];
    /** A list of edits to this content. */
    userContentEdits?: Maybe<UserContentEditConnection>;
    /** Whether or not the viewer can apply suggestion. */
    viewerCanApplySuggestion: Scalars['Boolean']['output'];
    /** Check if the viewer can restore the deleted head ref. */
    viewerCanDeleteHeadRef: Scalars['Boolean']['output'];
    /** Whether or not the viewer can disable auto-merge */
    viewerCanDisableAutoMerge: Scalars['Boolean']['output'];
    /** Whether or not the viewer can enable auto-merge */
    viewerCanEnableAutoMerge: Scalars['Boolean']['output'];
    /** Can user react to this subject */
    viewerCanReact: Scalars['Boolean']['output'];
    /** Check if the viewer is able to change their subscription status for the repository. */
    viewerCanSubscribe: Scalars['Boolean']['output'];
    /** Check if the current viewer can update this object. */
    viewerCanUpdate: Scalars['Boolean']['output'];
    /** Reasons why the current viewer can not update this comment. */
    viewerCannotUpdateReasons: Array<CommentCannotUpdateReason>;
    /** Did the viewer author this comment. */
    viewerDidAuthor: Scalars['Boolean']['output'];
    /** The latest review given from the viewer. */
    viewerLatestReview?: Maybe<PullRequestReview>;
    /** The person who has requested the viewer for review on this pull request. */
    viewerLatestReviewRequest?: Maybe<ReviewRequest>;
    /** The merge body text for the viewer and method. */
    viewerMergeBodyText: Scalars['String']['output'];
    /** The merge headline text for the viewer and method. */
    viewerMergeHeadlineText: Scalars['String']['output'];
    /** Identifies if the viewer is watching, not watching, or ignoring the subscribable entity. */
    viewerSubscription?: Maybe<SubscriptionState>;
};
/** A repository pull request. */
export type PullRequestAssigneesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository pull request. */
export type PullRequestClosingIssuesReferencesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<IssueOrder>;
};
/** A repository pull request. */
export type PullRequestCommentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<IssueCommentOrder>;
};
/** A repository pull request. */
export type PullRequestCommitsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository pull request. */
export type PullRequestFilesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository pull request. */
export type PullRequestHovercardArgs = {
    includeNotificationContexts?: InputMaybe<Scalars['Boolean']['input']>;
};
/** A repository pull request. */
export type PullRequestLabelsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<LabelOrder>;
};
/** A repository pull request. */
export type PullRequestLatestOpinionatedReviewsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    writersOnly?: InputMaybe<Scalars['Boolean']['input']>;
};
/** A repository pull request. */
export type PullRequestLatestReviewsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository pull request. */
export type PullRequestParticipantsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository pull request. */
export type PullRequestProjectCardsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    archivedStates?: InputMaybe<Array<InputMaybe<ProjectCardArchivedState>>>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository pull request. */
export type PullRequestReactionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    content?: InputMaybe<ReactionContent>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ReactionOrder>;
};
/** A repository pull request. */
export type PullRequestReviewRequestsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository pull request. */
export type PullRequestReviewThreadsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository pull request. */
export type PullRequestReviewsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    author?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    states?: InputMaybe<Array<PullRequestReviewState>>;
};
/** A repository pull request. */
export type PullRequestTimelineArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    since?: InputMaybe<Scalars['DateTime']['input']>;
};
/** A repository pull request. */
export type PullRequestTimelineItemsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    itemTypes?: InputMaybe<Array<PullRequestTimelineItemsItemType>>;
    last?: InputMaybe<Scalars['Int']['input']>;
    since?: InputMaybe<Scalars['DateTime']['input']>;
    skip?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository pull request. */
export type PullRequestUserContentEditsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository pull request. */
export type PullRequestViewerMergeBodyTextArgs = {
    mergeType?: InputMaybe<PullRequestMergeMethod>;
};
/** A repository pull request. */
export type PullRequestViewerMergeHeadlineTextArgs = {
    mergeType?: InputMaybe<PullRequestMergeMethod>;
};
/** A file changed in a pull request. */
export type PullRequestChangedFile = {
    __typename?: 'PullRequestChangedFile';
    /** The number of additions to the file. */
    additions: Scalars['Int']['output'];
    /** The number of deletions to the file. */
    deletions: Scalars['Int']['output'];
    /** The path of the file. */
    path: Scalars['String']['output'];
    /** The state of the file for the viewer. */
    viewerViewedState: FileViewedState;
};
/** The connection type for PullRequestChangedFile. */
export type PullRequestChangedFileConnection = {
    __typename?: 'PullRequestChangedFileConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<PullRequestChangedFileEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<PullRequestChangedFile>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type PullRequestChangedFileEdge = {
    __typename?: 'PullRequestChangedFileEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<PullRequestChangedFile>;
};
/** Represents a Git commit part of a pull request. */
export type PullRequestCommit = Node & UniformResourceLocatable & {
    __typename?: 'PullRequestCommit';
    /** The Git commit object */
    commit: Commit;
    id: Scalars['ID']['output'];
    /** The pull request this commit belongs to */
    pullRequest: PullRequest;
    /** The HTTP path for this pull request commit */
    resourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this pull request commit */
    url: Scalars['URI']['output'];
};
/** Represents a commit comment thread part of a pull request. */
export type PullRequestCommitCommentThread = Node & RepositoryNode & {
    __typename?: 'PullRequestCommitCommentThread';
    /** The comments that exist in this thread. */
    comments: CommitCommentConnection;
    /** The commit the comments were made on. */
    commit: Commit;
    id: Scalars['ID']['output'];
    /** The file the comments were made on. */
    path?: Maybe<Scalars['String']['output']>;
    /** The position in the diff for the commit that the comment was made on. */
    position?: Maybe<Scalars['Int']['output']>;
    /** The pull request this commit comment thread belongs to */
    pullRequest: PullRequest;
    /** The repository associated with this node. */
    repository: Repository;
};
/** Represents a commit comment thread part of a pull request. */
export type PullRequestCommitCommentThreadCommentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** The connection type for PullRequestCommit. */
export type PullRequestCommitConnection = {
    __typename?: 'PullRequestCommitConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<PullRequestCommitEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<PullRequestCommit>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type PullRequestCommitEdge = {
    __typename?: 'PullRequestCommitEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<PullRequestCommit>;
};
/** The connection type for PullRequest. */
export type PullRequestConnection = {
    __typename?: 'PullRequestConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<PullRequestEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<PullRequest>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** This aggregates pull requests opened by a user within one repository. */
export type PullRequestContributionsByRepository = {
    __typename?: 'PullRequestContributionsByRepository';
    /** The pull request contributions. */
    contributions: CreatedPullRequestContributionConnection;
    /** The repository in which the pull requests were opened. */
    repository: Repository;
};
/** This aggregates pull requests opened by a user within one repository. */
export type PullRequestContributionsByRepositoryContributionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ContributionOrder>;
};
/** An edge in a connection. */
export type PullRequestEdge = {
    __typename?: 'PullRequestEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<PullRequest>;
};
/** Represents available types of methods to use when merging a pull request. */
export declare enum PullRequestMergeMethod {
    /** Add all commits from the head branch to the base branch with a merge commit. */
    Merge = "MERGE",
    /** Add all commits from the head branch onto the base branch individually. */
    Rebase = "REBASE",
    /** Combine all commits from the head branch into a single commit in the base branch. */
    Squash = "SQUASH"
}
/** Ways in which lists of issues can be ordered upon return. */
export type PullRequestOrder = {
    /** The direction in which to order pull requests by the specified field. */
    direction: OrderDirection;
    /** The field in which to order pull requests by. */
    field: PullRequestOrderField;
};
/** Properties by which pull_requests connections can be ordered. */
export declare enum PullRequestOrderField {
    /** Order pull_requests by creation time */
    CreatedAt = "CREATED_AT",
    /** Order pull_requests by update time */
    UpdatedAt = "UPDATED_AT"
}
/** A review object for a given pull request. */
export type PullRequestReview = Comment & Deletable & Node & Reactable & RepositoryNode & Updatable & UpdatableComment & {
    __typename?: 'PullRequestReview';
    /** The actor who authored the comment. */
    author?: Maybe<Actor>;
    /** Author's association with the subject of the comment. */
    authorAssociation: CommentAuthorAssociation;
    /** Indicates whether the author of this review has push access to the repository. */
    authorCanPushToRepository: Scalars['Boolean']['output'];
    /** Identifies the pull request review body. */
    body: Scalars['String']['output'];
    /** The body rendered to HTML. */
    bodyHTML: Scalars['HTML']['output'];
    /** The body of this review rendered as plain text. */
    bodyText: Scalars['String']['output'];
    /** A list of review comments for the current pull request review. */
    comments: PullRequestReviewCommentConnection;
    /** Identifies the commit associated with this pull request review. */
    commit?: Maybe<Commit>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Check if this comment was created via an email reply. */
    createdViaEmail: Scalars['Boolean']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The actor who edited the comment. */
    editor?: Maybe<Actor>;
    id: Scalars['ID']['output'];
    /** Check if this comment was edited and includes an edit with the creation data */
    includesCreatedEdit: Scalars['Boolean']['output'];
    /** The moment the editor made the last edit */
    lastEditedAt?: Maybe<Scalars['DateTime']['output']>;
    /** A list of teams that this review was made on behalf of. */
    onBehalfOf: TeamConnection;
    /** Identifies when the comment was published at. */
    publishedAt?: Maybe<Scalars['DateTime']['output']>;
    /** Identifies the pull request associated with this pull request review. */
    pullRequest: PullRequest;
    /** A list of reactions grouped by content left on the subject. */
    reactionGroups?: Maybe<Array<ReactionGroup>>;
    /** A list of Reactions left on the Issue. */
    reactions: ReactionConnection;
    /** The repository associated with this node. */
    repository: Repository;
    /** The HTTP path permalink for this PullRequestReview. */
    resourcePath: Scalars['URI']['output'];
    /** Identifies the current state of the pull request review. */
    state: PullRequestReviewState;
    /** Identifies when the Pull Request Review was submitted */
    submittedAt?: Maybe<Scalars['DateTime']['output']>;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL permalink for this PullRequestReview. */
    url: Scalars['URI']['output'];
    /** A list of edits to this content. */
    userContentEdits?: Maybe<UserContentEditConnection>;
    /** Check if the current viewer can delete this object. */
    viewerCanDelete: Scalars['Boolean']['output'];
    /** Can user react to this subject */
    viewerCanReact: Scalars['Boolean']['output'];
    /** Check if the current viewer can update this object. */
    viewerCanUpdate: Scalars['Boolean']['output'];
    /** Reasons why the current viewer can not update this comment. */
    viewerCannotUpdateReasons: Array<CommentCannotUpdateReason>;
    /** Did the viewer author this comment. */
    viewerDidAuthor: Scalars['Boolean']['output'];
};
/** A review object for a given pull request. */
export type PullRequestReviewCommentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A review object for a given pull request. */
export type PullRequestReviewOnBehalfOfArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A review object for a given pull request. */
export type PullRequestReviewReactionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    content?: InputMaybe<ReactionContent>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ReactionOrder>;
};
/** A review object for a given pull request. */
export type PullRequestReviewUserContentEditsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A review comment associated with a given repository pull request. */
export type PullRequestReviewComment = Comment & Deletable & Minimizable & Node & Reactable & RepositoryNode & Updatable & UpdatableComment & {
    __typename?: 'PullRequestReviewComment';
    /** The actor who authored the comment. */
    author?: Maybe<Actor>;
    /** Author's association with the subject of the comment. */
    authorAssociation: CommentAuthorAssociation;
    /** The comment body of this review comment. */
    body: Scalars['String']['output'];
    /** The body rendered to HTML. */
    bodyHTML: Scalars['HTML']['output'];
    /** The comment body of this review comment rendered as plain text. */
    bodyText: Scalars['String']['output'];
    /** Identifies the commit associated with the comment. */
    commit?: Maybe<Commit>;
    /** Identifies when the comment was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Check if this comment was created via an email reply. */
    createdViaEmail: Scalars['Boolean']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The diff hunk to which the comment applies. */
    diffHunk: Scalars['String']['output'];
    /** Identifies when the comment was created in a draft state. */
    draftedAt: Scalars['DateTime']['output'];
    /** The actor who edited the comment. */
    editor?: Maybe<Actor>;
    id: Scalars['ID']['output'];
    /** Check if this comment was edited and includes an edit with the creation data */
    includesCreatedEdit: Scalars['Boolean']['output'];
    /** Returns whether or not a comment has been minimized. */
    isMinimized: Scalars['Boolean']['output'];
    /** The moment the editor made the last edit */
    lastEditedAt?: Maybe<Scalars['DateTime']['output']>;
    /** Returns why the comment was minimized. */
    minimizedReason?: Maybe<Scalars['String']['output']>;
    /** Identifies the original commit associated with the comment. */
    originalCommit?: Maybe<Commit>;
    /** The original line index in the diff to which the comment applies. */
    originalPosition: Scalars['Int']['output'];
    /** Identifies when the comment body is outdated */
    outdated: Scalars['Boolean']['output'];
    /** The path to which the comment applies. */
    path: Scalars['String']['output'];
    /** The line index in the diff to which the comment applies. */
    position?: Maybe<Scalars['Int']['output']>;
    /** Identifies when the comment was published at. */
    publishedAt?: Maybe<Scalars['DateTime']['output']>;
    /** The pull request associated with this review comment. */
    pullRequest: PullRequest;
    /** The pull request review associated with this review comment. */
    pullRequestReview?: Maybe<PullRequestReview>;
    /** A list of reactions grouped by content left on the subject. */
    reactionGroups?: Maybe<Array<ReactionGroup>>;
    /** A list of Reactions left on the Issue. */
    reactions: ReactionConnection;
    /** The comment this is a reply to. */
    replyTo?: Maybe<PullRequestReviewComment>;
    /** The repository associated with this node. */
    repository: Repository;
    /** The HTTP path permalink for this review comment. */
    resourcePath: Scalars['URI']['output'];
    /** Identifies the state of the comment. */
    state: PullRequestReviewCommentState;
    /** Identifies when the comment was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL permalink for this review comment. */
    url: Scalars['URI']['output'];
    /** A list of edits to this content. */
    userContentEdits?: Maybe<UserContentEditConnection>;
    /** Check if the current viewer can delete this object. */
    viewerCanDelete: Scalars['Boolean']['output'];
    /** Check if the current viewer can minimize this object. */
    viewerCanMinimize: Scalars['Boolean']['output'];
    /** Can user react to this subject */
    viewerCanReact: Scalars['Boolean']['output'];
    /** Check if the current viewer can update this object. */
    viewerCanUpdate: Scalars['Boolean']['output'];
    /** Reasons why the current viewer can not update this comment. */
    viewerCannotUpdateReasons: Array<CommentCannotUpdateReason>;
    /** Did the viewer author this comment. */
    viewerDidAuthor: Scalars['Boolean']['output'];
};
/** A review comment associated with a given repository pull request. */
export type PullRequestReviewCommentReactionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    content?: InputMaybe<ReactionContent>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ReactionOrder>;
};
/** A review comment associated with a given repository pull request. */
export type PullRequestReviewCommentUserContentEditsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** The connection type for PullRequestReviewComment. */
export type PullRequestReviewCommentConnection = {
    __typename?: 'PullRequestReviewCommentConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<PullRequestReviewCommentEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<PullRequestReviewComment>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type PullRequestReviewCommentEdge = {
    __typename?: 'PullRequestReviewCommentEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<PullRequestReviewComment>;
};
/** The possible states of a pull request review comment. */
export declare enum PullRequestReviewCommentState {
    /** A comment that is part of a pending review */
    Pending = "PENDING",
    /** A comment that is part of a submitted review */
    Submitted = "SUBMITTED"
}
/** The connection type for PullRequestReview. */
export type PullRequestReviewConnection = {
    __typename?: 'PullRequestReviewConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<PullRequestReviewEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<PullRequestReview>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** This aggregates pull request reviews made by a user within one repository. */
export type PullRequestReviewContributionsByRepository = {
    __typename?: 'PullRequestReviewContributionsByRepository';
    /** The pull request review contributions. */
    contributions: CreatedPullRequestReviewContributionConnection;
    /** The repository in which the pull request reviews were made. */
    repository: Repository;
};
/** This aggregates pull request reviews made by a user within one repository. */
export type PullRequestReviewContributionsByRepositoryContributionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ContributionOrder>;
};
/** The review status of a pull request. */
export declare enum PullRequestReviewDecision {
    /** The pull request has received an approving review. */
    Approved = "APPROVED",
    /** Changes have been requested on the pull request. */
    ChangesRequested = "CHANGES_REQUESTED",
    /** A review is required before the pull request can be merged. */
    ReviewRequired = "REVIEW_REQUIRED"
}
/** An edge in a connection. */
export type PullRequestReviewEdge = {
    __typename?: 'PullRequestReviewEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<PullRequestReview>;
};
/** The possible events to perform on a pull request review. */
export declare enum PullRequestReviewEvent {
    /** Submit feedback and approve merging these changes. */
    Approve = "APPROVE",
    /** Submit general feedback without explicit approval. */
    Comment = "COMMENT",
    /** Dismiss review so it now longer effects merging. */
    Dismiss = "DISMISS",
    /** Submit feedback that must be addressed before merging. */
    RequestChanges = "REQUEST_CHANGES"
}
/** The possible states of a pull request review. */
export declare enum PullRequestReviewState {
    /** A review allowing the pull request to merge. */
    Approved = "APPROVED",
    /** A review blocking the pull request from merging. */
    ChangesRequested = "CHANGES_REQUESTED",
    /** An informational review. */
    Commented = "COMMENTED",
    /** A review that has been dismissed. */
    Dismissed = "DISMISSED",
    /** A review that has not yet been submitted. */
    Pending = "PENDING"
}
/** A threaded list of comments for a given pull request. */
export type PullRequestReviewThread = Node & {
    __typename?: 'PullRequestReviewThread';
    /** A list of pull request comments associated with the thread. */
    comments: PullRequestReviewCommentConnection;
    /** The side of the diff on which this thread was placed. */
    diffSide: DiffSide;
    id: Scalars['ID']['output'];
    /** Whether or not the thread has been collapsed (outdated or resolved) */
    isCollapsed: Scalars['Boolean']['output'];
    /** Indicates whether this thread was outdated by newer changes. */
    isOutdated: Scalars['Boolean']['output'];
    /** Whether this thread has been resolved */
    isResolved: Scalars['Boolean']['output'];
    /** The line in the file to which this thread refers */
    line?: Maybe<Scalars['Int']['output']>;
    /** The original line in the file to which this thread refers. */
    originalLine?: Maybe<Scalars['Int']['output']>;
    /** The original start line in the file to which this thread refers (multi-line only). */
    originalStartLine?: Maybe<Scalars['Int']['output']>;
    /** Identifies the file path of this thread. */
    path: Scalars['String']['output'];
    /** Identifies the pull request associated with this thread. */
    pullRequest: PullRequest;
    /** Identifies the repository associated with this thread. */
    repository: Repository;
    /** The user who resolved this thread */
    resolvedBy?: Maybe<User>;
    /** The side of the diff that the first line of the thread starts on (multi-line only) */
    startDiffSide?: Maybe<DiffSide>;
    /** The start line in the file to which this thread refers (multi-line only) */
    startLine?: Maybe<Scalars['Int']['output']>;
    /** Indicates whether the current viewer can reply to this thread. */
    viewerCanReply: Scalars['Boolean']['output'];
    /** Whether or not the viewer can resolve this thread */
    viewerCanResolve: Scalars['Boolean']['output'];
    /** Whether or not the viewer can unresolve this thread */
    viewerCanUnresolve: Scalars['Boolean']['output'];
};
/** A threaded list of comments for a given pull request. */
export type PullRequestReviewThreadCommentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    skip?: InputMaybe<Scalars['Int']['input']>;
};
/** Review comment threads for a pull request review. */
export type PullRequestReviewThreadConnection = {
    __typename?: 'PullRequestReviewThreadConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<PullRequestReviewThreadEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<PullRequestReviewThread>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type PullRequestReviewThreadEdge = {
    __typename?: 'PullRequestReviewThreadEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<PullRequestReviewThread>;
};
/** Represents the latest point in the pull request timeline for which the viewer has seen the pull request's commits. */
export type PullRequestRevisionMarker = {
    __typename?: 'PullRequestRevisionMarker';
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The last commit the viewer has seen. */
    lastSeenCommit: Commit;
    /** The pull request to which the marker belongs. */
    pullRequest: PullRequest;
};
/** The possible states of a pull request. */
export declare enum PullRequestState {
    /** A pull request that has been closed without being merged. */
    Closed = "CLOSED",
    /** A pull request that has been closed by being merged. */
    Merged = "MERGED",
    /** A pull request that is still open. */
    Open = "OPEN"
}
/** A repository pull request template. */
export type PullRequestTemplate = {
    __typename?: 'PullRequestTemplate';
    /** The body of the template */
    body?: Maybe<Scalars['String']['output']>;
    /** The filename of the template */
    filename?: Maybe<Scalars['String']['output']>;
    /** The repository the template belongs to */
    repository: Repository;
};
/** The connection type for PullRequestTimelineItem. */
export type PullRequestTimelineConnection = {
    __typename?: 'PullRequestTimelineConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<PullRequestTimelineItemEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<PullRequestTimelineItem>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An item in a pull request timeline */
export type PullRequestTimelineItem = AssignedEvent | BaseRefDeletedEvent | BaseRefForcePushedEvent | ClosedEvent | Commit | CommitCommentThread | CrossReferencedEvent | DemilestonedEvent | DeployedEvent | DeploymentEnvironmentChangedEvent | HeadRefDeletedEvent | HeadRefForcePushedEvent | HeadRefRestoredEvent | IssueComment | LabeledEvent | LockedEvent | MergedEvent | MilestonedEvent | PullRequestReview | PullRequestReviewComment | PullRequestReviewThread | ReferencedEvent | RenamedTitleEvent | ReopenedEvent | ReviewDismissedEvent | ReviewRequestRemovedEvent | ReviewRequestedEvent | SubscribedEvent | UnassignedEvent | UnlabeledEvent | UnlockedEvent | UnsubscribedEvent | UserBlockedEvent;
/** An edge in a connection. */
export type PullRequestTimelineItemEdge = {
    __typename?: 'PullRequestTimelineItemEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<PullRequestTimelineItem>;
};
/** An item in a pull request timeline */
export type PullRequestTimelineItems = AddedToProjectEvent | AssignedEvent | AutoMergeDisabledEvent | AutoMergeEnabledEvent | AutoRebaseEnabledEvent | AutoSquashEnabledEvent | AutomaticBaseChangeFailedEvent | AutomaticBaseChangeSucceededEvent | BaseRefChangedEvent | BaseRefDeletedEvent | BaseRefForcePushedEvent | ClosedEvent | CommentDeletedEvent | ConnectedEvent | ConvertToDraftEvent | ConvertedNoteToIssueEvent | CrossReferencedEvent | DemilestonedEvent | DeployedEvent | DeploymentEnvironmentChangedEvent | DisconnectedEvent | HeadRefDeletedEvent | HeadRefForcePushedEvent | HeadRefRestoredEvent | IssueComment | LabeledEvent | LockedEvent | MarkedAsDuplicateEvent | MentionedEvent | MergedEvent | MilestonedEvent | MovedColumnsInProjectEvent | PinnedEvent | PullRequestCommit | PullRequestCommitCommentThread | PullRequestReview | PullRequestReviewThread | PullRequestRevisionMarker | ReadyForReviewEvent | ReferencedEvent | RemovedFromProjectEvent | RenamedTitleEvent | ReopenedEvent | ReviewDismissedEvent | ReviewRequestRemovedEvent | ReviewRequestedEvent | SubscribedEvent | TransferredEvent | UnassignedEvent | UnlabeledEvent | UnlockedEvent | UnmarkedAsDuplicateEvent | UnpinnedEvent | UnsubscribedEvent | UserBlockedEvent;
/** The connection type for PullRequestTimelineItems. */
export type PullRequestTimelineItemsConnection = {
    __typename?: 'PullRequestTimelineItemsConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<PullRequestTimelineItemsEdge>>>;
    /** Identifies the count of items after applying `before` and `after` filters. */
    filteredCount: Scalars['Int']['output'];
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<PullRequestTimelineItems>>>;
    /** Identifies the count of items after applying `before`/`after` filters and `first`/`last`/`skip` slicing. */
    pageCount: Scalars['Int']['output'];
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
    /** Identifies the date and time when the timeline was last updated. */
    updatedAt: Scalars['DateTime']['output'];
};
/** An edge in a connection. */
export type PullRequestTimelineItemsEdge = {
    __typename?: 'PullRequestTimelineItemsEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<PullRequestTimelineItems>;
};
/** The possible item types found in a timeline. */
export declare enum PullRequestTimelineItemsItemType {
    /** Represents a 'added_to_project' event on a given issue or pull request. */
    AddedToProjectEvent = "ADDED_TO_PROJECT_EVENT",
    /** Represents an 'assigned' event on any assignable object. */
    AssignedEvent = "ASSIGNED_EVENT",
    /** Represents a 'automatic_base_change_failed' event on a given pull request. */
    AutomaticBaseChangeFailedEvent = "AUTOMATIC_BASE_CHANGE_FAILED_EVENT",
    /** Represents a 'automatic_base_change_succeeded' event on a given pull request. */
    AutomaticBaseChangeSucceededEvent = "AUTOMATIC_BASE_CHANGE_SUCCEEDED_EVENT",
    /** Represents a 'auto_merge_disabled' event on a given pull request. */
    AutoMergeDisabledEvent = "AUTO_MERGE_DISABLED_EVENT",
    /** Represents a 'auto_merge_enabled' event on a given pull request. */
    AutoMergeEnabledEvent = "AUTO_MERGE_ENABLED_EVENT",
    /** Represents a 'auto_rebase_enabled' event on a given pull request. */
    AutoRebaseEnabledEvent = "AUTO_REBASE_ENABLED_EVENT",
    /** Represents a 'auto_squash_enabled' event on a given pull request. */
    AutoSquashEnabledEvent = "AUTO_SQUASH_ENABLED_EVENT",
    /** Represents a 'base_ref_changed' event on a given issue or pull request. */
    BaseRefChangedEvent = "BASE_REF_CHANGED_EVENT",
    /** Represents a 'base_ref_deleted' event on a given pull request. */
    BaseRefDeletedEvent = "BASE_REF_DELETED_EVENT",
    /** Represents a 'base_ref_force_pushed' event on a given pull request. */
    BaseRefForcePushedEvent = "BASE_REF_FORCE_PUSHED_EVENT",
    /** Represents a 'closed' event on any `Closable`. */
    ClosedEvent = "CLOSED_EVENT",
    /** Represents a 'comment_deleted' event on a given issue or pull request. */
    CommentDeletedEvent = "COMMENT_DELETED_EVENT",
    /** Represents a 'connected' event on a given issue or pull request. */
    ConnectedEvent = "CONNECTED_EVENT",
    /** Represents a 'converted_note_to_issue' event on a given issue or pull request. */
    ConvertedNoteToIssueEvent = "CONVERTED_NOTE_TO_ISSUE_EVENT",
    /** Represents a 'convert_to_draft' event on a given pull request. */
    ConvertToDraftEvent = "CONVERT_TO_DRAFT_EVENT",
    /** Represents a mention made by one issue or pull request to another. */
    CrossReferencedEvent = "CROSS_REFERENCED_EVENT",
    /** Represents a 'demilestoned' event on a given issue or pull request. */
    DemilestonedEvent = "DEMILESTONED_EVENT",
    /** Represents a 'deployed' event on a given pull request. */
    DeployedEvent = "DEPLOYED_EVENT",
    /** Represents a 'deployment_environment_changed' event on a given pull request. */
    DeploymentEnvironmentChangedEvent = "DEPLOYMENT_ENVIRONMENT_CHANGED_EVENT",
    /** Represents a 'disconnected' event on a given issue or pull request. */
    DisconnectedEvent = "DISCONNECTED_EVENT",
    /** Represents a 'head_ref_deleted' event on a given pull request. */
    HeadRefDeletedEvent = "HEAD_REF_DELETED_EVENT",
    /** Represents a 'head_ref_force_pushed' event on a given pull request. */
    HeadRefForcePushedEvent = "HEAD_REF_FORCE_PUSHED_EVENT",
    /** Represents a 'head_ref_restored' event on a given pull request. */
    HeadRefRestoredEvent = "HEAD_REF_RESTORED_EVENT",
    /** Represents a comment on an Issue. */
    IssueComment = "ISSUE_COMMENT",
    /** Represents a 'labeled' event on a given issue or pull request. */
    LabeledEvent = "LABELED_EVENT",
    /** Represents a 'locked' event on a given issue or pull request. */
    LockedEvent = "LOCKED_EVENT",
    /** Represents a 'marked_as_duplicate' event on a given issue or pull request. */
    MarkedAsDuplicateEvent = "MARKED_AS_DUPLICATE_EVENT",
    /** Represents a 'mentioned' event on a given issue or pull request. */
    MentionedEvent = "MENTIONED_EVENT",
    /** Represents a 'merged' event on a given pull request. */
    MergedEvent = "MERGED_EVENT",
    /** Represents a 'milestoned' event on a given issue or pull request. */
    MilestonedEvent = "MILESTONED_EVENT",
    /** Represents a 'moved_columns_in_project' event on a given issue or pull request. */
    MovedColumnsInProjectEvent = "MOVED_COLUMNS_IN_PROJECT_EVENT",
    /** Represents a 'pinned' event on a given issue or pull request. */
    PinnedEvent = "PINNED_EVENT",
    /** Represents a Git commit part of a pull request. */
    PullRequestCommit = "PULL_REQUEST_COMMIT",
    /** Represents a commit comment thread part of a pull request. */
    PullRequestCommitCommentThread = "PULL_REQUEST_COMMIT_COMMENT_THREAD",
    /** A review object for a given pull request. */
    PullRequestReview = "PULL_REQUEST_REVIEW",
    /** A threaded list of comments for a given pull request. */
    PullRequestReviewThread = "PULL_REQUEST_REVIEW_THREAD",
    /** Represents the latest point in the pull request timeline for which the viewer has seen the pull request's commits. */
    PullRequestRevisionMarker = "PULL_REQUEST_REVISION_MARKER",
    /** Represents a 'ready_for_review' event on a given pull request. */
    ReadyForReviewEvent = "READY_FOR_REVIEW_EVENT",
    /** Represents a 'referenced' event on a given `ReferencedSubject`. */
    ReferencedEvent = "REFERENCED_EVENT",
    /** Represents a 'removed_from_project' event on a given issue or pull request. */
    RemovedFromProjectEvent = "REMOVED_FROM_PROJECT_EVENT",
    /** Represents a 'renamed' event on a given issue or pull request */
    RenamedTitleEvent = "RENAMED_TITLE_EVENT",
    /** Represents a 'reopened' event on any `Closable`. */
    ReopenedEvent = "REOPENED_EVENT",
    /** Represents a 'review_dismissed' event on a given issue or pull request. */
    ReviewDismissedEvent = "REVIEW_DISMISSED_EVENT",
    /** Represents an 'review_requested' event on a given pull request. */
    ReviewRequestedEvent = "REVIEW_REQUESTED_EVENT",
    /** Represents an 'review_request_removed' event on a given pull request. */
    ReviewRequestRemovedEvent = "REVIEW_REQUEST_REMOVED_EVENT",
    /** Represents a 'subscribed' event on a given `Subscribable`. */
    SubscribedEvent = "SUBSCRIBED_EVENT",
    /** Represents a 'transferred' event on a given issue or pull request. */
    TransferredEvent = "TRANSFERRED_EVENT",
    /** Represents an 'unassigned' event on any assignable object. */
    UnassignedEvent = "UNASSIGNED_EVENT",
    /** Represents an 'unlabeled' event on a given issue or pull request. */
    UnlabeledEvent = "UNLABELED_EVENT",
    /** Represents an 'unlocked' event on a given issue or pull request. */
    UnlockedEvent = "UNLOCKED_EVENT",
    /** Represents an 'unmarked_as_duplicate' event on a given issue or pull request. */
    UnmarkedAsDuplicateEvent = "UNMARKED_AS_DUPLICATE_EVENT",
    /** Represents an 'unpinned' event on a given issue or pull request. */
    UnpinnedEvent = "UNPINNED_EVENT",
    /** Represents an 'unsubscribed' event on a given `Subscribable`. */
    UnsubscribedEvent = "UNSUBSCRIBED_EVENT",
    /** Represents a 'user_blocked' event on a given user. */
    UserBlockedEvent = "USER_BLOCKED_EVENT"
}
/** The possible target states when updating a pull request. */
export declare enum PullRequestUpdateState {
    /** A pull request that has been closed without being merged. */
    Closed = "CLOSED",
    /** A pull request that is still open. */
    Open = "OPEN"
}
/** A Git push. */
export type Push = Node & {
    __typename?: 'Push';
    id: Scalars['ID']['output'];
    /** The SHA after the push */
    nextSha?: Maybe<Scalars['GitObjectID']['output']>;
    /** The permalink for this push. */
    permalink: Scalars['URI']['output'];
    /** The SHA before the push */
    previousSha?: Maybe<Scalars['GitObjectID']['output']>;
    /** The user who pushed */
    pusher: User;
    /** The repository that was pushed to */
    repository: Repository;
};
/** A team, user or app who has the ability to push to a protected branch. */
export type PushAllowance = Node & {
    __typename?: 'PushAllowance';
    /** The actor that can push. */
    actor?: Maybe<PushAllowanceActor>;
    /** Identifies the branch protection rule associated with the allowed user or team. */
    branchProtectionRule?: Maybe<BranchProtectionRule>;
    id: Scalars['ID']['output'];
};
/** Types that can be an actor. */
export type PushAllowanceActor = App | Team | User;
/** The connection type for PushAllowance. */
export type PushAllowanceConnection = {
    __typename?: 'PushAllowanceConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<PushAllowanceEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<PushAllowance>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type PushAllowanceEdge = {
    __typename?: 'PushAllowanceEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<PushAllowance>;
};
/** The query root of GitHub's GraphQL interface. */
export type Query = {
    __typename?: 'Query';
    /** Look up a code of conduct by its key */
    codeOfConduct?: Maybe<CodeOfConduct>;
    /** Look up a code of conduct by its key */
    codesOfConduct?: Maybe<Array<Maybe<CodeOfConduct>>>;
    /** Look up an enterprise by URL slug. */
    enterprise?: Maybe<Enterprise>;
    /** Look up an open source license by its key */
    license?: Maybe<License>;
    /** Return a list of known open source licenses */
    licenses: Array<Maybe<License>>;
    /** Return information about the GitHub instance */
    meta: GitHubMetadata;
    /** Fetches an object given its ID. */
    node?: Maybe<Node>;
    /** Lookup nodes by a list of IDs. */
    nodes: Array<Maybe<Node>>;
    /** Lookup a organization by login. */
    organization?: Maybe<Organization>;
    /** A list of organizations. */
    organizations: OrganizationConnection;
    /** The client's rate limit information. */
    rateLimit?: Maybe<RateLimit>;
    /** Hack to workaround https://github.com/facebook/relay/issues/112 re-exposing the root query object */
    relay: Query;
    /** Lookup a given repository by the owner and repository name. */
    repository?: Maybe<Repository>;
    /** Lookup a repository owner (ie. either a User or an Organization) by login. */
    repositoryOwner?: Maybe<RepositoryOwner>;
    /** Lookup resource by a URL. */
    resource?: Maybe<UniformResourceLocatable>;
    /** Perform a search across resources. */
    search: SearchResultItemConnection;
    /** GitHub Security Advisories */
    securityAdvisories: SecurityAdvisoryConnection;
    /** Fetch a Security Advisory by its GHSA ID */
    securityAdvisory?: Maybe<SecurityAdvisory>;
    /** Software Vulnerabilities documented by GitHub Security Advisories */
    securityVulnerabilities: SecurityVulnerabilityConnection;
    /** Look up a topic by name. */
    topic?: Maybe<Topic>;
    /** Lookup a user by login. */
    user?: Maybe<User>;
    /** A list of users. */
    users: UserConnection;
    /** The currently authenticated user. */
    viewer: User;
};
/** The query root of GitHub's GraphQL interface. */
export type QueryCodeOfConductArgs = {
    key: Scalars['String']['input'];
};
/** The query root of GitHub's GraphQL interface. */
export type QueryEnterpriseArgs = {
    invitationToken?: InputMaybe<Scalars['String']['input']>;
    slug: Scalars['String']['input'];
};
/** The query root of GitHub's GraphQL interface. */
export type QueryLicenseArgs = {
    key: Scalars['String']['input'];
};
/** The query root of GitHub's GraphQL interface. */
export type QueryNodeArgs = {
    id: Scalars['ID']['input'];
};
/** The query root of GitHub's GraphQL interface. */
export type QueryNodesArgs = {
    ids: Array<Scalars['ID']['input']>;
};
/** The query root of GitHub's GraphQL interface. */
export type QueryOrganizationArgs = {
    login: Scalars['String']['input'];
};
/** The query root of GitHub's GraphQL interface. */
export type QueryOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** The query root of GitHub's GraphQL interface. */
export type QueryRateLimitArgs = {
    dryRun?: InputMaybe<Scalars['Boolean']['input']>;
};
/** The query root of GitHub's GraphQL interface. */
export type QueryRepositoryArgs = {
    name: Scalars['String']['input'];
    owner: Scalars['String']['input'];
};
/** The query root of GitHub's GraphQL interface. */
export type QueryRepositoryOwnerArgs = {
    login: Scalars['String']['input'];
};
/** The query root of GitHub's GraphQL interface. */
export type QueryResourceArgs = {
    url: Scalars['URI']['input'];
};
/** The query root of GitHub's GraphQL interface. */
export type QuerySearchArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    query: Scalars['String']['input'];
    type: SearchType;
};
/** The query root of GitHub's GraphQL interface. */
export type QuerySecurityAdvisoriesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    publishedSince?: InputMaybe<Scalars['DateTime']['input']>;
    updatedSince?: InputMaybe<Scalars['DateTime']['input']>;
};
/** The query root of GitHub's GraphQL interface. */
export type QuerySecurityAdvisoryArgs = {
    ghsaId: Scalars['String']['input'];
};
/** The query root of GitHub's GraphQL interface. */
export type QuerySecurityVulnerabilitiesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    ecosystem?: InputMaybe<SecurityAdvisoryEcosystem>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    package?: InputMaybe<Scalars['String']['input']>;
    severities?: InputMaybe<Array<SecurityAdvisorySeverity>>;
};
/** The query root of GitHub's GraphQL interface. */
export type QueryTopicArgs = {
    name: Scalars['String']['input'];
};
/** The query root of GitHub's GraphQL interface. */
export type QueryUserArgs = {
    login: Scalars['String']['input'];
};
/** The query root of GitHub's GraphQL interface. */
export type QueryUsersArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** Represents the client's rate limit. */
export type RateLimit = {
    __typename?: 'RateLimit';
    /** The point cost for the current query counting against the rate limit. */
    cost: Scalars['Int']['output'];
    /** The maximum number of points the client is permitted to consume in a 60 minute window. */
    limit: Scalars['Int']['output'];
    /** The maximum number of nodes this query may return */
    nodeCount: Scalars['Int']['output'];
    /** The number of points remaining in the current rate limit window. */
    remaining: Scalars['Int']['output'];
    /** The time at which the current rate limit window resets in UTC epoch seconds. */
    resetAt: Scalars['DateTime']['output'];
    /** The number of points used in the current rate limit window. */
    used: Scalars['Int']['output'];
};
/** Represents a subject that can be reacted on. */
export type Reactable = {
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** A list of reactions grouped by content left on the subject. */
    reactionGroups?: Maybe<Array<ReactionGroup>>;
    /** A list of Reactions left on the Issue. */
    reactions: ReactionConnection;
    /** Can user react to this subject */
    viewerCanReact: Scalars['Boolean']['output'];
};
/** Represents a subject that can be reacted on. */
export type ReactableReactionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    content?: InputMaybe<ReactionContent>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ReactionOrder>;
};
/** The connection type for User. */
export type ReactingUserConnection = {
    __typename?: 'ReactingUserConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<ReactingUserEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<User>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** Represents a user that's made a reaction. */
export type ReactingUserEdge = {
    __typename?: 'ReactingUserEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    node: User;
    /** The moment when the user made the reaction. */
    reactedAt: Scalars['DateTime']['output'];
};
/** An emoji reaction to a particular piece of content. */
export type Reaction = Node & {
    __typename?: 'Reaction';
    /** Identifies the emoji reaction. */
    content: ReactionContent;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** The reactable piece of content */
    reactable: Reactable;
    /** Identifies the user who created this reaction. */
    user?: Maybe<User>;
};
/** A list of reactions that have been left on the subject. */
export type ReactionConnection = {
    __typename?: 'ReactionConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<ReactionEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Reaction>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
    /** Whether or not the authenticated user has left a reaction on the subject. */
    viewerHasReacted: Scalars['Boolean']['output'];
};
/** Emojis that can be attached to Issues, Pull Requests and Comments. */
export declare enum ReactionContent {
    /** Represents the `:confused:` emoji. */
    Confused = "CONFUSED",
    /** Represents the `:eyes:` emoji. */
    Eyes = "EYES",
    /** Represents the `:heart:` emoji. */
    Heart = "HEART",
    /** Represents the `:hooray:` emoji. */
    Hooray = "HOORAY",
    /** Represents the `:laugh:` emoji. */
    Laugh = "LAUGH",
    /** Represents the `:rocket:` emoji. */
    Rocket = "ROCKET",
    /** Represents the `:-1:` emoji. */
    ThumbsDown = "THUMBS_DOWN",
    /** Represents the `:+1:` emoji. */
    ThumbsUp = "THUMBS_UP"
}
/** An edge in a connection. */
export type ReactionEdge = {
    __typename?: 'ReactionEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Reaction>;
};
/** A group of emoji reactions to a particular piece of content. */
export type ReactionGroup = {
    __typename?: 'ReactionGroup';
    /** Identifies the emoji reaction. */
    content: ReactionContent;
    /** Identifies when the reaction was created. */
    createdAt?: Maybe<Scalars['DateTime']['output']>;
    /** Reactors to the reaction subject with the emotion represented by this reaction group. */
    reactors: ReactorConnection;
    /** The subject that was reacted to. */
    subject: Reactable;
    /**
     * Users who have reacted to the reaction subject with the emotion represented by this reaction group
     * @deprecated Reactors can now be mannequins, bots, and organizations. Use the `reactors` field instead. Removal on 2021-10-01 UTC.
     */
    users: ReactingUserConnection;
    /** Whether or not the authenticated user has left a reaction on the subject. */
    viewerHasReacted: Scalars['Boolean']['output'];
};
/** A group of emoji reactions to a particular piece of content. */
export type ReactionGroupReactorsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A group of emoji reactions to a particular piece of content. */
export type ReactionGroupUsersArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** Ways in which lists of reactions can be ordered upon return. */
export type ReactionOrder = {
    /** The direction in which to order reactions by the specified field. */
    direction: OrderDirection;
    /** The field in which to order reactions by. */
    field: ReactionOrderField;
};
/** A list of fields that reactions can be ordered by. */
export declare enum ReactionOrderField {
    /** Allows ordering a list of reactions by when they were created. */
    CreatedAt = "CREATED_AT"
}
/** Types that can be assigned to reactions. */
export type Reactor = Bot | Mannequin | Organization | User;
/** The connection type for Reactor. */
export type ReactorConnection = {
    __typename?: 'ReactorConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<ReactorEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Reactor>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** Represents an author of a reaction. */
export type ReactorEdge = {
    __typename?: 'ReactorEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The author of the reaction. */
    node: Reactor;
    /** The moment when the user made the reaction. */
    reactedAt: Scalars['DateTime']['output'];
};
/** Represents a 'ready_for_review' event on a given pull request. */
export type ReadyForReviewEvent = Node & UniformResourceLocatable & {
    __typename?: 'ReadyForReviewEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** PullRequest referenced by event. */
    pullRequest: PullRequest;
    /** The HTTP path for this ready for review event. */
    resourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this ready for review event. */
    url: Scalars['URI']['output'];
};
/** Represents a Git reference. */
export type Ref = Node & {
    __typename?: 'Ref';
    /** A list of pull requests with this ref as the head ref. */
    associatedPullRequests: PullRequestConnection;
    /** Branch protection rules for this ref */
    branchProtectionRule?: Maybe<BranchProtectionRule>;
    id: Scalars['ID']['output'];
    /** The ref name. */
    name: Scalars['String']['output'];
    /** The ref's prefix, such as `refs/heads/` or `refs/tags/`. */
    prefix: Scalars['String']['output'];
    /** Branch protection rules that are viewable by non-admins */
    refUpdateRule?: Maybe<RefUpdateRule>;
    /** The repository the ref belongs to. */
    repository: Repository;
    /** The object the ref points to. Returns null when object does not exist. */
    target?: Maybe<GitObject>;
};
/** Represents a Git reference. */
export type RefAssociatedPullRequestsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    baseRefName?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    headRefName?: InputMaybe<Scalars['String']['input']>;
    labels?: InputMaybe<Array<Scalars['String']['input']>>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<IssueOrder>;
    states?: InputMaybe<Array<PullRequestState>>;
};
/** The connection type for Ref. */
export type RefConnection = {
    __typename?: 'RefConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<RefEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Ref>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type RefEdge = {
    __typename?: 'RefEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Ref>;
};
/** Ways in which lists of git refs can be ordered upon return. */
export type RefOrder = {
    /** The direction in which to order refs by the specified field. */
    direction: OrderDirection;
    /** The field in which to order refs by. */
    field: RefOrderField;
};
/** Properties by which ref connections can be ordered. */
export declare enum RefOrderField {
    /** Order refs by their alphanumeric name */
    Alphabetical = "ALPHABETICAL",
    /** Order refs by underlying commit date if the ref prefix is refs/tags/ */
    TagCommitDate = "TAG_COMMIT_DATE"
}
/** A ref update */
export type RefUpdate = {
    /** The value this ref should be updated to. */
    afterOid: Scalars['GitObjectID']['input'];
    /** The value this ref needs to point to before the update. */
    beforeOid?: InputMaybe<Scalars['GitObjectID']['input']>;
    /** Force a non fast-forward update. */
    force?: InputMaybe<Scalars['Boolean']['input']>;
    /** The fully qualified name of the ref to be update. For example `refs/heads/branch-name` */
    name: Scalars['GitRefname']['input'];
};
/** A ref update rules for a viewer. */
export type RefUpdateRule = {
    __typename?: 'RefUpdateRule';
    /** Can this branch be deleted. */
    allowsDeletions: Scalars['Boolean']['output'];
    /** Are force pushes allowed on this branch. */
    allowsForcePushes: Scalars['Boolean']['output'];
    /** Identifies the protection rule pattern. */
    pattern: Scalars['String']['output'];
    /** Number of approving reviews required to update matching branches. */
    requiredApprovingReviewCount?: Maybe<Scalars['Int']['output']>;
    /** List of required status check contexts that must pass for commits to be accepted to matching branches. */
    requiredStatusCheckContexts?: Maybe<Array<Maybe<Scalars['String']['output']>>>;
    /** Are reviews from code owners required to update matching branches. */
    requiresCodeOwnerReviews: Scalars['Boolean']['output'];
    /** Are conversations required to be resolved before merging. */
    requiresConversationResolution: Scalars['Boolean']['output'];
    /** Are merge commits prohibited from being pushed to this branch. */
    requiresLinearHistory: Scalars['Boolean']['output'];
    /** Are commits required to be signed. */
    requiresSignatures: Scalars['Boolean']['output'];
    /** Is the viewer allowed to dismiss reviews. */
    viewerAllowedToDismissReviews: Scalars['Boolean']['output'];
    /** Can the viewer push to the branch */
    viewerCanPush: Scalars['Boolean']['output'];
};
/** Represents a 'referenced' event on a given `ReferencedSubject`. */
export type ReferencedEvent = Node & {
    __typename?: 'ReferencedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the commit associated with the 'referenced' event. */
    commit?: Maybe<Commit>;
    /** Identifies the repository associated with the 'referenced' event. */
    commitRepository: Repository;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** Reference originated in a different repository. */
    isCrossRepository: Scalars['Boolean']['output'];
    /** Checks if the commit message itself references the subject. Can be false in the case of a commit comment reference. */
    isDirectReference: Scalars['Boolean']['output'];
    /** Object referenced by event. */
    subject: ReferencedSubject;
};
/** Any referencable object */
export type ReferencedSubject = Issue | PullRequest;
/** Autogenerated input type of RegenerateVerifiableDomainToken */
export type RegenerateVerifiableDomainTokenInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the verifiable domain to regenerate the verification token of. */
    id: Scalars['ID']['input'];
};
/** Autogenerated return type of RegenerateVerifiableDomainToken */
export type RegenerateVerifiableDomainTokenPayload = {
    __typename?: 'RegenerateVerifiableDomainTokenPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The verification token that was generated. */
    verificationToken?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of RejectDeployments */
export type RejectDeploymentsInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** Optional comment for rejecting deployments */
    comment?: InputMaybe<Scalars['String']['input']>;
    /** The ids of environments to reject deployments */
    environmentIds: Array<Scalars['ID']['input']>;
    /** The node ID of the workflow run containing the pending deployments. */
    workflowRunId: Scalars['ID']['input'];
};
/** Autogenerated return type of RejectDeployments */
export type RejectDeploymentsPayload = {
    __typename?: 'RejectDeploymentsPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The affected deployments. */
    deployments?: Maybe<Array<Deployment>>;
};
/** A release contains the content for a release. */
export type Release = Node & Reactable & UniformResourceLocatable & {
    __typename?: 'Release';
    /** The author of the release */
    author?: Maybe<User>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The description of the release. */
    description?: Maybe<Scalars['String']['output']>;
    /** The description of this release rendered to HTML. */
    descriptionHTML?: Maybe<Scalars['HTML']['output']>;
    id: Scalars['ID']['output'];
    /** Whether or not the release is a draft */
    isDraft: Scalars['Boolean']['output'];
    /** Whether or not the release is the latest releast */
    isLatest: Scalars['Boolean']['output'];
    /** Whether or not the release is a prerelease */
    isPrerelease: Scalars['Boolean']['output'];
    /** A list of users mentioned in the release description */
    mentions?: Maybe<UserConnection>;
    /** The title of the release. */
    name?: Maybe<Scalars['String']['output']>;
    /** Identifies the date and time when the release was created. */
    publishedAt?: Maybe<Scalars['DateTime']['output']>;
    /** A list of reactions grouped by content left on the subject. */
    reactionGroups?: Maybe<Array<ReactionGroup>>;
    /** A list of Reactions left on the Issue. */
    reactions: ReactionConnection;
    /** List of releases assets which are dependent on this release. */
    releaseAssets: ReleaseAssetConnection;
    /** The repository that the release belongs to. */
    repository: Repository;
    /** The HTTP path for this issue */
    resourcePath: Scalars['URI']['output'];
    /** A description of the release, rendered to HTML without any links in it. */
    shortDescriptionHTML?: Maybe<Scalars['HTML']['output']>;
    /** The Git tag the release points to */
    tag?: Maybe<Ref>;
    /** The tag commit for this release. */
    tagCommit?: Maybe<Commit>;
    /** The name of the release's Git tag */
    tagName: Scalars['String']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this issue */
    url: Scalars['URI']['output'];
    /** Can user react to this subject */
    viewerCanReact: Scalars['Boolean']['output'];
};
/** A release contains the content for a release. */
export type ReleaseMentionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A release contains the content for a release. */
export type ReleaseReactionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    content?: InputMaybe<ReactionContent>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ReactionOrder>;
};
/** A release contains the content for a release. */
export type ReleaseReleaseAssetsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    name?: InputMaybe<Scalars['String']['input']>;
};
/** A release contains the content for a release. */
export type ReleaseShortDescriptionHtmlArgs = {
    limit?: InputMaybe<Scalars['Int']['input']>;
};
/** A release asset contains the content for a release asset. */
export type ReleaseAsset = Node & {
    __typename?: 'ReleaseAsset';
    /** The asset's content-type */
    contentType: Scalars['String']['output'];
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The number of times this asset was downloaded */
    downloadCount: Scalars['Int']['output'];
    /** Identifies the URL where you can download the release asset via the browser. */
    downloadUrl: Scalars['URI']['output'];
    id: Scalars['ID']['output'];
    /** Identifies the title of the release asset. */
    name: Scalars['String']['output'];
    /** Release that the asset is associated with */
    release?: Maybe<Release>;
    /** The size (in bytes) of the asset */
    size: Scalars['Int']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The user that performed the upload */
    uploadedBy: User;
    /** Identifies the URL of the release asset. */
    url: Scalars['URI']['output'];
};
/** The connection type for ReleaseAsset. */
export type ReleaseAssetConnection = {
    __typename?: 'ReleaseAssetConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<ReleaseAssetEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<ReleaseAsset>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type ReleaseAssetEdge = {
    __typename?: 'ReleaseAssetEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<ReleaseAsset>;
};
/** The connection type for Release. */
export type ReleaseConnection = {
    __typename?: 'ReleaseConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<ReleaseEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Release>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type ReleaseEdge = {
    __typename?: 'ReleaseEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Release>;
};
/** Ways in which lists of releases can be ordered upon return. */
export type ReleaseOrder = {
    /** The direction in which to order releases by the specified field. */
    direction: OrderDirection;
    /** The field in which to order releases by. */
    field: ReleaseOrderField;
};
/** Properties by which release connections can be ordered. */
export declare enum ReleaseOrderField {
    /** Order releases by creation time */
    CreatedAt = "CREATED_AT",
    /** Order releases alphabetically by name */
    Name = "NAME"
}
/** Autogenerated input type of RemoveAssigneesFromAssignable */
export type RemoveAssigneesFromAssignableInput = {
    /** The id of the assignable object to remove assignees from. */
    assignableId: Scalars['ID']['input'];
    /** The id of users to remove as assignees. */
    assigneeIds: Array<Scalars['ID']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
};
/** Autogenerated return type of RemoveAssigneesFromAssignable */
export type RemoveAssigneesFromAssignablePayload = {
    __typename?: 'RemoveAssigneesFromAssignablePayload';
    /** The item that was unassigned. */
    assignable?: Maybe<Assignable>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of RemoveEnterpriseAdmin */
export type RemoveEnterpriseAdminInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Enterprise ID from which to remove the administrator. */
    enterpriseId: Scalars['ID']['input'];
    /** The login of the user to remove as an administrator. */
    login: Scalars['String']['input'];
};
/** Autogenerated return type of RemoveEnterpriseAdmin */
export type RemoveEnterpriseAdminPayload = {
    __typename?: 'RemoveEnterpriseAdminPayload';
    /** The user who was removed as an administrator. */
    admin?: Maybe<User>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated enterprise. */
    enterprise?: Maybe<Enterprise>;
    /** A message confirming the result of removing an administrator. */
    message?: Maybe<Scalars['String']['output']>;
    /** The viewer performing the mutation. */
    viewer?: Maybe<User>;
};
/** Autogenerated input type of RemoveLabelsFromLabelable */
export type RemoveLabelsFromLabelableInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ids of labels to remove. */
    labelIds: Array<Scalars['ID']['input']>;
    /** The id of the Labelable to remove labels from. */
    labelableId: Scalars['ID']['input'];
};
/** Autogenerated return type of RemoveLabelsFromLabelable */
export type RemoveLabelsFromLabelablePayload = {
    __typename?: 'RemoveLabelsFromLabelablePayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The Labelable the labels were removed from. */
    labelable?: Maybe<Labelable>;
};
/** Autogenerated input type of RemoveOutsideCollaborator */
export type RemoveOutsideCollaboratorInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the organization to remove the outside collaborator from. */
    organizationId: Scalars['ID']['input'];
    /** The ID of the outside collaborator to remove. */
    userId: Scalars['ID']['input'];
};
/** Autogenerated return type of RemoveOutsideCollaborator */
export type RemoveOutsideCollaboratorPayload = {
    __typename?: 'RemoveOutsideCollaboratorPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The user that was removed as an outside collaborator. */
    removedUser?: Maybe<User>;
};
/** Autogenerated input type of RemoveReaction */
export type RemoveReactionInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The name of the emoji reaction to remove. */
    content: ReactionContent;
    /** The Node ID of the subject to modify. */
    subjectId: Scalars['ID']['input'];
};
/** Autogenerated return type of RemoveReaction */
export type RemoveReactionPayload = {
    __typename?: 'RemoveReactionPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The reaction object. */
    reaction?: Maybe<Reaction>;
    /** The reactable subject. */
    subject?: Maybe<Reactable>;
};
/** Autogenerated input type of RemoveStar */
export type RemoveStarInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Starrable ID to unstar. */
    starrableId: Scalars['ID']['input'];
};
/** Autogenerated return type of RemoveStar */
export type RemoveStarPayload = {
    __typename?: 'RemoveStarPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The starrable. */
    starrable?: Maybe<Starrable>;
};
/** Autogenerated input type of RemoveUpvote */
export type RemoveUpvoteInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the discussion or comment to remove upvote. */
    subjectId: Scalars['ID']['input'];
};
/** Autogenerated return type of RemoveUpvote */
export type RemoveUpvotePayload = {
    __typename?: 'RemoveUpvotePayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The votable subject. */
    subject?: Maybe<Votable>;
};
/** Represents a 'removed_from_project' event on a given issue or pull request. */
export type RemovedFromProjectEvent = Node & {
    __typename?: 'RemovedFromProjectEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** Project referenced by event. */
    project?: Maybe<Project>;
    /** Column name referenced by this project event. */
    projectColumnName: Scalars['String']['output'];
};
/** Represents a 'renamed' event on a given issue or pull request */
export type RenamedTitleEvent = Node & {
    __typename?: 'RenamedTitleEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the current title of the issue or pull request. */
    currentTitle: Scalars['String']['output'];
    id: Scalars['ID']['output'];
    /** Identifies the previous title of the issue or pull request. */
    previousTitle: Scalars['String']['output'];
    /** Subject that was renamed. */
    subject: RenamedTitleSubject;
};
/** An object which has a renamable title */
export type RenamedTitleSubject = Issue | PullRequest;
/** Autogenerated input type of ReopenIssue */
export type ReopenIssueInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** ID of the issue to be opened. */
    issueId: Scalars['ID']['input'];
};
/** Autogenerated return type of ReopenIssue */
export type ReopenIssuePayload = {
    __typename?: 'ReopenIssuePayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The issue that was opened. */
    issue?: Maybe<Issue>;
};
/** Autogenerated input type of ReopenPullRequest */
export type ReopenPullRequestInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** ID of the pull request to be reopened. */
    pullRequestId: Scalars['ID']['input'];
};
/** Autogenerated return type of ReopenPullRequest */
export type ReopenPullRequestPayload = {
    __typename?: 'ReopenPullRequestPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The pull request that was reopened. */
    pullRequest?: Maybe<PullRequest>;
};
/** Represents a 'reopened' event on any `Closable`. */
export type ReopenedEvent = Node & {
    __typename?: 'ReopenedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Object that was reopened. */
    closable: Closable;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
};
/** Audit log entry for a repo.access event. */
export type RepoAccessAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'RepoAccessAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
    /** The visibility of the repository */
    visibility?: Maybe<RepoAccessAuditEntryVisibility>;
};
/** The privacy of a repository */
export declare enum RepoAccessAuditEntryVisibility {
    /** The repository is visible only to users in the same business. */
    Internal = "INTERNAL",
    /** The repository is visible only to those with explicit access. */
    Private = "PRIVATE",
    /** The repository is visible to everyone. */
    Public = "PUBLIC"
}
/** Audit log entry for a repo.add_member event. */
export type RepoAddMemberAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'RepoAddMemberAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
    /** The visibility of the repository */
    visibility?: Maybe<RepoAddMemberAuditEntryVisibility>;
};
/** The privacy of a repository */
export declare enum RepoAddMemberAuditEntryVisibility {
    /** The repository is visible only to users in the same business. */
    Internal = "INTERNAL",
    /** The repository is visible only to those with explicit access. */
    Private = "PRIVATE",
    /** The repository is visible to everyone. */
    Public = "PUBLIC"
}
/** Audit log entry for a repo.add_topic event. */
export type RepoAddTopicAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & TopicAuditEntryData & {
    __typename?: 'RepoAddTopicAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The name of the topic added to the repository */
    topic?: Maybe<Topic>;
    /** The name of the topic added to the repository */
    topicName?: Maybe<Scalars['String']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a repo.archived event. */
export type RepoArchivedAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'RepoArchivedAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
    /** The visibility of the repository */
    visibility?: Maybe<RepoArchivedAuditEntryVisibility>;
};
/** The privacy of a repository */
export declare enum RepoArchivedAuditEntryVisibility {
    /** The repository is visible only to users in the same business. */
    Internal = "INTERNAL",
    /** The repository is visible only to those with explicit access. */
    Private = "PRIVATE",
    /** The repository is visible to everyone. */
    Public = "PUBLIC"
}
/** Audit log entry for a repo.change_merge_setting event. */
export type RepoChangeMergeSettingAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'RepoChangeMergeSettingAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** Whether the change was to enable (true) or disable (false) the merge type */
    isEnabled?: Maybe<Scalars['Boolean']['output']>;
    /** The merge method affected by the change */
    mergeType?: Maybe<RepoChangeMergeSettingAuditEntryMergeType>;
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** The merge options available for pull requests to this repository. */
export declare enum RepoChangeMergeSettingAuditEntryMergeType {
    /** The pull request is added to the base branch in a merge commit. */
    Merge = "MERGE",
    /** Commits from the pull request are added onto the base branch individually without a merge commit. */
    Rebase = "REBASE",
    /** The pull request's commits are squashed into a single commit before they are merged to the base branch. */
    Squash = "SQUASH"
}
/** Audit log entry for a repo.config.disable_anonymous_git_access event. */
export type RepoConfigDisableAnonymousGitAccessAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'RepoConfigDisableAnonymousGitAccessAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a repo.config.disable_collaborators_only event. */
export type RepoConfigDisableCollaboratorsOnlyAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'RepoConfigDisableCollaboratorsOnlyAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a repo.config.disable_contributors_only event. */
export type RepoConfigDisableContributorsOnlyAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'RepoConfigDisableContributorsOnlyAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a repo.config.disable_sockpuppet_disallowed event. */
export type RepoConfigDisableSockpuppetDisallowedAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'RepoConfigDisableSockpuppetDisallowedAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a repo.config.enable_anonymous_git_access event. */
export type RepoConfigEnableAnonymousGitAccessAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'RepoConfigEnableAnonymousGitAccessAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a repo.config.enable_collaborators_only event. */
export type RepoConfigEnableCollaboratorsOnlyAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'RepoConfigEnableCollaboratorsOnlyAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a repo.config.enable_contributors_only event. */
export type RepoConfigEnableContributorsOnlyAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'RepoConfigEnableContributorsOnlyAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a repo.config.enable_sockpuppet_disallowed event. */
export type RepoConfigEnableSockpuppetDisallowedAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'RepoConfigEnableSockpuppetDisallowedAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a repo.config.lock_anonymous_git_access event. */
export type RepoConfigLockAnonymousGitAccessAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'RepoConfigLockAnonymousGitAccessAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a repo.config.unlock_anonymous_git_access event. */
export type RepoConfigUnlockAnonymousGitAccessAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'RepoConfigUnlockAnonymousGitAccessAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a repo.create event. */
export type RepoCreateAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'RepoCreateAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    /** The name of the parent repository for this forked repository. */
    forkParentName?: Maybe<Scalars['String']['output']>;
    /** The name of the root repository for this network. */
    forkSourceName?: Maybe<Scalars['String']['output']>;
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
    /** The visibility of the repository */
    visibility?: Maybe<RepoCreateAuditEntryVisibility>;
};
/** The privacy of a repository */
export declare enum RepoCreateAuditEntryVisibility {
    /** The repository is visible only to users in the same business. */
    Internal = "INTERNAL",
    /** The repository is visible only to those with explicit access. */
    Private = "PRIVATE",
    /** The repository is visible to everyone. */
    Public = "PUBLIC"
}
/** Audit log entry for a repo.destroy event. */
export type RepoDestroyAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'RepoDestroyAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
    /** The visibility of the repository */
    visibility?: Maybe<RepoDestroyAuditEntryVisibility>;
};
/** The privacy of a repository */
export declare enum RepoDestroyAuditEntryVisibility {
    /** The repository is visible only to users in the same business. */
    Internal = "INTERNAL",
    /** The repository is visible only to those with explicit access. */
    Private = "PRIVATE",
    /** The repository is visible to everyone. */
    Public = "PUBLIC"
}
/** Audit log entry for a repo.remove_member event. */
export type RepoRemoveMemberAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & {
    __typename?: 'RepoRemoveMemberAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
    /** The visibility of the repository */
    visibility?: Maybe<RepoRemoveMemberAuditEntryVisibility>;
};
/** The privacy of a repository */
export declare enum RepoRemoveMemberAuditEntryVisibility {
    /** The repository is visible only to users in the same business. */
    Internal = "INTERNAL",
    /** The repository is visible only to those with explicit access. */
    Private = "PRIVATE",
    /** The repository is visible to everyone. */
    Public = "PUBLIC"
}
/** Audit log entry for a repo.remove_topic event. */
export type RepoRemoveTopicAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & TopicAuditEntryData & {
    __typename?: 'RepoRemoveTopicAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The name of the topic added to the repository */
    topic?: Maybe<Topic>;
    /** The name of the topic added to the repository */
    topicName?: Maybe<Scalars['String']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** The reasons a piece of content can be reported or minimized. */
export declare enum ReportedContentClassifiers {
    /** A duplicated piece of content */
    Duplicate = "DUPLICATE",
    /** An irrelevant piece of content */
    OffTopic = "OFF_TOPIC",
    /** An outdated piece of content */
    Outdated = "OUTDATED",
    /** The content has been resolved */
    Resolved = "RESOLVED"
}
/** A repository contains the content for a project. */
export type Repository = Node & PackageOwner & ProjectOwner & RepositoryInfo & Starrable & Subscribable & UniformResourceLocatable & {
    __typename?: 'Repository';
    /** A list of users that can be assigned to issues in this repository. */
    assignableUsers: UserConnection;
    /** A list of branch protection rules for this repository. */
    branchProtectionRules: BranchProtectionRuleConnection;
    /** Returns the code of conduct for this repository */
    codeOfConduct?: Maybe<CodeOfConduct>;
    /** A list of collaborators associated with the repository. */
    collaborators?: Maybe<RepositoryCollaboratorConnection>;
    /** A list of commit comments associated with the repository. */
    commitComments: CommitCommentConnection;
    /** Returns a list of contact links associated to the repository */
    contactLinks?: Maybe<Array<RepositoryContactLink>>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The Ref associated with the repository's default branch. */
    defaultBranchRef?: Maybe<Ref>;
    /** Whether or not branches are automatically deleted when merged in this repository. */
    deleteBranchOnMerge: Scalars['Boolean']['output'];
    /** A list of deploy keys that are on this repository. */
    deployKeys: DeployKeyConnection;
    /** Deployments associated with the repository */
    deployments: DeploymentConnection;
    /** The description of the repository. */
    description?: Maybe<Scalars['String']['output']>;
    /** The description of the repository rendered to HTML. */
    descriptionHTML: Scalars['HTML']['output'];
    /** Returns a single discussion from the current repository by number. */
    discussion?: Maybe<Discussion>;
    /** A list of discussion categories that are available in the repository. */
    discussionCategories: DiscussionCategoryConnection;
    /** A list of discussions that have been opened in the repository. */
    discussions: DiscussionConnection;
    /** The number of kilobytes this repository occupies on disk. */
    diskUsage?: Maybe<Scalars['Int']['output']>;
    /** Returns a single active environment from the current repository by name. */
    environment?: Maybe<Environment>;
    /** A list of environments that are in this repository. */
    environments: EnvironmentConnection;
    /** Returns how many forks there are of this repository in the whole network. */
    forkCount: Scalars['Int']['output'];
    /** A list of direct forked repositories. */
    forks: RepositoryConnection;
    /** Indicates if the repository has anonymous Git read access feature enabled. */
    hasAnonymousAccessEnabled: Scalars['Boolean']['output'];
    /** Indicates if the repository has issues feature enabled. */
    hasIssuesEnabled: Scalars['Boolean']['output'];
    /** Indicates if the repository has the Projects feature enabled. */
    hasProjectsEnabled: Scalars['Boolean']['output'];
    /** Indicates if the repository has wiki feature enabled. */
    hasWikiEnabled: Scalars['Boolean']['output'];
    /** The repository's URL. */
    homepageUrl?: Maybe<Scalars['URI']['output']>;
    id: Scalars['ID']['output'];
    /** Indicates if the repository is unmaintained. */
    isArchived: Scalars['Boolean']['output'];
    /** Returns true if blank issue creation is allowed */
    isBlankIssuesEnabled: Scalars['Boolean']['output'];
    /** Returns whether or not this repository disabled. */
    isDisabled: Scalars['Boolean']['output'];
    /** Returns whether or not this repository is empty. */
    isEmpty: Scalars['Boolean']['output'];
    /** Identifies if the repository is a fork. */
    isFork: Scalars['Boolean']['output'];
    /** Indicates if a repository is either owned by an organization, or is a private fork of an organization repository. */
    isInOrganization: Scalars['Boolean']['output'];
    /** Indicates if the repository has been locked or not. */
    isLocked: Scalars['Boolean']['output'];
    /** Identifies if the repository is a mirror. */
    isMirror: Scalars['Boolean']['output'];
    /** Identifies if the repository is private or internal. */
    isPrivate: Scalars['Boolean']['output'];
    /** Returns true if this repository has a security policy */
    isSecurityPolicyEnabled?: Maybe<Scalars['Boolean']['output']>;
    /** Identifies if the repository is a template that can be used to generate new repositories. */
    isTemplate: Scalars['Boolean']['output'];
    /** Is this repository a user configuration repository? */
    isUserConfigurationRepository: Scalars['Boolean']['output'];
    /** Returns a single issue from the current repository by number. */
    issue?: Maybe<Issue>;
    /** Returns a single issue-like object from the current repository by number. */
    issueOrPullRequest?: Maybe<IssueOrPullRequest>;
    /** Returns a list of issue templates associated to the repository */
    issueTemplates?: Maybe<Array<IssueTemplate>>;
    /** A list of issues that have been opened in the repository. */
    issues: IssueConnection;
    /** Returns a single label by name */
    label?: Maybe<Label>;
    /** A list of labels associated with the repository. */
    labels?: Maybe<LabelConnection>;
    /** A list containing a breakdown of the language composition of the repository. */
    languages?: Maybe<LanguageConnection>;
    /** Get the latest release for the repository if one exists. */
    latestRelease?: Maybe<Release>;
    /** The license associated with the repository */
    licenseInfo?: Maybe<License>;
    /** The reason the repository has been locked. */
    lockReason?: Maybe<RepositoryLockReason>;
    /** A list of Users that can be mentioned in the context of the repository. */
    mentionableUsers: UserConnection;
    /** Whether or not PRs are merged with a merge commit on this repository. */
    mergeCommitAllowed: Scalars['Boolean']['output'];
    /** Returns a single milestone from the current repository by number. */
    milestone?: Maybe<Milestone>;
    /** A list of milestones associated with the repository. */
    milestones?: Maybe<MilestoneConnection>;
    /** The repository's original mirror URL. */
    mirrorUrl?: Maybe<Scalars['URI']['output']>;
    /** The name of the repository. */
    name: Scalars['String']['output'];
    /** The repository's name with owner. */
    nameWithOwner: Scalars['String']['output'];
    /** A Git object in the repository */
    object?: Maybe<GitObject>;
    /** The image used to represent this repository in Open Graph data. */
    openGraphImageUrl: Scalars['URI']['output'];
    /** The User owner of the repository. */
    owner: RepositoryOwner;
    /** A list of packages under the owner. */
    packages: PackageConnection;
    /** The repository parent, if this is a fork. */
    parent?: Maybe<Repository>;
    /** A list of discussions that have been pinned in this repository. */
    pinnedDiscussions: PinnedDiscussionConnection;
    /** A list of pinned issues for this repository. */
    pinnedIssues?: Maybe<PinnedIssueConnection>;
    /** The primary language of the repository's code. */
    primaryLanguage?: Maybe<Language>;
    /** Find project by number. */
    project?: Maybe<Project>;
    /** A list of projects under the owner. */
    projects: ProjectConnection;
    /** The HTTP path listing the repository's projects */
    projectsResourcePath: Scalars['URI']['output'];
    /** The HTTP URL listing the repository's projects */
    projectsUrl: Scalars['URI']['output'];
    /** Returns a single pull request from the current repository by number. */
    pullRequest?: Maybe<PullRequest>;
    /** Returns a list of pull request templates associated to the repository */
    pullRequestTemplates?: Maybe<Array<PullRequestTemplate>>;
    /** A list of pull requests that have been opened in the repository. */
    pullRequests: PullRequestConnection;
    /** Identifies when the repository was last pushed to. */
    pushedAt?: Maybe<Scalars['DateTime']['output']>;
    /** Whether or not rebase-merging is enabled on this repository. */
    rebaseMergeAllowed: Scalars['Boolean']['output'];
    /** Fetch a given ref from the repository */
    ref?: Maybe<Ref>;
    /** Fetch a list of refs from the repository */
    refs?: Maybe<RefConnection>;
    /** Lookup a single release given various criteria. */
    release?: Maybe<Release>;
    /** List of releases which are dependent on this repository. */
    releases: ReleaseConnection;
    /** A list of applied repository-topic associations for this repository. */
    repositoryTopics: RepositoryTopicConnection;
    /** The HTTP path for this repository */
    resourcePath: Scalars['URI']['output'];
    /** The security policy URL. */
    securityPolicyUrl?: Maybe<Scalars['URI']['output']>;
    /** A description of the repository, rendered to HTML without any links in it. */
    shortDescriptionHTML: Scalars['HTML']['output'];
    /** Whether or not squash-merging is enabled on this repository. */
    squashMergeAllowed: Scalars['Boolean']['output'];
    /** The SSH URL to clone this repository */
    sshUrl: Scalars['GitSSHRemote']['output'];
    /** Returns a count of how many stargazers there are on this object */
    stargazerCount: Scalars['Int']['output'];
    /** A list of users who have starred this starrable. */
    stargazers: StargazerConnection;
    /**
     * Returns a list of all submodules in this repository parsed from the
     * .gitmodules file as of the default branch's HEAD commit.
     */
    submodules: SubmoduleConnection;
    /** Temporary authentication token for cloning this repository. */
    tempCloneToken?: Maybe<Scalars['String']['output']>;
    /** The repository from which this repository was generated, if any. */
    templateRepository?: Maybe<Repository>;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this repository */
    url: Scalars['URI']['output'];
    /** Whether this repository has a custom image to use with Open Graph as opposed to being represented by the owner's avatar. */
    usesCustomOpenGraphImage: Scalars['Boolean']['output'];
    /** Indicates whether the viewer has admin permissions on this repository. */
    viewerCanAdminister: Scalars['Boolean']['output'];
    /** Can the current viewer create new projects on this owner. */
    viewerCanCreateProjects: Scalars['Boolean']['output'];
    /** Check if the viewer is able to change their subscription status for the repository. */
    viewerCanSubscribe: Scalars['Boolean']['output'];
    /** Indicates whether the viewer can update the topics of this repository. */
    viewerCanUpdateTopics: Scalars['Boolean']['output'];
    /** The last commit email for the viewer. */
    viewerDefaultCommitEmail?: Maybe<Scalars['String']['output']>;
    /** The last used merge method by the viewer or the default for the repository. */
    viewerDefaultMergeMethod: PullRequestMergeMethod;
    /** Returns a boolean indicating whether the viewing user has starred this starrable. */
    viewerHasStarred: Scalars['Boolean']['output'];
    /** The users permission level on the repository. Will return null if authenticated as an GitHub App. */
    viewerPermission?: Maybe<RepositoryPermission>;
    /** A list of emails this viewer can commit with. */
    viewerPossibleCommitEmails?: Maybe<Array<Scalars['String']['output']>>;
    /** Identifies if the viewer is watching, not watching, or ignoring the subscribable entity. */
    viewerSubscription?: Maybe<SubscriptionState>;
    /** Indicates the repository's visibility level. */
    visibility: RepositoryVisibility;
    /** A list of vulnerability alerts that are on this repository. */
    vulnerabilityAlerts?: Maybe<RepositoryVulnerabilityAlertConnection>;
    /** A list of users watching the repository. */
    watchers: UserConnection;
};
/** A repository contains the content for a project. */
export type RepositoryAssignableUsersArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    query?: InputMaybe<Scalars['String']['input']>;
};
/** A repository contains the content for a project. */
export type RepositoryBranchProtectionRulesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository contains the content for a project. */
export type RepositoryCollaboratorsArgs = {
    affiliation?: InputMaybe<CollaboratorAffiliation>;
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    query?: InputMaybe<Scalars['String']['input']>;
};
/** A repository contains the content for a project. */
export type RepositoryCommitCommentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository contains the content for a project. */
export type RepositoryDeployKeysArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository contains the content for a project. */
export type RepositoryDeploymentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    environments?: InputMaybe<Array<Scalars['String']['input']>>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<DeploymentOrder>;
};
/** A repository contains the content for a project. */
export type RepositoryDiscussionArgs = {
    number: Scalars['Int']['input'];
};
/** A repository contains the content for a project. */
export type RepositoryDiscussionCategoriesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository contains the content for a project. */
export type RepositoryDiscussionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    categoryId?: InputMaybe<Scalars['ID']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<DiscussionOrder>;
};
/** A repository contains the content for a project. */
export type RepositoryEnvironmentArgs = {
    name: Scalars['String']['input'];
};
/** A repository contains the content for a project. */
export type RepositoryEnvironmentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository contains the content for a project. */
export type RepositoryForksArgs = {
    affiliations?: InputMaybe<Array<InputMaybe<RepositoryAffiliation>>>;
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    isLocked?: InputMaybe<Scalars['Boolean']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<RepositoryOrder>;
    ownerAffiliations?: InputMaybe<Array<InputMaybe<RepositoryAffiliation>>>;
    privacy?: InputMaybe<RepositoryPrivacy>;
};
/** A repository contains the content for a project. */
export type RepositoryIssueArgs = {
    number: Scalars['Int']['input'];
};
/** A repository contains the content for a project. */
export type RepositoryIssueOrPullRequestArgs = {
    number: Scalars['Int']['input'];
};
/** A repository contains the content for a project. */
export type RepositoryIssuesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    filterBy?: InputMaybe<IssueFilters>;
    first?: InputMaybe<Scalars['Int']['input']>;
    labels?: InputMaybe<Array<Scalars['String']['input']>>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<IssueOrder>;
    states?: InputMaybe<Array<IssueState>>;
};
/** A repository contains the content for a project. */
export type RepositoryLabelArgs = {
    name: Scalars['String']['input'];
};
/** A repository contains the content for a project. */
export type RepositoryLabelsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<LabelOrder>;
    query?: InputMaybe<Scalars['String']['input']>;
};
/** A repository contains the content for a project. */
export type RepositoryLanguagesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<LanguageOrder>;
};
/** A repository contains the content for a project. */
export type RepositoryMentionableUsersArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    query?: InputMaybe<Scalars['String']['input']>;
};
/** A repository contains the content for a project. */
export type RepositoryMilestoneArgs = {
    number: Scalars['Int']['input'];
};
/** A repository contains the content for a project. */
export type RepositoryMilestonesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<MilestoneOrder>;
    query?: InputMaybe<Scalars['String']['input']>;
    states?: InputMaybe<Array<MilestoneState>>;
};
/** A repository contains the content for a project. */
export type RepositoryObjectArgs = {
    expression?: InputMaybe<Scalars['String']['input']>;
    oid?: InputMaybe<Scalars['GitObjectID']['input']>;
};
/** A repository contains the content for a project. */
export type RepositoryPackagesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    names?: InputMaybe<Array<InputMaybe<Scalars['String']['input']>>>;
    orderBy?: InputMaybe<PackageOrder>;
    packageType?: InputMaybe<PackageType>;
    repositoryId?: InputMaybe<Scalars['ID']['input']>;
};
/** A repository contains the content for a project. */
export type RepositoryPinnedDiscussionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository contains the content for a project. */
export type RepositoryPinnedIssuesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository contains the content for a project. */
export type RepositoryProjectArgs = {
    number: Scalars['Int']['input'];
};
/** A repository contains the content for a project. */
export type RepositoryProjectsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ProjectOrder>;
    search?: InputMaybe<Scalars['String']['input']>;
    states?: InputMaybe<Array<ProjectState>>;
};
/** A repository contains the content for a project. */
export type RepositoryPullRequestArgs = {
    number: Scalars['Int']['input'];
};
/** A repository contains the content for a project. */
export type RepositoryPullRequestsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    baseRefName?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    headRefName?: InputMaybe<Scalars['String']['input']>;
    labels?: InputMaybe<Array<Scalars['String']['input']>>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<IssueOrder>;
    states?: InputMaybe<Array<PullRequestState>>;
};
/** A repository contains the content for a project. */
export type RepositoryRefArgs = {
    qualifiedName: Scalars['String']['input'];
};
/** A repository contains the content for a project. */
export type RepositoryRefsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    direction?: InputMaybe<OrderDirection>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<RefOrder>;
    query?: InputMaybe<Scalars['String']['input']>;
    refPrefix: Scalars['String']['input'];
};
/** A repository contains the content for a project. */
export type RepositoryReleaseArgs = {
    tagName: Scalars['String']['input'];
};
/** A repository contains the content for a project. */
export type RepositoryReleasesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ReleaseOrder>;
};
/** A repository contains the content for a project. */
export type RepositoryRepositoryTopicsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository contains the content for a project. */
export type RepositoryShortDescriptionHtmlArgs = {
    limit?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository contains the content for a project. */
export type RepositoryStargazersArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<StarOrder>;
};
/** A repository contains the content for a project. */
export type RepositorySubmodulesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository contains the content for a project. */
export type RepositoryVulnerabilityAlertsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A repository contains the content for a project. */
export type RepositoryWatchersArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** The affiliation of a user to a repository */
export declare enum RepositoryAffiliation {
    /** Repositories that the user has been added to as a collaborator. */
    Collaborator = "COLLABORATOR",
    /**
     * Repositories that the user has access to through being a member of an
     * organization. This includes every repository on every team that the user is on.
     */
    OrganizationMember = "ORGANIZATION_MEMBER",
    /** Repositories that are owned by the authenticated user. */
    Owner = "OWNER"
}
/** Metadata for an audit entry with action repo.* */
export type RepositoryAuditEntryData = {
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
};
/** The connection type for User. */
export type RepositoryCollaboratorConnection = {
    __typename?: 'RepositoryCollaboratorConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<RepositoryCollaboratorEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<User>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** Represents a user who is a collaborator of a repository. */
export type RepositoryCollaboratorEdge = {
    __typename?: 'RepositoryCollaboratorEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    node: User;
    /** The permission the user has on the repository. */
    permission: RepositoryPermission;
    /** A list of sources for the user's access to the repository. */
    permissionSources?: Maybe<Array<PermissionSource>>;
};
/** A list of repositories owned by the subject. */
export type RepositoryConnection = {
    __typename?: 'RepositoryConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<RepositoryEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Repository>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
    /** The total size in kilobytes of all repositories in the connection. */
    totalDiskUsage: Scalars['Int']['output'];
};
/** A repository contact link. */
export type RepositoryContactLink = {
    __typename?: 'RepositoryContactLink';
    /** The contact link purpose. */
    about: Scalars['String']['output'];
    /** The contact link name. */
    name: Scalars['String']['output'];
    /** The contact link URL. */
    url: Scalars['URI']['output'];
};
/** The reason a repository is listed as 'contributed'. */
export declare enum RepositoryContributionType {
    /** Created a commit */
    Commit = "COMMIT",
    /** Created an issue */
    Issue = "ISSUE",
    /** Created a pull request */
    PullRequest = "PULL_REQUEST",
    /** Reviewed a pull request */
    PullRequestReview = "PULL_REQUEST_REVIEW",
    /** Created the repository */
    Repository = "REPOSITORY"
}
/** Represents an author of discussions in repositories. */
export type RepositoryDiscussionAuthor = {
    /** Discussions this user has started. */
    repositoryDiscussions: DiscussionConnection;
};
/** Represents an author of discussions in repositories. */
export type RepositoryDiscussionAuthorRepositoryDiscussionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    answered?: InputMaybe<Scalars['Boolean']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<DiscussionOrder>;
    repositoryId?: InputMaybe<Scalars['ID']['input']>;
};
/** Represents an author of discussion comments in repositories. */
export type RepositoryDiscussionCommentAuthor = {
    /** Discussion comments this user has authored. */
    repositoryDiscussionComments: DiscussionCommentConnection;
};
/** Represents an author of discussion comments in repositories. */
export type RepositoryDiscussionCommentAuthorRepositoryDiscussionCommentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    onlyAnswers?: InputMaybe<Scalars['Boolean']['input']>;
    repositoryId?: InputMaybe<Scalars['ID']['input']>;
};
/** An edge in a connection. */
export type RepositoryEdge = {
    __typename?: 'RepositoryEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Repository>;
};
/** A subset of repository info. */
export type RepositoryInfo = {
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The description of the repository. */
    description?: Maybe<Scalars['String']['output']>;
    /** The description of the repository rendered to HTML. */
    descriptionHTML: Scalars['HTML']['output'];
    /** Returns how many forks there are of this repository in the whole network. */
    forkCount: Scalars['Int']['output'];
    /** Indicates if the repository has anonymous Git read access feature enabled. */
    hasAnonymousAccessEnabled: Scalars['Boolean']['output'];
    /** Indicates if the repository has issues feature enabled. */
    hasIssuesEnabled: Scalars['Boolean']['output'];
    /** Indicates if the repository has the Projects feature enabled. */
    hasProjectsEnabled: Scalars['Boolean']['output'];
    /** Indicates if the repository has wiki feature enabled. */
    hasWikiEnabled: Scalars['Boolean']['output'];
    /** The repository's URL. */
    homepageUrl?: Maybe<Scalars['URI']['output']>;
    /** Indicates if the repository is unmaintained. */
    isArchived: Scalars['Boolean']['output'];
    /** Identifies if the repository is a fork. */
    isFork: Scalars['Boolean']['output'];
    /** Indicates if a repository is either owned by an organization, or is a private fork of an organization repository. */
    isInOrganization: Scalars['Boolean']['output'];
    /** Indicates if the repository has been locked or not. */
    isLocked: Scalars['Boolean']['output'];
    /** Identifies if the repository is a mirror. */
    isMirror: Scalars['Boolean']['output'];
    /** Identifies if the repository is private or internal. */
    isPrivate: Scalars['Boolean']['output'];
    /** Identifies if the repository is a template that can be used to generate new repositories. */
    isTemplate: Scalars['Boolean']['output'];
    /** The license associated with the repository */
    licenseInfo?: Maybe<License>;
    /** The reason the repository has been locked. */
    lockReason?: Maybe<RepositoryLockReason>;
    /** The repository's original mirror URL. */
    mirrorUrl?: Maybe<Scalars['URI']['output']>;
    /** The name of the repository. */
    name: Scalars['String']['output'];
    /** The repository's name with owner. */
    nameWithOwner: Scalars['String']['output'];
    /** The image used to represent this repository in Open Graph data. */
    openGraphImageUrl: Scalars['URI']['output'];
    /** The User owner of the repository. */
    owner: RepositoryOwner;
    /** Identifies when the repository was last pushed to. */
    pushedAt?: Maybe<Scalars['DateTime']['output']>;
    /** The HTTP path for this repository */
    resourcePath: Scalars['URI']['output'];
    /** A description of the repository, rendered to HTML without any links in it. */
    shortDescriptionHTML: Scalars['HTML']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this repository */
    url: Scalars['URI']['output'];
    /** Whether this repository has a custom image to use with Open Graph as opposed to being represented by the owner's avatar. */
    usesCustomOpenGraphImage: Scalars['Boolean']['output'];
    /** Indicates the repository's visibility level. */
    visibility: RepositoryVisibility;
};
/** A subset of repository info. */
export type RepositoryInfoShortDescriptionHtmlArgs = {
    limit?: InputMaybe<Scalars['Int']['input']>;
};
/** An invitation for a user to be added to a repository. */
export type RepositoryInvitation = Node & {
    __typename?: 'RepositoryInvitation';
    /** The email address that received the invitation. */
    email?: Maybe<Scalars['String']['output']>;
    id: Scalars['ID']['output'];
    /** The user who received the invitation. */
    invitee?: Maybe<User>;
    /** The user who created the invitation. */
    inviter: User;
    /** The permalink for this repository invitation. */
    permalink: Scalars['URI']['output'];
    /** The permission granted on this repository by this invitation. */
    permission: RepositoryPermission;
    /** The Repository the user is invited to. */
    repository?: Maybe<RepositoryInfo>;
};
/** The connection type for RepositoryInvitation. */
export type RepositoryInvitationConnection = {
    __typename?: 'RepositoryInvitationConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<RepositoryInvitationEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<RepositoryInvitation>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type RepositoryInvitationEdge = {
    __typename?: 'RepositoryInvitationEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<RepositoryInvitation>;
};
/** Ordering options for repository invitation connections. */
export type RepositoryInvitationOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order repository invitations by. */
    field: RepositoryInvitationOrderField;
};
/** Properties by which repository invitation connections can be ordered. */
export declare enum RepositoryInvitationOrderField {
    /** Order repository invitations by creation time */
    CreatedAt = "CREATED_AT",
    /**
     * Order repository invitations by invitee login
     * @deprecated `INVITEE_LOGIN` is no longer a valid field value. Repository invitations can now be associated with an email, not only an invitee. Removal on 2020-10-01 UTC.
     */
    InviteeLogin = "INVITEE_LOGIN"
}
/** The possible reasons a given repository could be in a locked state. */
export declare enum RepositoryLockReason {
    /** The repository is locked due to a billing related reason. */
    Billing = "BILLING",
    /** The repository is locked due to a migration. */
    Migrating = "MIGRATING",
    /** The repository is locked due to a move. */
    Moving = "MOVING",
    /** The repository is locked due to a rename. */
    Rename = "RENAME"
}
/** Represents a object that belongs to a repository. */
export type RepositoryNode = {
    /** The repository associated with this node. */
    repository: Repository;
};
/** Ordering options for repository connections */
export type RepositoryOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order repositories by. */
    field: RepositoryOrderField;
};
/** Properties by which repository connections can be ordered. */
export declare enum RepositoryOrderField {
    /** Order repositories by creation time */
    CreatedAt = "CREATED_AT",
    /** Order repositories by name */
    Name = "NAME",
    /** Order repositories by push time */
    PushedAt = "PUSHED_AT",
    /** Order repositories by number of stargazers */
    Stargazers = "STARGAZERS",
    /** Order repositories by update time */
    UpdatedAt = "UPDATED_AT"
}
/** Represents an owner of a Repository. */
export type RepositoryOwner = {
    /** A URL pointing to the owner's public avatar. */
    avatarUrl: Scalars['URI']['output'];
    id: Scalars['ID']['output'];
    /** The username used to login. */
    login: Scalars['String']['output'];
    /** A list of repositories that the user owns. */
    repositories: RepositoryConnection;
    /** Find Repository. */
    repository?: Maybe<Repository>;
    /** The HTTP URL for the owner. */
    resourcePath: Scalars['URI']['output'];
    /** The HTTP URL for the owner. */
    url: Scalars['URI']['output'];
};
/** Represents an owner of a Repository. */
export type RepositoryOwnerAvatarUrlArgs = {
    size?: InputMaybe<Scalars['Int']['input']>;
};
/** Represents an owner of a Repository. */
export type RepositoryOwnerRepositoriesArgs = {
    affiliations?: InputMaybe<Array<InputMaybe<RepositoryAffiliation>>>;
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    isFork?: InputMaybe<Scalars['Boolean']['input']>;
    isLocked?: InputMaybe<Scalars['Boolean']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<RepositoryOrder>;
    ownerAffiliations?: InputMaybe<Array<InputMaybe<RepositoryAffiliation>>>;
    privacy?: InputMaybe<RepositoryPrivacy>;
};
/** Represents an owner of a Repository. */
export type RepositoryOwnerRepositoryArgs = {
    name: Scalars['String']['input'];
};
/** The access level to a repository */
export declare enum RepositoryPermission {
    /**
     * Can read, clone, and push to this repository. Can also manage issues, pull
     * requests, and repository settings, including adding collaborators
     */
    Admin = "ADMIN",
    /** Can read, clone, and push to this repository. They can also manage issues, pull requests, and some repository settings */
    Maintain = "MAINTAIN",
    /** Can read and clone this repository. Can also open and comment on issues and pull requests */
    Read = "READ",
    /** Can read and clone this repository. Can also manage issues and pull requests */
    Triage = "TRIAGE",
    /** Can read, clone, and push to this repository. Can also manage issues and pull requests */
    Write = "WRITE"
}
/** The privacy of a repository */
export declare enum RepositoryPrivacy {
    /** Private */
    Private = "PRIVATE",
    /** Public */
    Public = "PUBLIC"
}
/** A repository-topic connects a repository to a topic. */
export type RepositoryTopic = Node & UniformResourceLocatable & {
    __typename?: 'RepositoryTopic';
    id: Scalars['ID']['output'];
    /** The HTTP path for this repository-topic. */
    resourcePath: Scalars['URI']['output'];
    /** The topic. */
    topic: Topic;
    /** The HTTP URL for this repository-topic. */
    url: Scalars['URI']['output'];
};
/** The connection type for RepositoryTopic. */
export type RepositoryTopicConnection = {
    __typename?: 'RepositoryTopicConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<RepositoryTopicEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<RepositoryTopic>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type RepositoryTopicEdge = {
    __typename?: 'RepositoryTopicEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<RepositoryTopic>;
};
/** The repository's visibility level. */
export declare enum RepositoryVisibility {
    /** The repository is visible only to users in the same business. */
    Internal = "INTERNAL",
    /** The repository is visible only to those with explicit access. */
    Private = "PRIVATE",
    /** The repository is visible to everyone. */
    Public = "PUBLIC"
}
/** Audit log entry for a repository_visibility_change.disable event. */
export type RepositoryVisibilityChangeDisableAuditEntry = AuditEntry & EnterpriseAuditEntryData & Node & OrganizationAuditEntryData & {
    __typename?: 'RepositoryVisibilityChangeDisableAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    /** The HTTP path for this enterprise. */
    enterpriseResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The slug of the enterprise. */
    enterpriseSlug?: Maybe<Scalars['String']['output']>;
    /** The HTTP URL for this enterprise. */
    enterpriseUrl?: Maybe<Scalars['URI']['output']>;
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a repository_visibility_change.enable event. */
export type RepositoryVisibilityChangeEnableAuditEntry = AuditEntry & EnterpriseAuditEntryData & Node & OrganizationAuditEntryData & {
    __typename?: 'RepositoryVisibilityChangeEnableAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    /** The HTTP path for this enterprise. */
    enterpriseResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The slug of the enterprise. */
    enterpriseSlug?: Maybe<Scalars['String']['output']>;
    /** The HTTP URL for this enterprise. */
    enterpriseUrl?: Maybe<Scalars['URI']['output']>;
    id: Scalars['ID']['output'];
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** A Dependabot alert for a repository with a dependency affected by a security vulnerability. */
export type RepositoryVulnerabilityAlert = Node & RepositoryNode & {
    __typename?: 'RepositoryVulnerabilityAlert';
    /** When was the alert created? */
    createdAt: Scalars['DateTime']['output'];
    /** The reason the alert was dismissed */
    dismissReason?: Maybe<Scalars['String']['output']>;
    /** When was the alert dismissed? */
    dismissedAt?: Maybe<Scalars['DateTime']['output']>;
    /** The user who dismissed the alert */
    dismisser?: Maybe<User>;
    id: Scalars['ID']['output'];
    /** The associated repository */
    repository: Repository;
    /** The associated security advisory */
    securityAdvisory?: Maybe<SecurityAdvisory>;
    /** The associated security vulnerability */
    securityVulnerability?: Maybe<SecurityVulnerability>;
    /** The vulnerable manifest filename */
    vulnerableManifestFilename: Scalars['String']['output'];
    /** The vulnerable manifest path */
    vulnerableManifestPath: Scalars['String']['output'];
    /** The vulnerable requirements */
    vulnerableRequirements?: Maybe<Scalars['String']['output']>;
};
/** The connection type for RepositoryVulnerabilityAlert. */
export type RepositoryVulnerabilityAlertConnection = {
    __typename?: 'RepositoryVulnerabilityAlertConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<RepositoryVulnerabilityAlertEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<RepositoryVulnerabilityAlert>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type RepositoryVulnerabilityAlertEdge = {
    __typename?: 'RepositoryVulnerabilityAlertEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<RepositoryVulnerabilityAlert>;
};
/** Autogenerated input type of RequestReviews */
export type RequestReviewsInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the pull request to modify. */
    pullRequestId: Scalars['ID']['input'];
    /** The Node IDs of the team to request. */
    teamIds?: InputMaybe<Array<Scalars['ID']['input']>>;
    /** Add users to the set rather than replace. */
    union?: InputMaybe<Scalars['Boolean']['input']>;
    /** The Node IDs of the user to request. */
    userIds?: InputMaybe<Array<Scalars['ID']['input']>>;
};
/** Autogenerated return type of RequestReviews */
export type RequestReviewsPayload = {
    __typename?: 'RequestReviewsPayload';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The pull request that is getting requests. */
    pullRequest?: Maybe<PullRequest>;
    /** The edge from the pull request to the requested reviewers. */
    requestedReviewersEdge?: Maybe<UserEdge>;
};
/** The possible states that can be requested when creating a check run. */
export declare enum RequestableCheckStatusState {
    /** The check suite or run has been completed. */
    Completed = "COMPLETED",
    /** The check suite or run is in progress. */
    InProgress = "IN_PROGRESS",
    /** The check suite or run is in pending state. */
    Pending = "PENDING",
    /** The check suite or run has been queued. */
    Queued = "QUEUED",
    /** The check suite or run is in waiting state. */
    Waiting = "WAITING"
}
/** Types that can be requested reviewers. */
export type RequestedReviewer = Mannequin | Team | User;
/** Represents a type that can be required by a pull request for merging. */
export type RequirableByPullRequest = {
    /** Whether this is required to pass before merging for a specific pull request. */
    isRequired: Scalars['Boolean']['output'];
};
/** Represents a type that can be required by a pull request for merging. */
export type RequirableByPullRequestIsRequiredArgs = {
    pullRequestId?: InputMaybe<Scalars['ID']['input']>;
    pullRequestNumber?: InputMaybe<Scalars['Int']['input']>;
};
/** Autogenerated input type of RerequestCheckSuite */
export type RerequestCheckSuiteInput = {
    /** The Node ID of the check suite. */
    checkSuiteId: Scalars['ID']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the repository. */
    repositoryId: Scalars['ID']['input'];
};
/** Autogenerated return type of RerequestCheckSuite */
export type RerequestCheckSuitePayload = {
    __typename?: 'RerequestCheckSuitePayload';
    /** The requested check suite. */
    checkSuite?: Maybe<CheckSuite>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of ResolveReviewThread */
export type ResolveReviewThreadInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the thread to resolve */
    threadId: Scalars['ID']['input'];
};
/** Autogenerated return type of ResolveReviewThread */
export type ResolveReviewThreadPayload = {
    __typename?: 'ResolveReviewThreadPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The thread to resolve. */
    thread?: Maybe<PullRequestReviewThread>;
};
/** Represents a private contribution a user made on GitHub. */
export type RestrictedContribution = Contribution & {
    __typename?: 'RestrictedContribution';
    /**
     * Whether this contribution is associated with a record you do not have access to. For
     * example, your own 'first issue' contribution may have been made on a repository you can no
     * longer access.
     */
    isRestricted: Scalars['Boolean']['output'];
    /** When this contribution was made. */
    occurredAt: Scalars['DateTime']['output'];
    /** The HTTP path for this contribution. */
    resourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this contribution. */
    url: Scalars['URI']['output'];
    /** The user who made this contribution. */
    user: User;
};
/** A team or user who has the ability to dismiss a review on a protected branch. */
export type ReviewDismissalAllowance = Node & {
    __typename?: 'ReviewDismissalAllowance';
    /** The actor that can dismiss. */
    actor?: Maybe<ReviewDismissalAllowanceActor>;
    /** Identifies the branch protection rule associated with the allowed user or team. */
    branchProtectionRule?: Maybe<BranchProtectionRule>;
    id: Scalars['ID']['output'];
};
/** Types that can be an actor. */
export type ReviewDismissalAllowanceActor = Team | User;
/** The connection type for ReviewDismissalAllowance. */
export type ReviewDismissalAllowanceConnection = {
    __typename?: 'ReviewDismissalAllowanceConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<ReviewDismissalAllowanceEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<ReviewDismissalAllowance>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type ReviewDismissalAllowanceEdge = {
    __typename?: 'ReviewDismissalAllowanceEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<ReviewDismissalAllowance>;
};
/** Represents a 'review_dismissed' event on a given issue or pull request. */
export type ReviewDismissedEvent = Node & UniformResourceLocatable & {
    __typename?: 'ReviewDismissedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** Identifies the optional message associated with the 'review_dismissed' event. */
    dismissalMessage?: Maybe<Scalars['String']['output']>;
    /** Identifies the optional message associated with the event, rendered to HTML. */
    dismissalMessageHTML?: Maybe<Scalars['String']['output']>;
    id: Scalars['ID']['output'];
    /** Identifies the previous state of the review with the 'review_dismissed' event. */
    previousReviewState: PullRequestReviewState;
    /** PullRequest referenced by event. */
    pullRequest: PullRequest;
    /** Identifies the commit which caused the review to become stale. */
    pullRequestCommit?: Maybe<PullRequestCommit>;
    /** The HTTP path for this review dismissed event. */
    resourcePath: Scalars['URI']['output'];
    /** Identifies the review associated with the 'review_dismissed' event. */
    review?: Maybe<PullRequestReview>;
    /** The HTTP URL for this review dismissed event. */
    url: Scalars['URI']['output'];
};
/** A request for a user to review a pull request. */
export type ReviewRequest = Node & {
    __typename?: 'ReviewRequest';
    /** Whether this request was created for a code owner */
    asCodeOwner: Scalars['Boolean']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** Identifies the pull request associated with this review request. */
    pullRequest: PullRequest;
    /** The reviewer that is requested. */
    requestedReviewer?: Maybe<RequestedReviewer>;
};
/** The connection type for ReviewRequest. */
export type ReviewRequestConnection = {
    __typename?: 'ReviewRequestConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<ReviewRequestEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<ReviewRequest>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type ReviewRequestEdge = {
    __typename?: 'ReviewRequestEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<ReviewRequest>;
};
/** Represents an 'review_request_removed' event on a given pull request. */
export type ReviewRequestRemovedEvent = Node & {
    __typename?: 'ReviewRequestRemovedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** PullRequest referenced by event. */
    pullRequest: PullRequest;
    /** Identifies the reviewer whose review request was removed. */
    requestedReviewer?: Maybe<RequestedReviewer>;
};
/** Represents an 'review_requested' event on a given pull request. */
export type ReviewRequestedEvent = Node & {
    __typename?: 'ReviewRequestedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** PullRequest referenced by event. */
    pullRequest: PullRequest;
    /** Identifies the reviewer whose review was requested. */
    requestedReviewer?: Maybe<RequestedReviewer>;
};
/**
 * A hovercard context with a message describing the current code review state of the pull
 * request.
 */
export type ReviewStatusHovercardContext = HovercardContext & {
    __typename?: 'ReviewStatusHovercardContext';
    /** A string describing this context */
    message: Scalars['String']['output'];
    /** An octicon to accompany this context */
    octicon: Scalars['String']['output'];
    /** The current status of the pull request with respect to code review. */
    reviewDecision?: Maybe<PullRequestReviewDecision>;
};
/** The possible digest algorithms used to sign SAML requests for an identity provider. */
export declare enum SamlDigestAlgorithm {
    /** SHA1 */
    Sha1 = "SHA1",
    /** SHA256 */
    Sha256 = "SHA256",
    /** SHA384 */
    Sha384 = "SHA384",
    /** SHA512 */
    Sha512 = "SHA512"
}
/** The possible signature algorithms used to sign SAML requests for a Identity Provider. */
export declare enum SamlSignatureAlgorithm {
    /** RSA-SHA1 */
    RsaSha1 = "RSA_SHA1",
    /** RSA-SHA256 */
    RsaSha256 = "RSA_SHA256",
    /** RSA-SHA384 */
    RsaSha384 = "RSA_SHA384",
    /** RSA-SHA512 */
    RsaSha512 = "RSA_SHA512"
}
/** A Saved Reply is text a user can use to reply quickly. */
export type SavedReply = Node & {
    __typename?: 'SavedReply';
    /** The body of the saved reply. */
    body: Scalars['String']['output'];
    /** The saved reply body rendered to HTML. */
    bodyHTML: Scalars['HTML']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** The title of the saved reply. */
    title: Scalars['String']['output'];
    /** The user that saved this reply. */
    user?: Maybe<Actor>;
};
/** The connection type for SavedReply. */
export type SavedReplyConnection = {
    __typename?: 'SavedReplyConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<SavedReplyEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<SavedReply>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type SavedReplyEdge = {
    __typename?: 'SavedReplyEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<SavedReply>;
};
/** Ordering options for saved reply connections. */
export type SavedReplyOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order saved replies by. */
    field: SavedReplyOrderField;
};
/** Properties by which saved reply connections can be ordered. */
export declare enum SavedReplyOrderField {
    /** Order saved reply by when they were updated. */
    UpdatedAt = "UPDATED_AT"
}
/** The results of a search. */
export type SearchResultItem = App | Discussion | Issue | Organization | PullRequest | Repository | User;
/** A list of results that matched against a search query. */
export type SearchResultItemConnection = {
    __typename?: 'SearchResultItemConnection';
    /** The number of pieces of code that matched the search query. */
    codeCount: Scalars['Int']['output'];
    /** The number of discussions that matched the search query. */
    discussionCount: Scalars['Int']['output'];
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<SearchResultItemEdge>>>;
    /** The number of issues that matched the search query. */
    issueCount: Scalars['Int']['output'];
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<SearchResultItem>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** The number of repositories that matched the search query. */
    repositoryCount: Scalars['Int']['output'];
    /** The number of users that matched the search query. */
    userCount: Scalars['Int']['output'];
    /** The number of wiki pages that matched the search query. */
    wikiCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type SearchResultItemEdge = {
    __typename?: 'SearchResultItemEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<SearchResultItem>;
    /** Text matches on the result found. */
    textMatches?: Maybe<Array<Maybe<TextMatch>>>;
};
/** Represents the individual results of a search. */
export declare enum SearchType {
    /** Returns matching discussions in repositories. */
    Discussion = "DISCUSSION",
    /** Returns results matching issues in repositories. */
    Issue = "ISSUE",
    /** Returns results matching repositories. */
    Repository = "REPOSITORY",
    /** Returns results matching users and organizations on GitHub. */
    User = "USER"
}
/** A GitHub Security Advisory */
export type SecurityAdvisory = Node & {
    __typename?: 'SecurityAdvisory';
    /** The CVSS associated with this advisory */
    cvss: Cvss;
    /** CWEs associated with this Advisory */
    cwes: CweConnection;
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** This is a long plaintext description of the advisory */
    description: Scalars['String']['output'];
    /** The GitHub Security Advisory ID */
    ghsaId: Scalars['String']['output'];
    id: Scalars['ID']['output'];
    /** A list of identifiers for this advisory */
    identifiers: Array<SecurityAdvisoryIdentifier>;
    /** The permalink for the advisory's dependabot alerts page */
    notificationsPermalink?: Maybe<Scalars['URI']['output']>;
    /** The organization that originated the advisory */
    origin: Scalars['String']['output'];
    /** The permalink for the advisory */
    permalink?: Maybe<Scalars['URI']['output']>;
    /** When the advisory was published */
    publishedAt: Scalars['DateTime']['output'];
    /** A list of references for this advisory */
    references: Array<SecurityAdvisoryReference>;
    /** The severity of the advisory */
    severity: SecurityAdvisorySeverity;
    /** A short plaintext summary of the advisory */
    summary: Scalars['String']['output'];
    /** When the advisory was last updated */
    updatedAt: Scalars['DateTime']['output'];
    /** Vulnerabilities associated with this Advisory */
    vulnerabilities: SecurityVulnerabilityConnection;
    /** When the advisory was withdrawn, if it has been withdrawn */
    withdrawnAt?: Maybe<Scalars['DateTime']['output']>;
};
/** A GitHub Security Advisory */
export type SecurityAdvisoryCwesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A GitHub Security Advisory */
export type SecurityAdvisoryVulnerabilitiesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    ecosystem?: InputMaybe<SecurityAdvisoryEcosystem>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    package?: InputMaybe<Scalars['String']['input']>;
    severities?: InputMaybe<Array<SecurityAdvisorySeverity>>;
};
/** The connection type for SecurityAdvisory. */
export type SecurityAdvisoryConnection = {
    __typename?: 'SecurityAdvisoryConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<SecurityAdvisoryEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<SecurityAdvisory>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** The possible ecosystems of a security vulnerability's package. */
export declare enum SecurityAdvisoryEcosystem {
    /** PHP packages hosted at packagist.org */
    Composer = "COMPOSER",
    /** Go modules */
    Go = "GO",
    /** Java artifacts hosted at the Maven central repository */
    Maven = "MAVEN",
    /** JavaScript packages hosted at npmjs.com */
    Npm = "NPM",
    /** .NET packages hosted at the NuGet Gallery */
    Nuget = "NUGET",
    /** Applications, runtimes, operating systems and other kinds of software */
    Other = "OTHER",
    /** Python packages hosted at PyPI.org */
    Pip = "PIP",
    /** Ruby gems hosted at RubyGems.org */
    Rubygems = "RUBYGEMS"
}
/** An edge in a connection. */
export type SecurityAdvisoryEdge = {
    __typename?: 'SecurityAdvisoryEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<SecurityAdvisory>;
};
/** A GitHub Security Advisory Identifier */
export type SecurityAdvisoryIdentifier = {
    __typename?: 'SecurityAdvisoryIdentifier';
    /** The identifier type, e.g. GHSA, CVE */
    type: Scalars['String']['output'];
    /** The identifier */
    value: Scalars['String']['output'];
};
/** An individual package */
export type SecurityAdvisoryPackage = {
    __typename?: 'SecurityAdvisoryPackage';
    /** The ecosystem the package belongs to, e.g. RUBYGEMS, NPM */
    ecosystem: SecurityAdvisoryEcosystem;
    /** The package name */
    name: Scalars['String']['output'];
};
/** An individual package version */
export type SecurityAdvisoryPackageVersion = {
    __typename?: 'SecurityAdvisoryPackageVersion';
    /** The package name or version */
    identifier: Scalars['String']['output'];
};
/** A GitHub Security Advisory Reference */
export type SecurityAdvisoryReference = {
    __typename?: 'SecurityAdvisoryReference';
    /** A publicly accessible reference */
    url: Scalars['URI']['output'];
};
/** Severity of the vulnerability. */
export declare enum SecurityAdvisorySeverity {
    /** Critical. */
    Critical = "CRITICAL",
    /** High. */
    High = "HIGH",
    /** Low. */
    Low = "LOW",
    /** Moderate. */
    Moderate = "MODERATE"
}
/** An individual vulnerability within an Advisory */
export type SecurityVulnerability = {
    __typename?: 'SecurityVulnerability';
    /** The Advisory associated with this Vulnerability */
    advisory: SecurityAdvisory;
    /** The first version containing a fix for the vulnerability */
    firstPatchedVersion?: Maybe<SecurityAdvisoryPackageVersion>;
    /** A description of the vulnerable package */
    package: SecurityAdvisoryPackage;
    /** The severity of the vulnerability within this package */
    severity: SecurityAdvisorySeverity;
    /** When the vulnerability was last updated */
    updatedAt: Scalars['DateTime']['output'];
    /**
     * A string that describes the vulnerable package versions.
     * This string follows a basic syntax with a few forms.
     * + `= 0.2.0` denotes a single vulnerable version.
     * + `<= 1.0.8` denotes a version range up to and including the specified version
     * + `< 0.1.11` denotes a version range up to, but excluding, the specified version
     * + `>= 4.3.0, < 4.3.5` denotes a version range with a known minimum and maximum version.
     * + `>= 0.0.1` denotes a version range with a known minimum, but no known maximum
     */
    vulnerableVersionRange: Scalars['String']['output'];
};
/** The connection type for SecurityVulnerability. */
export type SecurityVulnerabilityConnection = {
    __typename?: 'SecurityVulnerabilityConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<SecurityVulnerabilityEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<SecurityVulnerability>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type SecurityVulnerabilityEdge = {
    __typename?: 'SecurityVulnerabilityEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<SecurityVulnerability>;
};
/** Represents an S/MIME signature on a Commit or Tag. */
export type SmimeSignature = GitSignature & {
    __typename?: 'SmimeSignature';
    /** Email used to sign this object. */
    email: Scalars['String']['output'];
    /** True if the signature is valid and verified by GitHub. */
    isValid: Scalars['Boolean']['output'];
    /** Payload for GPG signing object. Raw ODB object without the signature header. */
    payload: Scalars['String']['output'];
    /** ASCII-armored signature header from object. */
    signature: Scalars['String']['output'];
    /** GitHub user corresponding to the email signing this commit. */
    signer?: Maybe<User>;
    /**
     * The state of this signature. `VALID` if signature is valid and verified by
     * GitHub, otherwise represents reason why signature is considered invalid.
     */
    state: GitSignatureState;
    /** True if the signature was made with GitHub's signing key. */
    wasSignedByGitHub: Scalars['Boolean']['output'];
};
/** Entities that can sponsor others via GitHub Sponsors */
export type Sponsor = Organization | User;
/** Entities that can be sponsored through GitHub Sponsors */
export type Sponsorable = {
    /** This object's sponsorships as the maintainer. */
    sponsorshipsAsMaintainer: SponsorshipConnection;
    /** This object's sponsorships as the sponsor. */
    sponsorshipsAsSponsor: SponsorshipConnection;
};
/** Entities that can be sponsored through GitHub Sponsors */
export type SponsorableSponsorshipsAsMaintainerArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    includePrivate?: InputMaybe<Scalars['Boolean']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<SponsorshipOrder>;
};
/** Entities that can be sponsored through GitHub Sponsors */
export type SponsorableSponsorshipsAsSponsorArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<SponsorshipOrder>;
};
/** A sponsorship relationship between a sponsor and a maintainer */
export type Sponsorship = Node & {
    __typename?: 'Sponsorship';
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** Whether this sponsorship represents a one-time payment versus a recurring sponsorship. */
    isOneTimePayment: Scalars['Boolean']['output'];
    /**
     * The entity that is being sponsored
     * @deprecated `Sponsorship.maintainer` will be removed. Use `Sponsorship.sponsorable` instead. Removal on 2020-04-01 UTC.
     */
    maintainer: User;
    /** The privacy level for this sponsorship. */
    privacyLevel: SponsorshipPrivacy;
    /**
     * The user that is sponsoring. Returns null if the sponsorship is private or if sponsor is not a user.
     * @deprecated `Sponsorship.sponsor` will be removed. Use `Sponsorship.sponsorEntity` instead. Removal on 2020-10-01 UTC.
     */
    sponsor?: Maybe<User>;
    /** The user or organization that is sponsoring, if you have permission to view them. */
    sponsorEntity?: Maybe<Sponsor>;
    /** The entity that is being sponsored */
    sponsorable: Sponsorable;
    /** Identifies the date and time when the current tier was chosen for this sponsorship. */
    tierSelectedAt?: Maybe<Scalars['DateTime']['output']>;
};
/** The connection type for Sponsorship. */
export type SponsorshipConnection = {
    __typename?: 'SponsorshipConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<SponsorshipEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Sponsorship>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type SponsorshipEdge = {
    __typename?: 'SponsorshipEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Sponsorship>;
};
/** Ordering options for sponsorship connections. */
export type SponsorshipOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
};
/** The privacy of a sponsorship */
export declare enum SponsorshipPrivacy {
    /** Private */
    Private = "PRIVATE",
    /** Public */
    Public = "PUBLIC"
}
/** Ways in which star connections can be ordered. */
export type StarOrder = {
    /** The direction in which to order nodes. */
    direction: OrderDirection;
    /** The field in which to order nodes by. */
    field: StarOrderField;
};
/** Properties by which star connections can be ordered. */
export declare enum StarOrderField {
    /** Allows ordering a list of stars by when they were created. */
    StarredAt = "STARRED_AT"
}
/** The connection type for User. */
export type StargazerConnection = {
    __typename?: 'StargazerConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<StargazerEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<User>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** Represents a user that's starred a repository. */
export type StargazerEdge = {
    __typename?: 'StargazerEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    node: User;
    /** Identifies when the item was starred. */
    starredAt: Scalars['DateTime']['output'];
};
/** Things that can be starred. */
export type Starrable = {
    id: Scalars['ID']['output'];
    /** Returns a count of how many stargazers there are on this object */
    stargazerCount: Scalars['Int']['output'];
    /** A list of users who have starred this starrable. */
    stargazers: StargazerConnection;
    /** Returns a boolean indicating whether the viewing user has starred this starrable. */
    viewerHasStarred: Scalars['Boolean']['output'];
};
/** Things that can be starred. */
export type StarrableStargazersArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<StarOrder>;
};
/** The connection type for Repository. */
export type StarredRepositoryConnection = {
    __typename?: 'StarredRepositoryConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<StarredRepositoryEdge>>>;
    /** Is the list of stars for this user truncated? This is true for users that have many stars. */
    isOverLimit: Scalars['Boolean']['output'];
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Repository>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** Represents a starred repository. */
export type StarredRepositoryEdge = {
    __typename?: 'StarredRepositoryEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    node: Repository;
    /** Identifies when the item was starred. */
    starredAt: Scalars['DateTime']['output'];
};
/** Represents a commit status. */
export type Status = Node & {
    __typename?: 'Status';
    /** A list of status contexts and check runs for this commit. */
    combinedContexts: StatusCheckRollupContextConnection;
    /** The commit this status is attached to. */
    commit?: Maybe<Commit>;
    /** Looks up an individual status context by context name. */
    context?: Maybe<StatusContext>;
    /** The individual status contexts for this commit. */
    contexts: Array<StatusContext>;
    id: Scalars['ID']['output'];
    /** The combined commit status. */
    state: StatusState;
};
/** Represents a commit status. */
export type StatusCombinedContextsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** Represents a commit status. */
export type StatusContextArgs = {
    name: Scalars['String']['input'];
};
/** Represents the rollup for both the check runs and status for a commit. */
export type StatusCheckRollup = Node & {
    __typename?: 'StatusCheckRollup';
    /** The commit the status and check runs are attached to. */
    commit?: Maybe<Commit>;
    /** A list of status contexts and check runs for this commit. */
    contexts: StatusCheckRollupContextConnection;
    id: Scalars['ID']['output'];
    /** The combined status for the commit. */
    state: StatusState;
};
/** Represents the rollup for both the check runs and status for a commit. */
export type StatusCheckRollupContextsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** Types that can be inside a StatusCheckRollup context. */
export type StatusCheckRollupContext = CheckRun | StatusContext;
/** The connection type for StatusCheckRollupContext. */
export type StatusCheckRollupContextConnection = {
    __typename?: 'StatusCheckRollupContextConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<StatusCheckRollupContextEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<StatusCheckRollupContext>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type StatusCheckRollupContextEdge = {
    __typename?: 'StatusCheckRollupContextEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<StatusCheckRollupContext>;
};
/** Represents an individual commit status context */
export type StatusContext = Node & RequirableByPullRequest & {
    __typename?: 'StatusContext';
    /** The avatar of the OAuth application or the user that created the status */
    avatarUrl?: Maybe<Scalars['URI']['output']>;
    /** This commit this status context is attached to. */
    commit?: Maybe<Commit>;
    /** The name of this status context. */
    context: Scalars['String']['output'];
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The actor who created this status context. */
    creator?: Maybe<Actor>;
    /** The description for this status context. */
    description?: Maybe<Scalars['String']['output']>;
    id: Scalars['ID']['output'];
    /** Whether this is required to pass before merging for a specific pull request. */
    isRequired: Scalars['Boolean']['output'];
    /** The state of this status context. */
    state: StatusState;
    /** The URL for this status context. */
    targetUrl?: Maybe<Scalars['URI']['output']>;
};
/** Represents an individual commit status context */
export type StatusContextAvatarUrlArgs = {
    size?: InputMaybe<Scalars['Int']['input']>;
};
/** Represents an individual commit status context */
export type StatusContextIsRequiredArgs = {
    pullRequestId?: InputMaybe<Scalars['ID']['input']>;
    pullRequestNumber?: InputMaybe<Scalars['Int']['input']>;
};
/** The possible commit status states. */
export declare enum StatusState {
    /** Status is errored. */
    Error = "ERROR",
    /** Status is expected. */
    Expected = "EXPECTED",
    /** Status is failing. */
    Failure = "FAILURE",
    /** Status is pending. */
    Pending = "PENDING",
    /** Status is successful. */
    Success = "SUCCESS"
}
/** Autogenerated input type of SubmitPullRequestReview */
export type SubmitPullRequestReviewInput = {
    /** The text field to set on the Pull Request Review. */
    body?: InputMaybe<Scalars['String']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The event to send to the Pull Request Review. */
    event: PullRequestReviewEvent;
    /** The Pull Request ID to submit any pending reviews. */
    pullRequestId?: InputMaybe<Scalars['ID']['input']>;
    /** The Pull Request Review ID to submit. */
    pullRequestReviewId?: InputMaybe<Scalars['ID']['input']>;
};
/** Autogenerated return type of SubmitPullRequestReview */
export type SubmitPullRequestReviewPayload = {
    __typename?: 'SubmitPullRequestReviewPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The submitted pull request review. */
    pullRequestReview?: Maybe<PullRequestReview>;
};
/** A pointer to a repository at a specific revision embedded inside another repository. */
export type Submodule = {
    __typename?: 'Submodule';
    /** The branch of the upstream submodule for tracking updates */
    branch?: Maybe<Scalars['String']['output']>;
    /** The git URL of the submodule repository */
    gitUrl: Scalars['URI']['output'];
    /** The name of the submodule in .gitmodules */
    name: Scalars['String']['output'];
    /** The path in the superproject that this submodule is located in */
    path: Scalars['String']['output'];
    /** The commit revision of the subproject repository being tracked by the submodule */
    subprojectCommitOid?: Maybe<Scalars['GitObjectID']['output']>;
};
/** The connection type for Submodule. */
export type SubmoduleConnection = {
    __typename?: 'SubmoduleConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<SubmoduleEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Submodule>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type SubmoduleEdge = {
    __typename?: 'SubmoduleEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Submodule>;
};
/** Entities that can be subscribed to for web and email notifications. */
export type Subscribable = {
    id: Scalars['ID']['output'];
    /** Check if the viewer is able to change their subscription status for the repository. */
    viewerCanSubscribe: Scalars['Boolean']['output'];
    /** Identifies if the viewer is watching, not watching, or ignoring the subscribable entity. */
    viewerSubscription?: Maybe<SubscriptionState>;
};
/** Represents a 'subscribed' event on a given `Subscribable`. */
export type SubscribedEvent = Node & {
    __typename?: 'SubscribedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** Object referenced by event. */
    subscribable: Subscribable;
};
/** The possible states of a subscription. */
export declare enum SubscriptionState {
    /** The User is never notified. */
    Ignored = "IGNORED",
    /** The User is notified of all conversations. */
    Subscribed = "SUBSCRIBED",
    /** The User is only notified when participating or @mentioned. */
    Unsubscribed = "UNSUBSCRIBED"
}
/** A suggestion to review a pull request based on a user's commit history and review comments. */
export type SuggestedReviewer = {
    __typename?: 'SuggestedReviewer';
    /** Is this suggestion based on past commits? */
    isAuthor: Scalars['Boolean']['output'];
    /** Is this suggestion based on past review comments? */
    isCommenter: Scalars['Boolean']['output'];
    /** Identifies the user suggested to review the pull request. */
    reviewer: User;
};
/** Represents a Git tag. */
export type Tag = GitObject & Node & {
    __typename?: 'Tag';
    /** An abbreviated version of the Git object ID */
    abbreviatedOid: Scalars['String']['output'];
    /** The HTTP path for this Git object */
    commitResourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this Git object */
    commitUrl: Scalars['URI']['output'];
    id: Scalars['ID']['output'];
    /** The Git tag message. */
    message?: Maybe<Scalars['String']['output']>;
    /** The Git tag name. */
    name: Scalars['String']['output'];
    /** The Git object ID */
    oid: Scalars['GitObjectID']['output'];
    /** The Repository the Git object belongs to */
    repository: Repository;
    /** Details about the tag author. */
    tagger?: Maybe<GitActor>;
    /** The Git object the tag points to. */
    target: GitObject;
};
/** A team of users in an organization. */
export type Team = MemberStatusable & Node & Subscribable & {
    __typename?: 'Team';
    /** A list of teams that are ancestors of this team. */
    ancestors: TeamConnection;
    /** A URL pointing to the team's avatar. */
    avatarUrl?: Maybe<Scalars['URI']['output']>;
    /** List of child teams belonging to this team */
    childTeams: TeamConnection;
    /** The slug corresponding to the organization and team. */
    combinedSlug: Scalars['String']['output'];
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The description of the team. */
    description?: Maybe<Scalars['String']['output']>;
    /** Find a team discussion by its number. */
    discussion?: Maybe<TeamDiscussion>;
    /** A list of team discussions. */
    discussions: TeamDiscussionConnection;
    /** The HTTP path for team discussions */
    discussionsResourcePath: Scalars['URI']['output'];
    /** The HTTP URL for team discussions */
    discussionsUrl: Scalars['URI']['output'];
    /** The HTTP path for editing this team */
    editTeamResourcePath: Scalars['URI']['output'];
    /** The HTTP URL for editing this team */
    editTeamUrl: Scalars['URI']['output'];
    id: Scalars['ID']['output'];
    /** A list of pending invitations for users to this team */
    invitations?: Maybe<OrganizationInvitationConnection>;
    /** Get the status messages members of this entity have set that are either public or visible only to the organization. */
    memberStatuses: UserStatusConnection;
    /** A list of users who are members of this team. */
    members: TeamMemberConnection;
    /** The HTTP path for the team' members */
    membersResourcePath: Scalars['URI']['output'];
    /** The HTTP URL for the team' members */
    membersUrl: Scalars['URI']['output'];
    /** The name of the team. */
    name: Scalars['String']['output'];
    /** The HTTP path creating a new team */
    newTeamResourcePath: Scalars['URI']['output'];
    /** The HTTP URL creating a new team */
    newTeamUrl: Scalars['URI']['output'];
    /** The organization that owns this team. */
    organization: Organization;
    /** The parent team of the team. */
    parentTeam?: Maybe<Team>;
    /** The level of privacy the team has. */
    privacy: TeamPrivacy;
    /** A list of repositories this team has access to. */
    repositories: TeamRepositoryConnection;
    /** The HTTP path for this team's repositories */
    repositoriesResourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this team's repositories */
    repositoriesUrl: Scalars['URI']['output'];
    /** The HTTP path for this team */
    resourcePath: Scalars['URI']['output'];
    /** What algorithm is used for review assignment for this team */
    reviewRequestDelegationAlgorithm?: Maybe<TeamReviewAssignmentAlgorithm>;
    /** True if review assignment is enabled for this team */
    reviewRequestDelegationEnabled: Scalars['Boolean']['output'];
    /** How many team members are required for review assignment for this team */
    reviewRequestDelegationMemberCount?: Maybe<Scalars['Int']['output']>;
    /** When assigning team members via delegation, whether the entire team should be notified as well. */
    reviewRequestDelegationNotifyTeam: Scalars['Boolean']['output'];
    /** The slug corresponding to the team. */
    slug: Scalars['String']['output'];
    /** The HTTP path for this team's teams */
    teamsResourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this team's teams */
    teamsUrl: Scalars['URI']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this team */
    url: Scalars['URI']['output'];
    /** Team is adminable by the viewer. */
    viewerCanAdminister: Scalars['Boolean']['output'];
    /** Check if the viewer is able to change their subscription status for the repository. */
    viewerCanSubscribe: Scalars['Boolean']['output'];
    /** Identifies if the viewer is watching, not watching, or ignoring the subscribable entity. */
    viewerSubscription?: Maybe<SubscriptionState>;
};
/** A team of users in an organization. */
export type TeamAncestorsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A team of users in an organization. */
export type TeamAvatarUrlArgs = {
    size?: InputMaybe<Scalars['Int']['input']>;
};
/** A team of users in an organization. */
export type TeamChildTeamsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    immediateOnly?: InputMaybe<Scalars['Boolean']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<TeamOrder>;
    userLogins?: InputMaybe<Array<Scalars['String']['input']>>;
};
/** A team of users in an organization. */
export type TeamDiscussionArgs = {
    number: Scalars['Int']['input'];
};
/** A team of users in an organization. */
export type TeamDiscussionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    isPinned?: InputMaybe<Scalars['Boolean']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<TeamDiscussionOrder>;
};
/** A team of users in an organization. */
export type TeamInvitationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A team of users in an organization. */
export type TeamMemberStatusesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<UserStatusOrder>;
};
/** A team of users in an organization. */
export type TeamMembersArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    membership?: InputMaybe<TeamMembershipType>;
    orderBy?: InputMaybe<TeamMemberOrder>;
    query?: InputMaybe<Scalars['String']['input']>;
    role?: InputMaybe<TeamMemberRole>;
};
/** A team of users in an organization. */
export type TeamRepositoriesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<TeamRepositoryOrder>;
    query?: InputMaybe<Scalars['String']['input']>;
};
/** Audit log entry for a team.add_member event. */
export type TeamAddMemberAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & TeamAuditEntryData & {
    __typename?: 'TeamAddMemberAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** Whether the team was mapped to an LDAP Group. */
    isLdapMapped?: Maybe<Scalars['Boolean']['output']>;
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The team associated with the action */
    team?: Maybe<Team>;
    /** The name of the team */
    teamName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for this team */
    teamResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for this team */
    teamUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a team.add_repository event. */
export type TeamAddRepositoryAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & TeamAuditEntryData & {
    __typename?: 'TeamAddRepositoryAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** Whether the team was mapped to an LDAP Group. */
    isLdapMapped?: Maybe<Scalars['Boolean']['output']>;
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The team associated with the action */
    team?: Maybe<Team>;
    /** The name of the team */
    teamName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for this team */
    teamResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for this team */
    teamUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Metadata for an audit entry with action team.* */
export type TeamAuditEntryData = {
    /** The team associated with the action */
    team?: Maybe<Team>;
    /** The name of the team */
    teamName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for this team */
    teamResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for this team */
    teamUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a team.change_parent_team event. */
export type TeamChangeParentTeamAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & TeamAuditEntryData & {
    __typename?: 'TeamChangeParentTeamAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** Whether the team was mapped to an LDAP Group. */
    isLdapMapped?: Maybe<Scalars['Boolean']['output']>;
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The new parent team. */
    parentTeam?: Maybe<Team>;
    /** The name of the new parent team */
    parentTeamName?: Maybe<Scalars['String']['output']>;
    /** The name of the former parent team */
    parentTeamNameWas?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the parent team */
    parentTeamResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the parent team */
    parentTeamUrl?: Maybe<Scalars['URI']['output']>;
    /** The former parent team. */
    parentTeamWas?: Maybe<Team>;
    /** The HTTP path for the previous parent team */
    parentTeamWasResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the previous parent team */
    parentTeamWasUrl?: Maybe<Scalars['URI']['output']>;
    /** The team associated with the action */
    team?: Maybe<Team>;
    /** The name of the team */
    teamName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for this team */
    teamResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for this team */
    teamUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** The connection type for Team. */
export type TeamConnection = {
    __typename?: 'TeamConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<TeamEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Team>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** A team discussion. */
export type TeamDiscussion = Comment & Deletable & Node & Reactable & Subscribable & UniformResourceLocatable & Updatable & UpdatableComment & {
    __typename?: 'TeamDiscussion';
    /** The actor who authored the comment. */
    author?: Maybe<Actor>;
    /** Author's association with the discussion's team. */
    authorAssociation: CommentAuthorAssociation;
    /** The body as Markdown. */
    body: Scalars['String']['output'];
    /** The body rendered to HTML. */
    bodyHTML: Scalars['HTML']['output'];
    /** The body rendered to text. */
    bodyText: Scalars['String']['output'];
    /** Identifies the discussion body hash. */
    bodyVersion: Scalars['String']['output'];
    /** A list of comments on this discussion. */
    comments: TeamDiscussionCommentConnection;
    /** The HTTP path for discussion comments */
    commentsResourcePath: Scalars['URI']['output'];
    /** The HTTP URL for discussion comments */
    commentsUrl: Scalars['URI']['output'];
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Check if this comment was created via an email reply. */
    createdViaEmail: Scalars['Boolean']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The actor who edited the comment. */
    editor?: Maybe<Actor>;
    id: Scalars['ID']['output'];
    /** Check if this comment was edited and includes an edit with the creation data */
    includesCreatedEdit: Scalars['Boolean']['output'];
    /** Whether or not the discussion is pinned. */
    isPinned: Scalars['Boolean']['output'];
    /** Whether or not the discussion is only visible to team members and org admins. */
    isPrivate: Scalars['Boolean']['output'];
    /** The moment the editor made the last edit */
    lastEditedAt?: Maybe<Scalars['DateTime']['output']>;
    /** Identifies the discussion within its team. */
    number: Scalars['Int']['output'];
    /** Identifies when the comment was published at. */
    publishedAt?: Maybe<Scalars['DateTime']['output']>;
    /** A list of reactions grouped by content left on the subject. */
    reactionGroups?: Maybe<Array<ReactionGroup>>;
    /** A list of Reactions left on the Issue. */
    reactions: ReactionConnection;
    /** The HTTP path for this discussion */
    resourcePath: Scalars['URI']['output'];
    /** The team that defines the context of this discussion. */
    team: Team;
    /** The title of the discussion */
    title: Scalars['String']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this discussion */
    url: Scalars['URI']['output'];
    /** A list of edits to this content. */
    userContentEdits?: Maybe<UserContentEditConnection>;
    /** Check if the current viewer can delete this object. */
    viewerCanDelete: Scalars['Boolean']['output'];
    /** Whether or not the current viewer can pin this discussion. */
    viewerCanPin: Scalars['Boolean']['output'];
    /** Can user react to this subject */
    viewerCanReact: Scalars['Boolean']['output'];
    /** Check if the viewer is able to change their subscription status for the repository. */
    viewerCanSubscribe: Scalars['Boolean']['output'];
    /** Check if the current viewer can update this object. */
    viewerCanUpdate: Scalars['Boolean']['output'];
    /** Reasons why the current viewer can not update this comment. */
    viewerCannotUpdateReasons: Array<CommentCannotUpdateReason>;
    /** Did the viewer author this comment. */
    viewerDidAuthor: Scalars['Boolean']['output'];
    /** Identifies if the viewer is watching, not watching, or ignoring the subscribable entity. */
    viewerSubscription?: Maybe<SubscriptionState>;
};
/** A team discussion. */
export type TeamDiscussionCommentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    fromComment?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<TeamDiscussionCommentOrder>;
};
/** A team discussion. */
export type TeamDiscussionReactionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    content?: InputMaybe<ReactionContent>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ReactionOrder>;
};
/** A team discussion. */
export type TeamDiscussionUserContentEditsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A comment on a team discussion. */
export type TeamDiscussionComment = Comment & Deletable & Node & Reactable & UniformResourceLocatable & Updatable & UpdatableComment & {
    __typename?: 'TeamDiscussionComment';
    /** The actor who authored the comment. */
    author?: Maybe<Actor>;
    /** Author's association with the comment's team. */
    authorAssociation: CommentAuthorAssociation;
    /** The body as Markdown. */
    body: Scalars['String']['output'];
    /** The body rendered to HTML. */
    bodyHTML: Scalars['HTML']['output'];
    /** The body rendered to text. */
    bodyText: Scalars['String']['output'];
    /** The current version of the body content. */
    bodyVersion: Scalars['String']['output'];
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Check if this comment was created via an email reply. */
    createdViaEmail: Scalars['Boolean']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The discussion this comment is about. */
    discussion: TeamDiscussion;
    /** The actor who edited the comment. */
    editor?: Maybe<Actor>;
    id: Scalars['ID']['output'];
    /** Check if this comment was edited and includes an edit with the creation data */
    includesCreatedEdit: Scalars['Boolean']['output'];
    /** The moment the editor made the last edit */
    lastEditedAt?: Maybe<Scalars['DateTime']['output']>;
    /** Identifies the comment number. */
    number: Scalars['Int']['output'];
    /** Identifies when the comment was published at. */
    publishedAt?: Maybe<Scalars['DateTime']['output']>;
    /** A list of reactions grouped by content left on the subject. */
    reactionGroups?: Maybe<Array<ReactionGroup>>;
    /** A list of Reactions left on the Issue. */
    reactions: ReactionConnection;
    /** The HTTP path for this comment */
    resourcePath: Scalars['URI']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this comment */
    url: Scalars['URI']['output'];
    /** A list of edits to this content. */
    userContentEdits?: Maybe<UserContentEditConnection>;
    /** Check if the current viewer can delete this object. */
    viewerCanDelete: Scalars['Boolean']['output'];
    /** Can user react to this subject */
    viewerCanReact: Scalars['Boolean']['output'];
    /** Check if the current viewer can update this object. */
    viewerCanUpdate: Scalars['Boolean']['output'];
    /** Reasons why the current viewer can not update this comment. */
    viewerCannotUpdateReasons: Array<CommentCannotUpdateReason>;
    /** Did the viewer author this comment. */
    viewerDidAuthor: Scalars['Boolean']['output'];
};
/** A comment on a team discussion. */
export type TeamDiscussionCommentReactionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    content?: InputMaybe<ReactionContent>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ReactionOrder>;
};
/** A comment on a team discussion. */
export type TeamDiscussionCommentUserContentEditsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** The connection type for TeamDiscussionComment. */
export type TeamDiscussionCommentConnection = {
    __typename?: 'TeamDiscussionCommentConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<TeamDiscussionCommentEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<TeamDiscussionComment>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type TeamDiscussionCommentEdge = {
    __typename?: 'TeamDiscussionCommentEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<TeamDiscussionComment>;
};
/** Ways in which team discussion comment connections can be ordered. */
export type TeamDiscussionCommentOrder = {
    /** The direction in which to order nodes. */
    direction: OrderDirection;
    /** The field by which to order nodes. */
    field: TeamDiscussionCommentOrderField;
};
/** Properties by which team discussion comment connections can be ordered. */
export declare enum TeamDiscussionCommentOrderField {
    /** Allows sequential ordering of team discussion comments (which is equivalent to chronological ordering). */
    Number = "NUMBER"
}
/** The connection type for TeamDiscussion. */
export type TeamDiscussionConnection = {
    __typename?: 'TeamDiscussionConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<TeamDiscussionEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<TeamDiscussion>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type TeamDiscussionEdge = {
    __typename?: 'TeamDiscussionEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<TeamDiscussion>;
};
/** Ways in which team discussion connections can be ordered. */
export type TeamDiscussionOrder = {
    /** The direction in which to order nodes. */
    direction: OrderDirection;
    /** The field by which to order nodes. */
    field: TeamDiscussionOrderField;
};
/** Properties by which team discussion connections can be ordered. */
export declare enum TeamDiscussionOrderField {
    /** Allows chronological ordering of team discussions. */
    CreatedAt = "CREATED_AT"
}
/** An edge in a connection. */
export type TeamEdge = {
    __typename?: 'TeamEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<Team>;
};
/** The connection type for User. */
export type TeamMemberConnection = {
    __typename?: 'TeamMemberConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<TeamMemberEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<User>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** Represents a user who is a member of a team. */
export type TeamMemberEdge = {
    __typename?: 'TeamMemberEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The HTTP path to the organization's member access page. */
    memberAccessResourcePath: Scalars['URI']['output'];
    /** The HTTP URL to the organization's member access page. */
    memberAccessUrl: Scalars['URI']['output'];
    node: User;
    /** The role the member has on the team. */
    role: TeamMemberRole;
};
/** Ordering options for team member connections */
export type TeamMemberOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order team members by. */
    field: TeamMemberOrderField;
};
/** Properties by which team member connections can be ordered. */
export declare enum TeamMemberOrderField {
    /** Order team members by creation time */
    CreatedAt = "CREATED_AT",
    /** Order team members by login */
    Login = "LOGIN"
}
/** The possible team member roles; either 'maintainer' or 'member'. */
export declare enum TeamMemberRole {
    /** A team maintainer has permission to add and remove team members. */
    Maintainer = "MAINTAINER",
    /** A team member has no administrative permissions on the team. */
    Member = "MEMBER"
}
/** Defines which types of team members are included in the returned list. Can be one of IMMEDIATE, CHILD_TEAM or ALL. */
export declare enum TeamMembershipType {
    /** Includes immediate and child team members for the team. */
    All = "ALL",
    /** Includes only child team members for the team. */
    ChildTeam = "CHILD_TEAM",
    /** Includes only immediate members of the team. */
    Immediate = "IMMEDIATE"
}
/** Ways in which team connections can be ordered. */
export type TeamOrder = {
    /** The direction in which to order nodes. */
    direction: OrderDirection;
    /** The field in which to order nodes by. */
    field: TeamOrderField;
};
/** Properties by which team connections can be ordered. */
export declare enum TeamOrderField {
    /** Allows ordering a list of teams by name. */
    Name = "NAME"
}
/** The possible team privacy values. */
export declare enum TeamPrivacy {
    /** A secret team can only be seen by its members. */
    Secret = "SECRET",
    /** A visible team can be seen and @mentioned by every member of the organization. */
    Visible = "VISIBLE"
}
/** Audit log entry for a team.remove_member event. */
export type TeamRemoveMemberAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & TeamAuditEntryData & {
    __typename?: 'TeamRemoveMemberAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** Whether the team was mapped to an LDAP Group. */
    isLdapMapped?: Maybe<Scalars['Boolean']['output']>;
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The team associated with the action */
    team?: Maybe<Team>;
    /** The name of the team */
    teamName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for this team */
    teamResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for this team */
    teamUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** Audit log entry for a team.remove_repository event. */
export type TeamRemoveRepositoryAuditEntry = AuditEntry & Node & OrganizationAuditEntryData & RepositoryAuditEntryData & TeamAuditEntryData & {
    __typename?: 'TeamRemoveRepositoryAuditEntry';
    /** The action name */
    action: Scalars['String']['output'];
    /** The user who initiated the action */
    actor?: Maybe<AuditEntryActor>;
    /** The IP address of the actor */
    actorIp?: Maybe<Scalars['String']['output']>;
    /** A readable representation of the actor's location */
    actorLocation?: Maybe<ActorLocation>;
    /** The username of the user who initiated the action */
    actorLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the actor. */
    actorResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the actor. */
    actorUrl?: Maybe<Scalars['URI']['output']>;
    /** The time the action was initiated */
    createdAt: Scalars['PreciseDateTime']['output'];
    id: Scalars['ID']['output'];
    /** Whether the team was mapped to an LDAP Group. */
    isLdapMapped?: Maybe<Scalars['Boolean']['output']>;
    /** The corresponding operation type for the action */
    operationType?: Maybe<OperationType>;
    /** The Organization associated with the Audit Entry. */
    organization?: Maybe<Organization>;
    /** The name of the Organization. */
    organizationName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the organization */
    organizationResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the organization */
    organizationUrl?: Maybe<Scalars['URI']['output']>;
    /** The repository associated with the action */
    repository?: Maybe<Repository>;
    /** The name of the repository */
    repositoryName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the repository */
    repositoryResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the repository */
    repositoryUrl?: Maybe<Scalars['URI']['output']>;
    /** The team associated with the action */
    team?: Maybe<Team>;
    /** The name of the team */
    teamName?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for this team */
    teamResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for this team */
    teamUrl?: Maybe<Scalars['URI']['output']>;
    /** The user affected by the action */
    user?: Maybe<User>;
    /** For actions involving two users, the actor is the initiator and the user is the affected user. */
    userLogin?: Maybe<Scalars['String']['output']>;
    /** The HTTP path for the user. */
    userResourcePath?: Maybe<Scalars['URI']['output']>;
    /** The HTTP URL for the user. */
    userUrl?: Maybe<Scalars['URI']['output']>;
};
/** The connection type for Repository. */
export type TeamRepositoryConnection = {
    __typename?: 'TeamRepositoryConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<TeamRepositoryEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<Repository>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** Represents a team repository. */
export type TeamRepositoryEdge = {
    __typename?: 'TeamRepositoryEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    node: Repository;
    /** The permission level the team has on the repository */
    permission: RepositoryPermission;
};
/** Ordering options for team repository connections */
export type TeamRepositoryOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order repositories by. */
    field: TeamRepositoryOrderField;
};
/** Properties by which team repository connections can be ordered. */
export declare enum TeamRepositoryOrderField {
    /** Order repositories by creation time */
    CreatedAt = "CREATED_AT",
    /** Order repositories by name */
    Name = "NAME",
    /** Order repositories by permission */
    Permission = "PERMISSION",
    /** Order repositories by push time */
    PushedAt = "PUSHED_AT",
    /** Order repositories by number of stargazers */
    Stargazers = "STARGAZERS",
    /** Order repositories by update time */
    UpdatedAt = "UPDATED_AT"
}
/** The possible team review assignment algorithms */
export declare enum TeamReviewAssignmentAlgorithm {
    /** Balance review load across the entire team */
    LoadBalance = "LOAD_BALANCE",
    /** Alternate reviews between each team member */
    RoundRobin = "ROUND_ROBIN"
}
/** The role of a user on a team. */
export declare enum TeamRole {
    /** User has admin rights on the team. */
    Admin = "ADMIN",
    /** User is a member of the team. */
    Member = "MEMBER"
}
/** A text match within a search result. */
export type TextMatch = {
    __typename?: 'TextMatch';
    /** The specific text fragment within the property matched on. */
    fragment: Scalars['String']['output'];
    /** Highlights within the matched fragment. */
    highlights: Array<TextMatchHighlight>;
    /** The property matched on. */
    property: Scalars['String']['output'];
};
/** Represents a single highlight in a search result match. */
export type TextMatchHighlight = {
    __typename?: 'TextMatchHighlight';
    /** The indice in the fragment where the matched text begins. */
    beginIndice: Scalars['Int']['output'];
    /** The indice in the fragment where the matched text ends. */
    endIndice: Scalars['Int']['output'];
    /** The text matched. */
    text: Scalars['String']['output'];
};
/** A topic aggregates entities that are related to a subject. */
export type Topic = Node & Starrable & {
    __typename?: 'Topic';
    id: Scalars['ID']['output'];
    /** The topic's name. */
    name: Scalars['String']['output'];
    /**
     * A list of related topics, including aliases of this topic, sorted with the most relevant
     * first. Returns up to 10 Topics.
     */
    relatedTopics: Array<Topic>;
    /** Returns a count of how many stargazers there are on this object */
    stargazerCount: Scalars['Int']['output'];
    /** A list of users who have starred this starrable. */
    stargazers: StargazerConnection;
    /** Returns a boolean indicating whether the viewing user has starred this starrable. */
    viewerHasStarred: Scalars['Boolean']['output'];
};
/** A topic aggregates entities that are related to a subject. */
export type TopicRelatedTopicsArgs = {
    first?: InputMaybe<Scalars['Int']['input']>;
};
/** A topic aggregates entities that are related to a subject. */
export type TopicStargazersArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<StarOrder>;
};
/** Metadata for an audit entry with a topic. */
export type TopicAuditEntryData = {
    /** The name of the topic added to the repository */
    topic?: Maybe<Topic>;
    /** The name of the topic added to the repository */
    topicName?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of TransferIssue */
export type TransferIssueInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the issue to be transferred */
    issueId: Scalars['ID']['input'];
    /** The Node ID of the repository the issue should be transferred to */
    repositoryId: Scalars['ID']['input'];
};
/** Autogenerated return type of TransferIssue */
export type TransferIssuePayload = {
    __typename?: 'TransferIssuePayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The issue that was transferred */
    issue?: Maybe<Issue>;
};
/** Represents a 'transferred' event on a given issue or pull request. */
export type TransferredEvent = Node & {
    __typename?: 'TransferredEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The repository this came from */
    fromRepository?: Maybe<Repository>;
    id: Scalars['ID']['output'];
    /** Identifies the issue associated with the event. */
    issue: Issue;
};
/** Represents a Git tree. */
export type Tree = GitObject & Node & {
    __typename?: 'Tree';
    /** An abbreviated version of the Git object ID */
    abbreviatedOid: Scalars['String']['output'];
    /** The HTTP path for this Git object */
    commitResourcePath: Scalars['URI']['output'];
    /** The HTTP URL for this Git object */
    commitUrl: Scalars['URI']['output'];
    /** A list of tree entries. */
    entries?: Maybe<Array<TreeEntry>>;
    id: Scalars['ID']['output'];
    /** The Git object ID */
    oid: Scalars['GitObjectID']['output'];
    /** The Repository the Git object belongs to */
    repository: Repository;
};
/** Represents a Git tree entry. */
export type TreeEntry = {
    __typename?: 'TreeEntry';
    /** The extension of the file */
    extension?: Maybe<Scalars['String']['output']>;
    /** Whether or not this tree entry is generated */
    isGenerated: Scalars['Boolean']['output'];
    /** Entry file mode. */
    mode: Scalars['Int']['output'];
    /** Entry file name. */
    name: Scalars['String']['output'];
    /** Entry file object. */
    object?: Maybe<GitObject>;
    /** Entry file Git object ID. */
    oid: Scalars['GitObjectID']['output'];
    /** The full path of the file. */
    path?: Maybe<Scalars['String']['output']>;
    /** The Repository the tree entry belongs to */
    repository: Repository;
    /** If the TreeEntry is for a directory occupied by a submodule project, this returns the corresponding submodule */
    submodule?: Maybe<Submodule>;
    /** Entry file type. */
    type: Scalars['String']['output'];
};
/** Autogenerated input type of UnarchiveRepository */
export type UnarchiveRepositoryInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the repository to unarchive. */
    repositoryId: Scalars['ID']['input'];
};
/** Autogenerated return type of UnarchiveRepository */
export type UnarchiveRepositoryPayload = {
    __typename?: 'UnarchiveRepositoryPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The repository that was unarchived. */
    repository?: Maybe<Repository>;
};
/** Represents an 'unassigned' event on any assignable object. */
export type UnassignedEvent = Node & {
    __typename?: 'UnassignedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the assignable associated with the event. */
    assignable: Assignable;
    /** Identifies the user or mannequin that was unassigned. */
    assignee?: Maybe<Assignee>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /**
     * Identifies the subject (user) who was unassigned.
     * @deprecated Assignees can now be mannequins. Use the `assignee` field instead. Removal on 2020-01-01 UTC.
     */
    user?: Maybe<User>;
};
/** Autogenerated input type of UnfollowUser */
export type UnfollowUserInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** ID of the user to unfollow. */
    userId: Scalars['ID']['input'];
};
/** Autogenerated return type of UnfollowUser */
export type UnfollowUserPayload = {
    __typename?: 'UnfollowUserPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The user that was unfollowed. */
    user?: Maybe<User>;
};
/** Represents a type that can be retrieved by a URL. */
export type UniformResourceLocatable = {
    /** The HTML path to this resource. */
    resourcePath: Scalars['URI']['output'];
    /** The URL to this resource. */
    url: Scalars['URI']['output'];
};
/** Represents an unknown signature on a Commit or Tag. */
export type UnknownSignature = GitSignature & {
    __typename?: 'UnknownSignature';
    /** Email used to sign this object. */
    email: Scalars['String']['output'];
    /** True if the signature is valid and verified by GitHub. */
    isValid: Scalars['Boolean']['output'];
    /** Payload for GPG signing object. Raw ODB object without the signature header. */
    payload: Scalars['String']['output'];
    /** ASCII-armored signature header from object. */
    signature: Scalars['String']['output'];
    /** GitHub user corresponding to the email signing this commit. */
    signer?: Maybe<User>;
    /**
     * The state of this signature. `VALID` if signature is valid and verified by
     * GitHub, otherwise represents reason why signature is considered invalid.
     */
    state: GitSignatureState;
    /** True if the signature was made with GitHub's signing key. */
    wasSignedByGitHub: Scalars['Boolean']['output'];
};
/** Represents an 'unlabeled' event on a given issue or pull request. */
export type UnlabeledEvent = Node & {
    __typename?: 'UnlabeledEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** Identifies the label associated with the 'unlabeled' event. */
    label: Label;
    /** Identifies the `Labelable` associated with the event. */
    labelable: Labelable;
};
/** Autogenerated input type of UnlinkRepositoryFromProject */
export type UnlinkRepositoryFromProjectInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the Project linked to the Repository. */
    projectId: Scalars['ID']['input'];
    /** The ID of the Repository linked to the Project. */
    repositoryId: Scalars['ID']['input'];
};
/** Autogenerated return type of UnlinkRepositoryFromProject */
export type UnlinkRepositoryFromProjectPayload = {
    __typename?: 'UnlinkRepositoryFromProjectPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The linked Project. */
    project?: Maybe<Project>;
    /** The linked Repository. */
    repository?: Maybe<Repository>;
};
/** Autogenerated input type of UnlockLockable */
export type UnlockLockableInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** ID of the item to be unlocked. */
    lockableId: Scalars['ID']['input'];
};
/** Autogenerated return type of UnlockLockable */
export type UnlockLockablePayload = {
    __typename?: 'UnlockLockablePayload';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The item that was unlocked. */
    unlockedRecord?: Maybe<Lockable>;
};
/** Represents an 'unlocked' event on a given issue or pull request. */
export type UnlockedEvent = Node & {
    __typename?: 'UnlockedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** Object that was unlocked. */
    lockable: Lockable;
};
/** Autogenerated input type of UnmarkDiscussionCommentAsAnswer */
export type UnmarkDiscussionCommentAsAnswerInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the discussion comment to unmark as an answer. */
    id: Scalars['ID']['input'];
};
/** Autogenerated return type of UnmarkDiscussionCommentAsAnswer */
export type UnmarkDiscussionCommentAsAnswerPayload = {
    __typename?: 'UnmarkDiscussionCommentAsAnswerPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The discussion that includes the comment. */
    discussion?: Maybe<Discussion>;
};
/** Autogenerated input type of UnmarkFileAsViewed */
export type UnmarkFileAsViewedInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The path of the file to mark as unviewed */
    path: Scalars['String']['input'];
    /** The Node ID of the pull request. */
    pullRequestId: Scalars['ID']['input'];
};
/** Autogenerated return type of UnmarkFileAsViewed */
export type UnmarkFileAsViewedPayload = {
    __typename?: 'UnmarkFileAsViewedPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated pull request. */
    pullRequest?: Maybe<PullRequest>;
};
/** Autogenerated input type of UnmarkIssueAsDuplicate */
export type UnmarkIssueAsDuplicateInput = {
    /** ID of the issue or pull request currently considered canonical/authoritative/original. */
    canonicalId: Scalars['ID']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** ID of the issue or pull request currently marked as a duplicate. */
    duplicateId: Scalars['ID']['input'];
};
/** Autogenerated return type of UnmarkIssueAsDuplicate */
export type UnmarkIssueAsDuplicatePayload = {
    __typename?: 'UnmarkIssueAsDuplicatePayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The issue or pull request that was marked as a duplicate. */
    duplicate?: Maybe<IssueOrPullRequest>;
};
/** Represents an 'unmarked_as_duplicate' event on a given issue or pull request. */
export type UnmarkedAsDuplicateEvent = Node & {
    __typename?: 'UnmarkedAsDuplicateEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** The authoritative issue or pull request which has been duplicated by another. */
    canonical?: Maybe<IssueOrPullRequest>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** The issue or pull request which has been marked as a duplicate of another. */
    duplicate?: Maybe<IssueOrPullRequest>;
    id: Scalars['ID']['output'];
    /** Canonical and duplicate belong to different repositories. */
    isCrossRepository: Scalars['Boolean']['output'];
};
/** Autogenerated input type of UnminimizeComment */
export type UnminimizeCommentInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the subject to modify. */
    subjectId: Scalars['ID']['input'];
};
/** Autogenerated return type of UnminimizeComment */
export type UnminimizeCommentPayload = {
    __typename?: 'UnminimizeCommentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The comment that was unminimized. */
    unminimizedComment?: Maybe<Minimizable>;
};
/** Autogenerated input type of UnpinIssue */
export type UnpinIssueInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the issue to be unpinned */
    issueId: Scalars['ID']['input'];
};
/** Autogenerated return type of UnpinIssue */
export type UnpinIssuePayload = {
    __typename?: 'UnpinIssuePayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The issue that was unpinned */
    issue?: Maybe<Issue>;
};
/** Represents an 'unpinned' event on a given issue or pull request. */
export type UnpinnedEvent = Node & {
    __typename?: 'UnpinnedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** Identifies the issue associated with the event. */
    issue: Issue;
};
/** Autogenerated input type of UnresolveReviewThread */
export type UnresolveReviewThreadInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the thread to unresolve */
    threadId: Scalars['ID']['input'];
};
/** Autogenerated return type of UnresolveReviewThread */
export type UnresolveReviewThreadPayload = {
    __typename?: 'UnresolveReviewThreadPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The thread to resolve. */
    thread?: Maybe<PullRequestReviewThread>;
};
/** Represents an 'unsubscribed' event on a given `Subscribable`. */
export type UnsubscribedEvent = Node & {
    __typename?: 'UnsubscribedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** Object referenced by event. */
    subscribable: Subscribable;
};
/** Entities that can be updated. */
export type Updatable = {
    /** Check if the current viewer can update this object. */
    viewerCanUpdate: Scalars['Boolean']['output'];
};
/** Comments that can be updated. */
export type UpdatableComment = {
    /** Reasons why the current viewer can not update this comment. */
    viewerCannotUpdateReasons: Array<CommentCannotUpdateReason>;
};
/** Autogenerated input type of UpdateBranchProtectionRule */
export type UpdateBranchProtectionRuleInput = {
    /** Can this branch be deleted. */
    allowsDeletions?: InputMaybe<Scalars['Boolean']['input']>;
    /** Are force pushes allowed on this branch. */
    allowsForcePushes?: InputMaybe<Scalars['Boolean']['input']>;
    /** The global relay id of the branch protection rule to be updated. */
    branchProtectionRuleId: Scalars['ID']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** Will new commits pushed to matching branches dismiss pull request review approvals. */
    dismissesStaleReviews?: InputMaybe<Scalars['Boolean']['input']>;
    /** Can admins overwrite branch protection. */
    isAdminEnforced?: InputMaybe<Scalars['Boolean']['input']>;
    /** The glob-like pattern used to determine matching branches. */
    pattern?: InputMaybe<Scalars['String']['input']>;
    /** A list of User, Team or App IDs allowed to push to matching branches. */
    pushActorIds?: InputMaybe<Array<Scalars['ID']['input']>>;
    /** Number of approving reviews required to update matching branches. */
    requiredApprovingReviewCount?: InputMaybe<Scalars['Int']['input']>;
    /** List of required status check contexts that must pass for commits to be accepted to matching branches. */
    requiredStatusCheckContexts?: InputMaybe<Array<Scalars['String']['input']>>;
    /** Are approving reviews required to update matching branches. */
    requiresApprovingReviews?: InputMaybe<Scalars['Boolean']['input']>;
    /** Are reviews from code owners required to update matching branches. */
    requiresCodeOwnerReviews?: InputMaybe<Scalars['Boolean']['input']>;
    /** Are commits required to be signed. */
    requiresCommitSignatures?: InputMaybe<Scalars['Boolean']['input']>;
    /** Are conversations required to be resolved before merging. */
    requiresConversationResolution?: InputMaybe<Scalars['Boolean']['input']>;
    /** Are merge commits prohibited from being pushed to this branch. */
    requiresLinearHistory?: InputMaybe<Scalars['Boolean']['input']>;
    /** Are status checks required to update matching branches. */
    requiresStatusChecks?: InputMaybe<Scalars['Boolean']['input']>;
    /** Are branches required to be up to date before merging. */
    requiresStrictStatusChecks?: InputMaybe<Scalars['Boolean']['input']>;
    /** Is pushing to matching branches restricted. */
    restrictsPushes?: InputMaybe<Scalars['Boolean']['input']>;
    /** Is dismissal of pull request reviews restricted. */
    restrictsReviewDismissals?: InputMaybe<Scalars['Boolean']['input']>;
    /** A list of User or Team IDs allowed to dismiss reviews on pull requests targeting matching branches. */
    reviewDismissalActorIds?: InputMaybe<Array<Scalars['ID']['input']>>;
};
/** Autogenerated return type of UpdateBranchProtectionRule */
export type UpdateBranchProtectionRulePayload = {
    __typename?: 'UpdateBranchProtectionRulePayload';
    /** The newly created BranchProtectionRule. */
    branchProtectionRule?: Maybe<BranchProtectionRule>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of UpdateCheckRun */
export type UpdateCheckRunInput = {
    /** Possible further actions the integrator can perform, which a user may trigger. */
    actions?: InputMaybe<Array<CheckRunAction>>;
    /** The node of the check. */
    checkRunId: Scalars['ID']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The time that the check run finished. */
    completedAt?: InputMaybe<Scalars['DateTime']['input']>;
    /** The final conclusion of the check. */
    conclusion?: InputMaybe<CheckConclusionState>;
    /** The URL of the integrator's site that has the full details of the check. */
    detailsUrl?: InputMaybe<Scalars['URI']['input']>;
    /** A reference for the run on the integrator's system. */
    externalId?: InputMaybe<Scalars['String']['input']>;
    /** The name of the check. */
    name?: InputMaybe<Scalars['String']['input']>;
    /** Descriptive details about the run. */
    output?: InputMaybe<CheckRunOutput>;
    /** The node ID of the repository. */
    repositoryId: Scalars['ID']['input'];
    /** The time that the check run began. */
    startedAt?: InputMaybe<Scalars['DateTime']['input']>;
    /** The current status. */
    status?: InputMaybe<RequestableCheckStatusState>;
};
/** Autogenerated return type of UpdateCheckRun */
export type UpdateCheckRunPayload = {
    __typename?: 'UpdateCheckRunPayload';
    /** The updated check run. */
    checkRun?: Maybe<CheckRun>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of UpdateCheckSuitePreferences */
export type UpdateCheckSuitePreferencesInput = {
    /** The check suite preferences to modify. */
    autoTriggerPreferences: Array<CheckSuiteAutoTriggerPreference>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the repository. */
    repositoryId: Scalars['ID']['input'];
};
/** Autogenerated return type of UpdateCheckSuitePreferences */
export type UpdateCheckSuitePreferencesPayload = {
    __typename?: 'UpdateCheckSuitePreferencesPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated repository. */
    repository?: Maybe<Repository>;
};
/** Autogenerated input type of UpdateDiscussionComment */
export type UpdateDiscussionCommentInput = {
    /** The new contents of the comment body. */
    body: Scalars['String']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the discussion comment to update. */
    commentId: Scalars['ID']['input'];
};
/** Autogenerated return type of UpdateDiscussionComment */
export type UpdateDiscussionCommentPayload = {
    __typename?: 'UpdateDiscussionCommentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The modified discussion comment. */
    comment?: Maybe<DiscussionComment>;
};
/** Autogenerated input type of UpdateDiscussion */
export type UpdateDiscussionInput = {
    /** The new contents of the discussion body. */
    body?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of a discussion category within the same repository to change this discussion to. */
    categoryId?: InputMaybe<Scalars['ID']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the discussion to update. */
    discussionId: Scalars['ID']['input'];
    /** The new discussion title. */
    title?: InputMaybe<Scalars['String']['input']>;
};
/** Autogenerated return type of UpdateDiscussion */
export type UpdateDiscussionPayload = {
    __typename?: 'UpdateDiscussionPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The modified discussion. */
    discussion?: Maybe<Discussion>;
};
/** Autogenerated input type of UpdateEnterpriseAllowPrivateRepositoryForkingSetting */
export type UpdateEnterpriseAllowPrivateRepositoryForkingSettingInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the enterprise on which to set the allow private repository forking setting. */
    enterpriseId: Scalars['ID']['input'];
    /** The value for the allow private repository forking setting on the enterprise. */
    settingValue: EnterpriseEnabledDisabledSettingValue;
};
/** Autogenerated return type of UpdateEnterpriseAllowPrivateRepositoryForkingSetting */
export type UpdateEnterpriseAllowPrivateRepositoryForkingSettingPayload = {
    __typename?: 'UpdateEnterpriseAllowPrivateRepositoryForkingSettingPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The enterprise with the updated allow private repository forking setting. */
    enterprise?: Maybe<Enterprise>;
    /** A message confirming the result of updating the allow private repository forking setting. */
    message?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of UpdateEnterpriseDefaultRepositoryPermissionSetting */
export type UpdateEnterpriseDefaultRepositoryPermissionSettingInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the enterprise on which to set the base repository permission setting. */
    enterpriseId: Scalars['ID']['input'];
    /** The value for the base repository permission setting on the enterprise. */
    settingValue: EnterpriseDefaultRepositoryPermissionSettingValue;
};
/** Autogenerated return type of UpdateEnterpriseDefaultRepositoryPermissionSetting */
export type UpdateEnterpriseDefaultRepositoryPermissionSettingPayload = {
    __typename?: 'UpdateEnterpriseDefaultRepositoryPermissionSettingPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The enterprise with the updated base repository permission setting. */
    enterprise?: Maybe<Enterprise>;
    /** A message confirming the result of updating the base repository permission setting. */
    message?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of UpdateEnterpriseMembersCanChangeRepositoryVisibilitySetting */
export type UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the enterprise on which to set the members can change repository visibility setting. */
    enterpriseId: Scalars['ID']['input'];
    /** The value for the members can change repository visibility setting on the enterprise. */
    settingValue: EnterpriseEnabledDisabledSettingValue;
};
/** Autogenerated return type of UpdateEnterpriseMembersCanChangeRepositoryVisibilitySetting */
export type UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingPayload = {
    __typename?: 'UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The enterprise with the updated members can change repository visibility setting. */
    enterprise?: Maybe<Enterprise>;
    /** A message confirming the result of updating the members can change repository visibility setting. */
    message?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of UpdateEnterpriseMembersCanCreateRepositoriesSetting */
export type UpdateEnterpriseMembersCanCreateRepositoriesSettingInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the enterprise on which to set the members can create repositories setting. */
    enterpriseId: Scalars['ID']['input'];
    /** Allow members to create internal repositories. Defaults to current value. */
    membersCanCreateInternalRepositories?: InputMaybe<Scalars['Boolean']['input']>;
    /** Allow members to create private repositories. Defaults to current value. */
    membersCanCreatePrivateRepositories?: InputMaybe<Scalars['Boolean']['input']>;
    /** Allow members to create public repositories. Defaults to current value. */
    membersCanCreatePublicRepositories?: InputMaybe<Scalars['Boolean']['input']>;
    /** When false, allow member organizations to set their own repository creation member privileges. */
    membersCanCreateRepositoriesPolicyEnabled?: InputMaybe<Scalars['Boolean']['input']>;
    /**
     * Value for the members can create repositories setting on the enterprise. This
     * or the granular public/private/internal allowed fields (but not both) must be provided.
     */
    settingValue?: InputMaybe<EnterpriseMembersCanCreateRepositoriesSettingValue>;
};
/** Autogenerated return type of UpdateEnterpriseMembersCanCreateRepositoriesSetting */
export type UpdateEnterpriseMembersCanCreateRepositoriesSettingPayload = {
    __typename?: 'UpdateEnterpriseMembersCanCreateRepositoriesSettingPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The enterprise with the updated members can create repositories setting. */
    enterprise?: Maybe<Enterprise>;
    /** A message confirming the result of updating the members can create repositories setting. */
    message?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of UpdateEnterpriseMembersCanDeleteIssuesSetting */
export type UpdateEnterpriseMembersCanDeleteIssuesSettingInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the enterprise on which to set the members can delete issues setting. */
    enterpriseId: Scalars['ID']['input'];
    /** The value for the members can delete issues setting on the enterprise. */
    settingValue: EnterpriseEnabledDisabledSettingValue;
};
/** Autogenerated return type of UpdateEnterpriseMembersCanDeleteIssuesSetting */
export type UpdateEnterpriseMembersCanDeleteIssuesSettingPayload = {
    __typename?: 'UpdateEnterpriseMembersCanDeleteIssuesSettingPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The enterprise with the updated members can delete issues setting. */
    enterprise?: Maybe<Enterprise>;
    /** A message confirming the result of updating the members can delete issues setting. */
    message?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of UpdateEnterpriseMembersCanDeleteRepositoriesSetting */
export type UpdateEnterpriseMembersCanDeleteRepositoriesSettingInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the enterprise on which to set the members can delete repositories setting. */
    enterpriseId: Scalars['ID']['input'];
    /** The value for the members can delete repositories setting on the enterprise. */
    settingValue: EnterpriseEnabledDisabledSettingValue;
};
/** Autogenerated return type of UpdateEnterpriseMembersCanDeleteRepositoriesSetting */
export type UpdateEnterpriseMembersCanDeleteRepositoriesSettingPayload = {
    __typename?: 'UpdateEnterpriseMembersCanDeleteRepositoriesSettingPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The enterprise with the updated members can delete repositories setting. */
    enterprise?: Maybe<Enterprise>;
    /** A message confirming the result of updating the members can delete repositories setting. */
    message?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of UpdateEnterpriseMembersCanInviteCollaboratorsSetting */
export type UpdateEnterpriseMembersCanInviteCollaboratorsSettingInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the enterprise on which to set the members can invite collaborators setting. */
    enterpriseId: Scalars['ID']['input'];
    /** The value for the members can invite collaborators setting on the enterprise. */
    settingValue: EnterpriseEnabledDisabledSettingValue;
};
/** Autogenerated return type of UpdateEnterpriseMembersCanInviteCollaboratorsSetting */
export type UpdateEnterpriseMembersCanInviteCollaboratorsSettingPayload = {
    __typename?: 'UpdateEnterpriseMembersCanInviteCollaboratorsSettingPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The enterprise with the updated members can invite collaborators setting. */
    enterprise?: Maybe<Enterprise>;
    /** A message confirming the result of updating the members can invite collaborators setting. */
    message?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of UpdateEnterpriseMembersCanMakePurchasesSetting */
export type UpdateEnterpriseMembersCanMakePurchasesSettingInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the enterprise on which to set the members can make purchases setting. */
    enterpriseId: Scalars['ID']['input'];
    /** The value for the members can make purchases setting on the enterprise. */
    settingValue: EnterpriseMembersCanMakePurchasesSettingValue;
};
/** Autogenerated return type of UpdateEnterpriseMembersCanMakePurchasesSetting */
export type UpdateEnterpriseMembersCanMakePurchasesSettingPayload = {
    __typename?: 'UpdateEnterpriseMembersCanMakePurchasesSettingPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The enterprise with the updated members can make purchases setting. */
    enterprise?: Maybe<Enterprise>;
    /** A message confirming the result of updating the members can make purchases setting. */
    message?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of UpdateEnterpriseMembersCanUpdateProtectedBranchesSetting */
export type UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the enterprise on which to set the members can update protected branches setting. */
    enterpriseId: Scalars['ID']['input'];
    /** The value for the members can update protected branches setting on the enterprise. */
    settingValue: EnterpriseEnabledDisabledSettingValue;
};
/** Autogenerated return type of UpdateEnterpriseMembersCanUpdateProtectedBranchesSetting */
export type UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingPayload = {
    __typename?: 'UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The enterprise with the updated members can update protected branches setting. */
    enterprise?: Maybe<Enterprise>;
    /** A message confirming the result of updating the members can update protected branches setting. */
    message?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of UpdateEnterpriseMembersCanViewDependencyInsightsSetting */
export type UpdateEnterpriseMembersCanViewDependencyInsightsSettingInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the enterprise on which to set the members can view dependency insights setting. */
    enterpriseId: Scalars['ID']['input'];
    /** The value for the members can view dependency insights setting on the enterprise. */
    settingValue: EnterpriseEnabledDisabledSettingValue;
};
/** Autogenerated return type of UpdateEnterpriseMembersCanViewDependencyInsightsSetting */
export type UpdateEnterpriseMembersCanViewDependencyInsightsSettingPayload = {
    __typename?: 'UpdateEnterpriseMembersCanViewDependencyInsightsSettingPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The enterprise with the updated members can view dependency insights setting. */
    enterprise?: Maybe<Enterprise>;
    /** A message confirming the result of updating the members can view dependency insights setting. */
    message?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of UpdateEnterpriseOrganizationProjectsSetting */
export type UpdateEnterpriseOrganizationProjectsSettingInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the enterprise on which to set the organization projects setting. */
    enterpriseId: Scalars['ID']['input'];
    /** The value for the organization projects setting on the enterprise. */
    settingValue: EnterpriseEnabledDisabledSettingValue;
};
/** Autogenerated return type of UpdateEnterpriseOrganizationProjectsSetting */
export type UpdateEnterpriseOrganizationProjectsSettingPayload = {
    __typename?: 'UpdateEnterpriseOrganizationProjectsSettingPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The enterprise with the updated organization projects setting. */
    enterprise?: Maybe<Enterprise>;
    /** A message confirming the result of updating the organization projects setting. */
    message?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of UpdateEnterpriseProfile */
export type UpdateEnterpriseProfileInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The description of the enterprise. */
    description?: InputMaybe<Scalars['String']['input']>;
    /** The Enterprise ID to update. */
    enterpriseId: Scalars['ID']['input'];
    /** The location of the enterprise. */
    location?: InputMaybe<Scalars['String']['input']>;
    /** The name of the enterprise. */
    name?: InputMaybe<Scalars['String']['input']>;
    /** The URL of the enterprise's website. */
    websiteUrl?: InputMaybe<Scalars['String']['input']>;
};
/** Autogenerated return type of UpdateEnterpriseProfile */
export type UpdateEnterpriseProfilePayload = {
    __typename?: 'UpdateEnterpriseProfilePayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated enterprise. */
    enterprise?: Maybe<Enterprise>;
};
/** Autogenerated input type of UpdateEnterpriseRepositoryProjectsSetting */
export type UpdateEnterpriseRepositoryProjectsSettingInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the enterprise on which to set the repository projects setting. */
    enterpriseId: Scalars['ID']['input'];
    /** The value for the repository projects setting on the enterprise. */
    settingValue: EnterpriseEnabledDisabledSettingValue;
};
/** Autogenerated return type of UpdateEnterpriseRepositoryProjectsSetting */
export type UpdateEnterpriseRepositoryProjectsSettingPayload = {
    __typename?: 'UpdateEnterpriseRepositoryProjectsSettingPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The enterprise with the updated repository projects setting. */
    enterprise?: Maybe<Enterprise>;
    /** A message confirming the result of updating the repository projects setting. */
    message?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of UpdateEnterpriseTeamDiscussionsSetting */
export type UpdateEnterpriseTeamDiscussionsSettingInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the enterprise on which to set the team discussions setting. */
    enterpriseId: Scalars['ID']['input'];
    /** The value for the team discussions setting on the enterprise. */
    settingValue: EnterpriseEnabledDisabledSettingValue;
};
/** Autogenerated return type of UpdateEnterpriseTeamDiscussionsSetting */
export type UpdateEnterpriseTeamDiscussionsSettingPayload = {
    __typename?: 'UpdateEnterpriseTeamDiscussionsSettingPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The enterprise with the updated team discussions setting. */
    enterprise?: Maybe<Enterprise>;
    /** A message confirming the result of updating the team discussions setting. */
    message?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of UpdateEnterpriseTwoFactorAuthenticationRequiredSetting */
export type UpdateEnterpriseTwoFactorAuthenticationRequiredSettingInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the enterprise on which to set the two factor authentication required setting. */
    enterpriseId: Scalars['ID']['input'];
    /** The value for the two factor authentication required setting on the enterprise. */
    settingValue: EnterpriseEnabledSettingValue;
};
/** Autogenerated return type of UpdateEnterpriseTwoFactorAuthenticationRequiredSetting */
export type UpdateEnterpriseTwoFactorAuthenticationRequiredSettingPayload = {
    __typename?: 'UpdateEnterpriseTwoFactorAuthenticationRequiredSettingPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The enterprise with the updated two factor authentication required setting. */
    enterprise?: Maybe<Enterprise>;
    /** A message confirming the result of updating the two factor authentication required setting. */
    message?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of UpdateEnvironment */
export type UpdateEnvironmentInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The node ID of the environment. */
    environmentId: Scalars['ID']['input'];
    /** The ids of users or teams that can approve deployments to this environment */
    reviewers?: InputMaybe<Array<Scalars['ID']['input']>>;
    /** The wait timer in minutes. */
    waitTimer?: InputMaybe<Scalars['Int']['input']>;
};
/** Autogenerated return type of UpdateEnvironment */
export type UpdateEnvironmentPayload = {
    __typename?: 'UpdateEnvironmentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated environment. */
    environment?: Maybe<Environment>;
};
/** Autogenerated input type of UpdateIpAllowListEnabledSetting */
export type UpdateIpAllowListEnabledSettingInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the owner on which to set the IP allow list enabled setting. */
    ownerId: Scalars['ID']['input'];
    /** The value for the IP allow list enabled setting. */
    settingValue: IpAllowListEnabledSettingValue;
};
/** Autogenerated return type of UpdateIpAllowListEnabledSetting */
export type UpdateIpAllowListEnabledSettingPayload = {
    __typename?: 'UpdateIpAllowListEnabledSettingPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The IP allow list owner on which the setting was updated. */
    owner?: Maybe<IpAllowListOwner>;
};
/** Autogenerated input type of UpdateIpAllowListEntry */
export type UpdateIpAllowListEntryInput = {
    /** An IP address or range of addresses in CIDR notation. */
    allowListValue: Scalars['String']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the IP allow list entry to update. */
    ipAllowListEntryId: Scalars['ID']['input'];
    /** Whether the IP allow list entry is active when an IP allow list is enabled. */
    isActive: Scalars['Boolean']['input'];
    /** An optional name for the IP allow list entry. */
    name?: InputMaybe<Scalars['String']['input']>;
};
/** Autogenerated return type of UpdateIpAllowListEntry */
export type UpdateIpAllowListEntryPayload = {
    __typename?: 'UpdateIpAllowListEntryPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The IP allow list entry that was updated. */
    ipAllowListEntry?: Maybe<IpAllowListEntry>;
};
/** Autogenerated input type of UpdateIpAllowListForInstalledAppsEnabledSetting */
export type UpdateIpAllowListForInstalledAppsEnabledSettingInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the owner. */
    ownerId: Scalars['ID']['input'];
    /** The value for the IP allow list configuration for installed GitHub Apps setting. */
    settingValue: IpAllowListForInstalledAppsEnabledSettingValue;
};
/** Autogenerated return type of UpdateIpAllowListForInstalledAppsEnabledSetting */
export type UpdateIpAllowListForInstalledAppsEnabledSettingPayload = {
    __typename?: 'UpdateIpAllowListForInstalledAppsEnabledSettingPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The IP allow list owner on which the setting was updated. */
    owner?: Maybe<IpAllowListOwner>;
};
/** Autogenerated input type of UpdateIssueComment */
export type UpdateIssueCommentInput = {
    /** The updated text of the comment. */
    body: Scalars['String']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the IssueComment to modify. */
    id: Scalars['ID']['input'];
};
/** Autogenerated return type of UpdateIssueComment */
export type UpdateIssueCommentPayload = {
    __typename?: 'UpdateIssueCommentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated comment. */
    issueComment?: Maybe<IssueComment>;
};
/** Autogenerated input type of UpdateIssue */
export type UpdateIssueInput = {
    /** An array of Node IDs of users for this issue. */
    assigneeIds?: InputMaybe<Array<Scalars['ID']['input']>>;
    /** The body for the issue description. */
    body?: InputMaybe<Scalars['String']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the Issue to modify. */
    id: Scalars['ID']['input'];
    /** An array of Node IDs of labels for this issue. */
    labelIds?: InputMaybe<Array<Scalars['ID']['input']>>;
    /** The Node ID of the milestone for this issue. */
    milestoneId?: InputMaybe<Scalars['ID']['input']>;
    /** An array of Node IDs for projects associated with this issue. */
    projectIds?: InputMaybe<Array<Scalars['ID']['input']>>;
    /** The desired issue state. */
    state?: InputMaybe<IssueState>;
    /** The title for the issue. */
    title?: InputMaybe<Scalars['String']['input']>;
};
/** Autogenerated return type of UpdateIssue */
export type UpdateIssuePayload = {
    __typename?: 'UpdateIssuePayload';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The issue. */
    issue?: Maybe<Issue>;
};
/** Autogenerated input type of UpdateLabel */
export type UpdateLabelInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** A 6 character hex code, without the leading #, identifying the updated color of the label. */
    color?: InputMaybe<Scalars['String']['input']>;
    /** A brief description of the label, such as its purpose. */
    description?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the label to be updated. */
    id: Scalars['ID']['input'];
    /** The updated name of the label. */
    name?: InputMaybe<Scalars['String']['input']>;
};
/** Autogenerated return type of UpdateLabel */
export type UpdateLabelPayload = {
    __typename?: 'UpdateLabelPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated label. */
    label?: Maybe<Label>;
};
/** Autogenerated input type of UpdateNotificationRestrictionSetting */
export type UpdateNotificationRestrictionSettingInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the owner on which to set the restrict notifications setting. */
    ownerId: Scalars['ID']['input'];
    /** The value for the restrict notifications setting. */
    settingValue: NotificationRestrictionSettingValue;
};
/** Autogenerated return type of UpdateNotificationRestrictionSetting */
export type UpdateNotificationRestrictionSettingPayload = {
    __typename?: 'UpdateNotificationRestrictionSettingPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The owner on which the setting was updated. */
    owner?: Maybe<VerifiableDomainOwner>;
};
/** Autogenerated input type of UpdateProjectCard */
export type UpdateProjectCardInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** Whether or not the ProjectCard should be archived */
    isArchived?: InputMaybe<Scalars['Boolean']['input']>;
    /** The note of ProjectCard. */
    note?: InputMaybe<Scalars['String']['input']>;
    /** The ProjectCard ID to update. */
    projectCardId: Scalars['ID']['input'];
};
/** Autogenerated return type of UpdateProjectCard */
export type UpdateProjectCardPayload = {
    __typename?: 'UpdateProjectCardPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated ProjectCard. */
    projectCard?: Maybe<ProjectCard>;
};
/** Autogenerated input type of UpdateProjectColumn */
export type UpdateProjectColumnInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The name of project column. */
    name: Scalars['String']['input'];
    /** The ProjectColumn ID to update. */
    projectColumnId: Scalars['ID']['input'];
};
/** Autogenerated return type of UpdateProjectColumn */
export type UpdateProjectColumnPayload = {
    __typename?: 'UpdateProjectColumnPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated project column. */
    projectColumn?: Maybe<ProjectColumn>;
};
/** Autogenerated input type of UpdateProject */
export type UpdateProjectInput = {
    /** The description of project. */
    body?: InputMaybe<Scalars['String']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The name of project. */
    name?: InputMaybe<Scalars['String']['input']>;
    /** The Project ID to update. */
    projectId: Scalars['ID']['input'];
    /** Whether the project is public or not. */
    public?: InputMaybe<Scalars['Boolean']['input']>;
    /** Whether the project is open or closed. */
    state?: InputMaybe<ProjectState>;
};
/** Autogenerated return type of UpdateProject */
export type UpdateProjectPayload = {
    __typename?: 'UpdateProjectPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated project. */
    project?: Maybe<Project>;
};
/** Autogenerated input type of UpdatePullRequest */
export type UpdatePullRequestInput = {
    /** An array of Node IDs of users for this pull request. */
    assigneeIds?: InputMaybe<Array<Scalars['ID']['input']>>;
    /**
     * The name of the branch you want your changes pulled into. This should be an existing branch
     * on the current repository.
     */
    baseRefName?: InputMaybe<Scalars['String']['input']>;
    /** The contents of the pull request. */
    body?: InputMaybe<Scalars['String']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** An array of Node IDs of labels for this pull request. */
    labelIds?: InputMaybe<Array<Scalars['ID']['input']>>;
    /** Indicates whether maintainers can modify the pull request. */
    maintainerCanModify?: InputMaybe<Scalars['Boolean']['input']>;
    /** The Node ID of the milestone for this pull request. */
    milestoneId?: InputMaybe<Scalars['ID']['input']>;
    /** An array of Node IDs for projects associated with this pull request. */
    projectIds?: InputMaybe<Array<Scalars['ID']['input']>>;
    /** The Node ID of the pull request. */
    pullRequestId: Scalars['ID']['input'];
    /** The target state of the pull request. */
    state?: InputMaybe<PullRequestUpdateState>;
    /** The title of the pull request. */
    title?: InputMaybe<Scalars['String']['input']>;
};
/** Autogenerated return type of UpdatePullRequest */
export type UpdatePullRequestPayload = {
    __typename?: 'UpdatePullRequestPayload';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated pull request. */
    pullRequest?: Maybe<PullRequest>;
};
/** Autogenerated input type of UpdatePullRequestReviewComment */
export type UpdatePullRequestReviewCommentInput = {
    /** The text of the comment. */
    body: Scalars['String']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the comment to modify. */
    pullRequestReviewCommentId: Scalars['ID']['input'];
};
/** Autogenerated return type of UpdatePullRequestReviewComment */
export type UpdatePullRequestReviewCommentPayload = {
    __typename?: 'UpdatePullRequestReviewCommentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated comment. */
    pullRequestReviewComment?: Maybe<PullRequestReviewComment>;
};
/** Autogenerated input type of UpdatePullRequestReview */
export type UpdatePullRequestReviewInput = {
    /** The contents of the pull request review body. */
    body: Scalars['String']['input'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the pull request review to modify. */
    pullRequestReviewId: Scalars['ID']['input'];
};
/** Autogenerated return type of UpdatePullRequestReview */
export type UpdatePullRequestReviewPayload = {
    __typename?: 'UpdatePullRequestReviewPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated pull request review. */
    pullRequestReview?: Maybe<PullRequestReview>;
};
/** Autogenerated input type of UpdateRef */
export type UpdateRefInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** Permit updates of branch Refs that are not fast-forwards? */
    force?: InputMaybe<Scalars['Boolean']['input']>;
    /** The GitObjectID that the Ref shall be updated to target. */
    oid: Scalars['GitObjectID']['input'];
    /** The Node ID of the Ref to be updated. */
    refId: Scalars['ID']['input'];
};
/** Autogenerated return type of UpdateRef */
export type UpdateRefPayload = {
    __typename?: 'UpdateRefPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated Ref. */
    ref?: Maybe<Ref>;
};
/** Autogenerated input type of UpdateRefs */
export type UpdateRefsInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** A list of ref updates. */
    refUpdates: Array<RefUpdate>;
    /** The Node ID of the repository. */
    repositoryId: Scalars['ID']['input'];
};
/** Autogenerated return type of UpdateRefs */
export type UpdateRefsPayload = {
    __typename?: 'UpdateRefsPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
};
/** Autogenerated input type of UpdateRepository */
export type UpdateRepositoryInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** A new description for the repository. Pass an empty string to erase the existing description. */
    description?: InputMaybe<Scalars['String']['input']>;
    /** Indicates if the repository should have the issues feature enabled. */
    hasIssuesEnabled?: InputMaybe<Scalars['Boolean']['input']>;
    /** Indicates if the repository should have the project boards feature enabled. */
    hasProjectsEnabled?: InputMaybe<Scalars['Boolean']['input']>;
    /** Indicates if the repository should have the wiki feature enabled. */
    hasWikiEnabled?: InputMaybe<Scalars['Boolean']['input']>;
    /** The URL for a web page about this repository. Pass an empty string to erase the existing URL. */
    homepageUrl?: InputMaybe<Scalars['URI']['input']>;
    /** The new name of the repository. */
    name?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the repository to update. */
    repositoryId: Scalars['ID']['input'];
    /**
     * Whether this repository should be marked as a template such that anyone who
     * can access it can create new repositories with the same files and directory structure.
     */
    template?: InputMaybe<Scalars['Boolean']['input']>;
};
/** Autogenerated return type of UpdateRepository */
export type UpdateRepositoryPayload = {
    __typename?: 'UpdateRepositoryPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated repository. */
    repository?: Maybe<Repository>;
};
/** Autogenerated input type of UpdateSubscription */
export type UpdateSubscriptionInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The new state of the subscription. */
    state: SubscriptionState;
    /** The Node ID of the subscribable object to modify. */
    subscribableId: Scalars['ID']['input'];
};
/** Autogenerated return type of UpdateSubscription */
export type UpdateSubscriptionPayload = {
    __typename?: 'UpdateSubscriptionPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The input subscribable entity. */
    subscribable?: Maybe<Subscribable>;
};
/** Autogenerated input type of UpdateTeamDiscussionComment */
export type UpdateTeamDiscussionCommentInput = {
    /** The updated text of the comment. */
    body: Scalars['String']['input'];
    /** The current version of the body content. */
    bodyVersion?: InputMaybe<Scalars['String']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the comment to modify. */
    id: Scalars['ID']['input'];
};
/** Autogenerated return type of UpdateTeamDiscussionComment */
export type UpdateTeamDiscussionCommentPayload = {
    __typename?: 'UpdateTeamDiscussionCommentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated comment. */
    teamDiscussionComment?: Maybe<TeamDiscussionComment>;
};
/** Autogenerated input type of UpdateTeamDiscussion */
export type UpdateTeamDiscussionInput = {
    /** The updated text of the discussion. */
    body?: InputMaybe<Scalars['String']['input']>;
    /**
     * The current version of the body content. If provided, this update operation
     * will be rejected if the given version does not match the latest version on the server.
     */
    bodyVersion?: InputMaybe<Scalars['String']['input']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the discussion to modify. */
    id: Scalars['ID']['input'];
    /** If provided, sets the pinned state of the updated discussion. */
    pinned?: InputMaybe<Scalars['Boolean']['input']>;
    /** The updated title of the discussion. */
    title?: InputMaybe<Scalars['String']['input']>;
};
/** Autogenerated return type of UpdateTeamDiscussion */
export type UpdateTeamDiscussionPayload = {
    __typename?: 'UpdateTeamDiscussionPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The updated discussion. */
    teamDiscussion?: Maybe<TeamDiscussion>;
};
/** Autogenerated input type of UpdateTeamReviewAssignment */
export type UpdateTeamReviewAssignmentInput = {
    /** The algorithm to use for review assignment */
    algorithm?: InputMaybe<TeamReviewAssignmentAlgorithm>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** Turn on or off review assignment */
    enabled: Scalars['Boolean']['input'];
    /** An array of team member IDs to exclude */
    excludedTeamMemberIds?: InputMaybe<Array<Scalars['ID']['input']>>;
    /** The Node ID of the team to update review assignments of */
    id: Scalars['ID']['input'];
    /** Notify the entire team of the PR if it is delegated */
    notifyTeam?: InputMaybe<Scalars['Boolean']['input']>;
    /** The number of team members to assign */
    teamMemberCount?: InputMaybe<Scalars['Int']['input']>;
};
/** Autogenerated return type of UpdateTeamReviewAssignment */
export type UpdateTeamReviewAssignmentPayload = {
    __typename?: 'UpdateTeamReviewAssignmentPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The team that was modified */
    team?: Maybe<Team>;
};
/** Autogenerated input type of UpdateTopics */
export type UpdateTopicsInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The Node ID of the repository. */
    repositoryId: Scalars['ID']['input'];
    /** An array of topic names. */
    topicNames: Array<Scalars['String']['input']>;
};
/** Autogenerated return type of UpdateTopics */
export type UpdateTopicsPayload = {
    __typename?: 'UpdateTopicsPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** Names of the provided topics that are not valid. */
    invalidTopicNames?: Maybe<Array<Scalars['String']['output']>>;
    /** The updated repository. */
    repository?: Maybe<Repository>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type User = Actor & Node & PackageOwner & ProfileOwner & ProjectOwner & RepositoryDiscussionAuthor & RepositoryDiscussionCommentAuthor & RepositoryOwner & Sponsorable & UniformResourceLocatable & {
    __typename?: 'User';
    /** Determine if this repository owner has any items that can be pinned to their profile. */
    anyPinnableItems: Scalars['Boolean']['output'];
    /** A URL pointing to the user's public avatar. */
    avatarUrl: Scalars['URI']['output'];
    /** The user's public profile bio. */
    bio?: Maybe<Scalars['String']['output']>;
    /** The user's public profile bio as HTML. */
    bioHTML: Scalars['HTML']['output'];
    /** Could this user receive email notifications, if the organization had notification restrictions enabled? */
    canReceiveOrganizationEmailsWhenNotificationsRestricted: Scalars['Boolean']['output'];
    /** A list of commit comments made by this user. */
    commitComments: CommitCommentConnection;
    /** The user's public profile company. */
    company?: Maybe<Scalars['String']['output']>;
    /** The user's public profile company as HTML. */
    companyHTML: Scalars['HTML']['output'];
    /** The collection of contributions this user has made to different repositories. */
    contributionsCollection: ContributionsCollection;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The user's publicly visible profile email. */
    email: Scalars['String']['output'];
    /** A list of users the given user is followed by. */
    followers: FollowerConnection;
    /** A list of users the given user is following. */
    following: FollowingConnection;
    /** Find gist by repo name. */
    gist?: Maybe<Gist>;
    /** A list of gist comments made by this user. */
    gistComments: GistCommentConnection;
    /** A list of the Gists the user has created. */
    gists: GistConnection;
    /** The hovercard information for this user in a given context */
    hovercard: Hovercard;
    id: Scalars['ID']['output'];
    /** Whether or not this user is a participant in the GitHub Security Bug Bounty. */
    isBountyHunter: Scalars['Boolean']['output'];
    /** Whether or not this user is a participant in the GitHub Campus Experts Program. */
    isCampusExpert: Scalars['Boolean']['output'];
    /** Whether or not this user is a GitHub Developer Program member. */
    isDeveloperProgramMember: Scalars['Boolean']['output'];
    /** Whether or not this user is a GitHub employee. */
    isEmployee: Scalars['Boolean']['output'];
    /** Whether or not this user is a member of the GitHub Stars Program. */
    isGitHubStar: Scalars['Boolean']['output'];
    /** Whether or not the user has marked themselves as for hire. */
    isHireable: Scalars['Boolean']['output'];
    /** Whether or not this user is a site administrator. */
    isSiteAdmin: Scalars['Boolean']['output'];
    /** Whether or not this user is the viewing user. */
    isViewer: Scalars['Boolean']['output'];
    /** A list of issue comments made by this user. */
    issueComments: IssueCommentConnection;
    /** A list of issues associated with this user. */
    issues: IssueConnection;
    /**
     * Showcases a selection of repositories and gists that the profile owner has
     * either curated or that have been selected automatically based on popularity.
     */
    itemShowcase: ProfileItemShowcase;
    /** The user's public profile location. */
    location?: Maybe<Scalars['String']['output']>;
    /** The username used to login. */
    login: Scalars['String']['output'];
    /** The user's public profile name. */
    name?: Maybe<Scalars['String']['output']>;
    /** Find an organization by its login that the user belongs to. */
    organization?: Maybe<Organization>;
    /** Verified email addresses that match verified domains for a specified organization the user is a member of. */
    organizationVerifiedDomainEmails: Array<Scalars['String']['output']>;
    /** A list of organizations the user belongs to. */
    organizations: OrganizationConnection;
    /** A list of packages under the owner. */
    packages: PackageConnection;
    /** A list of repositories and gists this profile owner can pin to their profile. */
    pinnableItems: PinnableItemConnection;
    /** A list of repositories and gists this profile owner has pinned to their profile */
    pinnedItems: PinnableItemConnection;
    /** Returns how many more items this profile owner can pin to their profile. */
    pinnedItemsRemaining: Scalars['Int']['output'];
    /** Find project by number. */
    project?: Maybe<Project>;
    /** A list of projects under the owner. */
    projects: ProjectConnection;
    /** The HTTP path listing user's projects */
    projectsResourcePath: Scalars['URI']['output'];
    /** The HTTP URL listing user's projects */
    projectsUrl: Scalars['URI']['output'];
    /** A list of public keys associated with this user. */
    publicKeys: PublicKeyConnection;
    /** A list of pull requests associated with this user. */
    pullRequests: PullRequestConnection;
    /** A list of repositories that the user owns. */
    repositories: RepositoryConnection;
    /** A list of repositories that the user recently contributed to. */
    repositoriesContributedTo: RepositoryConnection;
    /** Find Repository. */
    repository?: Maybe<Repository>;
    /** Discussion comments this user has authored. */
    repositoryDiscussionComments: DiscussionCommentConnection;
    /** Discussions this user has started. */
    repositoryDiscussions: DiscussionConnection;
    /** The HTTP path for this user */
    resourcePath: Scalars['URI']['output'];
    /** Replies this user has saved */
    savedReplies?: Maybe<SavedReplyConnection>;
    /** This object's sponsorships as the maintainer. */
    sponsorshipsAsMaintainer: SponsorshipConnection;
    /** This object's sponsorships as the sponsor. */
    sponsorshipsAsSponsor: SponsorshipConnection;
    /** Repositories the user has starred. */
    starredRepositories: StarredRepositoryConnection;
    /** The user's description of what they're currently doing. */
    status?: Maybe<UserStatus>;
    /** Identifies the date and time when the user was suspended. */
    suspendedAt?: Maybe<Scalars['DateTime']['output']>;
    /** Repositories the user has contributed to, ordered by contribution rank, plus repositories the user has created */
    topRepositories: RepositoryConnection;
    /** The user's Twitter username. */
    twitterUsername?: Maybe<Scalars['String']['output']>;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this user */
    url: Scalars['URI']['output'];
    /** Can the viewer pin repositories and gists to the profile? */
    viewerCanChangePinnedItems: Scalars['Boolean']['output'];
    /** Can the current viewer create new projects on this owner. */
    viewerCanCreateProjects: Scalars['Boolean']['output'];
    /** Whether or not the viewer is able to follow the user. */
    viewerCanFollow: Scalars['Boolean']['output'];
    /** Whether or not this user is followed by the viewer. */
    viewerIsFollowing: Scalars['Boolean']['output'];
    /** A list of repositories the given user is watching. */
    watching: RepositoryConnection;
    /** A URL pointing to the user's public website/blog. */
    websiteUrl?: Maybe<Scalars['URI']['output']>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserAnyPinnableItemsArgs = {
    type?: InputMaybe<PinnableItemType>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserAvatarUrlArgs = {
    size?: InputMaybe<Scalars['Int']['input']>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserCanReceiveOrganizationEmailsWhenNotificationsRestrictedArgs = {
    login: Scalars['String']['input'];
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserCommitCommentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserContributionsCollectionArgs = {
    from?: InputMaybe<Scalars['DateTime']['input']>;
    organizationID?: InputMaybe<Scalars['ID']['input']>;
    to?: InputMaybe<Scalars['DateTime']['input']>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserFollowersArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserFollowingArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserGistArgs = {
    name: Scalars['String']['input'];
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserGistCommentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserGistsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<GistOrder>;
    privacy?: InputMaybe<GistPrivacy>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserHovercardArgs = {
    primarySubjectId?: InputMaybe<Scalars['ID']['input']>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserIssueCommentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<IssueCommentOrder>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserIssuesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    filterBy?: InputMaybe<IssueFilters>;
    first?: InputMaybe<Scalars['Int']['input']>;
    labels?: InputMaybe<Array<Scalars['String']['input']>>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<IssueOrder>;
    states?: InputMaybe<Array<IssueState>>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserOrganizationArgs = {
    login: Scalars['String']['input'];
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserOrganizationVerifiedDomainEmailsArgs = {
    login: Scalars['String']['input'];
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserOrganizationsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserPackagesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    names?: InputMaybe<Array<InputMaybe<Scalars['String']['input']>>>;
    orderBy?: InputMaybe<PackageOrder>;
    packageType?: InputMaybe<PackageType>;
    repositoryId?: InputMaybe<Scalars['ID']['input']>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserPinnableItemsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    types?: InputMaybe<Array<PinnableItemType>>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserPinnedItemsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    types?: InputMaybe<Array<PinnableItemType>>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserProjectArgs = {
    number: Scalars['Int']['input'];
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserProjectsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<ProjectOrder>;
    search?: InputMaybe<Scalars['String']['input']>;
    states?: InputMaybe<Array<ProjectState>>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserPublicKeysArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserPullRequestsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    baseRefName?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    headRefName?: InputMaybe<Scalars['String']['input']>;
    labels?: InputMaybe<Array<Scalars['String']['input']>>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<IssueOrder>;
    states?: InputMaybe<Array<PullRequestState>>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserRepositoriesArgs = {
    affiliations?: InputMaybe<Array<InputMaybe<RepositoryAffiliation>>>;
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    isFork?: InputMaybe<Scalars['Boolean']['input']>;
    isLocked?: InputMaybe<Scalars['Boolean']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<RepositoryOrder>;
    ownerAffiliations?: InputMaybe<Array<InputMaybe<RepositoryAffiliation>>>;
    privacy?: InputMaybe<RepositoryPrivacy>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserRepositoriesContributedToArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    contributionTypes?: InputMaybe<Array<InputMaybe<RepositoryContributionType>>>;
    first?: InputMaybe<Scalars['Int']['input']>;
    includeUserRepositories?: InputMaybe<Scalars['Boolean']['input']>;
    isLocked?: InputMaybe<Scalars['Boolean']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<RepositoryOrder>;
    privacy?: InputMaybe<RepositoryPrivacy>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserRepositoryArgs = {
    name: Scalars['String']['input'];
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserRepositoryDiscussionCommentsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    onlyAnswers?: InputMaybe<Scalars['Boolean']['input']>;
    repositoryId?: InputMaybe<Scalars['ID']['input']>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserRepositoryDiscussionsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    answered?: InputMaybe<Scalars['Boolean']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<DiscussionOrder>;
    repositoryId?: InputMaybe<Scalars['ID']['input']>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserSavedRepliesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<SavedReplyOrder>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserSponsorshipsAsMaintainerArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    includePrivate?: InputMaybe<Scalars['Boolean']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<SponsorshipOrder>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserSponsorshipsAsSponsorArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<SponsorshipOrder>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserStarredRepositoriesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<StarOrder>;
    ownedByViewer?: InputMaybe<Scalars['Boolean']['input']>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserTopRepositoriesArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy: RepositoryOrder;
    since?: InputMaybe<Scalars['DateTime']['input']>;
};
/** A user is an individual's account on GitHub that owns repositories and can make new content. */
export type UserWatchingArgs = {
    affiliations?: InputMaybe<Array<InputMaybe<RepositoryAffiliation>>>;
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    isLocked?: InputMaybe<Scalars['Boolean']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
    orderBy?: InputMaybe<RepositoryOrder>;
    ownerAffiliations?: InputMaybe<Array<InputMaybe<RepositoryAffiliation>>>;
    privacy?: InputMaybe<RepositoryPrivacy>;
};
/** The possible durations that a user can be blocked for. */
export declare enum UserBlockDuration {
    /** The user was blocked for 1 day */
    OneDay = "ONE_DAY",
    /** The user was blocked for 30 days */
    OneMonth = "ONE_MONTH",
    /** The user was blocked for 7 days */
    OneWeek = "ONE_WEEK",
    /** The user was blocked permanently */
    Permanent = "PERMANENT",
    /** The user was blocked for 3 days */
    ThreeDays = "THREE_DAYS"
}
/** Represents a 'user_blocked' event on a given user. */
export type UserBlockedEvent = Node & {
    __typename?: 'UserBlockedEvent';
    /** Identifies the actor who performed the event. */
    actor?: Maybe<Actor>;
    /** Number of days that the user was blocked for. */
    blockDuration: UserBlockDuration;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    id: Scalars['ID']['output'];
    /** The user who was blocked. */
    subject?: Maybe<User>;
};
/** The connection type for User. */
export type UserConnection = {
    __typename?: 'UserConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<UserEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<User>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edit on user content */
export type UserContentEdit = Node & {
    __typename?: 'UserContentEdit';
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the date and time when the object was deleted. */
    deletedAt?: Maybe<Scalars['DateTime']['output']>;
    /** The actor who deleted this content */
    deletedBy?: Maybe<Actor>;
    /** A summary of the changes for this edit */
    diff?: Maybe<Scalars['String']['output']>;
    /** When this content was edited */
    editedAt: Scalars['DateTime']['output'];
    /** The actor who edited this content */
    editor?: Maybe<Actor>;
    id: Scalars['ID']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
};
/** A list of edits to content. */
export type UserContentEditConnection = {
    __typename?: 'UserContentEditConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<UserContentEditEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<UserContentEdit>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type UserContentEditEdge = {
    __typename?: 'UserContentEditEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<UserContentEdit>;
};
/** Represents a user. */
export type UserEdge = {
    __typename?: 'UserEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<User>;
};
/** Email attributes from External Identity */
export type UserEmailMetadata = {
    __typename?: 'UserEmailMetadata';
    /** Boolean to identify primary emails */
    primary?: Maybe<Scalars['Boolean']['output']>;
    /** Type of email */
    type?: Maybe<Scalars['String']['output']>;
    /** Email id */
    value: Scalars['String']['output'];
};
/** The user's description of what they're currently doing. */
export type UserStatus = Node & {
    __typename?: 'UserStatus';
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** An emoji summarizing the user's status. */
    emoji?: Maybe<Scalars['String']['output']>;
    /** The status emoji as HTML. */
    emojiHTML?: Maybe<Scalars['HTML']['output']>;
    /** If set, the status will not be shown after this date. */
    expiresAt?: Maybe<Scalars['DateTime']['output']>;
    id: Scalars['ID']['output'];
    /** Whether this status indicates the user is not fully available on GitHub. */
    indicatesLimitedAvailability: Scalars['Boolean']['output'];
    /** A brief message describing what the user is doing. */
    message?: Maybe<Scalars['String']['output']>;
    /** The organization whose members can see this status. If null, this status is publicly visible. */
    organization?: Maybe<Organization>;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The user who has this status. */
    user: User;
};
/** The connection type for UserStatus. */
export type UserStatusConnection = {
    __typename?: 'UserStatusConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<UserStatusEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<UserStatus>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type UserStatusEdge = {
    __typename?: 'UserStatusEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<UserStatus>;
};
/** Ordering options for user status connections. */
export type UserStatusOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order user statuses by. */
    field: UserStatusOrderField;
};
/** Properties by which user status connections can be ordered. */
export declare enum UserStatusOrderField {
    /** Order user statuses by when they were updated. */
    UpdatedAt = "UPDATED_AT"
}
/** A domain that can be verified or approved for an organization or an enterprise. */
export type VerifiableDomain = Node & {
    __typename?: 'VerifiableDomain';
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The DNS host name that should be used for verification. */
    dnsHostName?: Maybe<Scalars['URI']['output']>;
    /** The unicode encoded domain. */
    domain: Scalars['URI']['output'];
    /** Whether a TXT record for verification with the expected host name was found. */
    hasFoundHostName: Scalars['Boolean']['output'];
    /** Whether a TXT record for verification with the expected verification token was found. */
    hasFoundVerificationToken: Scalars['Boolean']['output'];
    id: Scalars['ID']['output'];
    /** Whether or not the domain is approved. */
    isApproved: Scalars['Boolean']['output'];
    /** Whether this domain is required to exist for an organization or enterprise policy to be enforced. */
    isRequiredForPolicyEnforcement: Scalars['Boolean']['output'];
    /** Whether or not the domain is verified. */
    isVerified: Scalars['Boolean']['output'];
    /** The owner of the domain. */
    owner: VerifiableDomainOwner;
    /** The punycode encoded domain. */
    punycodeEncodedDomain: Scalars['URI']['output'];
    /** The time that the current verification token will expire. */
    tokenExpirationTime?: Maybe<Scalars['DateTime']['output']>;
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The current verification token for the domain. */
    verificationToken?: Maybe<Scalars['String']['output']>;
};
/** The connection type for VerifiableDomain. */
export type VerifiableDomainConnection = {
    __typename?: 'VerifiableDomainConnection';
    /** A list of edges. */
    edges?: Maybe<Array<Maybe<VerifiableDomainEdge>>>;
    /** A list of nodes. */
    nodes?: Maybe<Array<Maybe<VerifiableDomain>>>;
    /** Information to aid in pagination. */
    pageInfo: PageInfo;
    /** Identifies the total count of items in the connection. */
    totalCount: Scalars['Int']['output'];
};
/** An edge in a connection. */
export type VerifiableDomainEdge = {
    __typename?: 'VerifiableDomainEdge';
    /** A cursor for use in pagination. */
    cursor: Scalars['String']['output'];
    /** The item at the end of the edge. */
    node?: Maybe<VerifiableDomain>;
};
/** Ordering options for verifiable domain connections. */
export type VerifiableDomainOrder = {
    /** The ordering direction. */
    direction: OrderDirection;
    /** The field to order verifiable domains by. */
    field: VerifiableDomainOrderField;
};
/** Properties by which verifiable domain connections can be ordered. */
export declare enum VerifiableDomainOrderField {
    /** Order verifiable domains by their creation date. */
    CreatedAt = "CREATED_AT",
    /** Order verifiable domains by the domain name. */
    Domain = "DOMAIN"
}
/** Types that can own a verifiable domain. */
export type VerifiableDomainOwner = Enterprise | Organization;
/** Autogenerated input type of VerifyVerifiableDomain */
export type VerifyVerifiableDomainInput = {
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: InputMaybe<Scalars['String']['input']>;
    /** The ID of the verifiable domain to verify. */
    id: Scalars['ID']['input'];
};
/** Autogenerated return type of VerifyVerifiableDomain */
export type VerifyVerifiableDomainPayload = {
    __typename?: 'VerifyVerifiableDomainPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']['output']>;
    /** The verifiable domain that was verified. */
    domain?: Maybe<VerifiableDomain>;
};
/** A hovercard context with a message describing how the viewer is related. */
export type ViewerHovercardContext = HovercardContext & {
    __typename?: 'ViewerHovercardContext';
    /** A string describing this context */
    message: Scalars['String']['output'];
    /** An octicon to accompany this context */
    octicon: Scalars['String']['output'];
    /** Identifies the user who is related to this context. */
    viewer: User;
};
/** A subject that may be upvoted. */
export type Votable = {
    /** Number of upvotes that this subject has received. */
    upvoteCount: Scalars['Int']['output'];
    /** Whether or not the current user can add or remove an upvote on this subject. */
    viewerCanUpvote: Scalars['Boolean']['output'];
    /** Whether or not the current user has already upvoted this subject. */
    viewerHasUpvoted: Scalars['Boolean']['output'];
};
/** A workflow contains meta information about an Actions workflow file. */
export type Workflow = Node & {
    __typename?: 'Workflow';
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    id: Scalars['ID']['output'];
    /** The name of the workflow. */
    name: Scalars['String']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
};
/** A workflow run. */
export type WorkflowRun = Node & {
    __typename?: 'WorkflowRun';
    /** The check suite this workflow run belongs to. */
    checkSuite: CheckSuite;
    /** Identifies the date and time when the object was created. */
    createdAt: Scalars['DateTime']['output'];
    /** Identifies the primary key from the database. */
    databaseId?: Maybe<Scalars['Int']['output']>;
    /** The log of deployment reviews */
    deploymentReviews: DeploymentReviewConnection;
    id: Scalars['ID']['output'];
    /** The pending deployment requests of all check runs in this workflow run */
    pendingDeploymentRequests: DeploymentRequestConnection;
    /** The HTTP path for this workflow run */
    resourcePath: Scalars['URI']['output'];
    /** A number that uniquely identifies this workflow run in its parent workflow. */
    runNumber: Scalars['Int']['output'];
    /** Identifies the date and time when the object was last updated. */
    updatedAt: Scalars['DateTime']['output'];
    /** The HTTP URL for this workflow run */
    url: Scalars['URI']['output'];
    /** The workflow executed in this workflow run. */
    workflow: Workflow;
};
/** A workflow run. */
export type WorkflowRunDeploymentReviewsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
/** A workflow run. */
export type WorkflowRunPendingDeploymentRequestsArgs = {
    after?: InputMaybe<Scalars['String']['input']>;
    before?: InputMaybe<Scalars['String']['input']>;
    first?: InputMaybe<Scalars['Int']['input']>;
    last?: InputMaybe<Scalars['Int']['input']>;
};
export type ResolverTypeWrapper<T> = Promise<T> | T;
export type ResolverWithResolve<TResult, TParent, TContext, TArgs> = {
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export type Resolver<TResult, TParent = {}, TContext = {}, TArgs = {}> = ResolverFn<TResult, TParent, TContext, TArgs> | ResolverWithResolve<TResult, TParent, TContext, TArgs>;
export type ResolverFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => Promise<TResult> | TResult;
export type SubscriptionSubscribeFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => AsyncIterable<TResult> | Promise<AsyncIterable<TResult>>;
export type SubscriptionResolveFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
export interface SubscriptionSubscriberObject<TResult, TKey extends string, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<{
        [key in TKey]: TResult;
    }, TParent, TContext, TArgs>;
    resolve?: SubscriptionResolveFn<TResult, {
        [key in TKey]: TResult;
    }, TContext, TArgs>;
}
export interface SubscriptionResolverObject<TResult, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<any, TParent, TContext, TArgs>;
    resolve: SubscriptionResolveFn<TResult, any, TContext, TArgs>;
}
export type SubscriptionObject<TResult, TKey extends string, TParent, TContext, TArgs> = SubscriptionSubscriberObject<TResult, TKey, TParent, TContext, TArgs> | SubscriptionResolverObject<TResult, TParent, TContext, TArgs>;
export type SubscriptionResolver<TResult, TKey extends string, TParent = {}, TContext = {}, TArgs = {}> = ((...args: any[]) => SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>) | SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>;
export type TypeResolveFn<TTypes, TParent = {}, TContext = {}> = (parent: TParent, context: TContext, info: GraphQLResolveInfo) => Maybe<TTypes> | Promise<Maybe<TTypes>>;
export type IsTypeOfResolverFn<T = {}, TContext = {}> = (obj: T, context: TContext, info: GraphQLResolveInfo) => boolean | Promise<boolean>;
export type NextResolverFn<T> = () => Promise<T>;
export type DirectiveResolverFn<TResult = {}, TParent = {}, TContext = {}, TArgs = {}> = (next: NextResolverFn<TResult>, parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
/** Mapping of union types */
export type ResolversUnionTypes<_RefType extends Record<string, unknown>> = {
    Assignee: (Bot) | (Omit<Mannequin, 'claimant'> & {
        claimant?: Maybe<_RefType['User']>;
    }) | (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    AuditEntryActor: (Bot) | (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    Closer: (Omit<Commit, 'associatedPullRequests' | 'blame' | 'checkSuites' | 'comments' | 'deployments' | 'file' | 'history' | 'onBehalfOf' | 'parents' | 'repository' | 'signature' | 'status' | 'statusCheckRollup' | 'tree'> & {
        associatedPullRequests?: Maybe<_RefType['PullRequestConnection']>;
        blame: _RefType['Blame'];
        checkSuites?: Maybe<_RefType['CheckSuiteConnection']>;
        comments: _RefType['CommitCommentConnection'];
        deployments?: Maybe<_RefType['DeploymentConnection']>;
        file?: Maybe<_RefType['TreeEntry']>;
        history: _RefType['CommitHistoryConnection'];
        onBehalfOf?: Maybe<_RefType['Organization']>;
        parents: _RefType['CommitConnection'];
        repository: _RefType['Repository'];
        signature?: Maybe<_RefType['GitSignature']>;
        status?: Maybe<_RefType['Status']>;
        statusCheckRollup?: Maybe<_RefType['StatusCheckRollup']>;
        tree: _RefType['Tree'];
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    });
    CreatedIssueOrRestrictedContribution: (Omit<CreatedIssueContribution, 'issue' | 'user'> & {
        issue: _RefType['Issue'];
        user: _RefType['User'];
    }) | (Omit<RestrictedContribution, 'user'> & {
        user: _RefType['User'];
    });
    CreatedPullRequestOrRestrictedContribution: (Omit<CreatedPullRequestContribution, 'pullRequest' | 'user'> & {
        pullRequest: _RefType['PullRequest'];
        user: _RefType['User'];
    }) | (Omit<RestrictedContribution, 'user'> & {
        user: _RefType['User'];
    });
    CreatedRepositoryOrRestrictedContribution: (Omit<CreatedRepositoryContribution, 'repository' | 'user'> & {
        repository: _RefType['Repository'];
        user: _RefType['User'];
    }) | (Omit<RestrictedContribution, 'user'> & {
        user: _RefType['User'];
    });
    DeploymentReviewer: (Omit<Team, 'discussion' | 'discussions' | 'invitations' | 'memberStatuses' | 'organization' | 'parentTeam' | 'repositories'> & {
        discussion?: Maybe<_RefType['TeamDiscussion']>;
        discussions: _RefType['TeamDiscussionConnection'];
        invitations?: Maybe<_RefType['OrganizationInvitationConnection']>;
        memberStatuses: _RefType['UserStatusConnection'];
        organization: _RefType['Organization'];
        parentTeam?: Maybe<_RefType['Team']>;
        repositories: _RefType['TeamRepositoryConnection'];
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    EnterpriseMember: (Omit<EnterpriseUserAccount, 'enterprise' | 'organizations' | 'user'> & {
        enterprise: _RefType['Enterprise'];
        organizations: _RefType['EnterpriseOrganizationMembershipConnection'];
        user?: Maybe<_RefType['User']>;
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    IpAllowListOwner: (Omit<App, 'ipAllowListEntries'> & {
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
    }) | (Omit<Enterprise, 'billingInfo' | 'members' | 'organizations' | 'ownerInfo' | 'userAccounts'> & {
        billingInfo?: Maybe<_RefType['EnterpriseBillingInfo']>;
        members: _RefType['EnterpriseMemberConnection'];
        organizations: _RefType['OrganizationConnection'];
        ownerInfo?: Maybe<_RefType['EnterpriseOwnerInfo']>;
        userAccounts: _RefType['EnterpriseUserAccountConnection'];
    }) | (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    });
    IssueOrPullRequest: (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    });
    IssueTimelineItem: (Omit<AssignedEvent, 'actor' | 'assignable' | 'assignee' | 'user'> & {
        actor?: Maybe<_RefType['Actor']>;
        assignable: _RefType['Assignable'];
        assignee?: Maybe<_RefType['Assignee']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<ClosedEvent, 'actor' | 'closable' | 'closer'> & {
        actor?: Maybe<_RefType['Actor']>;
        closable: _RefType['Closable'];
        closer?: Maybe<_RefType['Closer']>;
    }) | (Omit<Commit, 'associatedPullRequests' | 'blame' | 'checkSuites' | 'comments' | 'deployments' | 'file' | 'history' | 'onBehalfOf' | 'parents' | 'repository' | 'signature' | 'status' | 'statusCheckRollup' | 'tree'> & {
        associatedPullRequests?: Maybe<_RefType['PullRequestConnection']>;
        blame: _RefType['Blame'];
        checkSuites?: Maybe<_RefType['CheckSuiteConnection']>;
        comments: _RefType['CommitCommentConnection'];
        deployments?: Maybe<_RefType['DeploymentConnection']>;
        file?: Maybe<_RefType['TreeEntry']>;
        history: _RefType['CommitHistoryConnection'];
        onBehalfOf?: Maybe<_RefType['Organization']>;
        parents: _RefType['CommitConnection'];
        repository: _RefType['Repository'];
        signature?: Maybe<_RefType['GitSignature']>;
        status?: Maybe<_RefType['Status']>;
        statusCheckRollup?: Maybe<_RefType['StatusCheckRollup']>;
        tree: _RefType['Tree'];
    }) | (Omit<CrossReferencedEvent, 'actor' | 'source' | 'target'> & {
        actor?: Maybe<_RefType['Actor']>;
        source: _RefType['ReferencedSubject'];
        target: _RefType['ReferencedSubject'];
    }) | (Omit<DemilestonedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject: _RefType['MilestoneItem'];
    }) | (Omit<IssueComment, 'author' | 'editor' | 'issue' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<LabeledEvent, 'actor' | 'label' | 'labelable'> & {
        actor?: Maybe<_RefType['Actor']>;
        label: _RefType['Label'];
        labelable: _RefType['Labelable'];
    }) | (Omit<LockedEvent, 'actor' | 'lockable'> & {
        actor?: Maybe<_RefType['Actor']>;
        lockable: _RefType['Lockable'];
    }) | (Omit<MilestonedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject: _RefType['MilestoneItem'];
    }) | (Omit<ReferencedEvent, 'actor' | 'commit' | 'commitRepository' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        commitRepository: _RefType['Repository'];
        subject: _RefType['ReferencedSubject'];
    }) | (Omit<RenamedTitleEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject: _RefType['RenamedTitleSubject'];
    }) | (Omit<ReopenedEvent, 'actor' | 'closable'> & {
        actor?: Maybe<_RefType['Actor']>;
        closable: _RefType['Closable'];
    }) | (Omit<SubscribedEvent, 'actor' | 'subscribable'> & {
        actor?: Maybe<_RefType['Actor']>;
        subscribable: _RefType['Subscribable'];
    }) | (Omit<TransferredEvent, 'actor' | 'fromRepository' | 'issue'> & {
        actor?: Maybe<_RefType['Actor']>;
        fromRepository?: Maybe<_RefType['Repository']>;
        issue: _RefType['Issue'];
    }) | (Omit<UnassignedEvent, 'actor' | 'assignable' | 'assignee' | 'user'> & {
        actor?: Maybe<_RefType['Actor']>;
        assignable: _RefType['Assignable'];
        assignee?: Maybe<_RefType['Assignee']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<UnlabeledEvent, 'actor' | 'label' | 'labelable'> & {
        actor?: Maybe<_RefType['Actor']>;
        label: _RefType['Label'];
        labelable: _RefType['Labelable'];
    }) | (Omit<UnlockedEvent, 'actor' | 'lockable'> & {
        actor?: Maybe<_RefType['Actor']>;
        lockable: _RefType['Lockable'];
    }) | (Omit<UnsubscribedEvent, 'actor' | 'subscribable'> & {
        actor?: Maybe<_RefType['Actor']>;
        subscribable: _RefType['Subscribable'];
    }) | (Omit<UserBlockedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject?: Maybe<_RefType['User']>;
    });
    IssueTimelineItems: (Omit<AddedToProjectEvent, 'actor' | 'project' | 'projectCard'> & {
        actor?: Maybe<_RefType['Actor']>;
        project?: Maybe<_RefType['Project']>;
        projectCard?: Maybe<_RefType['ProjectCard']>;
    }) | (Omit<AssignedEvent, 'actor' | 'assignable' | 'assignee' | 'user'> & {
        actor?: Maybe<_RefType['Actor']>;
        assignable: _RefType['Assignable'];
        assignee?: Maybe<_RefType['Assignee']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<ClosedEvent, 'actor' | 'closable' | 'closer'> & {
        actor?: Maybe<_RefType['Actor']>;
        closable: _RefType['Closable'];
        closer?: Maybe<_RefType['Closer']>;
    }) | (Omit<CommentDeletedEvent, 'actor' | 'deletedCommentAuthor'> & {
        actor?: Maybe<_RefType['Actor']>;
        deletedCommentAuthor?: Maybe<_RefType['Actor']>;
    }) | (Omit<ConnectedEvent, 'actor' | 'source' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        source: _RefType['ReferencedSubject'];
        subject: _RefType['ReferencedSubject'];
    }) | (Omit<ConvertedNoteToIssueEvent, 'actor' | 'project' | 'projectCard'> & {
        actor?: Maybe<_RefType['Actor']>;
        project?: Maybe<_RefType['Project']>;
        projectCard?: Maybe<_RefType['ProjectCard']>;
    }) | (Omit<CrossReferencedEvent, 'actor' | 'source' | 'target'> & {
        actor?: Maybe<_RefType['Actor']>;
        source: _RefType['ReferencedSubject'];
        target: _RefType['ReferencedSubject'];
    }) | (Omit<DemilestonedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject: _RefType['MilestoneItem'];
    }) | (Omit<DisconnectedEvent, 'actor' | 'source' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        source: _RefType['ReferencedSubject'];
        subject: _RefType['ReferencedSubject'];
    }) | (Omit<IssueComment, 'author' | 'editor' | 'issue' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<LabeledEvent, 'actor' | 'label' | 'labelable'> & {
        actor?: Maybe<_RefType['Actor']>;
        label: _RefType['Label'];
        labelable: _RefType['Labelable'];
    }) | (Omit<LockedEvent, 'actor' | 'lockable'> & {
        actor?: Maybe<_RefType['Actor']>;
        lockable: _RefType['Lockable'];
    }) | (Omit<MarkedAsDuplicateEvent, 'actor' | 'canonical' | 'duplicate'> & {
        actor?: Maybe<_RefType['Actor']>;
        canonical?: Maybe<_RefType['IssueOrPullRequest']>;
        duplicate?: Maybe<_RefType['IssueOrPullRequest']>;
    }) | (Omit<MentionedEvent, 'actor'> & {
        actor?: Maybe<_RefType['Actor']>;
    }) | (Omit<MilestonedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject: _RefType['MilestoneItem'];
    }) | (Omit<MovedColumnsInProjectEvent, 'actor' | 'project' | 'projectCard'> & {
        actor?: Maybe<_RefType['Actor']>;
        project?: Maybe<_RefType['Project']>;
        projectCard?: Maybe<_RefType['ProjectCard']>;
    }) | (Omit<PinnedEvent, 'actor' | 'issue'> & {
        actor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
    }) | (Omit<ReferencedEvent, 'actor' | 'commit' | 'commitRepository' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        commitRepository: _RefType['Repository'];
        subject: _RefType['ReferencedSubject'];
    }) | (Omit<RemovedFromProjectEvent, 'actor' | 'project'> & {
        actor?: Maybe<_RefType['Actor']>;
        project?: Maybe<_RefType['Project']>;
    }) | (Omit<RenamedTitleEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject: _RefType['RenamedTitleSubject'];
    }) | (Omit<ReopenedEvent, 'actor' | 'closable'> & {
        actor?: Maybe<_RefType['Actor']>;
        closable: _RefType['Closable'];
    }) | (Omit<SubscribedEvent, 'actor' | 'subscribable'> & {
        actor?: Maybe<_RefType['Actor']>;
        subscribable: _RefType['Subscribable'];
    }) | (Omit<TransferredEvent, 'actor' | 'fromRepository' | 'issue'> & {
        actor?: Maybe<_RefType['Actor']>;
        fromRepository?: Maybe<_RefType['Repository']>;
        issue: _RefType['Issue'];
    }) | (Omit<UnassignedEvent, 'actor' | 'assignable' | 'assignee' | 'user'> & {
        actor?: Maybe<_RefType['Actor']>;
        assignable: _RefType['Assignable'];
        assignee?: Maybe<_RefType['Assignee']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<UnlabeledEvent, 'actor' | 'label' | 'labelable'> & {
        actor?: Maybe<_RefType['Actor']>;
        label: _RefType['Label'];
        labelable: _RefType['Labelable'];
    }) | (Omit<UnlockedEvent, 'actor' | 'lockable'> & {
        actor?: Maybe<_RefType['Actor']>;
        lockable: _RefType['Lockable'];
    }) | (Omit<UnmarkedAsDuplicateEvent, 'actor' | 'canonical' | 'duplicate'> & {
        actor?: Maybe<_RefType['Actor']>;
        canonical?: Maybe<_RefType['IssueOrPullRequest']>;
        duplicate?: Maybe<_RefType['IssueOrPullRequest']>;
    }) | (Omit<UnpinnedEvent, 'actor' | 'issue'> & {
        actor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
    }) | (Omit<UnsubscribedEvent, 'actor' | 'subscribable'> & {
        actor?: Maybe<_RefType['Actor']>;
        subscribable: _RefType['Subscribable'];
    }) | (Omit<UserBlockedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject?: Maybe<_RefType['User']>;
    });
    MilestoneItem: (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    });
    OrgRestoreMemberAuditEntryMembership: (Omit<OrgRestoreMemberMembershipOrganizationAuditEntryData, 'organization'> & {
        organization?: Maybe<_RefType['Organization']>;
    }) | (Omit<OrgRestoreMemberMembershipRepositoryAuditEntryData, 'repository'> & {
        repository?: Maybe<_RefType['Repository']>;
    }) | (Omit<OrgRestoreMemberMembershipTeamAuditEntryData, 'team'> & {
        team?: Maybe<_RefType['Team']>;
    });
    OrganizationAuditEntry: (Omit<MembersCanDeleteReposClearAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<MembersCanDeleteReposDisableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<MembersCanDeleteReposEnableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OauthApplicationCreateAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgAddBillingManagerAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgAddMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgBlockUserAuditEntry, 'actor' | 'blockedUser' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        blockedUser?: Maybe<_RefType['User']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgConfigDisableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgConfigEnableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgCreateAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgDisableOauthAppRestrictionsAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgDisableSamlAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgDisableTwoFactorRequirementAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgEnableOauthAppRestrictionsAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgEnableSamlAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgEnableTwoFactorRequirementAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgInviteMemberAuditEntry, 'actor' | 'organization' | 'organizationInvitation' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        organizationInvitation?: Maybe<_RefType['OrganizationInvitation']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgInviteToBusinessAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgOauthAppAccessApprovedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgOauthAppAccessDeniedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgOauthAppAccessRequestedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgRemoveBillingManagerAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgRemoveMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgRemoveOutsideCollaboratorAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgRestoreMemberAuditEntry, 'actor' | 'organization' | 'restoredMemberships' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        restoredMemberships?: Maybe<Array<_RefType['OrgRestoreMemberAuditEntryMembership']>>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUnblockUserAuditEntry, 'actor' | 'blockedUser' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        blockedUser?: Maybe<_RefType['User']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUpdateDefaultRepositoryPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUpdateMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUpdateMemberRepositoryCreationPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUpdateMemberRepositoryInvitationPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<PrivateRepositoryForkingDisableAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<PrivateRepositoryForkingEnableAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoAddMemberAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoAddTopicAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoArchivedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoChangeMergeSettingAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableContributorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableSockpuppetDisallowedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableContributorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableSockpuppetDisallowedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigLockAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigUnlockAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoCreateAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoDestroyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoRemoveMemberAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoRemoveTopicAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepositoryVisibilityChangeDisableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepositoryVisibilityChangeEnableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamAddMemberAuditEntry, 'actor' | 'organization' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamAddRepositoryAuditEntry, 'actor' | 'organization' | 'repository' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamChangeParentTeamAuditEntry, 'actor' | 'organization' | 'parentTeam' | 'parentTeamWas' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        parentTeam?: Maybe<_RefType['Team']>;
        parentTeamWas?: Maybe<_RefType['Team']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamRemoveMemberAuditEntry, 'actor' | 'organization' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamRemoveRepositoryAuditEntry, 'actor' | 'organization' | 'repository' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    });
    PermissionGranter: (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<Repository, 'assignableUsers' | 'branchProtectionRules' | 'collaborators' | 'commitComments' | 'defaultBranchRef' | 'deployments' | 'discussion' | 'discussionCategories' | 'discussions' | 'environment' | 'environments' | 'forks' | 'issue' | 'issueOrPullRequest' | 'label' | 'labels' | 'latestRelease' | 'mentionableUsers' | 'milestone' | 'milestones' | 'object' | 'owner' | 'packages' | 'parent' | 'pinnedDiscussions' | 'pinnedIssues' | 'project' | 'projects' | 'pullRequest' | 'pullRequestTemplates' | 'pullRequests' | 'ref' | 'release' | 'releases' | 'templateRepository' | 'vulnerabilityAlerts' | 'watchers'> & {
        assignableUsers: _RefType['UserConnection'];
        branchProtectionRules: _RefType['BranchProtectionRuleConnection'];
        collaborators?: Maybe<_RefType['RepositoryCollaboratorConnection']>;
        commitComments: _RefType['CommitCommentConnection'];
        defaultBranchRef?: Maybe<_RefType['Ref']>;
        deployments: _RefType['DeploymentConnection'];
        discussion?: Maybe<_RefType['Discussion']>;
        discussionCategories: _RefType['DiscussionCategoryConnection'];
        discussions: _RefType['DiscussionConnection'];
        environment?: Maybe<_RefType['Environment']>;
        environments: _RefType['EnvironmentConnection'];
        forks: _RefType['RepositoryConnection'];
        issue?: Maybe<_RefType['Issue']>;
        issueOrPullRequest?: Maybe<_RefType['IssueOrPullRequest']>;
        label?: Maybe<_RefType['Label']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        latestRelease?: Maybe<_RefType['Release']>;
        mentionableUsers: _RefType['UserConnection'];
        milestone?: Maybe<_RefType['Milestone']>;
        milestones?: Maybe<_RefType['MilestoneConnection']>;
        object?: Maybe<_RefType['GitObject']>;
        owner: _RefType['RepositoryOwner'];
        packages: _RefType['PackageConnection'];
        parent?: Maybe<_RefType['Repository']>;
        pinnedDiscussions: _RefType['PinnedDiscussionConnection'];
        pinnedIssues?: Maybe<_RefType['PinnedIssueConnection']>;
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        pullRequestTemplates?: Maybe<Array<_RefType['PullRequestTemplate']>>;
        pullRequests: _RefType['PullRequestConnection'];
        ref?: Maybe<_RefType['Ref']>;
        release?: Maybe<_RefType['Release']>;
        releases: _RefType['ReleaseConnection'];
        templateRepository?: Maybe<_RefType['Repository']>;
        vulnerabilityAlerts?: Maybe<_RefType['RepositoryVulnerabilityAlertConnection']>;
        watchers: _RefType['UserConnection'];
    }) | (Omit<Team, 'discussion' | 'discussions' | 'invitations' | 'memberStatuses' | 'organization' | 'parentTeam' | 'repositories'> & {
        discussion?: Maybe<_RefType['TeamDiscussion']>;
        discussions: _RefType['TeamDiscussionConnection'];
        invitations?: Maybe<_RefType['OrganizationInvitationConnection']>;
        memberStatuses: _RefType['UserStatusConnection'];
        organization: _RefType['Organization'];
        parentTeam?: Maybe<_RefType['Team']>;
        repositories: _RefType['TeamRepositoryConnection'];
    });
    PinnableItem: (Omit<Gist, 'comments' | 'forks' | 'owner'> & {
        comments: _RefType['GistCommentConnection'];
        forks: _RefType['GistConnection'];
        owner?: Maybe<_RefType['RepositoryOwner']>;
    }) | (Omit<Repository, 'assignableUsers' | 'branchProtectionRules' | 'collaborators' | 'commitComments' | 'defaultBranchRef' | 'deployments' | 'discussion' | 'discussionCategories' | 'discussions' | 'environment' | 'environments' | 'forks' | 'issue' | 'issueOrPullRequest' | 'label' | 'labels' | 'latestRelease' | 'mentionableUsers' | 'milestone' | 'milestones' | 'object' | 'owner' | 'packages' | 'parent' | 'pinnedDiscussions' | 'pinnedIssues' | 'project' | 'projects' | 'pullRequest' | 'pullRequestTemplates' | 'pullRequests' | 'ref' | 'release' | 'releases' | 'templateRepository' | 'vulnerabilityAlerts' | 'watchers'> & {
        assignableUsers: _RefType['UserConnection'];
        branchProtectionRules: _RefType['BranchProtectionRuleConnection'];
        collaborators?: Maybe<_RefType['RepositoryCollaboratorConnection']>;
        commitComments: _RefType['CommitCommentConnection'];
        defaultBranchRef?: Maybe<_RefType['Ref']>;
        deployments: _RefType['DeploymentConnection'];
        discussion?: Maybe<_RefType['Discussion']>;
        discussionCategories: _RefType['DiscussionCategoryConnection'];
        discussions: _RefType['DiscussionConnection'];
        environment?: Maybe<_RefType['Environment']>;
        environments: _RefType['EnvironmentConnection'];
        forks: _RefType['RepositoryConnection'];
        issue?: Maybe<_RefType['Issue']>;
        issueOrPullRequest?: Maybe<_RefType['IssueOrPullRequest']>;
        label?: Maybe<_RefType['Label']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        latestRelease?: Maybe<_RefType['Release']>;
        mentionableUsers: _RefType['UserConnection'];
        milestone?: Maybe<_RefType['Milestone']>;
        milestones?: Maybe<_RefType['MilestoneConnection']>;
        object?: Maybe<_RefType['GitObject']>;
        owner: _RefType['RepositoryOwner'];
        packages: _RefType['PackageConnection'];
        parent?: Maybe<_RefType['Repository']>;
        pinnedDiscussions: _RefType['PinnedDiscussionConnection'];
        pinnedIssues?: Maybe<_RefType['PinnedIssueConnection']>;
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        pullRequestTemplates?: Maybe<Array<_RefType['PullRequestTemplate']>>;
        pullRequests: _RefType['PullRequestConnection'];
        ref?: Maybe<_RefType['Ref']>;
        release?: Maybe<_RefType['Release']>;
        releases: _RefType['ReleaseConnection'];
        templateRepository?: Maybe<_RefType['Repository']>;
        vulnerabilityAlerts?: Maybe<_RefType['RepositoryVulnerabilityAlertConnection']>;
        watchers: _RefType['UserConnection'];
    });
    ProjectCardItem: (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    });
    PullRequestTimelineItem: (Omit<AssignedEvent, 'actor' | 'assignable' | 'assignee' | 'user'> & {
        actor?: Maybe<_RefType['Actor']>;
        assignable: _RefType['Assignable'];
        assignee?: Maybe<_RefType['Assignee']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<BaseRefDeletedEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest?: Maybe<_RefType['PullRequest']>;
    }) | (Omit<BaseRefForcePushedEvent, 'actor' | 'afterCommit' | 'beforeCommit' | 'pullRequest' | 'ref'> & {
        actor?: Maybe<_RefType['Actor']>;
        afterCommit?: Maybe<_RefType['Commit']>;
        beforeCommit?: Maybe<_RefType['Commit']>;
        pullRequest: _RefType['PullRequest'];
        ref?: Maybe<_RefType['Ref']>;
    }) | (Omit<ClosedEvent, 'actor' | 'closable' | 'closer'> & {
        actor?: Maybe<_RefType['Actor']>;
        closable: _RefType['Closable'];
        closer?: Maybe<_RefType['Closer']>;
    }) | (Omit<Commit, 'associatedPullRequests' | 'blame' | 'checkSuites' | 'comments' | 'deployments' | 'file' | 'history' | 'onBehalfOf' | 'parents' | 'repository' | 'signature' | 'status' | 'statusCheckRollup' | 'tree'> & {
        associatedPullRequests?: Maybe<_RefType['PullRequestConnection']>;
        blame: _RefType['Blame'];
        checkSuites?: Maybe<_RefType['CheckSuiteConnection']>;
        comments: _RefType['CommitCommentConnection'];
        deployments?: Maybe<_RefType['DeploymentConnection']>;
        file?: Maybe<_RefType['TreeEntry']>;
        history: _RefType['CommitHistoryConnection'];
        onBehalfOf?: Maybe<_RefType['Organization']>;
        parents: _RefType['CommitConnection'];
        repository: _RefType['Repository'];
        signature?: Maybe<_RefType['GitSignature']>;
        status?: Maybe<_RefType['Status']>;
        statusCheckRollup?: Maybe<_RefType['StatusCheckRollup']>;
        tree: _RefType['Tree'];
    }) | (Omit<CommitCommentThread, 'comments' | 'commit' | 'repository'> & {
        comments: _RefType['CommitCommentConnection'];
        commit?: Maybe<_RefType['Commit']>;
        repository: _RefType['Repository'];
    }) | (Omit<CrossReferencedEvent, 'actor' | 'source' | 'target'> & {
        actor?: Maybe<_RefType['Actor']>;
        source: _RefType['ReferencedSubject'];
        target: _RefType['ReferencedSubject'];
    }) | (Omit<DemilestonedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject: _RefType['MilestoneItem'];
    }) | (Omit<DeployedEvent, 'actor' | 'deployment' | 'pullRequest' | 'ref'> & {
        actor?: Maybe<_RefType['Actor']>;
        deployment: _RefType['Deployment'];
        pullRequest: _RefType['PullRequest'];
        ref?: Maybe<_RefType['Ref']>;
    }) | (Omit<DeploymentEnvironmentChangedEvent, 'actor' | 'deploymentStatus' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        deploymentStatus: _RefType['DeploymentStatus'];
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<HeadRefDeletedEvent, 'actor' | 'headRef' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<HeadRefForcePushedEvent, 'actor' | 'afterCommit' | 'beforeCommit' | 'pullRequest' | 'ref'> & {
        actor?: Maybe<_RefType['Actor']>;
        afterCommit?: Maybe<_RefType['Commit']>;
        beforeCommit?: Maybe<_RefType['Commit']>;
        pullRequest: _RefType['PullRequest'];
        ref?: Maybe<_RefType['Ref']>;
    }) | (Omit<HeadRefRestoredEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<IssueComment, 'author' | 'editor' | 'issue' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<LabeledEvent, 'actor' | 'label' | 'labelable'> & {
        actor?: Maybe<_RefType['Actor']>;
        label: _RefType['Label'];
        labelable: _RefType['Labelable'];
    }) | (Omit<LockedEvent, 'actor' | 'lockable'> & {
        actor?: Maybe<_RefType['Actor']>;
        lockable: _RefType['Lockable'];
    }) | (Omit<MergedEvent, 'actor' | 'commit' | 'mergeRef' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        mergeRef?: Maybe<_RefType['Ref']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<MilestonedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject: _RefType['MilestoneItem'];
    }) | (Omit<PullRequestReview, 'author' | 'comments' | 'commit' | 'editor' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['PullRequestReviewCommentConnection'];
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequestReviewComment, 'author' | 'commit' | 'editor' | 'originalCommit' | 'pullRequest' | 'pullRequestReview' | 'reactionGroups' | 'reactions' | 'replyTo' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        originalCommit?: Maybe<_RefType['Commit']>;
        pullRequest: _RefType['PullRequest'];
        pullRequestReview?: Maybe<_RefType['PullRequestReview']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        replyTo?: Maybe<_RefType['PullRequestReviewComment']>;
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequestReviewThread, 'comments' | 'pullRequest' | 'repository' | 'resolvedBy'> & {
        comments: _RefType['PullRequestReviewCommentConnection'];
        pullRequest: _RefType['PullRequest'];
        repository: _RefType['Repository'];
        resolvedBy?: Maybe<_RefType['User']>;
    }) | (Omit<ReferencedEvent, 'actor' | 'commit' | 'commitRepository' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        commitRepository: _RefType['Repository'];
        subject: _RefType['ReferencedSubject'];
    }) | (Omit<RenamedTitleEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject: _RefType['RenamedTitleSubject'];
    }) | (Omit<ReopenedEvent, 'actor' | 'closable'> & {
        actor?: Maybe<_RefType['Actor']>;
        closable: _RefType['Closable'];
    }) | (Omit<ReviewDismissedEvent, 'actor' | 'pullRequest' | 'pullRequestCommit' | 'review'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        pullRequestCommit?: Maybe<_RefType['PullRequestCommit']>;
        review?: Maybe<_RefType['PullRequestReview']>;
    }) | (Omit<ReviewRequestRemovedEvent, 'actor' | 'pullRequest' | 'requestedReviewer'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        requestedReviewer?: Maybe<_RefType['RequestedReviewer']>;
    }) | (Omit<ReviewRequestedEvent, 'actor' | 'pullRequest' | 'requestedReviewer'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        requestedReviewer?: Maybe<_RefType['RequestedReviewer']>;
    }) | (Omit<SubscribedEvent, 'actor' | 'subscribable'> & {
        actor?: Maybe<_RefType['Actor']>;
        subscribable: _RefType['Subscribable'];
    }) | (Omit<UnassignedEvent, 'actor' | 'assignable' | 'assignee' | 'user'> & {
        actor?: Maybe<_RefType['Actor']>;
        assignable: _RefType['Assignable'];
        assignee?: Maybe<_RefType['Assignee']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<UnlabeledEvent, 'actor' | 'label' | 'labelable'> & {
        actor?: Maybe<_RefType['Actor']>;
        label: _RefType['Label'];
        labelable: _RefType['Labelable'];
    }) | (Omit<UnlockedEvent, 'actor' | 'lockable'> & {
        actor?: Maybe<_RefType['Actor']>;
        lockable: _RefType['Lockable'];
    }) | (Omit<UnsubscribedEvent, 'actor' | 'subscribable'> & {
        actor?: Maybe<_RefType['Actor']>;
        subscribable: _RefType['Subscribable'];
    }) | (Omit<UserBlockedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject?: Maybe<_RefType['User']>;
    });
    PullRequestTimelineItems: (Omit<AddedToProjectEvent, 'actor' | 'project' | 'projectCard'> & {
        actor?: Maybe<_RefType['Actor']>;
        project?: Maybe<_RefType['Project']>;
        projectCard?: Maybe<_RefType['ProjectCard']>;
    }) | (Omit<AssignedEvent, 'actor' | 'assignable' | 'assignee' | 'user'> & {
        actor?: Maybe<_RefType['Actor']>;
        assignable: _RefType['Assignable'];
        assignee?: Maybe<_RefType['Assignee']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<AutoMergeDisabledEvent, 'actor' | 'disabler' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        disabler?: Maybe<_RefType['User']>;
        pullRequest?: Maybe<_RefType['PullRequest']>;
    }) | (Omit<AutoMergeEnabledEvent, 'actor' | 'enabler' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        enabler?: Maybe<_RefType['User']>;
        pullRequest?: Maybe<_RefType['PullRequest']>;
    }) | (Omit<AutoRebaseEnabledEvent, 'actor' | 'enabler' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        enabler?: Maybe<_RefType['User']>;
        pullRequest?: Maybe<_RefType['PullRequest']>;
    }) | (Omit<AutoSquashEnabledEvent, 'actor' | 'enabler' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        enabler?: Maybe<_RefType['User']>;
        pullRequest?: Maybe<_RefType['PullRequest']>;
    }) | (Omit<AutomaticBaseChangeFailedEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<AutomaticBaseChangeSucceededEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<BaseRefChangedEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<BaseRefDeletedEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest?: Maybe<_RefType['PullRequest']>;
    }) | (Omit<BaseRefForcePushedEvent, 'actor' | 'afterCommit' | 'beforeCommit' | 'pullRequest' | 'ref'> & {
        actor?: Maybe<_RefType['Actor']>;
        afterCommit?: Maybe<_RefType['Commit']>;
        beforeCommit?: Maybe<_RefType['Commit']>;
        pullRequest: _RefType['PullRequest'];
        ref?: Maybe<_RefType['Ref']>;
    }) | (Omit<ClosedEvent, 'actor' | 'closable' | 'closer'> & {
        actor?: Maybe<_RefType['Actor']>;
        closable: _RefType['Closable'];
        closer?: Maybe<_RefType['Closer']>;
    }) | (Omit<CommentDeletedEvent, 'actor' | 'deletedCommentAuthor'> & {
        actor?: Maybe<_RefType['Actor']>;
        deletedCommentAuthor?: Maybe<_RefType['Actor']>;
    }) | (Omit<ConnectedEvent, 'actor' | 'source' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        source: _RefType['ReferencedSubject'];
        subject: _RefType['ReferencedSubject'];
    }) | (Omit<ConvertToDraftEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<ConvertedNoteToIssueEvent, 'actor' | 'project' | 'projectCard'> & {
        actor?: Maybe<_RefType['Actor']>;
        project?: Maybe<_RefType['Project']>;
        projectCard?: Maybe<_RefType['ProjectCard']>;
    }) | (Omit<CrossReferencedEvent, 'actor' | 'source' | 'target'> & {
        actor?: Maybe<_RefType['Actor']>;
        source: _RefType['ReferencedSubject'];
        target: _RefType['ReferencedSubject'];
    }) | (Omit<DemilestonedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject: _RefType['MilestoneItem'];
    }) | (Omit<DeployedEvent, 'actor' | 'deployment' | 'pullRequest' | 'ref'> & {
        actor?: Maybe<_RefType['Actor']>;
        deployment: _RefType['Deployment'];
        pullRequest: _RefType['PullRequest'];
        ref?: Maybe<_RefType['Ref']>;
    }) | (Omit<DeploymentEnvironmentChangedEvent, 'actor' | 'deploymentStatus' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        deploymentStatus: _RefType['DeploymentStatus'];
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<DisconnectedEvent, 'actor' | 'source' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        source: _RefType['ReferencedSubject'];
        subject: _RefType['ReferencedSubject'];
    }) | (Omit<HeadRefDeletedEvent, 'actor' | 'headRef' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<HeadRefForcePushedEvent, 'actor' | 'afterCommit' | 'beforeCommit' | 'pullRequest' | 'ref'> & {
        actor?: Maybe<_RefType['Actor']>;
        afterCommit?: Maybe<_RefType['Commit']>;
        beforeCommit?: Maybe<_RefType['Commit']>;
        pullRequest: _RefType['PullRequest'];
        ref?: Maybe<_RefType['Ref']>;
    }) | (Omit<HeadRefRestoredEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<IssueComment, 'author' | 'editor' | 'issue' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<LabeledEvent, 'actor' | 'label' | 'labelable'> & {
        actor?: Maybe<_RefType['Actor']>;
        label: _RefType['Label'];
        labelable: _RefType['Labelable'];
    }) | (Omit<LockedEvent, 'actor' | 'lockable'> & {
        actor?: Maybe<_RefType['Actor']>;
        lockable: _RefType['Lockable'];
    }) | (Omit<MarkedAsDuplicateEvent, 'actor' | 'canonical' | 'duplicate'> & {
        actor?: Maybe<_RefType['Actor']>;
        canonical?: Maybe<_RefType['IssueOrPullRequest']>;
        duplicate?: Maybe<_RefType['IssueOrPullRequest']>;
    }) | (Omit<MentionedEvent, 'actor'> & {
        actor?: Maybe<_RefType['Actor']>;
    }) | (Omit<MergedEvent, 'actor' | 'commit' | 'mergeRef' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        mergeRef?: Maybe<_RefType['Ref']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<MilestonedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject: _RefType['MilestoneItem'];
    }) | (Omit<MovedColumnsInProjectEvent, 'actor' | 'project' | 'projectCard'> & {
        actor?: Maybe<_RefType['Actor']>;
        project?: Maybe<_RefType['Project']>;
        projectCard?: Maybe<_RefType['ProjectCard']>;
    }) | (Omit<PinnedEvent, 'actor' | 'issue'> & {
        actor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
    }) | (Omit<PullRequestCommit, 'commit' | 'pullRequest'> & {
        commit: _RefType['Commit'];
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<PullRequestCommitCommentThread, 'comments' | 'commit' | 'pullRequest' | 'repository'> & {
        comments: _RefType['CommitCommentConnection'];
        commit: _RefType['Commit'];
        pullRequest: _RefType['PullRequest'];
        repository: _RefType['Repository'];
    }) | (Omit<PullRequestReview, 'author' | 'comments' | 'commit' | 'editor' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['PullRequestReviewCommentConnection'];
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequestReviewThread, 'comments' | 'pullRequest' | 'repository' | 'resolvedBy'> & {
        comments: _RefType['PullRequestReviewCommentConnection'];
        pullRequest: _RefType['PullRequest'];
        repository: _RefType['Repository'];
        resolvedBy?: Maybe<_RefType['User']>;
    }) | (Omit<PullRequestRevisionMarker, 'lastSeenCommit' | 'pullRequest'> & {
        lastSeenCommit: _RefType['Commit'];
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<ReadyForReviewEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<ReferencedEvent, 'actor' | 'commit' | 'commitRepository' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        commitRepository: _RefType['Repository'];
        subject: _RefType['ReferencedSubject'];
    }) | (Omit<RemovedFromProjectEvent, 'actor' | 'project'> & {
        actor?: Maybe<_RefType['Actor']>;
        project?: Maybe<_RefType['Project']>;
    }) | (Omit<RenamedTitleEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject: _RefType['RenamedTitleSubject'];
    }) | (Omit<ReopenedEvent, 'actor' | 'closable'> & {
        actor?: Maybe<_RefType['Actor']>;
        closable: _RefType['Closable'];
    }) | (Omit<ReviewDismissedEvent, 'actor' | 'pullRequest' | 'pullRequestCommit' | 'review'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        pullRequestCommit?: Maybe<_RefType['PullRequestCommit']>;
        review?: Maybe<_RefType['PullRequestReview']>;
    }) | (Omit<ReviewRequestRemovedEvent, 'actor' | 'pullRequest' | 'requestedReviewer'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        requestedReviewer?: Maybe<_RefType['RequestedReviewer']>;
    }) | (Omit<ReviewRequestedEvent, 'actor' | 'pullRequest' | 'requestedReviewer'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        requestedReviewer?: Maybe<_RefType['RequestedReviewer']>;
    }) | (Omit<SubscribedEvent, 'actor' | 'subscribable'> & {
        actor?: Maybe<_RefType['Actor']>;
        subscribable: _RefType['Subscribable'];
    }) | (Omit<TransferredEvent, 'actor' | 'fromRepository' | 'issue'> & {
        actor?: Maybe<_RefType['Actor']>;
        fromRepository?: Maybe<_RefType['Repository']>;
        issue: _RefType['Issue'];
    }) | (Omit<UnassignedEvent, 'actor' | 'assignable' | 'assignee' | 'user'> & {
        actor?: Maybe<_RefType['Actor']>;
        assignable: _RefType['Assignable'];
        assignee?: Maybe<_RefType['Assignee']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<UnlabeledEvent, 'actor' | 'label' | 'labelable'> & {
        actor?: Maybe<_RefType['Actor']>;
        label: _RefType['Label'];
        labelable: _RefType['Labelable'];
    }) | (Omit<UnlockedEvent, 'actor' | 'lockable'> & {
        actor?: Maybe<_RefType['Actor']>;
        lockable: _RefType['Lockable'];
    }) | (Omit<UnmarkedAsDuplicateEvent, 'actor' | 'canonical' | 'duplicate'> & {
        actor?: Maybe<_RefType['Actor']>;
        canonical?: Maybe<_RefType['IssueOrPullRequest']>;
        duplicate?: Maybe<_RefType['IssueOrPullRequest']>;
    }) | (Omit<UnpinnedEvent, 'actor' | 'issue'> & {
        actor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
    }) | (Omit<UnsubscribedEvent, 'actor' | 'subscribable'> & {
        actor?: Maybe<_RefType['Actor']>;
        subscribable: _RefType['Subscribable'];
    }) | (Omit<UserBlockedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject?: Maybe<_RefType['User']>;
    });
    PushAllowanceActor: (Omit<App, 'ipAllowListEntries'> & {
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
    }) | (Omit<Team, 'discussion' | 'discussions' | 'invitations' | 'memberStatuses' | 'organization' | 'parentTeam' | 'repositories'> & {
        discussion?: Maybe<_RefType['TeamDiscussion']>;
        discussions: _RefType['TeamDiscussionConnection'];
        invitations?: Maybe<_RefType['OrganizationInvitationConnection']>;
        memberStatuses: _RefType['UserStatusConnection'];
        organization: _RefType['Organization'];
        parentTeam?: Maybe<_RefType['Team']>;
        repositories: _RefType['TeamRepositoryConnection'];
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    Reactor: (Bot) | (Omit<Mannequin, 'claimant'> & {
        claimant?: Maybe<_RefType['User']>;
    }) | (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    ReferencedSubject: (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    });
    RenamedTitleSubject: (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    });
    RequestedReviewer: (Omit<Mannequin, 'claimant'> & {
        claimant?: Maybe<_RefType['User']>;
    }) | (Omit<Team, 'discussion' | 'discussions' | 'invitations' | 'memberStatuses' | 'organization' | 'parentTeam' | 'repositories'> & {
        discussion?: Maybe<_RefType['TeamDiscussion']>;
        discussions: _RefType['TeamDiscussionConnection'];
        invitations?: Maybe<_RefType['OrganizationInvitationConnection']>;
        memberStatuses: _RefType['UserStatusConnection'];
        organization: _RefType['Organization'];
        parentTeam?: Maybe<_RefType['Team']>;
        repositories: _RefType['TeamRepositoryConnection'];
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    ReviewDismissalAllowanceActor: (Omit<Team, 'discussion' | 'discussions' | 'invitations' | 'memberStatuses' | 'organization' | 'parentTeam' | 'repositories'> & {
        discussion?: Maybe<_RefType['TeamDiscussion']>;
        discussions: _RefType['TeamDiscussionConnection'];
        invitations?: Maybe<_RefType['OrganizationInvitationConnection']>;
        memberStatuses: _RefType['UserStatusConnection'];
        organization: _RefType['Organization'];
        parentTeam?: Maybe<_RefType['Team']>;
        repositories: _RefType['TeamRepositoryConnection'];
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    SearchResultItem: (Omit<App, 'ipAllowListEntries'> & {
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
    }) | (Omit<Discussion, 'answer' | 'answerChosenBy' | 'author' | 'category' | 'comments' | 'editor' | 'labels' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        answer?: Maybe<_RefType['DiscussionComment']>;
        answerChosenBy?: Maybe<_RefType['Actor']>;
        author?: Maybe<_RefType['Actor']>;
        category: _RefType['DiscussionCategory'];
        comments: _RefType['DiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    }) | (Omit<Repository, 'assignableUsers' | 'branchProtectionRules' | 'collaborators' | 'commitComments' | 'defaultBranchRef' | 'deployments' | 'discussion' | 'discussionCategories' | 'discussions' | 'environment' | 'environments' | 'forks' | 'issue' | 'issueOrPullRequest' | 'label' | 'labels' | 'latestRelease' | 'mentionableUsers' | 'milestone' | 'milestones' | 'object' | 'owner' | 'packages' | 'parent' | 'pinnedDiscussions' | 'pinnedIssues' | 'project' | 'projects' | 'pullRequest' | 'pullRequestTemplates' | 'pullRequests' | 'ref' | 'release' | 'releases' | 'templateRepository' | 'vulnerabilityAlerts' | 'watchers'> & {
        assignableUsers: _RefType['UserConnection'];
        branchProtectionRules: _RefType['BranchProtectionRuleConnection'];
        collaborators?: Maybe<_RefType['RepositoryCollaboratorConnection']>;
        commitComments: _RefType['CommitCommentConnection'];
        defaultBranchRef?: Maybe<_RefType['Ref']>;
        deployments: _RefType['DeploymentConnection'];
        discussion?: Maybe<_RefType['Discussion']>;
        discussionCategories: _RefType['DiscussionCategoryConnection'];
        discussions: _RefType['DiscussionConnection'];
        environment?: Maybe<_RefType['Environment']>;
        environments: _RefType['EnvironmentConnection'];
        forks: _RefType['RepositoryConnection'];
        issue?: Maybe<_RefType['Issue']>;
        issueOrPullRequest?: Maybe<_RefType['IssueOrPullRequest']>;
        label?: Maybe<_RefType['Label']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        latestRelease?: Maybe<_RefType['Release']>;
        mentionableUsers: _RefType['UserConnection'];
        milestone?: Maybe<_RefType['Milestone']>;
        milestones?: Maybe<_RefType['MilestoneConnection']>;
        object?: Maybe<_RefType['GitObject']>;
        owner: _RefType['RepositoryOwner'];
        packages: _RefType['PackageConnection'];
        parent?: Maybe<_RefType['Repository']>;
        pinnedDiscussions: _RefType['PinnedDiscussionConnection'];
        pinnedIssues?: Maybe<_RefType['PinnedIssueConnection']>;
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        pullRequestTemplates?: Maybe<Array<_RefType['PullRequestTemplate']>>;
        pullRequests: _RefType['PullRequestConnection'];
        ref?: Maybe<_RefType['Ref']>;
        release?: Maybe<_RefType['Release']>;
        releases: _RefType['ReleaseConnection'];
        templateRepository?: Maybe<_RefType['Repository']>;
        vulnerabilityAlerts?: Maybe<_RefType['RepositoryVulnerabilityAlertConnection']>;
        watchers: _RefType['UserConnection'];
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    Sponsor: (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    StatusCheckRollupContext: (Omit<CheckRun, 'checkSuite' | 'deployment' | 'pendingDeploymentRequest' | 'repository'> & {
        checkSuite: _RefType['CheckSuite'];
        deployment?: Maybe<_RefType['Deployment']>;
        pendingDeploymentRequest?: Maybe<_RefType['DeploymentRequest']>;
        repository: _RefType['Repository'];
    }) | (Omit<StatusContext, 'commit' | 'creator'> & {
        commit?: Maybe<_RefType['Commit']>;
        creator?: Maybe<_RefType['Actor']>;
    });
    VerifiableDomainOwner: (Omit<Enterprise, 'billingInfo' | 'members' | 'organizations' | 'ownerInfo' | 'userAccounts'> & {
        billingInfo?: Maybe<_RefType['EnterpriseBillingInfo']>;
        members: _RefType['EnterpriseMemberConnection'];
        organizations: _RefType['OrganizationConnection'];
        ownerInfo?: Maybe<_RefType['EnterpriseOwnerInfo']>;
        userAccounts: _RefType['EnterpriseUserAccountConnection'];
    }) | (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    });
};
/** Mapping of interface types */
export type ResolversInterfaceTypes<_RefType extends Record<string, unknown>> = {
    Actor: (Bot) | (Omit<EnterpriseUserAccount, 'enterprise' | 'organizations' | 'user'> & {
        enterprise: _RefType['Enterprise'];
        organizations: _RefType['EnterpriseOrganizationMembershipConnection'];
        user?: Maybe<_RefType['User']>;
    }) | (Omit<Mannequin, 'claimant'> & {
        claimant?: Maybe<_RefType['User']>;
    }) | (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    Assignable: (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    });
    AuditEntry: (Omit<MembersCanDeleteReposClearAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<MembersCanDeleteReposDisableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<MembersCanDeleteReposEnableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OauthApplicationCreateAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgAddBillingManagerAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgAddMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgBlockUserAuditEntry, 'actor' | 'blockedUser' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        blockedUser?: Maybe<_RefType['User']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgConfigDisableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgConfigEnableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgCreateAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgDisableOauthAppRestrictionsAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgDisableSamlAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgDisableTwoFactorRequirementAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgEnableOauthAppRestrictionsAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgEnableSamlAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgEnableTwoFactorRequirementAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgInviteMemberAuditEntry, 'actor' | 'organization' | 'organizationInvitation' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        organizationInvitation?: Maybe<_RefType['OrganizationInvitation']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgInviteToBusinessAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgOauthAppAccessApprovedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgOauthAppAccessDeniedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgOauthAppAccessRequestedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgRemoveBillingManagerAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgRemoveMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgRemoveOutsideCollaboratorAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgRestoreMemberAuditEntry, 'actor' | 'organization' | 'restoredMemberships' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        restoredMemberships?: Maybe<Array<_RefType['OrgRestoreMemberAuditEntryMembership']>>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUnblockUserAuditEntry, 'actor' | 'blockedUser' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        blockedUser?: Maybe<_RefType['User']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUpdateDefaultRepositoryPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUpdateMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUpdateMemberRepositoryCreationPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUpdateMemberRepositoryInvitationPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<PrivateRepositoryForkingDisableAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<PrivateRepositoryForkingEnableAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoAddMemberAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoAddTopicAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoArchivedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoChangeMergeSettingAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableContributorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableSockpuppetDisallowedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableContributorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableSockpuppetDisallowedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigLockAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigUnlockAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoCreateAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoDestroyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoRemoveMemberAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoRemoveTopicAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepositoryVisibilityChangeDisableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepositoryVisibilityChangeEnableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamAddMemberAuditEntry, 'actor' | 'organization' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamAddRepositoryAuditEntry, 'actor' | 'organization' | 'repository' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamChangeParentTeamAuditEntry, 'actor' | 'organization' | 'parentTeam' | 'parentTeamWas' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        parentTeam?: Maybe<_RefType['Team']>;
        parentTeamWas?: Maybe<_RefType['Team']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamRemoveMemberAuditEntry, 'actor' | 'organization' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamRemoveRepositoryAuditEntry, 'actor' | 'organization' | 'repository' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    });
    Closable: (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Milestone, 'creator' | 'pullRequests' | 'repository'> & {
        creator?: Maybe<_RefType['Actor']>;
        pullRequests: _RefType['PullRequestConnection'];
        repository: _RefType['Repository'];
    }) | (Omit<Project, 'columns' | 'creator' | 'owner' | 'pendingCards'> & {
        columns: _RefType['ProjectColumnConnection'];
        creator?: Maybe<_RefType['Actor']>;
        owner: _RefType['ProjectOwner'];
        pendingCards: _RefType['ProjectCardConnection'];
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    });
    Comment: (Omit<CommitComment, 'author' | 'commit' | 'editor' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Discussion, 'answer' | 'answerChosenBy' | 'author' | 'category' | 'comments' | 'editor' | 'labels' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        answer?: Maybe<_RefType['DiscussionComment']>;
        answerChosenBy?: Maybe<_RefType['Actor']>;
        author?: Maybe<_RefType['Actor']>;
        category: _RefType['DiscussionCategory'];
        comments: _RefType['DiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<DiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'replies' | 'replyTo' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        discussion?: Maybe<_RefType['Discussion']>;
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        replies: _RefType['DiscussionCommentConnection'];
        replyTo?: Maybe<_RefType['DiscussionComment']>;
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<GistComment, 'author' | 'editor' | 'gist' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        gist: _RefType['Gist'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<IssueComment, 'author' | 'editor' | 'issue' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    }) | (Omit<PullRequestReview, 'author' | 'comments' | 'commit' | 'editor' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['PullRequestReviewCommentConnection'];
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequestReviewComment, 'author' | 'commit' | 'editor' | 'originalCommit' | 'pullRequest' | 'pullRequestReview' | 'reactionGroups' | 'reactions' | 'replyTo' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        originalCommit?: Maybe<_RefType['Commit']>;
        pullRequest: _RefType['PullRequest'];
        pullRequestReview?: Maybe<_RefType['PullRequestReview']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        replyTo?: Maybe<_RefType['PullRequestReviewComment']>;
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<TeamDiscussion, 'author' | 'comments' | 'editor' | 'reactionGroups' | 'reactions' | 'team' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['TeamDiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        team: _RefType['Team'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<TeamDiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        discussion: _RefType['TeamDiscussion'];
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    });
    Contribution: (Omit<CreatedCommitContribution, 'repository' | 'user'> & {
        repository: _RefType['Repository'];
        user: _RefType['User'];
    }) | (Omit<CreatedIssueContribution, 'issue' | 'user'> & {
        issue: _RefType['Issue'];
        user: _RefType['User'];
    }) | (Omit<CreatedPullRequestContribution, 'pullRequest' | 'user'> & {
        pullRequest: _RefType['PullRequest'];
        user: _RefType['User'];
    }) | (Omit<CreatedPullRequestReviewContribution, 'pullRequest' | 'pullRequestReview' | 'repository' | 'user'> & {
        pullRequest: _RefType['PullRequest'];
        pullRequestReview: _RefType['PullRequestReview'];
        repository: _RefType['Repository'];
        user: _RefType['User'];
    }) | (Omit<CreatedRepositoryContribution, 'repository' | 'user'> & {
        repository: _RefType['Repository'];
        user: _RefType['User'];
    }) | (Omit<JoinedGitHubContribution, 'user'> & {
        user: _RefType['User'];
    }) | (Omit<RestrictedContribution, 'user'> & {
        user: _RefType['User'];
    });
    Deletable: (Omit<CommitComment, 'author' | 'commit' | 'editor' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Discussion, 'answer' | 'answerChosenBy' | 'author' | 'category' | 'comments' | 'editor' | 'labels' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        answer?: Maybe<_RefType['DiscussionComment']>;
        answerChosenBy?: Maybe<_RefType['Actor']>;
        author?: Maybe<_RefType['Actor']>;
        category: _RefType['DiscussionCategory'];
        comments: _RefType['DiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<DiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'replies' | 'replyTo' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        discussion?: Maybe<_RefType['Discussion']>;
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        replies: _RefType['DiscussionCommentConnection'];
        replyTo?: Maybe<_RefType['DiscussionComment']>;
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<GistComment, 'author' | 'editor' | 'gist' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        gist: _RefType['Gist'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<IssueComment, 'author' | 'editor' | 'issue' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequestReview, 'author' | 'comments' | 'commit' | 'editor' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['PullRequestReviewCommentConnection'];
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequestReviewComment, 'author' | 'commit' | 'editor' | 'originalCommit' | 'pullRequest' | 'pullRequestReview' | 'reactionGroups' | 'reactions' | 'replyTo' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        originalCommit?: Maybe<_RefType['Commit']>;
        pullRequest: _RefType['PullRequest'];
        pullRequestReview?: Maybe<_RefType['PullRequestReview']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        replyTo?: Maybe<_RefType['PullRequestReviewComment']>;
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<TeamDiscussion, 'author' | 'comments' | 'editor' | 'reactionGroups' | 'reactions' | 'team' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['TeamDiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        team: _RefType['Team'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<TeamDiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        discussion: _RefType['TeamDiscussion'];
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    });
    EnterpriseAuditEntryData: (Omit<MembersCanDeleteReposClearAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<MembersCanDeleteReposDisableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<MembersCanDeleteReposEnableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgInviteToBusinessAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<PrivateRepositoryForkingDisableAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<PrivateRepositoryForkingEnableAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepositoryVisibilityChangeDisableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepositoryVisibilityChangeEnableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    });
    GitObject: (Omit<Blob, 'repository'> & {
        repository: _RefType['Repository'];
    }) | (Omit<Commit, 'associatedPullRequests' | 'blame' | 'checkSuites' | 'comments' | 'deployments' | 'file' | 'history' | 'onBehalfOf' | 'parents' | 'repository' | 'signature' | 'status' | 'statusCheckRollup' | 'tree'> & {
        associatedPullRequests?: Maybe<_RefType['PullRequestConnection']>;
        blame: _RefType['Blame'];
        checkSuites?: Maybe<_RefType['CheckSuiteConnection']>;
        comments: _RefType['CommitCommentConnection'];
        deployments?: Maybe<_RefType['DeploymentConnection']>;
        file?: Maybe<_RefType['TreeEntry']>;
        history: _RefType['CommitHistoryConnection'];
        onBehalfOf?: Maybe<_RefType['Organization']>;
        parents: _RefType['CommitConnection'];
        repository: _RefType['Repository'];
        signature?: Maybe<_RefType['GitSignature']>;
        status?: Maybe<_RefType['Status']>;
        statusCheckRollup?: Maybe<_RefType['StatusCheckRollup']>;
        tree: _RefType['Tree'];
    }) | (Omit<Tag, 'repository' | 'target'> & {
        repository: _RefType['Repository'];
        target: _RefType['GitObject'];
    }) | (Omit<Tree, 'entries' | 'repository'> & {
        entries?: Maybe<Array<_RefType['TreeEntry']>>;
        repository: _RefType['Repository'];
    });
    GitSignature: (Omit<GpgSignature, 'signer'> & {
        signer?: Maybe<_RefType['User']>;
    }) | (Omit<SmimeSignature, 'signer'> & {
        signer?: Maybe<_RefType['User']>;
    }) | (Omit<UnknownSignature, 'signer'> & {
        signer?: Maybe<_RefType['User']>;
    });
    HovercardContext: (GenericHovercardContext) | (OrganizationTeamsHovercardContext) | (Omit<OrganizationsHovercardContext, 'relevantOrganizations'> & {
        relevantOrganizations: _RefType['OrganizationConnection'];
    }) | (ReviewStatusHovercardContext) | (Omit<ViewerHovercardContext, 'viewer'> & {
        viewer: _RefType['User'];
    });
    Labelable: (Omit<Discussion, 'answer' | 'answerChosenBy' | 'author' | 'category' | 'comments' | 'editor' | 'labels' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        answer?: Maybe<_RefType['DiscussionComment']>;
        answerChosenBy?: Maybe<_RefType['Actor']>;
        author?: Maybe<_RefType['Actor']>;
        category: _RefType['DiscussionCategory'];
        comments: _RefType['DiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    });
    Lockable: (Omit<Discussion, 'answer' | 'answerChosenBy' | 'author' | 'category' | 'comments' | 'editor' | 'labels' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        answer?: Maybe<_RefType['DiscussionComment']>;
        answerChosenBy?: Maybe<_RefType['Actor']>;
        author?: Maybe<_RefType['Actor']>;
        category: _RefType['DiscussionCategory'];
        comments: _RefType['DiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    });
    MemberStatusable: (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<Team, 'discussion' | 'discussions' | 'invitations' | 'memberStatuses' | 'organization' | 'parentTeam' | 'repositories'> & {
        discussion?: Maybe<_RefType['TeamDiscussion']>;
        discussions: _RefType['TeamDiscussionConnection'];
        invitations?: Maybe<_RefType['OrganizationInvitationConnection']>;
        memberStatuses: _RefType['UserStatusConnection'];
        organization: _RefType['Organization'];
        parentTeam?: Maybe<_RefType['Team']>;
        repositories: _RefType['TeamRepositoryConnection'];
    });
    Minimizable: (Omit<CommitComment, 'author' | 'commit' | 'editor' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<DiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'replies' | 'replyTo' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        discussion?: Maybe<_RefType['Discussion']>;
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        replies: _RefType['DiscussionCommentConnection'];
        replyTo?: Maybe<_RefType['DiscussionComment']>;
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<GistComment, 'author' | 'editor' | 'gist' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        gist: _RefType['Gist'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<IssueComment, 'author' | 'editor' | 'issue' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequestReviewComment, 'author' | 'commit' | 'editor' | 'originalCommit' | 'pullRequest' | 'pullRequestReview' | 'reactionGroups' | 'reactions' | 'replyTo' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        originalCommit?: Maybe<_RefType['Commit']>;
        pullRequest: _RefType['PullRequest'];
        pullRequestReview?: Maybe<_RefType['PullRequestReview']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        replyTo?: Maybe<_RefType['PullRequestReviewComment']>;
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    });
    Node: (Omit<AddedToProjectEvent, 'actor' | 'project' | 'projectCard'> & {
        actor?: Maybe<_RefType['Actor']>;
        project?: Maybe<_RefType['Project']>;
        projectCard?: Maybe<_RefType['ProjectCard']>;
    }) | (Omit<App, 'ipAllowListEntries'> & {
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
    }) | (Omit<AssignedEvent, 'actor' | 'assignable' | 'assignee' | 'user'> & {
        actor?: Maybe<_RefType['Actor']>;
        assignable: _RefType['Assignable'];
        assignee?: Maybe<_RefType['Assignee']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<AutoMergeDisabledEvent, 'actor' | 'disabler' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        disabler?: Maybe<_RefType['User']>;
        pullRequest?: Maybe<_RefType['PullRequest']>;
    }) | (Omit<AutoMergeEnabledEvent, 'actor' | 'enabler' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        enabler?: Maybe<_RefType['User']>;
        pullRequest?: Maybe<_RefType['PullRequest']>;
    }) | (Omit<AutoRebaseEnabledEvent, 'actor' | 'enabler' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        enabler?: Maybe<_RefType['User']>;
        pullRequest?: Maybe<_RefType['PullRequest']>;
    }) | (Omit<AutoSquashEnabledEvent, 'actor' | 'enabler' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        enabler?: Maybe<_RefType['User']>;
        pullRequest?: Maybe<_RefType['PullRequest']>;
    }) | (Omit<AutomaticBaseChangeFailedEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<AutomaticBaseChangeSucceededEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<BaseRefChangedEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<BaseRefDeletedEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest?: Maybe<_RefType['PullRequest']>;
    }) | (Omit<BaseRefForcePushedEvent, 'actor' | 'afterCommit' | 'beforeCommit' | 'pullRequest' | 'ref'> & {
        actor?: Maybe<_RefType['Actor']>;
        afterCommit?: Maybe<_RefType['Commit']>;
        beforeCommit?: Maybe<_RefType['Commit']>;
        pullRequest: _RefType['PullRequest'];
        ref?: Maybe<_RefType['Ref']>;
    }) | (Omit<Blob, 'repository'> & {
        repository: _RefType['Repository'];
    }) | (Bot) | (Omit<BranchProtectionRule, 'creator' | 'pushAllowances' | 'repository' | 'reviewDismissalAllowances'> & {
        creator?: Maybe<_RefType['Actor']>;
        pushAllowances: _RefType['PushAllowanceConnection'];
        repository?: Maybe<_RefType['Repository']>;
        reviewDismissalAllowances: _RefType['ReviewDismissalAllowanceConnection'];
    }) | (Cwe) | (Omit<CheckRun, 'checkSuite' | 'deployment' | 'pendingDeploymentRequest' | 'repository'> & {
        checkSuite: _RefType['CheckSuite'];
        deployment?: Maybe<_RefType['Deployment']>;
        pendingDeploymentRequest?: Maybe<_RefType['DeploymentRequest']>;
        repository: _RefType['Repository'];
    }) | (Omit<CheckSuite, 'app' | 'branch' | 'checkRuns' | 'commit' | 'creator' | 'matchingPullRequests' | 'push' | 'repository' | 'workflowRun'> & {
        app?: Maybe<_RefType['App']>;
        branch?: Maybe<_RefType['Ref']>;
        checkRuns?: Maybe<_RefType['CheckRunConnection']>;
        commit: _RefType['Commit'];
        creator?: Maybe<_RefType['User']>;
        matchingPullRequests?: Maybe<_RefType['PullRequestConnection']>;
        push?: Maybe<_RefType['Push']>;
        repository: _RefType['Repository'];
        workflowRun?: Maybe<_RefType['WorkflowRun']>;
    }) | (Omit<ClosedEvent, 'actor' | 'closable' | 'closer'> & {
        actor?: Maybe<_RefType['Actor']>;
        closable: _RefType['Closable'];
        closer?: Maybe<_RefType['Closer']>;
    }) | (CodeOfConduct) | (Omit<CommentDeletedEvent, 'actor' | 'deletedCommentAuthor'> & {
        actor?: Maybe<_RefType['Actor']>;
        deletedCommentAuthor?: Maybe<_RefType['Actor']>;
    }) | (Omit<Commit, 'associatedPullRequests' | 'blame' | 'checkSuites' | 'comments' | 'deployments' | 'file' | 'history' | 'onBehalfOf' | 'parents' | 'repository' | 'signature' | 'status' | 'statusCheckRollup' | 'tree'> & {
        associatedPullRequests?: Maybe<_RefType['PullRequestConnection']>;
        blame: _RefType['Blame'];
        checkSuites?: Maybe<_RefType['CheckSuiteConnection']>;
        comments: _RefType['CommitCommentConnection'];
        deployments?: Maybe<_RefType['DeploymentConnection']>;
        file?: Maybe<_RefType['TreeEntry']>;
        history: _RefType['CommitHistoryConnection'];
        onBehalfOf?: Maybe<_RefType['Organization']>;
        parents: _RefType['CommitConnection'];
        repository: _RefType['Repository'];
        signature?: Maybe<_RefType['GitSignature']>;
        status?: Maybe<_RefType['Status']>;
        statusCheckRollup?: Maybe<_RefType['StatusCheckRollup']>;
        tree: _RefType['Tree'];
    }) | (Omit<CommitComment, 'author' | 'commit' | 'editor' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<CommitCommentThread, 'comments' | 'commit' | 'repository'> & {
        comments: _RefType['CommitCommentConnection'];
        commit?: Maybe<_RefType['Commit']>;
        repository: _RefType['Repository'];
    }) | (Omit<ConnectedEvent, 'actor' | 'source' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        source: _RefType['ReferencedSubject'];
        subject: _RefType['ReferencedSubject'];
    }) | (Omit<ConvertToDraftEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<ConvertedNoteToIssueEvent, 'actor' | 'project' | 'projectCard'> & {
        actor?: Maybe<_RefType['Actor']>;
        project?: Maybe<_RefType['Project']>;
        projectCard?: Maybe<_RefType['ProjectCard']>;
    }) | (Omit<CrossReferencedEvent, 'actor' | 'source' | 'target'> & {
        actor?: Maybe<_RefType['Actor']>;
        source: _RefType['ReferencedSubject'];
        target: _RefType['ReferencedSubject'];
    }) | (Omit<DemilestonedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject: _RefType['MilestoneItem'];
    }) | (DeployKey) | (Omit<DeployedEvent, 'actor' | 'deployment' | 'pullRequest' | 'ref'> & {
        actor?: Maybe<_RefType['Actor']>;
        deployment: _RefType['Deployment'];
        pullRequest: _RefType['PullRequest'];
        ref?: Maybe<_RefType['Ref']>;
    }) | (Omit<Deployment, 'commit' | 'creator' | 'latestStatus' | 'ref' | 'repository' | 'statuses'> & {
        commit?: Maybe<_RefType['Commit']>;
        creator: _RefType['Actor'];
        latestStatus?: Maybe<_RefType['DeploymentStatus']>;
        ref?: Maybe<_RefType['Ref']>;
        repository: _RefType['Repository'];
        statuses?: Maybe<_RefType['DeploymentStatusConnection']>;
    }) | (Omit<DeploymentEnvironmentChangedEvent, 'actor' | 'deploymentStatus' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        deploymentStatus: _RefType['DeploymentStatus'];
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<DeploymentProtectionRule, 'reviewers'> & {
        reviewers: _RefType['DeploymentReviewerConnection'];
    }) | (Omit<DeploymentReview, 'environments' | 'user'> & {
        environments: _RefType['EnvironmentConnection'];
        user: _RefType['User'];
    }) | (Omit<DeploymentStatus, 'creator' | 'deployment'> & {
        creator: _RefType['Actor'];
        deployment: _RefType['Deployment'];
    }) | (Omit<DisconnectedEvent, 'actor' | 'source' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        source: _RefType['ReferencedSubject'];
        subject: _RefType['ReferencedSubject'];
    }) | (Omit<Discussion, 'answer' | 'answerChosenBy' | 'author' | 'category' | 'comments' | 'editor' | 'labels' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        answer?: Maybe<_RefType['DiscussionComment']>;
        answerChosenBy?: Maybe<_RefType['Actor']>;
        author?: Maybe<_RefType['Actor']>;
        category: _RefType['DiscussionCategory'];
        comments: _RefType['DiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<DiscussionCategory, 'repository'> & {
        repository: _RefType['Repository'];
    }) | (Omit<DiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'replies' | 'replyTo' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        discussion?: Maybe<_RefType['Discussion']>;
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        replies: _RefType['DiscussionCommentConnection'];
        replyTo?: Maybe<_RefType['DiscussionComment']>;
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Enterprise, 'billingInfo' | 'members' | 'organizations' | 'ownerInfo' | 'userAccounts'> & {
        billingInfo?: Maybe<_RefType['EnterpriseBillingInfo']>;
        members: _RefType['EnterpriseMemberConnection'];
        organizations: _RefType['OrganizationConnection'];
        ownerInfo?: Maybe<_RefType['EnterpriseOwnerInfo']>;
        userAccounts: _RefType['EnterpriseUserAccountConnection'];
    }) | (Omit<EnterpriseAdministratorInvitation, 'enterprise' | 'invitee' | 'inviter'> & {
        enterprise: _RefType['Enterprise'];
        invitee?: Maybe<_RefType['User']>;
        inviter?: Maybe<_RefType['User']>;
    }) | (Omit<EnterpriseIdentityProvider, 'enterprise' | 'externalIdentities'> & {
        enterprise?: Maybe<_RefType['Enterprise']>;
        externalIdentities: _RefType['ExternalIdentityConnection'];
    }) | (EnterpriseRepositoryInfo) | (Omit<EnterpriseServerInstallation, 'userAccounts' | 'userAccountsUploads'> & {
        userAccounts: _RefType['EnterpriseServerUserAccountConnection'];
        userAccountsUploads: _RefType['EnterpriseServerUserAccountsUploadConnection'];
    }) | (Omit<EnterpriseServerUserAccount, 'enterpriseServerInstallation'> & {
        enterpriseServerInstallation: _RefType['EnterpriseServerInstallation'];
    }) | (Omit<EnterpriseServerUserAccountEmail, 'userAccount'> & {
        userAccount: _RefType['EnterpriseServerUserAccount'];
    }) | (Omit<EnterpriseServerUserAccountsUpload, 'enterprise' | 'enterpriseServerInstallation'> & {
        enterprise: _RefType['Enterprise'];
        enterpriseServerInstallation: _RefType['EnterpriseServerInstallation'];
    }) | (Omit<EnterpriseUserAccount, 'enterprise' | 'organizations' | 'user'> & {
        enterprise: _RefType['Enterprise'];
        organizations: _RefType['EnterpriseOrganizationMembershipConnection'];
        user?: Maybe<_RefType['User']>;
    }) | (Omit<Environment, 'protectionRules'> & {
        protectionRules: _RefType['DeploymentProtectionRuleConnection'];
    }) | (Omit<ExternalIdentity, 'organizationInvitation' | 'user'> & {
        organizationInvitation?: Maybe<_RefType['OrganizationInvitation']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<Gist, 'comments' | 'forks' | 'owner'> & {
        comments: _RefType['GistCommentConnection'];
        forks: _RefType['GistConnection'];
        owner?: Maybe<_RefType['RepositoryOwner']>;
    }) | (Omit<GistComment, 'author' | 'editor' | 'gist' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        gist: _RefType['Gist'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<HeadRefDeletedEvent, 'actor' | 'headRef' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<HeadRefForcePushedEvent, 'actor' | 'afterCommit' | 'beforeCommit' | 'pullRequest' | 'ref'> & {
        actor?: Maybe<_RefType['Actor']>;
        afterCommit?: Maybe<_RefType['Commit']>;
        beforeCommit?: Maybe<_RefType['Commit']>;
        pullRequest: _RefType['PullRequest'];
        ref?: Maybe<_RefType['Ref']>;
    }) | (Omit<HeadRefRestoredEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<IpAllowListEntry, 'owner'> & {
        owner: _RefType['IpAllowListOwner'];
    }) | (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<IssueComment, 'author' | 'editor' | 'issue' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Label, 'pullRequests' | 'repository'> & {
        pullRequests: _RefType['PullRequestConnection'];
        repository: _RefType['Repository'];
    }) | (Omit<LabeledEvent, 'actor' | 'label' | 'labelable'> & {
        actor?: Maybe<_RefType['Actor']>;
        label: _RefType['Label'];
        labelable: _RefType['Labelable'];
    }) | (Language) | (License) | (Omit<LockedEvent, 'actor' | 'lockable'> & {
        actor?: Maybe<_RefType['Actor']>;
        lockable: _RefType['Lockable'];
    }) | (Omit<Mannequin, 'claimant'> & {
        claimant?: Maybe<_RefType['User']>;
    }) | (Omit<MarkedAsDuplicateEvent, 'actor' | 'canonical' | 'duplicate'> & {
        actor?: Maybe<_RefType['Actor']>;
        canonical?: Maybe<_RefType['IssueOrPullRequest']>;
        duplicate?: Maybe<_RefType['IssueOrPullRequest']>;
    }) | (Omit<MembersCanDeleteReposClearAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<MembersCanDeleteReposDisableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<MembersCanDeleteReposEnableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<MentionedEvent, 'actor'> & {
        actor?: Maybe<_RefType['Actor']>;
    }) | (Omit<MergedEvent, 'actor' | 'commit' | 'mergeRef' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        mergeRef?: Maybe<_RefType['Ref']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<Milestone, 'creator' | 'pullRequests' | 'repository'> & {
        creator?: Maybe<_RefType['Actor']>;
        pullRequests: _RefType['PullRequestConnection'];
        repository: _RefType['Repository'];
    }) | (Omit<MilestonedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject: _RefType['MilestoneItem'];
    }) | (Omit<MovedColumnsInProjectEvent, 'actor' | 'project' | 'projectCard'> & {
        actor?: Maybe<_RefType['Actor']>;
        project?: Maybe<_RefType['Project']>;
        projectCard?: Maybe<_RefType['ProjectCard']>;
    }) | (Omit<OauthApplicationCreateAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgAddBillingManagerAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgAddMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgBlockUserAuditEntry, 'actor' | 'blockedUser' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        blockedUser?: Maybe<_RefType['User']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgConfigDisableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgConfigEnableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgCreateAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgDisableOauthAppRestrictionsAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgDisableSamlAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgDisableTwoFactorRequirementAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgEnableOauthAppRestrictionsAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgEnableSamlAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgEnableTwoFactorRequirementAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgInviteMemberAuditEntry, 'actor' | 'organization' | 'organizationInvitation' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        organizationInvitation?: Maybe<_RefType['OrganizationInvitation']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgInviteToBusinessAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgOauthAppAccessApprovedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgOauthAppAccessDeniedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgOauthAppAccessRequestedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgRemoveBillingManagerAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgRemoveMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgRemoveOutsideCollaboratorAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgRestoreMemberAuditEntry, 'actor' | 'organization' | 'restoredMemberships' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        restoredMemberships?: Maybe<Array<_RefType['OrgRestoreMemberAuditEntryMembership']>>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUnblockUserAuditEntry, 'actor' | 'blockedUser' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        blockedUser?: Maybe<_RefType['User']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUpdateDefaultRepositoryPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUpdateMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUpdateMemberRepositoryCreationPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUpdateMemberRepositoryInvitationPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<OrganizationIdentityProvider, 'externalIdentities' | 'organization'> & {
        externalIdentities: _RefType['ExternalIdentityConnection'];
        organization?: Maybe<_RefType['Organization']>;
    }) | (Omit<OrganizationInvitation, 'invitee' | 'inviter' | 'organization'> & {
        invitee?: Maybe<_RefType['User']>;
        inviter: _RefType['User'];
        organization: _RefType['Organization'];
    }) | (Omit<Package, 'latestVersion' | 'repository' | 'version' | 'versions'> & {
        latestVersion?: Maybe<_RefType['PackageVersion']>;
        repository?: Maybe<_RefType['Repository']>;
        version?: Maybe<_RefType['PackageVersion']>;
        versions: _RefType['PackageVersionConnection'];
    }) | (Omit<PackageFile, 'packageVersion'> & {
        packageVersion?: Maybe<_RefType['PackageVersion']>;
    }) | (Omit<PackageTag, 'version'> & {
        version?: Maybe<_RefType['PackageVersion']>;
    }) | (Omit<PackageVersion, 'package' | 'release'> & {
        package?: Maybe<_RefType['Package']>;
        release?: Maybe<_RefType['Release']>;
    }) | (Omit<PinnedDiscussion, 'discussion' | 'pinnedBy' | 'repository'> & {
        discussion: _RefType['Discussion'];
        pinnedBy: _RefType['Actor'];
        repository: _RefType['Repository'];
    }) | (Omit<PinnedEvent, 'actor' | 'issue'> & {
        actor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
    }) | (Omit<PinnedIssue, 'issue' | 'pinnedBy' | 'repository'> & {
        issue: _RefType['Issue'];
        pinnedBy: _RefType['Actor'];
        repository: _RefType['Repository'];
    }) | (Omit<PrivateRepositoryForkingDisableAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<PrivateRepositoryForkingEnableAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<Project, 'columns' | 'creator' | 'owner' | 'pendingCards'> & {
        columns: _RefType['ProjectColumnConnection'];
        creator?: Maybe<_RefType['Actor']>;
        owner: _RefType['ProjectOwner'];
        pendingCards: _RefType['ProjectCardConnection'];
    }) | (Omit<ProjectCard, 'column' | 'content' | 'creator' | 'project'> & {
        column?: Maybe<_RefType['ProjectColumn']>;
        content?: Maybe<_RefType['ProjectCardItem']>;
        creator?: Maybe<_RefType['Actor']>;
        project: _RefType['Project'];
    }) | (Omit<ProjectColumn, 'cards' | 'project'> & {
        cards: _RefType['ProjectCardConnection'];
        project: _RefType['Project'];
    }) | (PublicKey) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    }) | (Omit<PullRequestCommit, 'commit' | 'pullRequest'> & {
        commit: _RefType['Commit'];
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<PullRequestCommitCommentThread, 'comments' | 'commit' | 'pullRequest' | 'repository'> & {
        comments: _RefType['CommitCommentConnection'];
        commit: _RefType['Commit'];
        pullRequest: _RefType['PullRequest'];
        repository: _RefType['Repository'];
    }) | (Omit<PullRequestReview, 'author' | 'comments' | 'commit' | 'editor' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['PullRequestReviewCommentConnection'];
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequestReviewComment, 'author' | 'commit' | 'editor' | 'originalCommit' | 'pullRequest' | 'pullRequestReview' | 'reactionGroups' | 'reactions' | 'replyTo' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        originalCommit?: Maybe<_RefType['Commit']>;
        pullRequest: _RefType['PullRequest'];
        pullRequestReview?: Maybe<_RefType['PullRequestReview']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        replyTo?: Maybe<_RefType['PullRequestReviewComment']>;
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequestReviewThread, 'comments' | 'pullRequest' | 'repository' | 'resolvedBy'> & {
        comments: _RefType['PullRequestReviewCommentConnection'];
        pullRequest: _RefType['PullRequest'];
        repository: _RefType['Repository'];
        resolvedBy?: Maybe<_RefType['User']>;
    }) | (Omit<Push, 'pusher' | 'repository'> & {
        pusher: _RefType['User'];
        repository: _RefType['Repository'];
    }) | (Omit<PushAllowance, 'actor' | 'branchProtectionRule'> & {
        actor?: Maybe<_RefType['PushAllowanceActor']>;
        branchProtectionRule?: Maybe<_RefType['BranchProtectionRule']>;
    }) | (Omit<Reaction, 'reactable' | 'user'> & {
        reactable: _RefType['Reactable'];
        user?: Maybe<_RefType['User']>;
    }) | (Omit<ReadyForReviewEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<Ref, 'associatedPullRequests' | 'branchProtectionRule' | 'repository' | 'target'> & {
        associatedPullRequests: _RefType['PullRequestConnection'];
        branchProtectionRule?: Maybe<_RefType['BranchProtectionRule']>;
        repository: _RefType['Repository'];
        target?: Maybe<_RefType['GitObject']>;
    }) | (Omit<ReferencedEvent, 'actor' | 'commit' | 'commitRepository' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        commitRepository: _RefType['Repository'];
        subject: _RefType['ReferencedSubject'];
    }) | (Omit<Release, 'author' | 'mentions' | 'reactionGroups' | 'reactions' | 'releaseAssets' | 'repository' | 'tag' | 'tagCommit'> & {
        author?: Maybe<_RefType['User']>;
        mentions?: Maybe<_RefType['UserConnection']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        releaseAssets: _RefType['ReleaseAssetConnection'];
        repository: _RefType['Repository'];
        tag?: Maybe<_RefType['Ref']>;
        tagCommit?: Maybe<_RefType['Commit']>;
    }) | (Omit<ReleaseAsset, 'release' | 'uploadedBy'> & {
        release?: Maybe<_RefType['Release']>;
        uploadedBy: _RefType['User'];
    }) | (Omit<RemovedFromProjectEvent, 'actor' | 'project'> & {
        actor?: Maybe<_RefType['Actor']>;
        project?: Maybe<_RefType['Project']>;
    }) | (Omit<RenamedTitleEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject: _RefType['RenamedTitleSubject'];
    }) | (Omit<ReopenedEvent, 'actor' | 'closable'> & {
        actor?: Maybe<_RefType['Actor']>;
        closable: _RefType['Closable'];
    }) | (Omit<RepoAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoAddMemberAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoAddTopicAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoArchivedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoChangeMergeSettingAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableContributorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableSockpuppetDisallowedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableContributorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableSockpuppetDisallowedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigLockAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigUnlockAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoCreateAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoDestroyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoRemoveMemberAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoRemoveTopicAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<Repository, 'assignableUsers' | 'branchProtectionRules' | 'collaborators' | 'commitComments' | 'defaultBranchRef' | 'deployments' | 'discussion' | 'discussionCategories' | 'discussions' | 'environment' | 'environments' | 'forks' | 'issue' | 'issueOrPullRequest' | 'label' | 'labels' | 'latestRelease' | 'mentionableUsers' | 'milestone' | 'milestones' | 'object' | 'owner' | 'packages' | 'parent' | 'pinnedDiscussions' | 'pinnedIssues' | 'project' | 'projects' | 'pullRequest' | 'pullRequestTemplates' | 'pullRequests' | 'ref' | 'release' | 'releases' | 'templateRepository' | 'vulnerabilityAlerts' | 'watchers'> & {
        assignableUsers: _RefType['UserConnection'];
        branchProtectionRules: _RefType['BranchProtectionRuleConnection'];
        collaborators?: Maybe<_RefType['RepositoryCollaboratorConnection']>;
        commitComments: _RefType['CommitCommentConnection'];
        defaultBranchRef?: Maybe<_RefType['Ref']>;
        deployments: _RefType['DeploymentConnection'];
        discussion?: Maybe<_RefType['Discussion']>;
        discussionCategories: _RefType['DiscussionCategoryConnection'];
        discussions: _RefType['DiscussionConnection'];
        environment?: Maybe<_RefType['Environment']>;
        environments: _RefType['EnvironmentConnection'];
        forks: _RefType['RepositoryConnection'];
        issue?: Maybe<_RefType['Issue']>;
        issueOrPullRequest?: Maybe<_RefType['IssueOrPullRequest']>;
        label?: Maybe<_RefType['Label']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        latestRelease?: Maybe<_RefType['Release']>;
        mentionableUsers: _RefType['UserConnection'];
        milestone?: Maybe<_RefType['Milestone']>;
        milestones?: Maybe<_RefType['MilestoneConnection']>;
        object?: Maybe<_RefType['GitObject']>;
        owner: _RefType['RepositoryOwner'];
        packages: _RefType['PackageConnection'];
        parent?: Maybe<_RefType['Repository']>;
        pinnedDiscussions: _RefType['PinnedDiscussionConnection'];
        pinnedIssues?: Maybe<_RefType['PinnedIssueConnection']>;
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        pullRequestTemplates?: Maybe<Array<_RefType['PullRequestTemplate']>>;
        pullRequests: _RefType['PullRequestConnection'];
        ref?: Maybe<_RefType['Ref']>;
        release?: Maybe<_RefType['Release']>;
        releases: _RefType['ReleaseConnection'];
        templateRepository?: Maybe<_RefType['Repository']>;
        vulnerabilityAlerts?: Maybe<_RefType['RepositoryVulnerabilityAlertConnection']>;
        watchers: _RefType['UserConnection'];
    }) | (Omit<RepositoryInvitation, 'invitee' | 'inviter' | 'repository'> & {
        invitee?: Maybe<_RefType['User']>;
        inviter: _RefType['User'];
        repository?: Maybe<_RefType['RepositoryInfo']>;
    }) | (RepositoryTopic) | (Omit<RepositoryVisibilityChangeDisableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepositoryVisibilityChangeEnableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepositoryVulnerabilityAlert, 'dismisser' | 'repository'> & {
        dismisser?: Maybe<_RefType['User']>;
        repository: _RefType['Repository'];
    }) | (Omit<ReviewDismissalAllowance, 'actor' | 'branchProtectionRule'> & {
        actor?: Maybe<_RefType['ReviewDismissalAllowanceActor']>;
        branchProtectionRule?: Maybe<_RefType['BranchProtectionRule']>;
    }) | (Omit<ReviewDismissedEvent, 'actor' | 'pullRequest' | 'pullRequestCommit' | 'review'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        pullRequestCommit?: Maybe<_RefType['PullRequestCommit']>;
        review?: Maybe<_RefType['PullRequestReview']>;
    }) | (Omit<ReviewRequest, 'pullRequest' | 'requestedReviewer'> & {
        pullRequest: _RefType['PullRequest'];
        requestedReviewer?: Maybe<_RefType['RequestedReviewer']>;
    }) | (Omit<ReviewRequestRemovedEvent, 'actor' | 'pullRequest' | 'requestedReviewer'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        requestedReviewer?: Maybe<_RefType['RequestedReviewer']>;
    }) | (Omit<ReviewRequestedEvent, 'actor' | 'pullRequest' | 'requestedReviewer'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        requestedReviewer?: Maybe<_RefType['RequestedReviewer']>;
    }) | (Omit<SavedReply, 'user'> & {
        user?: Maybe<_RefType['Actor']>;
    }) | (SecurityAdvisory) | (Omit<Sponsorship, 'maintainer' | 'sponsor' | 'sponsorEntity' | 'sponsorable'> & {
        maintainer: _RefType['User'];
        sponsor?: Maybe<_RefType['User']>;
        sponsorEntity?: Maybe<_RefType['Sponsor']>;
        sponsorable: _RefType['Sponsorable'];
    }) | (Omit<Status, 'combinedContexts' | 'commit' | 'context' | 'contexts'> & {
        combinedContexts: _RefType['StatusCheckRollupContextConnection'];
        commit?: Maybe<_RefType['Commit']>;
        context?: Maybe<_RefType['StatusContext']>;
        contexts: Array<_RefType['StatusContext']>;
    }) | (Omit<StatusCheckRollup, 'commit' | 'contexts'> & {
        commit?: Maybe<_RefType['Commit']>;
        contexts: _RefType['StatusCheckRollupContextConnection'];
    }) | (Omit<StatusContext, 'commit' | 'creator'> & {
        commit?: Maybe<_RefType['Commit']>;
        creator?: Maybe<_RefType['Actor']>;
    }) | (Omit<SubscribedEvent, 'actor' | 'subscribable'> & {
        actor?: Maybe<_RefType['Actor']>;
        subscribable: _RefType['Subscribable'];
    }) | (Omit<Tag, 'repository' | 'target'> & {
        repository: _RefType['Repository'];
        target: _RefType['GitObject'];
    }) | (Omit<Team, 'discussion' | 'discussions' | 'invitations' | 'memberStatuses' | 'organization' | 'parentTeam' | 'repositories'> & {
        discussion?: Maybe<_RefType['TeamDiscussion']>;
        discussions: _RefType['TeamDiscussionConnection'];
        invitations?: Maybe<_RefType['OrganizationInvitationConnection']>;
        memberStatuses: _RefType['UserStatusConnection'];
        organization: _RefType['Organization'];
        parentTeam?: Maybe<_RefType['Team']>;
        repositories: _RefType['TeamRepositoryConnection'];
    }) | (Omit<TeamAddMemberAuditEntry, 'actor' | 'organization' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamAddRepositoryAuditEntry, 'actor' | 'organization' | 'repository' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamChangeParentTeamAuditEntry, 'actor' | 'organization' | 'parentTeam' | 'parentTeamWas' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        parentTeam?: Maybe<_RefType['Team']>;
        parentTeamWas?: Maybe<_RefType['Team']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamDiscussion, 'author' | 'comments' | 'editor' | 'reactionGroups' | 'reactions' | 'team' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['TeamDiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        team: _RefType['Team'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<TeamDiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        discussion: _RefType['TeamDiscussion'];
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<TeamRemoveMemberAuditEntry, 'actor' | 'organization' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamRemoveRepositoryAuditEntry, 'actor' | 'organization' | 'repository' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Topic) | (Omit<TransferredEvent, 'actor' | 'fromRepository' | 'issue'> & {
        actor?: Maybe<_RefType['Actor']>;
        fromRepository?: Maybe<_RefType['Repository']>;
        issue: _RefType['Issue'];
    }) | (Omit<Tree, 'entries' | 'repository'> & {
        entries?: Maybe<Array<_RefType['TreeEntry']>>;
        repository: _RefType['Repository'];
    }) | (Omit<UnassignedEvent, 'actor' | 'assignable' | 'assignee' | 'user'> & {
        actor?: Maybe<_RefType['Actor']>;
        assignable: _RefType['Assignable'];
        assignee?: Maybe<_RefType['Assignee']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<UnlabeledEvent, 'actor' | 'label' | 'labelable'> & {
        actor?: Maybe<_RefType['Actor']>;
        label: _RefType['Label'];
        labelable: _RefType['Labelable'];
    }) | (Omit<UnlockedEvent, 'actor' | 'lockable'> & {
        actor?: Maybe<_RefType['Actor']>;
        lockable: _RefType['Lockable'];
    }) | (Omit<UnmarkedAsDuplicateEvent, 'actor' | 'canonical' | 'duplicate'> & {
        actor?: Maybe<_RefType['Actor']>;
        canonical?: Maybe<_RefType['IssueOrPullRequest']>;
        duplicate?: Maybe<_RefType['IssueOrPullRequest']>;
    }) | (Omit<UnpinnedEvent, 'actor' | 'issue'> & {
        actor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
    }) | (Omit<UnsubscribedEvent, 'actor' | 'subscribable'> & {
        actor?: Maybe<_RefType['Actor']>;
        subscribable: _RefType['Subscribable'];
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    }) | (Omit<UserBlockedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<_RefType['Actor']>;
        subject?: Maybe<_RefType['User']>;
    }) | (Omit<UserContentEdit, 'deletedBy' | 'editor'> & {
        deletedBy?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
    }) | (Omit<UserStatus, 'organization' | 'user'> & {
        organization?: Maybe<_RefType['Organization']>;
        user: _RefType['User'];
    }) | (Omit<VerifiableDomain, 'owner'> & {
        owner: _RefType['VerifiableDomainOwner'];
    }) | (Workflow) | (Omit<WorkflowRun, 'checkSuite' | 'deploymentReviews' | 'pendingDeploymentRequests'> & {
        checkSuite: _RefType['CheckSuite'];
        deploymentReviews: _RefType['DeploymentReviewConnection'];
        pendingDeploymentRequests: _RefType['DeploymentRequestConnection'];
    });
    OauthApplicationAuditEntryData: (Omit<OauthApplicationCreateAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgOauthAppAccessApprovedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgOauthAppAccessDeniedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgOauthAppAccessRequestedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    });
    OrganizationAuditEntryData: (Omit<MembersCanDeleteReposClearAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<MembersCanDeleteReposDisableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<MembersCanDeleteReposEnableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OauthApplicationCreateAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgAddBillingManagerAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgAddMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgBlockUserAuditEntry, 'actor' | 'blockedUser' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        blockedUser?: Maybe<_RefType['User']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgConfigDisableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgConfigEnableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgCreateAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgDisableOauthAppRestrictionsAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgDisableSamlAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgDisableTwoFactorRequirementAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgEnableOauthAppRestrictionsAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgEnableSamlAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgEnableTwoFactorRequirementAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgInviteMemberAuditEntry, 'actor' | 'organization' | 'organizationInvitation' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        organizationInvitation?: Maybe<_RefType['OrganizationInvitation']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgInviteToBusinessAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgOauthAppAccessApprovedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgOauthAppAccessDeniedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgOauthAppAccessRequestedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgRemoveBillingManagerAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgRemoveMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgRemoveOutsideCollaboratorAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgRestoreMemberAuditEntry, 'actor' | 'organization' | 'restoredMemberships' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        restoredMemberships?: Maybe<Array<_RefType['OrgRestoreMemberAuditEntryMembership']>>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgRestoreMemberMembershipOrganizationAuditEntryData, 'organization'> & {
        organization?: Maybe<_RefType['Organization']>;
    }) | (Omit<OrgUnblockUserAuditEntry, 'actor' | 'blockedUser' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        blockedUser?: Maybe<_RefType['User']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUpdateDefaultRepositoryPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUpdateMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUpdateMemberRepositoryCreationPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<OrgUpdateMemberRepositoryInvitationPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<PrivateRepositoryForkingDisableAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<PrivateRepositoryForkingEnableAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoAddMemberAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoAddTopicAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoArchivedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoChangeMergeSettingAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableContributorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableSockpuppetDisallowedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableContributorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableSockpuppetDisallowedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigLockAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigUnlockAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoCreateAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoDestroyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoRemoveMemberAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoRemoveTopicAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepositoryVisibilityChangeDisableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepositoryVisibilityChangeEnableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamAddMemberAuditEntry, 'actor' | 'organization' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamAddRepositoryAuditEntry, 'actor' | 'organization' | 'repository' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamChangeParentTeamAuditEntry, 'actor' | 'organization' | 'parentTeam' | 'parentTeamWas' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        parentTeam?: Maybe<_RefType['Team']>;
        parentTeamWas?: Maybe<_RefType['Team']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamRemoveMemberAuditEntry, 'actor' | 'organization' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamRemoveRepositoryAuditEntry, 'actor' | 'organization' | 'repository' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    });
    PackageOwner: (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<Repository, 'assignableUsers' | 'branchProtectionRules' | 'collaborators' | 'commitComments' | 'defaultBranchRef' | 'deployments' | 'discussion' | 'discussionCategories' | 'discussions' | 'environment' | 'environments' | 'forks' | 'issue' | 'issueOrPullRequest' | 'label' | 'labels' | 'latestRelease' | 'mentionableUsers' | 'milestone' | 'milestones' | 'object' | 'owner' | 'packages' | 'parent' | 'pinnedDiscussions' | 'pinnedIssues' | 'project' | 'projects' | 'pullRequest' | 'pullRequestTemplates' | 'pullRequests' | 'ref' | 'release' | 'releases' | 'templateRepository' | 'vulnerabilityAlerts' | 'watchers'> & {
        assignableUsers: _RefType['UserConnection'];
        branchProtectionRules: _RefType['BranchProtectionRuleConnection'];
        collaborators?: Maybe<_RefType['RepositoryCollaboratorConnection']>;
        commitComments: _RefType['CommitCommentConnection'];
        defaultBranchRef?: Maybe<_RefType['Ref']>;
        deployments: _RefType['DeploymentConnection'];
        discussion?: Maybe<_RefType['Discussion']>;
        discussionCategories: _RefType['DiscussionCategoryConnection'];
        discussions: _RefType['DiscussionConnection'];
        environment?: Maybe<_RefType['Environment']>;
        environments: _RefType['EnvironmentConnection'];
        forks: _RefType['RepositoryConnection'];
        issue?: Maybe<_RefType['Issue']>;
        issueOrPullRequest?: Maybe<_RefType['IssueOrPullRequest']>;
        label?: Maybe<_RefType['Label']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        latestRelease?: Maybe<_RefType['Release']>;
        mentionableUsers: _RefType['UserConnection'];
        milestone?: Maybe<_RefType['Milestone']>;
        milestones?: Maybe<_RefType['MilestoneConnection']>;
        object?: Maybe<_RefType['GitObject']>;
        owner: _RefType['RepositoryOwner'];
        packages: _RefType['PackageConnection'];
        parent?: Maybe<_RefType['Repository']>;
        pinnedDiscussions: _RefType['PinnedDiscussionConnection'];
        pinnedIssues?: Maybe<_RefType['PinnedIssueConnection']>;
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        pullRequestTemplates?: Maybe<Array<_RefType['PullRequestTemplate']>>;
        pullRequests: _RefType['PullRequestConnection'];
        ref?: Maybe<_RefType['Ref']>;
        release?: Maybe<_RefType['Release']>;
        releases: _RefType['ReleaseConnection'];
        templateRepository?: Maybe<_RefType['Repository']>;
        vulnerabilityAlerts?: Maybe<_RefType['RepositoryVulnerabilityAlertConnection']>;
        watchers: _RefType['UserConnection'];
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    ProfileOwner: (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    ProjectOwner: (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<Repository, 'assignableUsers' | 'branchProtectionRules' | 'collaborators' | 'commitComments' | 'defaultBranchRef' | 'deployments' | 'discussion' | 'discussionCategories' | 'discussions' | 'environment' | 'environments' | 'forks' | 'issue' | 'issueOrPullRequest' | 'label' | 'labels' | 'latestRelease' | 'mentionableUsers' | 'milestone' | 'milestones' | 'object' | 'owner' | 'packages' | 'parent' | 'pinnedDiscussions' | 'pinnedIssues' | 'project' | 'projects' | 'pullRequest' | 'pullRequestTemplates' | 'pullRequests' | 'ref' | 'release' | 'releases' | 'templateRepository' | 'vulnerabilityAlerts' | 'watchers'> & {
        assignableUsers: _RefType['UserConnection'];
        branchProtectionRules: _RefType['BranchProtectionRuleConnection'];
        collaborators?: Maybe<_RefType['RepositoryCollaboratorConnection']>;
        commitComments: _RefType['CommitCommentConnection'];
        defaultBranchRef?: Maybe<_RefType['Ref']>;
        deployments: _RefType['DeploymentConnection'];
        discussion?: Maybe<_RefType['Discussion']>;
        discussionCategories: _RefType['DiscussionCategoryConnection'];
        discussions: _RefType['DiscussionConnection'];
        environment?: Maybe<_RefType['Environment']>;
        environments: _RefType['EnvironmentConnection'];
        forks: _RefType['RepositoryConnection'];
        issue?: Maybe<_RefType['Issue']>;
        issueOrPullRequest?: Maybe<_RefType['IssueOrPullRequest']>;
        label?: Maybe<_RefType['Label']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        latestRelease?: Maybe<_RefType['Release']>;
        mentionableUsers: _RefType['UserConnection'];
        milestone?: Maybe<_RefType['Milestone']>;
        milestones?: Maybe<_RefType['MilestoneConnection']>;
        object?: Maybe<_RefType['GitObject']>;
        owner: _RefType['RepositoryOwner'];
        packages: _RefType['PackageConnection'];
        parent?: Maybe<_RefType['Repository']>;
        pinnedDiscussions: _RefType['PinnedDiscussionConnection'];
        pinnedIssues?: Maybe<_RefType['PinnedIssueConnection']>;
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        pullRequestTemplates?: Maybe<Array<_RefType['PullRequestTemplate']>>;
        pullRequests: _RefType['PullRequestConnection'];
        ref?: Maybe<_RefType['Ref']>;
        release?: Maybe<_RefType['Release']>;
        releases: _RefType['ReleaseConnection'];
        templateRepository?: Maybe<_RefType['Repository']>;
        vulnerabilityAlerts?: Maybe<_RefType['RepositoryVulnerabilityAlertConnection']>;
        watchers: _RefType['UserConnection'];
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    Reactable: (Omit<CommitComment, 'author' | 'commit' | 'editor' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Discussion, 'answer' | 'answerChosenBy' | 'author' | 'category' | 'comments' | 'editor' | 'labels' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        answer?: Maybe<_RefType['DiscussionComment']>;
        answerChosenBy?: Maybe<_RefType['Actor']>;
        author?: Maybe<_RefType['Actor']>;
        category: _RefType['DiscussionCategory'];
        comments: _RefType['DiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<DiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'replies' | 'replyTo' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        discussion?: Maybe<_RefType['Discussion']>;
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        replies: _RefType['DiscussionCommentConnection'];
        replyTo?: Maybe<_RefType['DiscussionComment']>;
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<IssueComment, 'author' | 'editor' | 'issue' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    }) | (Omit<PullRequestReview, 'author' | 'comments' | 'commit' | 'editor' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['PullRequestReviewCommentConnection'];
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequestReviewComment, 'author' | 'commit' | 'editor' | 'originalCommit' | 'pullRequest' | 'pullRequestReview' | 'reactionGroups' | 'reactions' | 'replyTo' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        originalCommit?: Maybe<_RefType['Commit']>;
        pullRequest: _RefType['PullRequest'];
        pullRequestReview?: Maybe<_RefType['PullRequestReview']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        replyTo?: Maybe<_RefType['PullRequestReviewComment']>;
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Release, 'author' | 'mentions' | 'reactionGroups' | 'reactions' | 'releaseAssets' | 'repository' | 'tag' | 'tagCommit'> & {
        author?: Maybe<_RefType['User']>;
        mentions?: Maybe<_RefType['UserConnection']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        releaseAssets: _RefType['ReleaseAssetConnection'];
        repository: _RefType['Repository'];
        tag?: Maybe<_RefType['Ref']>;
        tagCommit?: Maybe<_RefType['Commit']>;
    }) | (Omit<TeamDiscussion, 'author' | 'comments' | 'editor' | 'reactionGroups' | 'reactions' | 'team' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['TeamDiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        team: _RefType['Team'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<TeamDiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        discussion: _RefType['TeamDiscussion'];
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    });
    RepositoryAuditEntryData: (Omit<OrgRestoreMemberMembershipRepositoryAuditEntryData, 'repository'> & {
        repository?: Maybe<_RefType['Repository']>;
    }) | (Omit<PrivateRepositoryForkingDisableAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<PrivateRepositoryForkingEnableAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoAddMemberAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoAddTopicAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoArchivedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoChangeMergeSettingAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableContributorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigDisableSockpuppetDisallowedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableContributorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigEnableSockpuppetDisallowedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigLockAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoConfigUnlockAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoCreateAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoDestroyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoRemoveMemberAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoRemoveTopicAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamAddRepositoryAuditEntry, 'actor' | 'organization' | 'repository' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamRemoveRepositoryAuditEntry, 'actor' | 'organization' | 'repository' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    });
    RepositoryDiscussionAuthor: (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    RepositoryDiscussionCommentAuthor: (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    RepositoryInfo: (Omit<Repository, 'assignableUsers' | 'branchProtectionRules' | 'collaborators' | 'commitComments' | 'defaultBranchRef' | 'deployments' | 'discussion' | 'discussionCategories' | 'discussions' | 'environment' | 'environments' | 'forks' | 'issue' | 'issueOrPullRequest' | 'label' | 'labels' | 'latestRelease' | 'mentionableUsers' | 'milestone' | 'milestones' | 'object' | 'owner' | 'packages' | 'parent' | 'pinnedDiscussions' | 'pinnedIssues' | 'project' | 'projects' | 'pullRequest' | 'pullRequestTemplates' | 'pullRequests' | 'ref' | 'release' | 'releases' | 'templateRepository' | 'vulnerabilityAlerts' | 'watchers'> & {
        assignableUsers: _RefType['UserConnection'];
        branchProtectionRules: _RefType['BranchProtectionRuleConnection'];
        collaborators?: Maybe<_RefType['RepositoryCollaboratorConnection']>;
        commitComments: _RefType['CommitCommentConnection'];
        defaultBranchRef?: Maybe<_RefType['Ref']>;
        deployments: _RefType['DeploymentConnection'];
        discussion?: Maybe<_RefType['Discussion']>;
        discussionCategories: _RefType['DiscussionCategoryConnection'];
        discussions: _RefType['DiscussionConnection'];
        environment?: Maybe<_RefType['Environment']>;
        environments: _RefType['EnvironmentConnection'];
        forks: _RefType['RepositoryConnection'];
        issue?: Maybe<_RefType['Issue']>;
        issueOrPullRequest?: Maybe<_RefType['IssueOrPullRequest']>;
        label?: Maybe<_RefType['Label']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        latestRelease?: Maybe<_RefType['Release']>;
        mentionableUsers: _RefType['UserConnection'];
        milestone?: Maybe<_RefType['Milestone']>;
        milestones?: Maybe<_RefType['MilestoneConnection']>;
        object?: Maybe<_RefType['GitObject']>;
        owner: _RefType['RepositoryOwner'];
        packages: _RefType['PackageConnection'];
        parent?: Maybe<_RefType['Repository']>;
        pinnedDiscussions: _RefType['PinnedDiscussionConnection'];
        pinnedIssues?: Maybe<_RefType['PinnedIssueConnection']>;
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        pullRequestTemplates?: Maybe<Array<_RefType['PullRequestTemplate']>>;
        pullRequests: _RefType['PullRequestConnection'];
        ref?: Maybe<_RefType['Ref']>;
        release?: Maybe<_RefType['Release']>;
        releases: _RefType['ReleaseConnection'];
        templateRepository?: Maybe<_RefType['Repository']>;
        vulnerabilityAlerts?: Maybe<_RefType['RepositoryVulnerabilityAlertConnection']>;
        watchers: _RefType['UserConnection'];
    });
    RepositoryNode: (Omit<CommitComment, 'author' | 'commit' | 'editor' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<CommitCommentThread, 'comments' | 'commit' | 'repository'> & {
        comments: _RefType['CommitCommentConnection'];
        commit?: Maybe<_RefType['Commit']>;
        repository: _RefType['Repository'];
    }) | (Omit<Discussion, 'answer' | 'answerChosenBy' | 'author' | 'category' | 'comments' | 'editor' | 'labels' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        answer?: Maybe<_RefType['DiscussionComment']>;
        answerChosenBy?: Maybe<_RefType['Actor']>;
        author?: Maybe<_RefType['Actor']>;
        category: _RefType['DiscussionCategory'];
        comments: _RefType['DiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<DiscussionCategory, 'repository'> & {
        repository: _RefType['Repository'];
    }) | (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<IssueComment, 'author' | 'editor' | 'issue' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PinnedDiscussion, 'discussion' | 'pinnedBy' | 'repository'> & {
        discussion: _RefType['Discussion'];
        pinnedBy: _RefType['Actor'];
        repository: _RefType['Repository'];
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    }) | (Omit<PullRequestCommitCommentThread, 'comments' | 'commit' | 'pullRequest' | 'repository'> & {
        comments: _RefType['CommitCommentConnection'];
        commit: _RefType['Commit'];
        pullRequest: _RefType['PullRequest'];
        repository: _RefType['Repository'];
    }) | (Omit<PullRequestReview, 'author' | 'comments' | 'commit' | 'editor' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['PullRequestReviewCommentConnection'];
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequestReviewComment, 'author' | 'commit' | 'editor' | 'originalCommit' | 'pullRequest' | 'pullRequestReview' | 'reactionGroups' | 'reactions' | 'replyTo' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        originalCommit?: Maybe<_RefType['Commit']>;
        pullRequest: _RefType['PullRequest'];
        pullRequestReview?: Maybe<_RefType['PullRequestReview']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        replyTo?: Maybe<_RefType['PullRequestReviewComment']>;
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<RepositoryVulnerabilityAlert, 'dismisser' | 'repository'> & {
        dismisser?: Maybe<_RefType['User']>;
        repository: _RefType['Repository'];
    });
    RepositoryOwner: (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    RequirableByPullRequest: (Omit<CheckRun, 'checkSuite' | 'deployment' | 'pendingDeploymentRequest' | 'repository'> & {
        checkSuite: _RefType['CheckSuite'];
        deployment?: Maybe<_RefType['Deployment']>;
        pendingDeploymentRequest?: Maybe<_RefType['DeploymentRequest']>;
        repository: _RefType['Repository'];
    }) | (Omit<StatusContext, 'commit' | 'creator'> & {
        commit?: Maybe<_RefType['Commit']>;
        creator?: Maybe<_RefType['Actor']>;
    });
    Sponsorable: (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    Starrable: (Omit<Gist, 'comments' | 'forks' | 'owner'> & {
        comments: _RefType['GistCommentConnection'];
        forks: _RefType['GistConnection'];
        owner?: Maybe<_RefType['RepositoryOwner']>;
    }) | (Omit<Repository, 'assignableUsers' | 'branchProtectionRules' | 'collaborators' | 'commitComments' | 'defaultBranchRef' | 'deployments' | 'discussion' | 'discussionCategories' | 'discussions' | 'environment' | 'environments' | 'forks' | 'issue' | 'issueOrPullRequest' | 'label' | 'labels' | 'latestRelease' | 'mentionableUsers' | 'milestone' | 'milestones' | 'object' | 'owner' | 'packages' | 'parent' | 'pinnedDiscussions' | 'pinnedIssues' | 'project' | 'projects' | 'pullRequest' | 'pullRequestTemplates' | 'pullRequests' | 'ref' | 'release' | 'releases' | 'templateRepository' | 'vulnerabilityAlerts' | 'watchers'> & {
        assignableUsers: _RefType['UserConnection'];
        branchProtectionRules: _RefType['BranchProtectionRuleConnection'];
        collaborators?: Maybe<_RefType['RepositoryCollaboratorConnection']>;
        commitComments: _RefType['CommitCommentConnection'];
        defaultBranchRef?: Maybe<_RefType['Ref']>;
        deployments: _RefType['DeploymentConnection'];
        discussion?: Maybe<_RefType['Discussion']>;
        discussionCategories: _RefType['DiscussionCategoryConnection'];
        discussions: _RefType['DiscussionConnection'];
        environment?: Maybe<_RefType['Environment']>;
        environments: _RefType['EnvironmentConnection'];
        forks: _RefType['RepositoryConnection'];
        issue?: Maybe<_RefType['Issue']>;
        issueOrPullRequest?: Maybe<_RefType['IssueOrPullRequest']>;
        label?: Maybe<_RefType['Label']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        latestRelease?: Maybe<_RefType['Release']>;
        mentionableUsers: _RefType['UserConnection'];
        milestone?: Maybe<_RefType['Milestone']>;
        milestones?: Maybe<_RefType['MilestoneConnection']>;
        object?: Maybe<_RefType['GitObject']>;
        owner: _RefType['RepositoryOwner'];
        packages: _RefType['PackageConnection'];
        parent?: Maybe<_RefType['Repository']>;
        pinnedDiscussions: _RefType['PinnedDiscussionConnection'];
        pinnedIssues?: Maybe<_RefType['PinnedIssueConnection']>;
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        pullRequestTemplates?: Maybe<Array<_RefType['PullRequestTemplate']>>;
        pullRequests: _RefType['PullRequestConnection'];
        ref?: Maybe<_RefType['Ref']>;
        release?: Maybe<_RefType['Release']>;
        releases: _RefType['ReleaseConnection'];
        templateRepository?: Maybe<_RefType['Repository']>;
        vulnerabilityAlerts?: Maybe<_RefType['RepositoryVulnerabilityAlertConnection']>;
        watchers: _RefType['UserConnection'];
    }) | (Topic);
    Subscribable: (Omit<Commit, 'associatedPullRequests' | 'blame' | 'checkSuites' | 'comments' | 'deployments' | 'file' | 'history' | 'onBehalfOf' | 'parents' | 'repository' | 'signature' | 'status' | 'statusCheckRollup' | 'tree'> & {
        associatedPullRequests?: Maybe<_RefType['PullRequestConnection']>;
        blame: _RefType['Blame'];
        checkSuites?: Maybe<_RefType['CheckSuiteConnection']>;
        comments: _RefType['CommitCommentConnection'];
        deployments?: Maybe<_RefType['DeploymentConnection']>;
        file?: Maybe<_RefType['TreeEntry']>;
        history: _RefType['CommitHistoryConnection'];
        onBehalfOf?: Maybe<_RefType['Organization']>;
        parents: _RefType['CommitConnection'];
        repository: _RefType['Repository'];
        signature?: Maybe<_RefType['GitSignature']>;
        status?: Maybe<_RefType['Status']>;
        statusCheckRollup?: Maybe<_RefType['StatusCheckRollup']>;
        tree: _RefType['Tree'];
    }) | (Omit<Discussion, 'answer' | 'answerChosenBy' | 'author' | 'category' | 'comments' | 'editor' | 'labels' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        answer?: Maybe<_RefType['DiscussionComment']>;
        answerChosenBy?: Maybe<_RefType['Actor']>;
        author?: Maybe<_RefType['Actor']>;
        category: _RefType['DiscussionCategory'];
        comments: _RefType['DiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    }) | (Omit<Repository, 'assignableUsers' | 'branchProtectionRules' | 'collaborators' | 'commitComments' | 'defaultBranchRef' | 'deployments' | 'discussion' | 'discussionCategories' | 'discussions' | 'environment' | 'environments' | 'forks' | 'issue' | 'issueOrPullRequest' | 'label' | 'labels' | 'latestRelease' | 'mentionableUsers' | 'milestone' | 'milestones' | 'object' | 'owner' | 'packages' | 'parent' | 'pinnedDiscussions' | 'pinnedIssues' | 'project' | 'projects' | 'pullRequest' | 'pullRequestTemplates' | 'pullRequests' | 'ref' | 'release' | 'releases' | 'templateRepository' | 'vulnerabilityAlerts' | 'watchers'> & {
        assignableUsers: _RefType['UserConnection'];
        branchProtectionRules: _RefType['BranchProtectionRuleConnection'];
        collaborators?: Maybe<_RefType['RepositoryCollaboratorConnection']>;
        commitComments: _RefType['CommitCommentConnection'];
        defaultBranchRef?: Maybe<_RefType['Ref']>;
        deployments: _RefType['DeploymentConnection'];
        discussion?: Maybe<_RefType['Discussion']>;
        discussionCategories: _RefType['DiscussionCategoryConnection'];
        discussions: _RefType['DiscussionConnection'];
        environment?: Maybe<_RefType['Environment']>;
        environments: _RefType['EnvironmentConnection'];
        forks: _RefType['RepositoryConnection'];
        issue?: Maybe<_RefType['Issue']>;
        issueOrPullRequest?: Maybe<_RefType['IssueOrPullRequest']>;
        label?: Maybe<_RefType['Label']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        latestRelease?: Maybe<_RefType['Release']>;
        mentionableUsers: _RefType['UserConnection'];
        milestone?: Maybe<_RefType['Milestone']>;
        milestones?: Maybe<_RefType['MilestoneConnection']>;
        object?: Maybe<_RefType['GitObject']>;
        owner: _RefType['RepositoryOwner'];
        packages: _RefType['PackageConnection'];
        parent?: Maybe<_RefType['Repository']>;
        pinnedDiscussions: _RefType['PinnedDiscussionConnection'];
        pinnedIssues?: Maybe<_RefType['PinnedIssueConnection']>;
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        pullRequestTemplates?: Maybe<Array<_RefType['PullRequestTemplate']>>;
        pullRequests: _RefType['PullRequestConnection'];
        ref?: Maybe<_RefType['Ref']>;
        release?: Maybe<_RefType['Release']>;
        releases: _RefType['ReleaseConnection'];
        templateRepository?: Maybe<_RefType['Repository']>;
        vulnerabilityAlerts?: Maybe<_RefType['RepositoryVulnerabilityAlertConnection']>;
        watchers: _RefType['UserConnection'];
    }) | (Omit<Team, 'discussion' | 'discussions' | 'invitations' | 'memberStatuses' | 'organization' | 'parentTeam' | 'repositories'> & {
        discussion?: Maybe<_RefType['TeamDiscussion']>;
        discussions: _RefType['TeamDiscussionConnection'];
        invitations?: Maybe<_RefType['OrganizationInvitationConnection']>;
        memberStatuses: _RefType['UserStatusConnection'];
        organization: _RefType['Organization'];
        parentTeam?: Maybe<_RefType['Team']>;
        repositories: _RefType['TeamRepositoryConnection'];
    }) | (Omit<TeamDiscussion, 'author' | 'comments' | 'editor' | 'reactionGroups' | 'reactions' | 'team' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['TeamDiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        team: _RefType['Team'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    });
    TeamAuditEntryData: (Omit<OrgRestoreMemberMembershipTeamAuditEntryData, 'team'> & {
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<TeamAddMemberAuditEntry, 'actor' | 'organization' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamAddRepositoryAuditEntry, 'actor' | 'organization' | 'repository' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamChangeParentTeamAuditEntry, 'actor' | 'organization' | 'parentTeam' | 'parentTeamWas' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        parentTeam?: Maybe<_RefType['Team']>;
        parentTeamWas?: Maybe<_RefType['Team']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamRemoveMemberAuditEntry, 'actor' | 'organization' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<TeamRemoveRepositoryAuditEntry, 'actor' | 'organization' | 'repository' | 'team' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        team?: Maybe<_RefType['Team']>;
        user?: Maybe<_RefType['User']>;
    });
    TopicAuditEntryData: (Omit<RepoAddTopicAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    }) | (Omit<RepoRemoveTopicAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<_RefType['AuditEntryActor']>;
        organization?: Maybe<_RefType['Organization']>;
        repository?: Maybe<_RefType['Repository']>;
        user?: Maybe<_RefType['User']>;
    });
    UniformResourceLocatable: (Bot) | (Omit<CheckRun, 'checkSuite' | 'deployment' | 'pendingDeploymentRequest' | 'repository'> & {
        checkSuite: _RefType['CheckSuite'];
        deployment?: Maybe<_RefType['Deployment']>;
        pendingDeploymentRequest?: Maybe<_RefType['DeploymentRequest']>;
        repository: _RefType['Repository'];
    }) | (Omit<ClosedEvent, 'actor' | 'closable' | 'closer'> & {
        actor?: Maybe<_RefType['Actor']>;
        closable: _RefType['Closable'];
        closer?: Maybe<_RefType['Closer']>;
    }) | (Omit<Commit, 'associatedPullRequests' | 'blame' | 'checkSuites' | 'comments' | 'deployments' | 'file' | 'history' | 'onBehalfOf' | 'parents' | 'repository' | 'signature' | 'status' | 'statusCheckRollup' | 'tree'> & {
        associatedPullRequests?: Maybe<_RefType['PullRequestConnection']>;
        blame: _RefType['Blame'];
        checkSuites?: Maybe<_RefType['CheckSuiteConnection']>;
        comments: _RefType['CommitCommentConnection'];
        deployments?: Maybe<_RefType['DeploymentConnection']>;
        file?: Maybe<_RefType['TreeEntry']>;
        history: _RefType['CommitHistoryConnection'];
        onBehalfOf?: Maybe<_RefType['Organization']>;
        parents: _RefType['CommitConnection'];
        repository: _RefType['Repository'];
        signature?: Maybe<_RefType['GitSignature']>;
        status?: Maybe<_RefType['Status']>;
        statusCheckRollup?: Maybe<_RefType['StatusCheckRollup']>;
        tree: _RefType['Tree'];
    }) | (Omit<ConvertToDraftEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<CrossReferencedEvent, 'actor' | 'source' | 'target'> & {
        actor?: Maybe<_RefType['Actor']>;
        source: _RefType['ReferencedSubject'];
        target: _RefType['ReferencedSubject'];
    }) | (Omit<Gist, 'comments' | 'forks' | 'owner'> & {
        comments: _RefType['GistCommentConnection'];
        forks: _RefType['GistConnection'];
        owner?: Maybe<_RefType['RepositoryOwner']>;
    }) | (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Mannequin, 'claimant'> & {
        claimant?: Maybe<_RefType['User']>;
    }) | (Omit<MergedEvent, 'actor' | 'commit' | 'mergeRef' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        mergeRef?: Maybe<_RefType['Ref']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<Milestone, 'creator' | 'pullRequests' | 'repository'> & {
        creator?: Maybe<_RefType['Actor']>;
        pullRequests: _RefType['PullRequestConnection'];
        repository: _RefType['Repository'];
    }) | (Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: _RefType['OrganizationAuditEntryConnection'];
        domains?: Maybe<_RefType['VerifiableDomainConnection']>;
        ipAllowListEntries: _RefType['IpAllowListEntryConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        memberStatuses: _RefType['UserStatusConnection'];
        packages: _RefType['PackageConnection'];
        pendingMembers: _RefType['UserConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        repositories: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        samlIdentityProvider?: Maybe<_RefType['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        team?: Maybe<_RefType['Team']>;
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    }) | (Omit<PullRequestCommit, 'commit' | 'pullRequest'> & {
        commit: _RefType['Commit'];
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<ReadyForReviewEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
    }) | (Omit<Release, 'author' | 'mentions' | 'reactionGroups' | 'reactions' | 'releaseAssets' | 'repository' | 'tag' | 'tagCommit'> & {
        author?: Maybe<_RefType['User']>;
        mentions?: Maybe<_RefType['UserConnection']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        releaseAssets: _RefType['ReleaseAssetConnection'];
        repository: _RefType['Repository'];
        tag?: Maybe<_RefType['Ref']>;
        tagCommit?: Maybe<_RefType['Commit']>;
    }) | (Omit<Repository, 'assignableUsers' | 'branchProtectionRules' | 'collaborators' | 'commitComments' | 'defaultBranchRef' | 'deployments' | 'discussion' | 'discussionCategories' | 'discussions' | 'environment' | 'environments' | 'forks' | 'issue' | 'issueOrPullRequest' | 'label' | 'labels' | 'latestRelease' | 'mentionableUsers' | 'milestone' | 'milestones' | 'object' | 'owner' | 'packages' | 'parent' | 'pinnedDiscussions' | 'pinnedIssues' | 'project' | 'projects' | 'pullRequest' | 'pullRequestTemplates' | 'pullRequests' | 'ref' | 'release' | 'releases' | 'templateRepository' | 'vulnerabilityAlerts' | 'watchers'> & {
        assignableUsers: _RefType['UserConnection'];
        branchProtectionRules: _RefType['BranchProtectionRuleConnection'];
        collaborators?: Maybe<_RefType['RepositoryCollaboratorConnection']>;
        commitComments: _RefType['CommitCommentConnection'];
        defaultBranchRef?: Maybe<_RefType['Ref']>;
        deployments: _RefType['DeploymentConnection'];
        discussion?: Maybe<_RefType['Discussion']>;
        discussionCategories: _RefType['DiscussionCategoryConnection'];
        discussions: _RefType['DiscussionConnection'];
        environment?: Maybe<_RefType['Environment']>;
        environments: _RefType['EnvironmentConnection'];
        forks: _RefType['RepositoryConnection'];
        issue?: Maybe<_RefType['Issue']>;
        issueOrPullRequest?: Maybe<_RefType['IssueOrPullRequest']>;
        label?: Maybe<_RefType['Label']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        latestRelease?: Maybe<_RefType['Release']>;
        mentionableUsers: _RefType['UserConnection'];
        milestone?: Maybe<_RefType['Milestone']>;
        milestones?: Maybe<_RefType['MilestoneConnection']>;
        object?: Maybe<_RefType['GitObject']>;
        owner: _RefType['RepositoryOwner'];
        packages: _RefType['PackageConnection'];
        parent?: Maybe<_RefType['Repository']>;
        pinnedDiscussions: _RefType['PinnedDiscussionConnection'];
        pinnedIssues?: Maybe<_RefType['PinnedIssueConnection']>;
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        pullRequestTemplates?: Maybe<Array<_RefType['PullRequestTemplate']>>;
        pullRequests: _RefType['PullRequestConnection'];
        ref?: Maybe<_RefType['Ref']>;
        release?: Maybe<_RefType['Release']>;
        releases: _RefType['ReleaseConnection'];
        templateRepository?: Maybe<_RefType['Repository']>;
        vulnerabilityAlerts?: Maybe<_RefType['RepositoryVulnerabilityAlertConnection']>;
        watchers: _RefType['UserConnection'];
    }) | (RepositoryTopic) | (Omit<ReviewDismissedEvent, 'actor' | 'pullRequest' | 'pullRequestCommit' | 'review'> & {
        actor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        pullRequestCommit?: Maybe<_RefType['PullRequestCommit']>;
        review?: Maybe<_RefType['PullRequestReview']>;
    }) | (Omit<TeamDiscussion, 'author' | 'comments' | 'editor' | 'reactionGroups' | 'reactions' | 'team' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['TeamDiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        team: _RefType['Team'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<TeamDiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        discussion: _RefType['TeamDiscussion'];
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: _RefType['CommitCommentConnection'];
        contributionsCollection: _RefType['ContributionsCollection'];
        followers: _RefType['FollowerConnection'];
        following: _RefType['FollowingConnection'];
        gist?: Maybe<_RefType['Gist']>;
        gistComments: _RefType['GistCommentConnection'];
        gists: _RefType['GistConnection'];
        hovercard: _RefType['Hovercard'];
        issueComments: _RefType['IssueCommentConnection'];
        itemShowcase: _RefType['ProfileItemShowcase'];
        organization?: Maybe<_RefType['Organization']>;
        organizations: _RefType['OrganizationConnection'];
        packages: _RefType['PackageConnection'];
        pinnableItems: _RefType['PinnableItemConnection'];
        pinnedItems: _RefType['PinnableItemConnection'];
        project?: Maybe<_RefType['Project']>;
        projects: _RefType['ProjectConnection'];
        pullRequests: _RefType['PullRequestConnection'];
        repositories: _RefType['RepositoryConnection'];
        repositoriesContributedTo: _RefType['RepositoryConnection'];
        repository?: Maybe<_RefType['Repository']>;
        repositoryDiscussionComments: _RefType['DiscussionCommentConnection'];
        repositoryDiscussions: _RefType['DiscussionConnection'];
        savedReplies?: Maybe<_RefType['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: _RefType['SponsorshipConnection'];
        sponsorshipsAsSponsor: _RefType['SponsorshipConnection'];
        starredRepositories: _RefType['StarredRepositoryConnection'];
        status?: Maybe<_RefType['UserStatus']>;
        topRepositories: _RefType['RepositoryConnection'];
        watching: _RefType['RepositoryConnection'];
    });
    Updatable: (Omit<CommitComment, 'author' | 'commit' | 'editor' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Discussion, 'answer' | 'answerChosenBy' | 'author' | 'category' | 'comments' | 'editor' | 'labels' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        answer?: Maybe<_RefType['DiscussionComment']>;
        answerChosenBy?: Maybe<_RefType['Actor']>;
        author?: Maybe<_RefType['Actor']>;
        category: _RefType['DiscussionCategory'];
        comments: _RefType['DiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<DiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'replies' | 'replyTo' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        discussion?: Maybe<_RefType['Discussion']>;
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        replies: _RefType['DiscussionCommentConnection'];
        replyTo?: Maybe<_RefType['DiscussionComment']>;
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<GistComment, 'author' | 'editor' | 'gist' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        gist: _RefType['Gist'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<IssueComment, 'author' | 'editor' | 'issue' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Project, 'columns' | 'creator' | 'owner' | 'pendingCards'> & {
        columns: _RefType['ProjectColumnConnection'];
        creator?: Maybe<_RefType['Actor']>;
        owner: _RefType['ProjectOwner'];
        pendingCards: _RefType['ProjectCardConnection'];
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    }) | (Omit<PullRequestReview, 'author' | 'comments' | 'commit' | 'editor' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['PullRequestReviewCommentConnection'];
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequestReviewComment, 'author' | 'commit' | 'editor' | 'originalCommit' | 'pullRequest' | 'pullRequestReview' | 'reactionGroups' | 'reactions' | 'replyTo' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        originalCommit?: Maybe<_RefType['Commit']>;
        pullRequest: _RefType['PullRequest'];
        pullRequestReview?: Maybe<_RefType['PullRequestReview']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        replyTo?: Maybe<_RefType['PullRequestReviewComment']>;
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<TeamDiscussion, 'author' | 'comments' | 'editor' | 'reactionGroups' | 'reactions' | 'team' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['TeamDiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        team: _RefType['Team'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<TeamDiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        discussion: _RefType['TeamDiscussion'];
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    });
    UpdatableComment: (Omit<CommitComment, 'author' | 'commit' | 'editor' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<DiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'replies' | 'replyTo' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        discussion?: Maybe<_RefType['Discussion']>;
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        replies: _RefType['DiscussionCommentConnection'];
        replyTo?: Maybe<_RefType['DiscussionComment']>;
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<GistComment, 'author' | 'editor' | 'gist' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        gist: _RefType['Gist'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['IssueCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        timeline: _RefType['IssueTimelineConnection'];
        timelineItems: _RefType['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<IssueComment, 'author' | 'editor' | 'issue' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        editor?: Maybe<_RefType['Actor']>;
        issue: _RefType['Issue'];
        pullRequest?: Maybe<_RefType['PullRequest']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: _RefType['UserConnection'];
        author?: Maybe<_RefType['Actor']>;
        autoMergeRequest?: Maybe<_RefType['AutoMergeRequest']>;
        baseRef?: Maybe<_RefType['Ref']>;
        baseRepository?: Maybe<_RefType['Repository']>;
        comments: _RefType['IssueCommentConnection'];
        commits: _RefType['PullRequestCommitConnection'];
        editor?: Maybe<_RefType['Actor']>;
        headRef?: Maybe<_RefType['Ref']>;
        headRepository?: Maybe<_RefType['Repository']>;
        headRepositoryOwner?: Maybe<_RefType['RepositoryOwner']>;
        hovercard: _RefType['Hovercard'];
        labels?: Maybe<_RefType['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        latestReviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<_RefType['Commit']>;
        mergedBy?: Maybe<_RefType['Actor']>;
        milestone?: Maybe<_RefType['Milestone']>;
        participants: _RefType['UserConnection'];
        potentialMergeCommit?: Maybe<_RefType['Commit']>;
        projectCards: _RefType['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        reviewRequests?: Maybe<_RefType['ReviewRequestConnection']>;
        reviewThreads: _RefType['PullRequestReviewThreadConnection'];
        reviews?: Maybe<_RefType['PullRequestReviewConnection']>;
        timeline: _RefType['PullRequestTimelineConnection'];
        timelineItems: _RefType['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<_RefType['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<_RefType['ReviewRequest']>;
    }) | (Omit<PullRequestReview, 'author' | 'comments' | 'commit' | 'editor' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['PullRequestReviewCommentConnection'];
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        pullRequest: _RefType['PullRequest'];
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<PullRequestReviewComment, 'author' | 'commit' | 'editor' | 'originalCommit' | 'pullRequest' | 'pullRequestReview' | 'reactionGroups' | 'reactions' | 'replyTo' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        commit?: Maybe<_RefType['Commit']>;
        editor?: Maybe<_RefType['Actor']>;
        originalCommit?: Maybe<_RefType['Commit']>;
        pullRequest: _RefType['PullRequest'];
        pullRequestReview?: Maybe<_RefType['PullRequestReview']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        replyTo?: Maybe<_RefType['PullRequestReviewComment']>;
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<TeamDiscussion, 'author' | 'comments' | 'editor' | 'reactionGroups' | 'reactions' | 'team' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        comments: _RefType['TeamDiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        team: _RefType['Team'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<TeamDiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        discussion: _RefType['TeamDiscussion'];
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    });
    Votable: (Omit<Discussion, 'answer' | 'answerChosenBy' | 'author' | 'category' | 'comments' | 'editor' | 'labels' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        answer?: Maybe<_RefType['DiscussionComment']>;
        answerChosenBy?: Maybe<_RefType['Actor']>;
        author?: Maybe<_RefType['Actor']>;
        category: _RefType['DiscussionCategory'];
        comments: _RefType['DiscussionCommentConnection'];
        editor?: Maybe<_RefType['Actor']>;
        labels?: Maybe<_RefType['LabelConnection']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        repository: _RefType['Repository'];
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    }) | (Omit<DiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'replies' | 'replyTo' | 'userContentEdits'> & {
        author?: Maybe<_RefType['Actor']>;
        discussion?: Maybe<_RefType['Discussion']>;
        editor?: Maybe<_RefType['Actor']>;
        reactionGroups?: Maybe<Array<_RefType['ReactionGroup']>>;
        reactions: _RefType['ReactionConnection'];
        replies: _RefType['DiscussionCommentConnection'];
        replyTo?: Maybe<_RefType['DiscussionComment']>;
        userContentEdits?: Maybe<_RefType['UserContentEditConnection']>;
    });
};
/** Mapping between all available schema types and the resolvers types */
export type ResolversTypes = {
    Actor: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['Actor']>;
    ActorLocation: ResolverTypeWrapper<ActorLocation>;
    AddAssigneesToAssignableInput: AddAssigneesToAssignableInput;
    AddAssigneesToAssignablePayload: ResolverTypeWrapper<Omit<AddAssigneesToAssignablePayload, 'assignable'> & {
        assignable?: Maybe<ResolversTypes['Assignable']>;
    }>;
    AddCommentInput: AddCommentInput;
    AddCommentPayload: ResolverTypeWrapper<Omit<AddCommentPayload, 'commentEdge' | 'subject' | 'timelineEdge'> & {
        commentEdge?: Maybe<ResolversTypes['IssueCommentEdge']>;
        subject?: Maybe<ResolversTypes['Node']>;
        timelineEdge?: Maybe<ResolversTypes['IssueTimelineItemEdge']>;
    }>;
    AddDiscussionCommentInput: AddDiscussionCommentInput;
    AddDiscussionCommentPayload: ResolverTypeWrapper<Omit<AddDiscussionCommentPayload, 'comment'> & {
        comment?: Maybe<ResolversTypes['DiscussionComment']>;
    }>;
    AddEnterpriseAdminInput: AddEnterpriseAdminInput;
    AddEnterpriseAdminPayload: ResolverTypeWrapper<Omit<AddEnterpriseAdminPayload, 'admin' | 'enterprise' | 'viewer'> & {
        admin?: Maybe<ResolversTypes['User']>;
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
        viewer?: Maybe<ResolversTypes['User']>;
    }>;
    AddLabelsToLabelableInput: AddLabelsToLabelableInput;
    AddLabelsToLabelablePayload: ResolverTypeWrapper<Omit<AddLabelsToLabelablePayload, 'labelable'> & {
        labelable?: Maybe<ResolversTypes['Labelable']>;
    }>;
    AddProjectCardInput: AddProjectCardInput;
    AddProjectCardPayload: ResolverTypeWrapper<Omit<AddProjectCardPayload, 'cardEdge' | 'projectColumn'> & {
        cardEdge?: Maybe<ResolversTypes['ProjectCardEdge']>;
        projectColumn?: Maybe<ResolversTypes['ProjectColumn']>;
    }>;
    AddProjectColumnInput: AddProjectColumnInput;
    AddProjectColumnPayload: ResolverTypeWrapper<Omit<AddProjectColumnPayload, 'columnEdge' | 'project'> & {
        columnEdge?: Maybe<ResolversTypes['ProjectColumnEdge']>;
        project?: Maybe<ResolversTypes['Project']>;
    }>;
    AddPullRequestReviewCommentInput: AddPullRequestReviewCommentInput;
    AddPullRequestReviewCommentPayload: ResolverTypeWrapper<Omit<AddPullRequestReviewCommentPayload, 'comment' | 'commentEdge'> & {
        comment?: Maybe<ResolversTypes['PullRequestReviewComment']>;
        commentEdge?: Maybe<ResolversTypes['PullRequestReviewCommentEdge']>;
    }>;
    AddPullRequestReviewInput: AddPullRequestReviewInput;
    AddPullRequestReviewPayload: ResolverTypeWrapper<Omit<AddPullRequestReviewPayload, 'pullRequestReview' | 'reviewEdge'> & {
        pullRequestReview?: Maybe<ResolversTypes['PullRequestReview']>;
        reviewEdge?: Maybe<ResolversTypes['PullRequestReviewEdge']>;
    }>;
    AddPullRequestReviewThreadInput: AddPullRequestReviewThreadInput;
    AddPullRequestReviewThreadPayload: ResolverTypeWrapper<Omit<AddPullRequestReviewThreadPayload, 'thread'> & {
        thread?: Maybe<ResolversTypes['PullRequestReviewThread']>;
    }>;
    AddReactionInput: AddReactionInput;
    AddReactionPayload: ResolverTypeWrapper<Omit<AddReactionPayload, 'reaction' | 'subject'> & {
        reaction?: Maybe<ResolversTypes['Reaction']>;
        subject?: Maybe<ResolversTypes['Reactable']>;
    }>;
    AddStarInput: AddStarInput;
    AddStarPayload: ResolverTypeWrapper<Omit<AddStarPayload, 'starrable'> & {
        starrable?: Maybe<ResolversTypes['Starrable']>;
    }>;
    AddUpvoteInput: AddUpvoteInput;
    AddUpvotePayload: ResolverTypeWrapper<Omit<AddUpvotePayload, 'subject'> & {
        subject?: Maybe<ResolversTypes['Votable']>;
    }>;
    AddVerifiableDomainInput: AddVerifiableDomainInput;
    AddVerifiableDomainPayload: ResolverTypeWrapper<Omit<AddVerifiableDomainPayload, 'domain'> & {
        domain?: Maybe<ResolversTypes['VerifiableDomain']>;
    }>;
    AddedToProjectEvent: ResolverTypeWrapper<Omit<AddedToProjectEvent, 'actor' | 'project' | 'projectCard'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        project?: Maybe<ResolversTypes['Project']>;
        projectCard?: Maybe<ResolversTypes['ProjectCard']>;
    }>;
    App: ResolverTypeWrapper<Omit<App, 'ipAllowListEntries'> & {
        ipAllowListEntries: ResolversTypes['IpAllowListEntryConnection'];
    }>;
    ApproveDeploymentsInput: ApproveDeploymentsInput;
    ApproveDeploymentsPayload: ResolverTypeWrapper<Omit<ApproveDeploymentsPayload, 'deployments'> & {
        deployments?: Maybe<Array<ResolversTypes['Deployment']>>;
    }>;
    ApproveVerifiableDomainInput: ApproveVerifiableDomainInput;
    ApproveVerifiableDomainPayload: ResolverTypeWrapper<Omit<ApproveVerifiableDomainPayload, 'domain'> & {
        domain?: Maybe<ResolversTypes['VerifiableDomain']>;
    }>;
    ArchiveRepositoryInput: ArchiveRepositoryInput;
    ArchiveRepositoryPayload: ResolverTypeWrapper<Omit<ArchiveRepositoryPayload, 'repository'> & {
        repository?: Maybe<ResolversTypes['Repository']>;
    }>;
    Assignable: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['Assignable']>;
    AssignedEvent: ResolverTypeWrapper<Omit<AssignedEvent, 'actor' | 'assignable' | 'assignee' | 'user'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        assignable: ResolversTypes['Assignable'];
        assignee?: Maybe<ResolversTypes['Assignee']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    Assignee: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['Assignee']>;
    AuditEntry: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['AuditEntry']>;
    AuditEntryActor: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['AuditEntryActor']>;
    AuditLogOrder: AuditLogOrder;
    AuditLogOrderField: AuditLogOrderField;
    AutoMergeDisabledEvent: ResolverTypeWrapper<Omit<AutoMergeDisabledEvent, 'actor' | 'disabler' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        disabler?: Maybe<ResolversTypes['User']>;
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
    }>;
    AutoMergeEnabledEvent: ResolverTypeWrapper<Omit<AutoMergeEnabledEvent, 'actor' | 'enabler' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        enabler?: Maybe<ResolversTypes['User']>;
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
    }>;
    AutoMergeRequest: ResolverTypeWrapper<Omit<AutoMergeRequest, 'enabledBy' | 'pullRequest'> & {
        enabledBy?: Maybe<ResolversTypes['Actor']>;
        pullRequest: ResolversTypes['PullRequest'];
    }>;
    AutoRebaseEnabledEvent: ResolverTypeWrapper<Omit<AutoRebaseEnabledEvent, 'actor' | 'enabler' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        enabler?: Maybe<ResolversTypes['User']>;
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
    }>;
    AutoSquashEnabledEvent: ResolverTypeWrapper<Omit<AutoSquashEnabledEvent, 'actor' | 'enabler' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        enabler?: Maybe<ResolversTypes['User']>;
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
    }>;
    AutomaticBaseChangeFailedEvent: ResolverTypeWrapper<Omit<AutomaticBaseChangeFailedEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        pullRequest: ResolversTypes['PullRequest'];
    }>;
    AutomaticBaseChangeSucceededEvent: ResolverTypeWrapper<Omit<AutomaticBaseChangeSucceededEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        pullRequest: ResolversTypes['PullRequest'];
    }>;
    BaseRefChangedEvent: ResolverTypeWrapper<Omit<BaseRefChangedEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        pullRequest: ResolversTypes['PullRequest'];
    }>;
    BaseRefDeletedEvent: ResolverTypeWrapper<Omit<BaseRefDeletedEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
    }>;
    BaseRefForcePushedEvent: ResolverTypeWrapper<Omit<BaseRefForcePushedEvent, 'actor' | 'afterCommit' | 'beforeCommit' | 'pullRequest' | 'ref'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        afterCommit?: Maybe<ResolversTypes['Commit']>;
        beforeCommit?: Maybe<ResolversTypes['Commit']>;
        pullRequest: ResolversTypes['PullRequest'];
        ref?: Maybe<ResolversTypes['Ref']>;
    }>;
    Blame: ResolverTypeWrapper<Omit<Blame, 'ranges'> & {
        ranges: Array<ResolversTypes['BlameRange']>;
    }>;
    BlameRange: ResolverTypeWrapper<Omit<BlameRange, 'commit'> & {
        commit: ResolversTypes['Commit'];
    }>;
    Blob: ResolverTypeWrapper<Omit<Blob, 'repository'> & {
        repository: ResolversTypes['Repository'];
    }>;
    Boolean: ResolverTypeWrapper<Scalars['Boolean']['output']>;
    Bot: ResolverTypeWrapper<Bot>;
    BranchProtectionRule: ResolverTypeWrapper<Omit<BranchProtectionRule, 'creator' | 'pushAllowances' | 'repository' | 'reviewDismissalAllowances'> & {
        creator?: Maybe<ResolversTypes['Actor']>;
        pushAllowances: ResolversTypes['PushAllowanceConnection'];
        repository?: Maybe<ResolversTypes['Repository']>;
        reviewDismissalAllowances: ResolversTypes['ReviewDismissalAllowanceConnection'];
    }>;
    BranchProtectionRuleConflict: ResolverTypeWrapper<Omit<BranchProtectionRuleConflict, 'branchProtectionRule' | 'conflictingBranchProtectionRule' | 'ref'> & {
        branchProtectionRule?: Maybe<ResolversTypes['BranchProtectionRule']>;
        conflictingBranchProtectionRule?: Maybe<ResolversTypes['BranchProtectionRule']>;
        ref?: Maybe<ResolversTypes['Ref']>;
    }>;
    BranchProtectionRuleConflictConnection: ResolverTypeWrapper<BranchProtectionRuleConflictConnection>;
    BranchProtectionRuleConflictEdge: ResolverTypeWrapper<BranchProtectionRuleConflictEdge>;
    BranchProtectionRuleConnection: ResolverTypeWrapper<Omit<BranchProtectionRuleConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['BranchProtectionRuleEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['BranchProtectionRule']>>>;
    }>;
    BranchProtectionRuleEdge: ResolverTypeWrapper<Omit<BranchProtectionRuleEdge, 'node'> & {
        node?: Maybe<ResolversTypes['BranchProtectionRule']>;
    }>;
    CVSS: ResolverTypeWrapper<Cvss>;
    CWE: ResolverTypeWrapper<Cwe>;
    CWEConnection: ResolverTypeWrapper<CweConnection>;
    CWEEdge: ResolverTypeWrapper<CweEdge>;
    ChangeUserStatusInput: ChangeUserStatusInput;
    ChangeUserStatusPayload: ResolverTypeWrapper<Omit<ChangeUserStatusPayload, 'status'> & {
        status?: Maybe<ResolversTypes['UserStatus']>;
    }>;
    CheckAnnotation: ResolverTypeWrapper<CheckAnnotation>;
    CheckAnnotationConnection: ResolverTypeWrapper<CheckAnnotationConnection>;
    CheckAnnotationData: CheckAnnotationData;
    CheckAnnotationEdge: ResolverTypeWrapper<CheckAnnotationEdge>;
    CheckAnnotationLevel: CheckAnnotationLevel;
    CheckAnnotationPosition: ResolverTypeWrapper<CheckAnnotationPosition>;
    CheckAnnotationRange: CheckAnnotationRange;
    CheckAnnotationSpan: ResolverTypeWrapper<CheckAnnotationSpan>;
    CheckConclusionState: CheckConclusionState;
    CheckRun: ResolverTypeWrapper<Omit<CheckRun, 'checkSuite' | 'deployment' | 'pendingDeploymentRequest' | 'repository'> & {
        checkSuite: ResolversTypes['CheckSuite'];
        deployment?: Maybe<ResolversTypes['Deployment']>;
        pendingDeploymentRequest?: Maybe<ResolversTypes['DeploymentRequest']>;
        repository: ResolversTypes['Repository'];
    }>;
    CheckRunAction: CheckRunAction;
    CheckRunConnection: ResolverTypeWrapper<Omit<CheckRunConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['CheckRunEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['CheckRun']>>>;
    }>;
    CheckRunEdge: ResolverTypeWrapper<Omit<CheckRunEdge, 'node'> & {
        node?: Maybe<ResolversTypes['CheckRun']>;
    }>;
    CheckRunFilter: CheckRunFilter;
    CheckRunOutput: CheckRunOutput;
    CheckRunOutputImage: CheckRunOutputImage;
    CheckRunType: CheckRunType;
    CheckStatusState: CheckStatusState;
    CheckStep: ResolverTypeWrapper<CheckStep>;
    CheckStepConnection: ResolverTypeWrapper<CheckStepConnection>;
    CheckStepEdge: ResolverTypeWrapper<CheckStepEdge>;
    CheckSuite: ResolverTypeWrapper<Omit<CheckSuite, 'app' | 'branch' | 'checkRuns' | 'commit' | 'creator' | 'matchingPullRequests' | 'push' | 'repository' | 'workflowRun'> & {
        app?: Maybe<ResolversTypes['App']>;
        branch?: Maybe<ResolversTypes['Ref']>;
        checkRuns?: Maybe<ResolversTypes['CheckRunConnection']>;
        commit: ResolversTypes['Commit'];
        creator?: Maybe<ResolversTypes['User']>;
        matchingPullRequests?: Maybe<ResolversTypes['PullRequestConnection']>;
        push?: Maybe<ResolversTypes['Push']>;
        repository: ResolversTypes['Repository'];
        workflowRun?: Maybe<ResolversTypes['WorkflowRun']>;
    }>;
    CheckSuiteAutoTriggerPreference: CheckSuiteAutoTriggerPreference;
    CheckSuiteConnection: ResolverTypeWrapper<Omit<CheckSuiteConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['CheckSuiteEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['CheckSuite']>>>;
    }>;
    CheckSuiteEdge: ResolverTypeWrapper<Omit<CheckSuiteEdge, 'node'> & {
        node?: Maybe<ResolversTypes['CheckSuite']>;
    }>;
    CheckSuiteFilter: CheckSuiteFilter;
    ClearLabelsFromLabelableInput: ClearLabelsFromLabelableInput;
    ClearLabelsFromLabelablePayload: ResolverTypeWrapper<Omit<ClearLabelsFromLabelablePayload, 'labelable'> & {
        labelable?: Maybe<ResolversTypes['Labelable']>;
    }>;
    CloneProjectInput: CloneProjectInput;
    CloneProjectPayload: ResolverTypeWrapper<Omit<CloneProjectPayload, 'project'> & {
        project?: Maybe<ResolversTypes['Project']>;
    }>;
    CloneTemplateRepositoryInput: CloneTemplateRepositoryInput;
    CloneTemplateRepositoryPayload: ResolverTypeWrapper<Omit<CloneTemplateRepositoryPayload, 'repository'> & {
        repository?: Maybe<ResolversTypes['Repository']>;
    }>;
    Closable: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['Closable']>;
    CloseIssueInput: CloseIssueInput;
    CloseIssuePayload: ResolverTypeWrapper<Omit<CloseIssuePayload, 'issue'> & {
        issue?: Maybe<ResolversTypes['Issue']>;
    }>;
    ClosePullRequestInput: ClosePullRequestInput;
    ClosePullRequestPayload: ResolverTypeWrapper<Omit<ClosePullRequestPayload, 'pullRequest'> & {
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
    }>;
    ClosedEvent: ResolverTypeWrapper<Omit<ClosedEvent, 'actor' | 'closable' | 'closer'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        closable: ResolversTypes['Closable'];
        closer?: Maybe<ResolversTypes['Closer']>;
    }>;
    Closer: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['Closer']>;
    CodeOfConduct: ResolverTypeWrapper<CodeOfConduct>;
    CollaboratorAffiliation: CollaboratorAffiliation;
    Comment: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['Comment']>;
    CommentAuthorAssociation: CommentAuthorAssociation;
    CommentCannotUpdateReason: CommentCannotUpdateReason;
    CommentDeletedEvent: ResolverTypeWrapper<Omit<CommentDeletedEvent, 'actor' | 'deletedCommentAuthor'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        deletedCommentAuthor?: Maybe<ResolversTypes['Actor']>;
    }>;
    Commit: ResolverTypeWrapper<Omit<Commit, 'associatedPullRequests' | 'blame' | 'checkSuites' | 'comments' | 'deployments' | 'file' | 'history' | 'onBehalfOf' | 'parents' | 'repository' | 'signature' | 'status' | 'statusCheckRollup' | 'tree'> & {
        associatedPullRequests?: Maybe<ResolversTypes['PullRequestConnection']>;
        blame: ResolversTypes['Blame'];
        checkSuites?: Maybe<ResolversTypes['CheckSuiteConnection']>;
        comments: ResolversTypes['CommitCommentConnection'];
        deployments?: Maybe<ResolversTypes['DeploymentConnection']>;
        file?: Maybe<ResolversTypes['TreeEntry']>;
        history: ResolversTypes['CommitHistoryConnection'];
        onBehalfOf?: Maybe<ResolversTypes['Organization']>;
        parents: ResolversTypes['CommitConnection'];
        repository: ResolversTypes['Repository'];
        signature?: Maybe<ResolversTypes['GitSignature']>;
        status?: Maybe<ResolversTypes['Status']>;
        statusCheckRollup?: Maybe<ResolversTypes['StatusCheckRollup']>;
        tree: ResolversTypes['Tree'];
    }>;
    CommitAuthor: CommitAuthor;
    CommitComment: ResolverTypeWrapper<Omit<CommitComment, 'author' | 'commit' | 'editor' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<ResolversTypes['Actor']>;
        commit?: Maybe<ResolversTypes['Commit']>;
        editor?: Maybe<ResolversTypes['Actor']>;
        reactionGroups?: Maybe<Array<ResolversTypes['ReactionGroup']>>;
        reactions: ResolversTypes['ReactionConnection'];
        repository: ResolversTypes['Repository'];
        userContentEdits?: Maybe<ResolversTypes['UserContentEditConnection']>;
    }>;
    CommitCommentConnection: ResolverTypeWrapper<Omit<CommitCommentConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['CommitCommentEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['CommitComment']>>>;
    }>;
    CommitCommentEdge: ResolverTypeWrapper<Omit<CommitCommentEdge, 'node'> & {
        node?: Maybe<ResolversTypes['CommitComment']>;
    }>;
    CommitCommentThread: ResolverTypeWrapper<Omit<CommitCommentThread, 'comments' | 'commit' | 'repository'> & {
        comments: ResolversTypes['CommitCommentConnection'];
        commit?: Maybe<ResolversTypes['Commit']>;
        repository: ResolversTypes['Repository'];
    }>;
    CommitConnection: ResolverTypeWrapper<Omit<CommitConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['CommitEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Commit']>>>;
    }>;
    CommitContributionOrder: CommitContributionOrder;
    CommitContributionOrderField: CommitContributionOrderField;
    CommitContributionsByRepository: ResolverTypeWrapper<Omit<CommitContributionsByRepository, 'contributions' | 'repository'> & {
        contributions: ResolversTypes['CreatedCommitContributionConnection'];
        repository: ResolversTypes['Repository'];
    }>;
    CommitEdge: ResolverTypeWrapper<Omit<CommitEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Commit']>;
    }>;
    CommitHistoryConnection: ResolverTypeWrapper<Omit<CommitHistoryConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['CommitEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Commit']>>>;
    }>;
    ConnectedEvent: ResolverTypeWrapper<Omit<ConnectedEvent, 'actor' | 'source' | 'subject'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        source: ResolversTypes['ReferencedSubject'];
        subject: ResolversTypes['ReferencedSubject'];
    }>;
    ContentAttachment: ResolverTypeWrapper<ContentAttachment>;
    ContentReference: ResolverTypeWrapper<ContentReference>;
    Contribution: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['Contribution']>;
    ContributionCalendar: ResolverTypeWrapper<ContributionCalendar>;
    ContributionCalendarDay: ResolverTypeWrapper<ContributionCalendarDay>;
    ContributionCalendarMonth: ResolverTypeWrapper<ContributionCalendarMonth>;
    ContributionCalendarWeek: ResolverTypeWrapper<ContributionCalendarWeek>;
    ContributionLevel: ContributionLevel;
    ContributionOrder: ContributionOrder;
    ContributionsCollection: ResolverTypeWrapper<Omit<ContributionsCollection, 'commitContributionsByRepository' | 'firstIssueContribution' | 'firstPullRequestContribution' | 'firstRepositoryContribution' | 'issueContributions' | 'issueContributionsByRepository' | 'joinedGitHubContribution' | 'mostRecentCollectionWithActivity' | 'mostRecentCollectionWithoutActivity' | 'popularIssueContribution' | 'popularPullRequestContribution' | 'pullRequestContributions' | 'pullRequestContributionsByRepository' | 'pullRequestReviewContributions' | 'pullRequestReviewContributionsByRepository' | 'repositoryContributions' | 'user'> & {
        commitContributionsByRepository: Array<ResolversTypes['CommitContributionsByRepository']>;
        firstIssueContribution?: Maybe<ResolversTypes['CreatedIssueOrRestrictedContribution']>;
        firstPullRequestContribution?: Maybe<ResolversTypes['CreatedPullRequestOrRestrictedContribution']>;
        firstRepositoryContribution?: Maybe<ResolversTypes['CreatedRepositoryOrRestrictedContribution']>;
        issueContributions: ResolversTypes['CreatedIssueContributionConnection'];
        issueContributionsByRepository: Array<ResolversTypes['IssueContributionsByRepository']>;
        joinedGitHubContribution?: Maybe<ResolversTypes['JoinedGitHubContribution']>;
        mostRecentCollectionWithActivity?: Maybe<ResolversTypes['ContributionsCollection']>;
        mostRecentCollectionWithoutActivity?: Maybe<ResolversTypes['ContributionsCollection']>;
        popularIssueContribution?: Maybe<ResolversTypes['CreatedIssueContribution']>;
        popularPullRequestContribution?: Maybe<ResolversTypes['CreatedPullRequestContribution']>;
        pullRequestContributions: ResolversTypes['CreatedPullRequestContributionConnection'];
        pullRequestContributionsByRepository: Array<ResolversTypes['PullRequestContributionsByRepository']>;
        pullRequestReviewContributions: ResolversTypes['CreatedPullRequestReviewContributionConnection'];
        pullRequestReviewContributionsByRepository: Array<ResolversTypes['PullRequestReviewContributionsByRepository']>;
        repositoryContributions: ResolversTypes['CreatedRepositoryContributionConnection'];
        user: ResolversTypes['User'];
    }>;
    ConvertProjectCardNoteToIssueInput: ConvertProjectCardNoteToIssueInput;
    ConvertProjectCardNoteToIssuePayload: ResolverTypeWrapper<Omit<ConvertProjectCardNoteToIssuePayload, 'projectCard'> & {
        projectCard?: Maybe<ResolversTypes['ProjectCard']>;
    }>;
    ConvertPullRequestToDraftInput: ConvertPullRequestToDraftInput;
    ConvertPullRequestToDraftPayload: ResolverTypeWrapper<Omit<ConvertPullRequestToDraftPayload, 'pullRequest'> & {
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
    }>;
    ConvertToDraftEvent: ResolverTypeWrapper<Omit<ConvertToDraftEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        pullRequest: ResolversTypes['PullRequest'];
    }>;
    ConvertedNoteToIssueEvent: ResolverTypeWrapper<Omit<ConvertedNoteToIssueEvent, 'actor' | 'project' | 'projectCard'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        project?: Maybe<ResolversTypes['Project']>;
        projectCard?: Maybe<ResolversTypes['ProjectCard']>;
    }>;
    CreateBranchProtectionRuleInput: CreateBranchProtectionRuleInput;
    CreateBranchProtectionRulePayload: ResolverTypeWrapper<Omit<CreateBranchProtectionRulePayload, 'branchProtectionRule'> & {
        branchProtectionRule?: Maybe<ResolversTypes['BranchProtectionRule']>;
    }>;
    CreateCheckRunInput: CreateCheckRunInput;
    CreateCheckRunPayload: ResolverTypeWrapper<Omit<CreateCheckRunPayload, 'checkRun'> & {
        checkRun?: Maybe<ResolversTypes['CheckRun']>;
    }>;
    CreateCheckSuiteInput: CreateCheckSuiteInput;
    CreateCheckSuitePayload: ResolverTypeWrapper<Omit<CreateCheckSuitePayload, 'checkSuite'> & {
        checkSuite?: Maybe<ResolversTypes['CheckSuite']>;
    }>;
    CreateContentAttachmentInput: CreateContentAttachmentInput;
    CreateContentAttachmentPayload: ResolverTypeWrapper<CreateContentAttachmentPayload>;
    CreateDeploymentInput: CreateDeploymentInput;
    CreateDeploymentPayload: ResolverTypeWrapper<Omit<CreateDeploymentPayload, 'deployment'> & {
        deployment?: Maybe<ResolversTypes['Deployment']>;
    }>;
    CreateDeploymentStatusInput: CreateDeploymentStatusInput;
    CreateDeploymentStatusPayload: ResolverTypeWrapper<Omit<CreateDeploymentStatusPayload, 'deploymentStatus'> & {
        deploymentStatus?: Maybe<ResolversTypes['DeploymentStatus']>;
    }>;
    CreateDiscussionInput: CreateDiscussionInput;
    CreateDiscussionPayload: ResolverTypeWrapper<Omit<CreateDiscussionPayload, 'discussion'> & {
        discussion?: Maybe<ResolversTypes['Discussion']>;
    }>;
    CreateEnterpriseOrganizationInput: CreateEnterpriseOrganizationInput;
    CreateEnterpriseOrganizationPayload: ResolverTypeWrapper<Omit<CreateEnterpriseOrganizationPayload, 'enterprise' | 'organization'> & {
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
        organization?: Maybe<ResolversTypes['Organization']>;
    }>;
    CreateEnvironmentInput: CreateEnvironmentInput;
    CreateEnvironmentPayload: ResolverTypeWrapper<Omit<CreateEnvironmentPayload, 'environment'> & {
        environment?: Maybe<ResolversTypes['Environment']>;
    }>;
    CreateIpAllowListEntryInput: CreateIpAllowListEntryInput;
    CreateIpAllowListEntryPayload: ResolverTypeWrapper<Omit<CreateIpAllowListEntryPayload, 'ipAllowListEntry'> & {
        ipAllowListEntry?: Maybe<ResolversTypes['IpAllowListEntry']>;
    }>;
    CreateIssueInput: CreateIssueInput;
    CreateIssuePayload: ResolverTypeWrapper<Omit<CreateIssuePayload, 'issue'> & {
        issue?: Maybe<ResolversTypes['Issue']>;
    }>;
    CreateLabelInput: CreateLabelInput;
    CreateLabelPayload: ResolverTypeWrapper<Omit<CreateLabelPayload, 'label'> & {
        label?: Maybe<ResolversTypes['Label']>;
    }>;
    CreateProjectInput: CreateProjectInput;
    CreateProjectPayload: ResolverTypeWrapper<Omit<CreateProjectPayload, 'project'> & {
        project?: Maybe<ResolversTypes['Project']>;
    }>;
    CreatePullRequestInput: CreatePullRequestInput;
    CreatePullRequestPayload: ResolverTypeWrapper<Omit<CreatePullRequestPayload, 'pullRequest'> & {
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
    }>;
    CreateRefInput: CreateRefInput;
    CreateRefPayload: ResolverTypeWrapper<Omit<CreateRefPayload, 'ref'> & {
        ref?: Maybe<ResolversTypes['Ref']>;
    }>;
    CreateRepositoryInput: CreateRepositoryInput;
    CreateRepositoryPayload: ResolverTypeWrapper<Omit<CreateRepositoryPayload, 'repository'> & {
        repository?: Maybe<ResolversTypes['Repository']>;
    }>;
    CreateTeamDiscussionCommentInput: CreateTeamDiscussionCommentInput;
    CreateTeamDiscussionCommentPayload: ResolverTypeWrapper<Omit<CreateTeamDiscussionCommentPayload, 'teamDiscussionComment'> & {
        teamDiscussionComment?: Maybe<ResolversTypes['TeamDiscussionComment']>;
    }>;
    CreateTeamDiscussionInput: CreateTeamDiscussionInput;
    CreateTeamDiscussionPayload: ResolverTypeWrapper<Omit<CreateTeamDiscussionPayload, 'teamDiscussion'> & {
        teamDiscussion?: Maybe<ResolversTypes['TeamDiscussion']>;
    }>;
    CreatedCommitContribution: ResolverTypeWrapper<Omit<CreatedCommitContribution, 'repository' | 'user'> & {
        repository: ResolversTypes['Repository'];
        user: ResolversTypes['User'];
    }>;
    CreatedCommitContributionConnection: ResolverTypeWrapper<Omit<CreatedCommitContributionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['CreatedCommitContributionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['CreatedCommitContribution']>>>;
    }>;
    CreatedCommitContributionEdge: ResolverTypeWrapper<Omit<CreatedCommitContributionEdge, 'node'> & {
        node?: Maybe<ResolversTypes['CreatedCommitContribution']>;
    }>;
    CreatedIssueContribution: ResolverTypeWrapper<Omit<CreatedIssueContribution, 'issue' | 'user'> & {
        issue: ResolversTypes['Issue'];
        user: ResolversTypes['User'];
    }>;
    CreatedIssueContributionConnection: ResolverTypeWrapper<Omit<CreatedIssueContributionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['CreatedIssueContributionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['CreatedIssueContribution']>>>;
    }>;
    CreatedIssueContributionEdge: ResolverTypeWrapper<Omit<CreatedIssueContributionEdge, 'node'> & {
        node?: Maybe<ResolversTypes['CreatedIssueContribution']>;
    }>;
    CreatedIssueOrRestrictedContribution: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['CreatedIssueOrRestrictedContribution']>;
    CreatedPullRequestContribution: ResolverTypeWrapper<Omit<CreatedPullRequestContribution, 'pullRequest' | 'user'> & {
        pullRequest: ResolversTypes['PullRequest'];
        user: ResolversTypes['User'];
    }>;
    CreatedPullRequestContributionConnection: ResolverTypeWrapper<Omit<CreatedPullRequestContributionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['CreatedPullRequestContributionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['CreatedPullRequestContribution']>>>;
    }>;
    CreatedPullRequestContributionEdge: ResolverTypeWrapper<Omit<CreatedPullRequestContributionEdge, 'node'> & {
        node?: Maybe<ResolversTypes['CreatedPullRequestContribution']>;
    }>;
    CreatedPullRequestOrRestrictedContribution: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['CreatedPullRequestOrRestrictedContribution']>;
    CreatedPullRequestReviewContribution: ResolverTypeWrapper<Omit<CreatedPullRequestReviewContribution, 'pullRequest' | 'pullRequestReview' | 'repository' | 'user'> & {
        pullRequest: ResolversTypes['PullRequest'];
        pullRequestReview: ResolversTypes['PullRequestReview'];
        repository: ResolversTypes['Repository'];
        user: ResolversTypes['User'];
    }>;
    CreatedPullRequestReviewContributionConnection: ResolverTypeWrapper<Omit<CreatedPullRequestReviewContributionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['CreatedPullRequestReviewContributionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['CreatedPullRequestReviewContribution']>>>;
    }>;
    CreatedPullRequestReviewContributionEdge: ResolverTypeWrapper<Omit<CreatedPullRequestReviewContributionEdge, 'node'> & {
        node?: Maybe<ResolversTypes['CreatedPullRequestReviewContribution']>;
    }>;
    CreatedRepositoryContribution: ResolverTypeWrapper<Omit<CreatedRepositoryContribution, 'repository' | 'user'> & {
        repository: ResolversTypes['Repository'];
        user: ResolversTypes['User'];
    }>;
    CreatedRepositoryContributionConnection: ResolverTypeWrapper<Omit<CreatedRepositoryContributionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['CreatedRepositoryContributionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['CreatedRepositoryContribution']>>>;
    }>;
    CreatedRepositoryContributionEdge: ResolverTypeWrapper<Omit<CreatedRepositoryContributionEdge, 'node'> & {
        node?: Maybe<ResolversTypes['CreatedRepositoryContribution']>;
    }>;
    CreatedRepositoryOrRestrictedContribution: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['CreatedRepositoryOrRestrictedContribution']>;
    CrossReferencedEvent: ResolverTypeWrapper<Omit<CrossReferencedEvent, 'actor' | 'source' | 'target'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        source: ResolversTypes['ReferencedSubject'];
        target: ResolversTypes['ReferencedSubject'];
    }>;
    Date: ResolverTypeWrapper<Scalars['Date']['output']>;
    DateTime: ResolverTypeWrapper<Scalars['DateTime']['output']>;
    DefaultRepositoryPermissionField: DefaultRepositoryPermissionField;
    Deletable: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['Deletable']>;
    DeleteBranchProtectionRuleInput: DeleteBranchProtectionRuleInput;
    DeleteBranchProtectionRulePayload: ResolverTypeWrapper<DeleteBranchProtectionRulePayload>;
    DeleteDeploymentInput: DeleteDeploymentInput;
    DeleteDeploymentPayload: ResolverTypeWrapper<DeleteDeploymentPayload>;
    DeleteDiscussionCommentInput: DeleteDiscussionCommentInput;
    DeleteDiscussionCommentPayload: ResolverTypeWrapper<Omit<DeleteDiscussionCommentPayload, 'comment'> & {
        comment?: Maybe<ResolversTypes['DiscussionComment']>;
    }>;
    DeleteDiscussionInput: DeleteDiscussionInput;
    DeleteDiscussionPayload: ResolverTypeWrapper<Omit<DeleteDiscussionPayload, 'discussion'> & {
        discussion?: Maybe<ResolversTypes['Discussion']>;
    }>;
    DeleteEnvironmentInput: DeleteEnvironmentInput;
    DeleteEnvironmentPayload: ResolverTypeWrapper<DeleteEnvironmentPayload>;
    DeleteIpAllowListEntryInput: DeleteIpAllowListEntryInput;
    DeleteIpAllowListEntryPayload: ResolverTypeWrapper<Omit<DeleteIpAllowListEntryPayload, 'ipAllowListEntry'> & {
        ipAllowListEntry?: Maybe<ResolversTypes['IpAllowListEntry']>;
    }>;
    DeleteIssueCommentInput: DeleteIssueCommentInput;
    DeleteIssueCommentPayload: ResolverTypeWrapper<DeleteIssueCommentPayload>;
    DeleteIssueInput: DeleteIssueInput;
    DeleteIssuePayload: ResolverTypeWrapper<Omit<DeleteIssuePayload, 'repository'> & {
        repository?: Maybe<ResolversTypes['Repository']>;
    }>;
    DeleteLabelInput: DeleteLabelInput;
    DeleteLabelPayload: ResolverTypeWrapper<DeleteLabelPayload>;
    DeletePackageVersionInput: DeletePackageVersionInput;
    DeletePackageVersionPayload: ResolverTypeWrapper<DeletePackageVersionPayload>;
    DeleteProjectCardInput: DeleteProjectCardInput;
    DeleteProjectCardPayload: ResolverTypeWrapper<Omit<DeleteProjectCardPayload, 'column'> & {
        column?: Maybe<ResolversTypes['ProjectColumn']>;
    }>;
    DeleteProjectColumnInput: DeleteProjectColumnInput;
    DeleteProjectColumnPayload: ResolverTypeWrapper<Omit<DeleteProjectColumnPayload, 'project'> & {
        project?: Maybe<ResolversTypes['Project']>;
    }>;
    DeleteProjectInput: DeleteProjectInput;
    DeleteProjectPayload: ResolverTypeWrapper<Omit<DeleteProjectPayload, 'owner'> & {
        owner?: Maybe<ResolversTypes['ProjectOwner']>;
    }>;
    DeletePullRequestReviewCommentInput: DeletePullRequestReviewCommentInput;
    DeletePullRequestReviewCommentPayload: ResolverTypeWrapper<Omit<DeletePullRequestReviewCommentPayload, 'pullRequestReview'> & {
        pullRequestReview?: Maybe<ResolversTypes['PullRequestReview']>;
    }>;
    DeletePullRequestReviewInput: DeletePullRequestReviewInput;
    DeletePullRequestReviewPayload: ResolverTypeWrapper<Omit<DeletePullRequestReviewPayload, 'pullRequestReview'> & {
        pullRequestReview?: Maybe<ResolversTypes['PullRequestReview']>;
    }>;
    DeleteRefInput: DeleteRefInput;
    DeleteRefPayload: ResolverTypeWrapper<DeleteRefPayload>;
    DeleteTeamDiscussionCommentInput: DeleteTeamDiscussionCommentInput;
    DeleteTeamDiscussionCommentPayload: ResolverTypeWrapper<DeleteTeamDiscussionCommentPayload>;
    DeleteTeamDiscussionInput: DeleteTeamDiscussionInput;
    DeleteTeamDiscussionPayload: ResolverTypeWrapper<DeleteTeamDiscussionPayload>;
    DeleteVerifiableDomainInput: DeleteVerifiableDomainInput;
    DeleteVerifiableDomainPayload: ResolverTypeWrapper<Omit<DeleteVerifiableDomainPayload, 'owner'> & {
        owner?: Maybe<ResolversTypes['VerifiableDomainOwner']>;
    }>;
    DemilestonedEvent: ResolverTypeWrapper<Omit<DemilestonedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        subject: ResolversTypes['MilestoneItem'];
    }>;
    DeployKey: ResolverTypeWrapper<DeployKey>;
    DeployKeyConnection: ResolverTypeWrapper<DeployKeyConnection>;
    DeployKeyEdge: ResolverTypeWrapper<DeployKeyEdge>;
    DeployedEvent: ResolverTypeWrapper<Omit<DeployedEvent, 'actor' | 'deployment' | 'pullRequest' | 'ref'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        deployment: ResolversTypes['Deployment'];
        pullRequest: ResolversTypes['PullRequest'];
        ref?: Maybe<ResolversTypes['Ref']>;
    }>;
    Deployment: ResolverTypeWrapper<Omit<Deployment, 'commit' | 'creator' | 'latestStatus' | 'ref' | 'repository' | 'statuses'> & {
        commit?: Maybe<ResolversTypes['Commit']>;
        creator: ResolversTypes['Actor'];
        latestStatus?: Maybe<ResolversTypes['DeploymentStatus']>;
        ref?: Maybe<ResolversTypes['Ref']>;
        repository: ResolversTypes['Repository'];
        statuses?: Maybe<ResolversTypes['DeploymentStatusConnection']>;
    }>;
    DeploymentConnection: ResolverTypeWrapper<Omit<DeploymentConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['DeploymentEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Deployment']>>>;
    }>;
    DeploymentEdge: ResolverTypeWrapper<Omit<DeploymentEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Deployment']>;
    }>;
    DeploymentEnvironmentChangedEvent: ResolverTypeWrapper<Omit<DeploymentEnvironmentChangedEvent, 'actor' | 'deploymentStatus' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        deploymentStatus: ResolversTypes['DeploymentStatus'];
        pullRequest: ResolversTypes['PullRequest'];
    }>;
    DeploymentOrder: DeploymentOrder;
    DeploymentOrderField: DeploymentOrderField;
    DeploymentProtectionRule: ResolverTypeWrapper<Omit<DeploymentProtectionRule, 'reviewers'> & {
        reviewers: ResolversTypes['DeploymentReviewerConnection'];
    }>;
    DeploymentProtectionRuleConnection: ResolverTypeWrapper<Omit<DeploymentProtectionRuleConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['DeploymentProtectionRuleEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['DeploymentProtectionRule']>>>;
    }>;
    DeploymentProtectionRuleEdge: ResolverTypeWrapper<Omit<DeploymentProtectionRuleEdge, 'node'> & {
        node?: Maybe<ResolversTypes['DeploymentProtectionRule']>;
    }>;
    DeploymentProtectionRuleType: DeploymentProtectionRuleType;
    DeploymentRequest: ResolverTypeWrapper<Omit<DeploymentRequest, 'environment' | 'reviewers'> & {
        environment: ResolversTypes['Environment'];
        reviewers: ResolversTypes['DeploymentReviewerConnection'];
    }>;
    DeploymentRequestConnection: ResolverTypeWrapper<Omit<DeploymentRequestConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['DeploymentRequestEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['DeploymentRequest']>>>;
    }>;
    DeploymentRequestEdge: ResolverTypeWrapper<Omit<DeploymentRequestEdge, 'node'> & {
        node?: Maybe<ResolversTypes['DeploymentRequest']>;
    }>;
    DeploymentReview: ResolverTypeWrapper<Omit<DeploymentReview, 'environments' | 'user'> & {
        environments: ResolversTypes['EnvironmentConnection'];
        user: ResolversTypes['User'];
    }>;
    DeploymentReviewConnection: ResolverTypeWrapper<Omit<DeploymentReviewConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['DeploymentReviewEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['DeploymentReview']>>>;
    }>;
    DeploymentReviewEdge: ResolverTypeWrapper<Omit<DeploymentReviewEdge, 'node'> & {
        node?: Maybe<ResolversTypes['DeploymentReview']>;
    }>;
    DeploymentReviewState: DeploymentReviewState;
    DeploymentReviewer: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['DeploymentReviewer']>;
    DeploymentReviewerConnection: ResolverTypeWrapper<Omit<DeploymentReviewerConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['DeploymentReviewerEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['DeploymentReviewer']>>>;
    }>;
    DeploymentReviewerEdge: ResolverTypeWrapper<Omit<DeploymentReviewerEdge, 'node'> & {
        node?: Maybe<ResolversTypes['DeploymentReviewer']>;
    }>;
    DeploymentState: DeploymentState;
    DeploymentStatus: ResolverTypeWrapper<Omit<DeploymentStatus, 'creator' | 'deployment'> & {
        creator: ResolversTypes['Actor'];
        deployment: ResolversTypes['Deployment'];
    }>;
    DeploymentStatusConnection: ResolverTypeWrapper<Omit<DeploymentStatusConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['DeploymentStatusEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['DeploymentStatus']>>>;
    }>;
    DeploymentStatusEdge: ResolverTypeWrapper<Omit<DeploymentStatusEdge, 'node'> & {
        node?: Maybe<ResolversTypes['DeploymentStatus']>;
    }>;
    DeploymentStatusState: DeploymentStatusState;
    DiffSide: DiffSide;
    DisablePullRequestAutoMergeInput: DisablePullRequestAutoMergeInput;
    DisablePullRequestAutoMergePayload: ResolverTypeWrapper<Omit<DisablePullRequestAutoMergePayload, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
    }>;
    DisconnectedEvent: ResolverTypeWrapper<Omit<DisconnectedEvent, 'actor' | 'source' | 'subject'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        source: ResolversTypes['ReferencedSubject'];
        subject: ResolversTypes['ReferencedSubject'];
    }>;
    Discussion: ResolverTypeWrapper<Omit<Discussion, 'answer' | 'answerChosenBy' | 'author' | 'category' | 'comments' | 'editor' | 'labels' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        answer?: Maybe<ResolversTypes['DiscussionComment']>;
        answerChosenBy?: Maybe<ResolversTypes['Actor']>;
        author?: Maybe<ResolversTypes['Actor']>;
        category: ResolversTypes['DiscussionCategory'];
        comments: ResolversTypes['DiscussionCommentConnection'];
        editor?: Maybe<ResolversTypes['Actor']>;
        labels?: Maybe<ResolversTypes['LabelConnection']>;
        reactionGroups?: Maybe<Array<ResolversTypes['ReactionGroup']>>;
        reactions: ResolversTypes['ReactionConnection'];
        repository: ResolversTypes['Repository'];
        userContentEdits?: Maybe<ResolversTypes['UserContentEditConnection']>;
    }>;
    DiscussionCategory: ResolverTypeWrapper<Omit<DiscussionCategory, 'repository'> & {
        repository: ResolversTypes['Repository'];
    }>;
    DiscussionCategoryConnection: ResolverTypeWrapper<Omit<DiscussionCategoryConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['DiscussionCategoryEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['DiscussionCategory']>>>;
    }>;
    DiscussionCategoryEdge: ResolverTypeWrapper<Omit<DiscussionCategoryEdge, 'node'> & {
        node?: Maybe<ResolversTypes['DiscussionCategory']>;
    }>;
    DiscussionComment: ResolverTypeWrapper<Omit<DiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'replies' | 'replyTo' | 'userContentEdits'> & {
        author?: Maybe<ResolversTypes['Actor']>;
        discussion?: Maybe<ResolversTypes['Discussion']>;
        editor?: Maybe<ResolversTypes['Actor']>;
        reactionGroups?: Maybe<Array<ResolversTypes['ReactionGroup']>>;
        reactions: ResolversTypes['ReactionConnection'];
        replies: ResolversTypes['DiscussionCommentConnection'];
        replyTo?: Maybe<ResolversTypes['DiscussionComment']>;
        userContentEdits?: Maybe<ResolversTypes['UserContentEditConnection']>;
    }>;
    DiscussionCommentConnection: ResolverTypeWrapper<Omit<DiscussionCommentConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['DiscussionCommentEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['DiscussionComment']>>>;
    }>;
    DiscussionCommentEdge: ResolverTypeWrapper<Omit<DiscussionCommentEdge, 'node'> & {
        node?: Maybe<ResolversTypes['DiscussionComment']>;
    }>;
    DiscussionConnection: ResolverTypeWrapper<Omit<DiscussionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['DiscussionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Discussion']>>>;
    }>;
    DiscussionEdge: ResolverTypeWrapper<Omit<DiscussionEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Discussion']>;
    }>;
    DiscussionOrder: DiscussionOrder;
    DiscussionOrderField: DiscussionOrderField;
    DismissPullRequestReviewInput: DismissPullRequestReviewInput;
    DismissPullRequestReviewPayload: ResolverTypeWrapper<Omit<DismissPullRequestReviewPayload, 'pullRequestReview'> & {
        pullRequestReview?: Maybe<ResolversTypes['PullRequestReview']>;
    }>;
    DraftPullRequestReviewComment: DraftPullRequestReviewComment;
    DraftPullRequestReviewThread: DraftPullRequestReviewThread;
    EnablePullRequestAutoMergeInput: EnablePullRequestAutoMergeInput;
    EnablePullRequestAutoMergePayload: ResolverTypeWrapper<Omit<EnablePullRequestAutoMergePayload, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
    }>;
    Enterprise: ResolverTypeWrapper<Omit<Enterprise, 'billingInfo' | 'members' | 'organizations' | 'ownerInfo' | 'userAccounts'> & {
        billingInfo?: Maybe<ResolversTypes['EnterpriseBillingInfo']>;
        members: ResolversTypes['EnterpriseMemberConnection'];
        organizations: ResolversTypes['OrganizationConnection'];
        ownerInfo?: Maybe<ResolversTypes['EnterpriseOwnerInfo']>;
        userAccounts: ResolversTypes['EnterpriseUserAccountConnection'];
    }>;
    EnterpriseAdministratorConnection: ResolverTypeWrapper<Omit<EnterpriseAdministratorConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['EnterpriseAdministratorEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['User']>>>;
    }>;
    EnterpriseAdministratorEdge: ResolverTypeWrapper<Omit<EnterpriseAdministratorEdge, 'node'> & {
        node?: Maybe<ResolversTypes['User']>;
    }>;
    EnterpriseAdministratorInvitation: ResolverTypeWrapper<Omit<EnterpriseAdministratorInvitation, 'enterprise' | 'invitee' | 'inviter'> & {
        enterprise: ResolversTypes['Enterprise'];
        invitee?: Maybe<ResolversTypes['User']>;
        inviter?: Maybe<ResolversTypes['User']>;
    }>;
    EnterpriseAdministratorInvitationConnection: ResolverTypeWrapper<Omit<EnterpriseAdministratorInvitationConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['EnterpriseAdministratorInvitationEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['EnterpriseAdministratorInvitation']>>>;
    }>;
    EnterpriseAdministratorInvitationEdge: ResolverTypeWrapper<Omit<EnterpriseAdministratorInvitationEdge, 'node'> & {
        node?: Maybe<ResolversTypes['EnterpriseAdministratorInvitation']>;
    }>;
    EnterpriseAdministratorInvitationOrder: EnterpriseAdministratorInvitationOrder;
    EnterpriseAdministratorInvitationOrderField: EnterpriseAdministratorInvitationOrderField;
    EnterpriseAdministratorRole: EnterpriseAdministratorRole;
    EnterpriseAuditEntryData: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['EnterpriseAuditEntryData']>;
    EnterpriseBillingInfo: ResolverTypeWrapper<EnterpriseBillingInfo>;
    EnterpriseDefaultRepositoryPermissionSettingValue: EnterpriseDefaultRepositoryPermissionSettingValue;
    EnterpriseEnabledDisabledSettingValue: EnterpriseEnabledDisabledSettingValue;
    EnterpriseEnabledSettingValue: EnterpriseEnabledSettingValue;
    EnterpriseIdentityProvider: ResolverTypeWrapper<Omit<EnterpriseIdentityProvider, 'enterprise' | 'externalIdentities'> & {
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
        externalIdentities: ResolversTypes['ExternalIdentityConnection'];
    }>;
    EnterpriseMember: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['EnterpriseMember']>;
    EnterpriseMemberConnection: ResolverTypeWrapper<Omit<EnterpriseMemberConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['EnterpriseMemberEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['EnterpriseMember']>>>;
    }>;
    EnterpriseMemberEdge: ResolverTypeWrapper<Omit<EnterpriseMemberEdge, 'node'> & {
        node?: Maybe<ResolversTypes['EnterpriseMember']>;
    }>;
    EnterpriseMemberOrder: EnterpriseMemberOrder;
    EnterpriseMemberOrderField: EnterpriseMemberOrderField;
    EnterpriseMembersCanCreateRepositoriesSettingValue: EnterpriseMembersCanCreateRepositoriesSettingValue;
    EnterpriseMembersCanMakePurchasesSettingValue: EnterpriseMembersCanMakePurchasesSettingValue;
    EnterpriseOrganizationMembershipConnection: ResolverTypeWrapper<Omit<EnterpriseOrganizationMembershipConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['EnterpriseOrganizationMembershipEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Organization']>>>;
    }>;
    EnterpriseOrganizationMembershipEdge: ResolverTypeWrapper<Omit<EnterpriseOrganizationMembershipEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Organization']>;
    }>;
    EnterpriseOutsideCollaboratorConnection: ResolverTypeWrapper<Omit<EnterpriseOutsideCollaboratorConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['EnterpriseOutsideCollaboratorEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['User']>>>;
    }>;
    EnterpriseOutsideCollaboratorEdge: ResolverTypeWrapper<Omit<EnterpriseOutsideCollaboratorEdge, 'node'> & {
        node?: Maybe<ResolversTypes['User']>;
    }>;
    EnterpriseOwnerInfo: ResolverTypeWrapper<Omit<EnterpriseOwnerInfo, 'admins' | 'affiliatedUsersWithTwoFactorDisabled' | 'allowPrivateRepositoryForkingSettingOrganizations' | 'defaultRepositoryPermissionSettingOrganizations' | 'domains' | 'ipAllowListEntries' | 'membersCanChangeRepositoryVisibilitySettingOrganizations' | 'membersCanCreateRepositoriesSettingOrganizations' | 'membersCanDeleteIssuesSettingOrganizations' | 'membersCanDeleteRepositoriesSettingOrganizations' | 'membersCanInviteCollaboratorsSettingOrganizations' | 'membersCanUpdateProtectedBranchesSettingOrganizations' | 'membersCanViewDependencyInsightsSettingOrganizations' | 'organizationProjectsSettingOrganizations' | 'outsideCollaborators' | 'pendingAdminInvitations' | 'pendingCollaboratorInvitations' | 'pendingCollaborators' | 'pendingMemberInvitations' | 'repositoryProjectsSettingOrganizations' | 'samlIdentityProvider' | 'samlIdentityProviderSettingOrganizations' | 'teamDiscussionsSettingOrganizations' | 'twoFactorRequiredSettingOrganizations'> & {
        admins: ResolversTypes['EnterpriseAdministratorConnection'];
        affiliatedUsersWithTwoFactorDisabled: ResolversTypes['UserConnection'];
        allowPrivateRepositoryForkingSettingOrganizations: ResolversTypes['OrganizationConnection'];
        defaultRepositoryPermissionSettingOrganizations: ResolversTypes['OrganizationConnection'];
        domains: ResolversTypes['VerifiableDomainConnection'];
        ipAllowListEntries: ResolversTypes['IpAllowListEntryConnection'];
        membersCanChangeRepositoryVisibilitySettingOrganizations: ResolversTypes['OrganizationConnection'];
        membersCanCreateRepositoriesSettingOrganizations: ResolversTypes['OrganizationConnection'];
        membersCanDeleteIssuesSettingOrganizations: ResolversTypes['OrganizationConnection'];
        membersCanDeleteRepositoriesSettingOrganizations: ResolversTypes['OrganizationConnection'];
        membersCanInviteCollaboratorsSettingOrganizations: ResolversTypes['OrganizationConnection'];
        membersCanUpdateProtectedBranchesSettingOrganizations: ResolversTypes['OrganizationConnection'];
        membersCanViewDependencyInsightsSettingOrganizations: ResolversTypes['OrganizationConnection'];
        organizationProjectsSettingOrganizations: ResolversTypes['OrganizationConnection'];
        outsideCollaborators: ResolversTypes['EnterpriseOutsideCollaboratorConnection'];
        pendingAdminInvitations: ResolversTypes['EnterpriseAdministratorInvitationConnection'];
        pendingCollaboratorInvitations: ResolversTypes['RepositoryInvitationConnection'];
        pendingCollaborators: ResolversTypes['EnterprisePendingCollaboratorConnection'];
        pendingMemberInvitations: ResolversTypes['EnterprisePendingMemberInvitationConnection'];
        repositoryProjectsSettingOrganizations: ResolversTypes['OrganizationConnection'];
        samlIdentityProvider?: Maybe<ResolversTypes['EnterpriseIdentityProvider']>;
        samlIdentityProviderSettingOrganizations: ResolversTypes['OrganizationConnection'];
        teamDiscussionsSettingOrganizations: ResolversTypes['OrganizationConnection'];
        twoFactorRequiredSettingOrganizations: ResolversTypes['OrganizationConnection'];
    }>;
    EnterprisePendingCollaboratorConnection: ResolverTypeWrapper<Omit<EnterprisePendingCollaboratorConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['EnterprisePendingCollaboratorEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['User']>>>;
    }>;
    EnterprisePendingCollaboratorEdge: ResolverTypeWrapper<Omit<EnterprisePendingCollaboratorEdge, 'node'> & {
        node?: Maybe<ResolversTypes['User']>;
    }>;
    EnterprisePendingMemberInvitationConnection: ResolverTypeWrapper<Omit<EnterprisePendingMemberInvitationConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['EnterprisePendingMemberInvitationEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['OrganizationInvitation']>>>;
    }>;
    EnterprisePendingMemberInvitationEdge: ResolverTypeWrapper<Omit<EnterprisePendingMemberInvitationEdge, 'node'> & {
        node?: Maybe<ResolversTypes['OrganizationInvitation']>;
    }>;
    EnterpriseRepositoryInfo: ResolverTypeWrapper<EnterpriseRepositoryInfo>;
    EnterpriseRepositoryInfoConnection: ResolverTypeWrapper<EnterpriseRepositoryInfoConnection>;
    EnterpriseRepositoryInfoEdge: ResolverTypeWrapper<EnterpriseRepositoryInfoEdge>;
    EnterpriseServerInstallation: ResolverTypeWrapper<Omit<EnterpriseServerInstallation, 'userAccounts' | 'userAccountsUploads'> & {
        userAccounts: ResolversTypes['EnterpriseServerUserAccountConnection'];
        userAccountsUploads: ResolversTypes['EnterpriseServerUserAccountsUploadConnection'];
    }>;
    EnterpriseServerUserAccount: ResolverTypeWrapper<Omit<EnterpriseServerUserAccount, 'enterpriseServerInstallation'> & {
        enterpriseServerInstallation: ResolversTypes['EnterpriseServerInstallation'];
    }>;
    EnterpriseServerUserAccountConnection: ResolverTypeWrapper<Omit<EnterpriseServerUserAccountConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['EnterpriseServerUserAccountEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['EnterpriseServerUserAccount']>>>;
    }>;
    EnterpriseServerUserAccountEdge: ResolverTypeWrapper<Omit<EnterpriseServerUserAccountEdge, 'node'> & {
        node?: Maybe<ResolversTypes['EnterpriseServerUserAccount']>;
    }>;
    EnterpriseServerUserAccountEmail: ResolverTypeWrapper<Omit<EnterpriseServerUserAccountEmail, 'userAccount'> & {
        userAccount: ResolversTypes['EnterpriseServerUserAccount'];
    }>;
    EnterpriseServerUserAccountEmailConnection: ResolverTypeWrapper<EnterpriseServerUserAccountEmailConnection>;
    EnterpriseServerUserAccountEmailEdge: ResolverTypeWrapper<EnterpriseServerUserAccountEmailEdge>;
    EnterpriseServerUserAccountEmailOrder: EnterpriseServerUserAccountEmailOrder;
    EnterpriseServerUserAccountEmailOrderField: EnterpriseServerUserAccountEmailOrderField;
    EnterpriseServerUserAccountOrder: EnterpriseServerUserAccountOrder;
    EnterpriseServerUserAccountOrderField: EnterpriseServerUserAccountOrderField;
    EnterpriseServerUserAccountsUpload: ResolverTypeWrapper<Omit<EnterpriseServerUserAccountsUpload, 'enterprise' | 'enterpriseServerInstallation'> & {
        enterprise: ResolversTypes['Enterprise'];
        enterpriseServerInstallation: ResolversTypes['EnterpriseServerInstallation'];
    }>;
    EnterpriseServerUserAccountsUploadConnection: ResolverTypeWrapper<Omit<EnterpriseServerUserAccountsUploadConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['EnterpriseServerUserAccountsUploadEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['EnterpriseServerUserAccountsUpload']>>>;
    }>;
    EnterpriseServerUserAccountsUploadEdge: ResolverTypeWrapper<Omit<EnterpriseServerUserAccountsUploadEdge, 'node'> & {
        node?: Maybe<ResolversTypes['EnterpriseServerUserAccountsUpload']>;
    }>;
    EnterpriseServerUserAccountsUploadOrder: EnterpriseServerUserAccountsUploadOrder;
    EnterpriseServerUserAccountsUploadOrderField: EnterpriseServerUserAccountsUploadOrderField;
    EnterpriseServerUserAccountsUploadSyncState: EnterpriseServerUserAccountsUploadSyncState;
    EnterpriseUserAccount: ResolverTypeWrapper<Omit<EnterpriseUserAccount, 'enterprise' | 'organizations' | 'user'> & {
        enterprise: ResolversTypes['Enterprise'];
        organizations: ResolversTypes['EnterpriseOrganizationMembershipConnection'];
        user?: Maybe<ResolversTypes['User']>;
    }>;
    EnterpriseUserAccountConnection: ResolverTypeWrapper<Omit<EnterpriseUserAccountConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['EnterpriseUserAccountEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['EnterpriseUserAccount']>>>;
    }>;
    EnterpriseUserAccountEdge: ResolverTypeWrapper<Omit<EnterpriseUserAccountEdge, 'node'> & {
        node?: Maybe<ResolversTypes['EnterpriseUserAccount']>;
    }>;
    EnterpriseUserAccountMembershipRole: EnterpriseUserAccountMembershipRole;
    EnterpriseUserDeployment: EnterpriseUserDeployment;
    Environment: ResolverTypeWrapper<Omit<Environment, 'protectionRules'> & {
        protectionRules: ResolversTypes['DeploymentProtectionRuleConnection'];
    }>;
    EnvironmentConnection: ResolverTypeWrapper<Omit<EnvironmentConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['EnvironmentEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Environment']>>>;
    }>;
    EnvironmentEdge: ResolverTypeWrapper<Omit<EnvironmentEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Environment']>;
    }>;
    ExternalIdentity: ResolverTypeWrapper<Omit<ExternalIdentity, 'organizationInvitation' | 'user'> & {
        organizationInvitation?: Maybe<ResolversTypes['OrganizationInvitation']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    ExternalIdentityConnection: ResolverTypeWrapper<Omit<ExternalIdentityConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['ExternalIdentityEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['ExternalIdentity']>>>;
    }>;
    ExternalIdentityEdge: ResolverTypeWrapper<Omit<ExternalIdentityEdge, 'node'> & {
        node?: Maybe<ResolversTypes['ExternalIdentity']>;
    }>;
    ExternalIdentitySamlAttributes: ResolverTypeWrapper<ExternalIdentitySamlAttributes>;
    ExternalIdentityScimAttributes: ResolverTypeWrapper<ExternalIdentityScimAttributes>;
    FileViewedState: FileViewedState;
    Float: ResolverTypeWrapper<Scalars['Float']['output']>;
    FollowUserInput: FollowUserInput;
    FollowUserPayload: ResolverTypeWrapper<Omit<FollowUserPayload, 'user'> & {
        user?: Maybe<ResolversTypes['User']>;
    }>;
    FollowerConnection: ResolverTypeWrapper<Omit<FollowerConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['UserEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['User']>>>;
    }>;
    FollowingConnection: ResolverTypeWrapper<Omit<FollowingConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['UserEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['User']>>>;
    }>;
    GenericHovercardContext: ResolverTypeWrapper<GenericHovercardContext>;
    Gist: ResolverTypeWrapper<Omit<Gist, 'comments' | 'forks' | 'owner'> & {
        comments: ResolversTypes['GistCommentConnection'];
        forks: ResolversTypes['GistConnection'];
        owner?: Maybe<ResolversTypes['RepositoryOwner']>;
    }>;
    GistComment: ResolverTypeWrapper<Omit<GistComment, 'author' | 'editor' | 'gist' | 'userContentEdits'> & {
        author?: Maybe<ResolversTypes['Actor']>;
        editor?: Maybe<ResolversTypes['Actor']>;
        gist: ResolversTypes['Gist'];
        userContentEdits?: Maybe<ResolversTypes['UserContentEditConnection']>;
    }>;
    GistCommentConnection: ResolverTypeWrapper<Omit<GistCommentConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['GistCommentEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['GistComment']>>>;
    }>;
    GistCommentEdge: ResolverTypeWrapper<Omit<GistCommentEdge, 'node'> & {
        node?: Maybe<ResolversTypes['GistComment']>;
    }>;
    GistConnection: ResolverTypeWrapper<Omit<GistConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['GistEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Gist']>>>;
    }>;
    GistEdge: ResolverTypeWrapper<Omit<GistEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Gist']>;
    }>;
    GistFile: ResolverTypeWrapper<GistFile>;
    GistOrder: GistOrder;
    GistOrderField: GistOrderField;
    GistPrivacy: GistPrivacy;
    GitActor: ResolverTypeWrapper<Omit<GitActor, 'user'> & {
        user?: Maybe<ResolversTypes['User']>;
    }>;
    GitActorConnection: ResolverTypeWrapper<GitActorConnection>;
    GitActorEdge: ResolverTypeWrapper<GitActorEdge>;
    GitHubMetadata: ResolverTypeWrapper<GitHubMetadata>;
    GitObject: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['GitObject']>;
    GitObjectID: ResolverTypeWrapper<Scalars['GitObjectID']['output']>;
    GitRefname: ResolverTypeWrapper<Scalars['GitRefname']['output']>;
    GitSSHRemote: ResolverTypeWrapper<Scalars['GitSSHRemote']['output']>;
    GitSignature: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['GitSignature']>;
    GitSignatureState: GitSignatureState;
    GitTimestamp: ResolverTypeWrapper<Scalars['GitTimestamp']['output']>;
    GpgSignature: ResolverTypeWrapper<Omit<GpgSignature, 'signer'> & {
        signer?: Maybe<ResolversTypes['User']>;
    }>;
    HTML: ResolverTypeWrapper<Scalars['HTML']['output']>;
    HeadRefDeletedEvent: ResolverTypeWrapper<Omit<HeadRefDeletedEvent, 'actor' | 'headRef' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        headRef?: Maybe<ResolversTypes['Ref']>;
        pullRequest: ResolversTypes['PullRequest'];
    }>;
    HeadRefForcePushedEvent: ResolverTypeWrapper<Omit<HeadRefForcePushedEvent, 'actor' | 'afterCommit' | 'beforeCommit' | 'pullRequest' | 'ref'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        afterCommit?: Maybe<ResolversTypes['Commit']>;
        beforeCommit?: Maybe<ResolversTypes['Commit']>;
        pullRequest: ResolversTypes['PullRequest'];
        ref?: Maybe<ResolversTypes['Ref']>;
    }>;
    HeadRefRestoredEvent: ResolverTypeWrapper<Omit<HeadRefRestoredEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        pullRequest: ResolversTypes['PullRequest'];
    }>;
    Hovercard: ResolverTypeWrapper<Omit<Hovercard, 'contexts'> & {
        contexts: Array<ResolversTypes['HovercardContext']>;
    }>;
    HovercardContext: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['HovercardContext']>;
    ID: ResolverTypeWrapper<Scalars['ID']['output']>;
    IdentityProviderConfigurationState: IdentityProviderConfigurationState;
    ImportProjectInput: ImportProjectInput;
    ImportProjectPayload: ResolverTypeWrapper<Omit<ImportProjectPayload, 'project'> & {
        project?: Maybe<ResolversTypes['Project']>;
    }>;
    Int: ResolverTypeWrapper<Scalars['Int']['output']>;
    IpAllowListEnabledSettingValue: IpAllowListEnabledSettingValue;
    IpAllowListEntry: ResolverTypeWrapper<Omit<IpAllowListEntry, 'owner'> & {
        owner: ResolversTypes['IpAllowListOwner'];
    }>;
    IpAllowListEntryConnection: ResolverTypeWrapper<Omit<IpAllowListEntryConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['IpAllowListEntryEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['IpAllowListEntry']>>>;
    }>;
    IpAllowListEntryEdge: ResolverTypeWrapper<Omit<IpAllowListEntryEdge, 'node'> & {
        node?: Maybe<ResolversTypes['IpAllowListEntry']>;
    }>;
    IpAllowListEntryOrder: IpAllowListEntryOrder;
    IpAllowListEntryOrderField: IpAllowListEntryOrderField;
    IpAllowListForInstalledAppsEnabledSettingValue: IpAllowListForInstalledAppsEnabledSettingValue;
    IpAllowListOwner: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['IpAllowListOwner']>;
    Issue: ResolverTypeWrapper<Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: ResolversTypes['UserConnection'];
        author?: Maybe<ResolversTypes['Actor']>;
        comments: ResolversTypes['IssueCommentConnection'];
        editor?: Maybe<ResolversTypes['Actor']>;
        hovercard: ResolversTypes['Hovercard'];
        labels?: Maybe<ResolversTypes['LabelConnection']>;
        milestone?: Maybe<ResolversTypes['Milestone']>;
        participants: ResolversTypes['UserConnection'];
        projectCards: ResolversTypes['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<ResolversTypes['ReactionGroup']>>;
        reactions: ResolversTypes['ReactionConnection'];
        repository: ResolversTypes['Repository'];
        timeline: ResolversTypes['IssueTimelineConnection'];
        timelineItems: ResolversTypes['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<ResolversTypes['UserContentEditConnection']>;
    }>;
    IssueComment: ResolverTypeWrapper<Omit<IssueComment, 'author' | 'editor' | 'issue' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<ResolversTypes['Actor']>;
        editor?: Maybe<ResolversTypes['Actor']>;
        issue: ResolversTypes['Issue'];
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
        reactionGroups?: Maybe<Array<ResolversTypes['ReactionGroup']>>;
        reactions: ResolversTypes['ReactionConnection'];
        repository: ResolversTypes['Repository'];
        userContentEdits?: Maybe<ResolversTypes['UserContentEditConnection']>;
    }>;
    IssueCommentConnection: ResolverTypeWrapper<Omit<IssueCommentConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['IssueCommentEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['IssueComment']>>>;
    }>;
    IssueCommentEdge: ResolverTypeWrapper<Omit<IssueCommentEdge, 'node'> & {
        node?: Maybe<ResolversTypes['IssueComment']>;
    }>;
    IssueCommentOrder: IssueCommentOrder;
    IssueCommentOrderField: IssueCommentOrderField;
    IssueConnection: ResolverTypeWrapper<Omit<IssueConnection, 'nodes'> & {
        nodes?: Maybe<Array<Maybe<ResolversTypes['Issue']>>>;
    }>;
    IssueContributionsByRepository: ResolverTypeWrapper<Omit<IssueContributionsByRepository, 'contributions' | 'repository'> & {
        contributions: ResolversTypes['CreatedIssueContributionConnection'];
        repository: ResolversTypes['Repository'];
    }>;
    IssueEdge: ResolverTypeWrapper<Omit<IssueEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Issue']>;
    }>;
    IssueFilters: IssueFilters;
    IssueOrPullRequest: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['IssueOrPullRequest']>;
    IssueOrder: IssueOrder;
    IssueOrderField: IssueOrderField;
    IssueState: IssueState;
    IssueTemplate: ResolverTypeWrapper<IssueTemplate>;
    IssueTimelineConnection: ResolverTypeWrapper<Omit<IssueTimelineConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['IssueTimelineItemEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['IssueTimelineItem']>>>;
    }>;
    IssueTimelineItem: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['IssueTimelineItem']>;
    IssueTimelineItemEdge: ResolverTypeWrapper<Omit<IssueTimelineItemEdge, 'node'> & {
        node?: Maybe<ResolversTypes['IssueTimelineItem']>;
    }>;
    IssueTimelineItems: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['IssueTimelineItems']>;
    IssueTimelineItemsConnection: ResolverTypeWrapper<Omit<IssueTimelineItemsConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['IssueTimelineItemsEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['IssueTimelineItems']>>>;
    }>;
    IssueTimelineItemsEdge: ResolverTypeWrapper<Omit<IssueTimelineItemsEdge, 'node'> & {
        node?: Maybe<ResolversTypes['IssueTimelineItems']>;
    }>;
    IssueTimelineItemsItemType: IssueTimelineItemsItemType;
    JoinedGitHubContribution: ResolverTypeWrapper<Omit<JoinedGitHubContribution, 'user'> & {
        user: ResolversTypes['User'];
    }>;
    Label: ResolverTypeWrapper<Omit<Label, 'pullRequests' | 'repository'> & {
        pullRequests: ResolversTypes['PullRequestConnection'];
        repository: ResolversTypes['Repository'];
    }>;
    LabelConnection: ResolverTypeWrapper<Omit<LabelConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['LabelEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Label']>>>;
    }>;
    LabelEdge: ResolverTypeWrapper<Omit<LabelEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Label']>;
    }>;
    LabelOrder: LabelOrder;
    LabelOrderField: LabelOrderField;
    Labelable: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['Labelable']>;
    LabeledEvent: ResolverTypeWrapper<Omit<LabeledEvent, 'actor' | 'label' | 'labelable'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        label: ResolversTypes['Label'];
        labelable: ResolversTypes['Labelable'];
    }>;
    Language: ResolverTypeWrapper<Language>;
    LanguageConnection: ResolverTypeWrapper<LanguageConnection>;
    LanguageEdge: ResolverTypeWrapper<LanguageEdge>;
    LanguageOrder: LanguageOrder;
    LanguageOrderField: LanguageOrderField;
    License: ResolverTypeWrapper<License>;
    LicenseRule: ResolverTypeWrapper<LicenseRule>;
    LinkRepositoryToProjectInput: LinkRepositoryToProjectInput;
    LinkRepositoryToProjectPayload: ResolverTypeWrapper<Omit<LinkRepositoryToProjectPayload, 'project' | 'repository'> & {
        project?: Maybe<ResolversTypes['Project']>;
        repository?: Maybe<ResolversTypes['Repository']>;
    }>;
    LockLockableInput: LockLockableInput;
    LockLockablePayload: ResolverTypeWrapper<Omit<LockLockablePayload, 'actor' | 'lockedRecord'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        lockedRecord?: Maybe<ResolversTypes['Lockable']>;
    }>;
    LockReason: LockReason;
    Lockable: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['Lockable']>;
    LockedEvent: ResolverTypeWrapper<Omit<LockedEvent, 'actor' | 'lockable'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        lockable: ResolversTypes['Lockable'];
    }>;
    Mannequin: ResolverTypeWrapper<Omit<Mannequin, 'claimant'> & {
        claimant?: Maybe<ResolversTypes['User']>;
    }>;
    MarkDiscussionCommentAsAnswerInput: MarkDiscussionCommentAsAnswerInput;
    MarkDiscussionCommentAsAnswerPayload: ResolverTypeWrapper<Omit<MarkDiscussionCommentAsAnswerPayload, 'discussion'> & {
        discussion?: Maybe<ResolversTypes['Discussion']>;
    }>;
    MarkFileAsViewedInput: MarkFileAsViewedInput;
    MarkFileAsViewedPayload: ResolverTypeWrapper<Omit<MarkFileAsViewedPayload, 'pullRequest'> & {
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
    }>;
    MarkPullRequestReadyForReviewInput: MarkPullRequestReadyForReviewInput;
    MarkPullRequestReadyForReviewPayload: ResolverTypeWrapper<Omit<MarkPullRequestReadyForReviewPayload, 'pullRequest'> & {
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
    }>;
    MarkedAsDuplicateEvent: ResolverTypeWrapper<Omit<MarkedAsDuplicateEvent, 'actor' | 'canonical' | 'duplicate'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        canonical?: Maybe<ResolversTypes['IssueOrPullRequest']>;
        duplicate?: Maybe<ResolversTypes['IssueOrPullRequest']>;
    }>;
    MemberStatusable: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['MemberStatusable']>;
    MembersCanDeleteReposClearAuditEntry: ResolverTypeWrapper<Omit<MembersCanDeleteReposClearAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    MembersCanDeleteReposDisableAuditEntry: ResolverTypeWrapper<Omit<MembersCanDeleteReposDisableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    MembersCanDeleteReposEnableAuditEntry: ResolverTypeWrapper<Omit<MembersCanDeleteReposEnableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    MentionedEvent: ResolverTypeWrapper<Omit<MentionedEvent, 'actor'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
    }>;
    MergeBranchInput: MergeBranchInput;
    MergeBranchPayload: ResolverTypeWrapper<Omit<MergeBranchPayload, 'mergeCommit'> & {
        mergeCommit?: Maybe<ResolversTypes['Commit']>;
    }>;
    MergePullRequestInput: MergePullRequestInput;
    MergePullRequestPayload: ResolverTypeWrapper<Omit<MergePullRequestPayload, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
    }>;
    MergeStateStatus: MergeStateStatus;
    MergeableState: MergeableState;
    MergedEvent: ResolverTypeWrapper<Omit<MergedEvent, 'actor' | 'commit' | 'mergeRef' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        commit?: Maybe<ResolversTypes['Commit']>;
        mergeRef?: Maybe<ResolversTypes['Ref']>;
        pullRequest: ResolversTypes['PullRequest'];
    }>;
    Milestone: ResolverTypeWrapper<Omit<Milestone, 'creator' | 'pullRequests' | 'repository'> & {
        creator?: Maybe<ResolversTypes['Actor']>;
        pullRequests: ResolversTypes['PullRequestConnection'];
        repository: ResolversTypes['Repository'];
    }>;
    MilestoneConnection: ResolverTypeWrapper<Omit<MilestoneConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['MilestoneEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Milestone']>>>;
    }>;
    MilestoneEdge: ResolverTypeWrapper<Omit<MilestoneEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Milestone']>;
    }>;
    MilestoneItem: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['MilestoneItem']>;
    MilestoneOrder: MilestoneOrder;
    MilestoneOrderField: MilestoneOrderField;
    MilestoneState: MilestoneState;
    MilestonedEvent: ResolverTypeWrapper<Omit<MilestonedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        subject: ResolversTypes['MilestoneItem'];
    }>;
    Minimizable: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['Minimizable']>;
    MinimizeCommentInput: MinimizeCommentInput;
    MinimizeCommentPayload: ResolverTypeWrapper<Omit<MinimizeCommentPayload, 'minimizedComment'> & {
        minimizedComment?: Maybe<ResolversTypes['Minimizable']>;
    }>;
    MoveProjectCardInput: MoveProjectCardInput;
    MoveProjectCardPayload: ResolverTypeWrapper<Omit<MoveProjectCardPayload, 'cardEdge'> & {
        cardEdge?: Maybe<ResolversTypes['ProjectCardEdge']>;
    }>;
    MoveProjectColumnInput: MoveProjectColumnInput;
    MoveProjectColumnPayload: ResolverTypeWrapper<Omit<MoveProjectColumnPayload, 'columnEdge'> & {
        columnEdge?: Maybe<ResolversTypes['ProjectColumnEdge']>;
    }>;
    MovedColumnsInProjectEvent: ResolverTypeWrapper<Omit<MovedColumnsInProjectEvent, 'actor' | 'project' | 'projectCard'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        project?: Maybe<ResolversTypes['Project']>;
        projectCard?: Maybe<ResolversTypes['ProjectCard']>;
    }>;
    Mutation: ResolverTypeWrapper<{}>;
    Node: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['Node']>;
    NotificationRestrictionSettingValue: NotificationRestrictionSettingValue;
    OauthApplicationAuditEntryData: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['OauthApplicationAuditEntryData']>;
    OauthApplicationCreateAuditEntry: ResolverTypeWrapper<Omit<OauthApplicationCreateAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OauthApplicationCreateAuditEntryState: OauthApplicationCreateAuditEntryState;
    OperationType: OperationType;
    OrderDirection: OrderDirection;
    OrgAddBillingManagerAuditEntry: ResolverTypeWrapper<Omit<OrgAddBillingManagerAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgAddMemberAuditEntry: ResolverTypeWrapper<Omit<OrgAddMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgAddMemberAuditEntryPermission: OrgAddMemberAuditEntryPermission;
    OrgBlockUserAuditEntry: ResolverTypeWrapper<Omit<OrgBlockUserAuditEntry, 'actor' | 'blockedUser' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        blockedUser?: Maybe<ResolversTypes['User']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgConfigDisableCollaboratorsOnlyAuditEntry: ResolverTypeWrapper<Omit<OrgConfigDisableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgConfigEnableCollaboratorsOnlyAuditEntry: ResolverTypeWrapper<Omit<OrgConfigEnableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgCreateAuditEntry: ResolverTypeWrapper<Omit<OrgCreateAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgCreateAuditEntryBillingPlan: OrgCreateAuditEntryBillingPlan;
    OrgDisableOauthAppRestrictionsAuditEntry: ResolverTypeWrapper<Omit<OrgDisableOauthAppRestrictionsAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgDisableSamlAuditEntry: ResolverTypeWrapper<Omit<OrgDisableSamlAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgDisableTwoFactorRequirementAuditEntry: ResolverTypeWrapper<Omit<OrgDisableTwoFactorRequirementAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgEnableOauthAppRestrictionsAuditEntry: ResolverTypeWrapper<Omit<OrgEnableOauthAppRestrictionsAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgEnableSamlAuditEntry: ResolverTypeWrapper<Omit<OrgEnableSamlAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgEnableTwoFactorRequirementAuditEntry: ResolverTypeWrapper<Omit<OrgEnableTwoFactorRequirementAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgInviteMemberAuditEntry: ResolverTypeWrapper<Omit<OrgInviteMemberAuditEntry, 'actor' | 'organization' | 'organizationInvitation' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        organizationInvitation?: Maybe<ResolversTypes['OrganizationInvitation']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgInviteToBusinessAuditEntry: ResolverTypeWrapper<Omit<OrgInviteToBusinessAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgOauthAppAccessApprovedAuditEntry: ResolverTypeWrapper<Omit<OrgOauthAppAccessApprovedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgOauthAppAccessDeniedAuditEntry: ResolverTypeWrapper<Omit<OrgOauthAppAccessDeniedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgOauthAppAccessRequestedAuditEntry: ResolverTypeWrapper<Omit<OrgOauthAppAccessRequestedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgRemoveBillingManagerAuditEntry: ResolverTypeWrapper<Omit<OrgRemoveBillingManagerAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgRemoveBillingManagerAuditEntryReason: OrgRemoveBillingManagerAuditEntryReason;
    OrgRemoveMemberAuditEntry: ResolverTypeWrapper<Omit<OrgRemoveMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgRemoveMemberAuditEntryMembershipType: OrgRemoveMemberAuditEntryMembershipType;
    OrgRemoveMemberAuditEntryReason: OrgRemoveMemberAuditEntryReason;
    OrgRemoveOutsideCollaboratorAuditEntry: ResolverTypeWrapper<Omit<OrgRemoveOutsideCollaboratorAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgRemoveOutsideCollaboratorAuditEntryMembershipType: OrgRemoveOutsideCollaboratorAuditEntryMembershipType;
    OrgRemoveOutsideCollaboratorAuditEntryReason: OrgRemoveOutsideCollaboratorAuditEntryReason;
    OrgRestoreMemberAuditEntry: ResolverTypeWrapper<Omit<OrgRestoreMemberAuditEntry, 'actor' | 'organization' | 'restoredMemberships' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        restoredMemberships?: Maybe<Array<ResolversTypes['OrgRestoreMemberAuditEntryMembership']>>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgRestoreMemberAuditEntryMembership: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['OrgRestoreMemberAuditEntryMembership']>;
    OrgRestoreMemberMembershipOrganizationAuditEntryData: ResolverTypeWrapper<Omit<OrgRestoreMemberMembershipOrganizationAuditEntryData, 'organization'> & {
        organization?: Maybe<ResolversTypes['Organization']>;
    }>;
    OrgRestoreMemberMembershipRepositoryAuditEntryData: ResolverTypeWrapper<Omit<OrgRestoreMemberMembershipRepositoryAuditEntryData, 'repository'> & {
        repository?: Maybe<ResolversTypes['Repository']>;
    }>;
    OrgRestoreMemberMembershipTeamAuditEntryData: ResolverTypeWrapper<Omit<OrgRestoreMemberMembershipTeamAuditEntryData, 'team'> & {
        team?: Maybe<ResolversTypes['Team']>;
    }>;
    OrgUnblockUserAuditEntry: ResolverTypeWrapper<Omit<OrgUnblockUserAuditEntry, 'actor' | 'blockedUser' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        blockedUser?: Maybe<ResolversTypes['User']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgUpdateDefaultRepositoryPermissionAuditEntry: ResolverTypeWrapper<Omit<OrgUpdateDefaultRepositoryPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgUpdateDefaultRepositoryPermissionAuditEntryPermission: OrgUpdateDefaultRepositoryPermissionAuditEntryPermission;
    OrgUpdateMemberAuditEntry: ResolverTypeWrapper<Omit<OrgUpdateMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgUpdateMemberAuditEntryPermission: OrgUpdateMemberAuditEntryPermission;
    OrgUpdateMemberRepositoryCreationPermissionAuditEntry: ResolverTypeWrapper<Omit<OrgUpdateMemberRepositoryCreationPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    OrgUpdateMemberRepositoryCreationPermissionAuditEntryVisibility: OrgUpdateMemberRepositoryCreationPermissionAuditEntryVisibility;
    OrgUpdateMemberRepositoryInvitationPermissionAuditEntry: ResolverTypeWrapper<Omit<OrgUpdateMemberRepositoryInvitationPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    Organization: ResolverTypeWrapper<Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: ResolversTypes['OrganizationAuditEntryConnection'];
        domains?: Maybe<ResolversTypes['VerifiableDomainConnection']>;
        ipAllowListEntries: ResolversTypes['IpAllowListEntryConnection'];
        itemShowcase: ResolversTypes['ProfileItemShowcase'];
        memberStatuses: ResolversTypes['UserStatusConnection'];
        packages: ResolversTypes['PackageConnection'];
        pendingMembers: ResolversTypes['UserConnection'];
        pinnableItems: ResolversTypes['PinnableItemConnection'];
        pinnedItems: ResolversTypes['PinnableItemConnection'];
        project?: Maybe<ResolversTypes['Project']>;
        projects: ResolversTypes['ProjectConnection'];
        repositories: ResolversTypes['RepositoryConnection'];
        repository?: Maybe<ResolversTypes['Repository']>;
        repositoryDiscussionComments: ResolversTypes['DiscussionCommentConnection'];
        repositoryDiscussions: ResolversTypes['DiscussionConnection'];
        samlIdentityProvider?: Maybe<ResolversTypes['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: ResolversTypes['SponsorshipConnection'];
        sponsorshipsAsSponsor: ResolversTypes['SponsorshipConnection'];
        team?: Maybe<ResolversTypes['Team']>;
    }>;
    OrganizationAuditEntry: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['OrganizationAuditEntry']>;
    OrganizationAuditEntryConnection: ResolverTypeWrapper<Omit<OrganizationAuditEntryConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['OrganizationAuditEntryEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['OrganizationAuditEntry']>>>;
    }>;
    OrganizationAuditEntryData: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['OrganizationAuditEntryData']>;
    OrganizationAuditEntryEdge: ResolverTypeWrapper<Omit<OrganizationAuditEntryEdge, 'node'> & {
        node?: Maybe<ResolversTypes['OrganizationAuditEntry']>;
    }>;
    OrganizationConnection: ResolverTypeWrapper<Omit<OrganizationConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['OrganizationEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Organization']>>>;
    }>;
    OrganizationEdge: ResolverTypeWrapper<Omit<OrganizationEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Organization']>;
    }>;
    OrganizationIdentityProvider: ResolverTypeWrapper<Omit<OrganizationIdentityProvider, 'externalIdentities' | 'organization'> & {
        externalIdentities: ResolversTypes['ExternalIdentityConnection'];
        organization?: Maybe<ResolversTypes['Organization']>;
    }>;
    OrganizationInvitation: ResolverTypeWrapper<Omit<OrganizationInvitation, 'invitee' | 'inviter' | 'organization'> & {
        invitee?: Maybe<ResolversTypes['User']>;
        inviter: ResolversTypes['User'];
        organization: ResolversTypes['Organization'];
    }>;
    OrganizationInvitationConnection: ResolverTypeWrapper<Omit<OrganizationInvitationConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['OrganizationInvitationEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['OrganizationInvitation']>>>;
    }>;
    OrganizationInvitationEdge: ResolverTypeWrapper<Omit<OrganizationInvitationEdge, 'node'> & {
        node?: Maybe<ResolversTypes['OrganizationInvitation']>;
    }>;
    OrganizationInvitationRole: OrganizationInvitationRole;
    OrganizationInvitationType: OrganizationInvitationType;
    OrganizationMemberConnection: ResolverTypeWrapper<Omit<OrganizationMemberConnection, 'nodes'> & {
        nodes?: Maybe<Array<Maybe<ResolversTypes['User']>>>;
    }>;
    OrganizationMemberEdge: ResolverTypeWrapper<Omit<OrganizationMemberEdge, 'node'> & {
        node?: Maybe<ResolversTypes['User']>;
    }>;
    OrganizationMemberRole: OrganizationMemberRole;
    OrganizationMembersCanCreateRepositoriesSettingValue: OrganizationMembersCanCreateRepositoriesSettingValue;
    OrganizationOrder: OrganizationOrder;
    OrganizationOrderField: OrganizationOrderField;
    OrganizationTeamsHovercardContext: ResolverTypeWrapper<OrganizationTeamsHovercardContext>;
    OrganizationsHovercardContext: ResolverTypeWrapper<Omit<OrganizationsHovercardContext, 'relevantOrganizations'> & {
        relevantOrganizations: ResolversTypes['OrganizationConnection'];
    }>;
    Package: ResolverTypeWrapper<Omit<Package, 'latestVersion' | 'repository' | 'version' | 'versions'> & {
        latestVersion?: Maybe<ResolversTypes['PackageVersion']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        version?: Maybe<ResolversTypes['PackageVersion']>;
        versions: ResolversTypes['PackageVersionConnection'];
    }>;
    PackageConnection: ResolverTypeWrapper<Omit<PackageConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['PackageEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Package']>>>;
    }>;
    PackageEdge: ResolverTypeWrapper<Omit<PackageEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Package']>;
    }>;
    PackageFile: ResolverTypeWrapper<Omit<PackageFile, 'packageVersion'> & {
        packageVersion?: Maybe<ResolversTypes['PackageVersion']>;
    }>;
    PackageFileConnection: ResolverTypeWrapper<PackageFileConnection>;
    PackageFileEdge: ResolverTypeWrapper<PackageFileEdge>;
    PackageFileOrder: PackageFileOrder;
    PackageFileOrderField: PackageFileOrderField;
    PackageOrder: PackageOrder;
    PackageOrderField: PackageOrderField;
    PackageOwner: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['PackageOwner']>;
    PackageStatistics: ResolverTypeWrapper<PackageStatistics>;
    PackageTag: ResolverTypeWrapper<Omit<PackageTag, 'version'> & {
        version?: Maybe<ResolversTypes['PackageVersion']>;
    }>;
    PackageType: PackageType;
    PackageVersion: ResolverTypeWrapper<Omit<PackageVersion, 'package' | 'release'> & {
        package?: Maybe<ResolversTypes['Package']>;
        release?: Maybe<ResolversTypes['Release']>;
    }>;
    PackageVersionConnection: ResolverTypeWrapper<Omit<PackageVersionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['PackageVersionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['PackageVersion']>>>;
    }>;
    PackageVersionEdge: ResolverTypeWrapper<Omit<PackageVersionEdge, 'node'> & {
        node?: Maybe<ResolversTypes['PackageVersion']>;
    }>;
    PackageVersionOrder: PackageVersionOrder;
    PackageVersionOrderField: PackageVersionOrderField;
    PackageVersionStatistics: ResolverTypeWrapper<PackageVersionStatistics>;
    PageInfo: ResolverTypeWrapper<PageInfo>;
    PermissionGranter: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['PermissionGranter']>;
    PermissionSource: ResolverTypeWrapper<Omit<PermissionSource, 'organization' | 'source'> & {
        organization: ResolversTypes['Organization'];
        source: ResolversTypes['PermissionGranter'];
    }>;
    PinIssueInput: PinIssueInput;
    PinIssuePayload: ResolverTypeWrapper<Omit<PinIssuePayload, 'issue'> & {
        issue?: Maybe<ResolversTypes['Issue']>;
    }>;
    PinnableItem: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['PinnableItem']>;
    PinnableItemConnection: ResolverTypeWrapper<Omit<PinnableItemConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['PinnableItemEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['PinnableItem']>>>;
    }>;
    PinnableItemEdge: ResolverTypeWrapper<Omit<PinnableItemEdge, 'node'> & {
        node?: Maybe<ResolversTypes['PinnableItem']>;
    }>;
    PinnableItemType: PinnableItemType;
    PinnedDiscussion: ResolverTypeWrapper<Omit<PinnedDiscussion, 'discussion' | 'pinnedBy' | 'repository'> & {
        discussion: ResolversTypes['Discussion'];
        pinnedBy: ResolversTypes['Actor'];
        repository: ResolversTypes['Repository'];
    }>;
    PinnedDiscussionConnection: ResolverTypeWrapper<Omit<PinnedDiscussionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['PinnedDiscussionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['PinnedDiscussion']>>>;
    }>;
    PinnedDiscussionEdge: ResolverTypeWrapper<Omit<PinnedDiscussionEdge, 'node'> & {
        node?: Maybe<ResolversTypes['PinnedDiscussion']>;
    }>;
    PinnedDiscussionGradient: PinnedDiscussionGradient;
    PinnedDiscussionPattern: PinnedDiscussionPattern;
    PinnedEvent: ResolverTypeWrapper<Omit<PinnedEvent, 'actor' | 'issue'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        issue: ResolversTypes['Issue'];
    }>;
    PinnedIssue: ResolverTypeWrapper<Omit<PinnedIssue, 'issue' | 'pinnedBy' | 'repository'> & {
        issue: ResolversTypes['Issue'];
        pinnedBy: ResolversTypes['Actor'];
        repository: ResolversTypes['Repository'];
    }>;
    PinnedIssueConnection: ResolverTypeWrapper<Omit<PinnedIssueConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['PinnedIssueEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['PinnedIssue']>>>;
    }>;
    PinnedIssueEdge: ResolverTypeWrapper<Omit<PinnedIssueEdge, 'node'> & {
        node?: Maybe<ResolversTypes['PinnedIssue']>;
    }>;
    PreciseDateTime: ResolverTypeWrapper<Scalars['PreciseDateTime']['output']>;
    PrivateRepositoryForkingDisableAuditEntry: ResolverTypeWrapper<Omit<PrivateRepositoryForkingDisableAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    PrivateRepositoryForkingEnableAuditEntry: ResolverTypeWrapper<Omit<PrivateRepositoryForkingEnableAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    ProfileItemShowcase: ResolverTypeWrapper<Omit<ProfileItemShowcase, 'items'> & {
        items: ResolversTypes['PinnableItemConnection'];
    }>;
    ProfileOwner: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['ProfileOwner']>;
    Project: ResolverTypeWrapper<Omit<Project, 'columns' | 'creator' | 'owner' | 'pendingCards'> & {
        columns: ResolversTypes['ProjectColumnConnection'];
        creator?: Maybe<ResolversTypes['Actor']>;
        owner: ResolversTypes['ProjectOwner'];
        pendingCards: ResolversTypes['ProjectCardConnection'];
    }>;
    ProjectCard: ResolverTypeWrapper<Omit<ProjectCard, 'column' | 'content' | 'creator' | 'project'> & {
        column?: Maybe<ResolversTypes['ProjectColumn']>;
        content?: Maybe<ResolversTypes['ProjectCardItem']>;
        creator?: Maybe<ResolversTypes['Actor']>;
        project: ResolversTypes['Project'];
    }>;
    ProjectCardArchivedState: ProjectCardArchivedState;
    ProjectCardConnection: ResolverTypeWrapper<Omit<ProjectCardConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['ProjectCardEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['ProjectCard']>>>;
    }>;
    ProjectCardEdge: ResolverTypeWrapper<Omit<ProjectCardEdge, 'node'> & {
        node?: Maybe<ResolversTypes['ProjectCard']>;
    }>;
    ProjectCardImport: ProjectCardImport;
    ProjectCardItem: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['ProjectCardItem']>;
    ProjectCardState: ProjectCardState;
    ProjectColumn: ResolverTypeWrapper<Omit<ProjectColumn, 'cards' | 'project'> & {
        cards: ResolversTypes['ProjectCardConnection'];
        project: ResolversTypes['Project'];
    }>;
    ProjectColumnConnection: ResolverTypeWrapper<Omit<ProjectColumnConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['ProjectColumnEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['ProjectColumn']>>>;
    }>;
    ProjectColumnEdge: ResolverTypeWrapper<Omit<ProjectColumnEdge, 'node'> & {
        node?: Maybe<ResolversTypes['ProjectColumn']>;
    }>;
    ProjectColumnImport: ProjectColumnImport;
    ProjectColumnPurpose: ProjectColumnPurpose;
    ProjectConnection: ResolverTypeWrapper<Omit<ProjectConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['ProjectEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Project']>>>;
    }>;
    ProjectEdge: ResolverTypeWrapper<Omit<ProjectEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Project']>;
    }>;
    ProjectOrder: ProjectOrder;
    ProjectOrderField: ProjectOrderField;
    ProjectOwner: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['ProjectOwner']>;
    ProjectProgress: ResolverTypeWrapper<ProjectProgress>;
    ProjectState: ProjectState;
    ProjectTemplate: ProjectTemplate;
    PublicKey: ResolverTypeWrapper<PublicKey>;
    PublicKeyConnection: ResolverTypeWrapper<PublicKeyConnection>;
    PublicKeyEdge: ResolverTypeWrapper<PublicKeyEdge>;
    PullRequest: ResolverTypeWrapper<Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: ResolversTypes['UserConnection'];
        author?: Maybe<ResolversTypes['Actor']>;
        autoMergeRequest?: Maybe<ResolversTypes['AutoMergeRequest']>;
        baseRef?: Maybe<ResolversTypes['Ref']>;
        baseRepository?: Maybe<ResolversTypes['Repository']>;
        comments: ResolversTypes['IssueCommentConnection'];
        commits: ResolversTypes['PullRequestCommitConnection'];
        editor?: Maybe<ResolversTypes['Actor']>;
        headRef?: Maybe<ResolversTypes['Ref']>;
        headRepository?: Maybe<ResolversTypes['Repository']>;
        headRepositoryOwner?: Maybe<ResolversTypes['RepositoryOwner']>;
        hovercard: ResolversTypes['Hovercard'];
        labels?: Maybe<ResolversTypes['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<ResolversTypes['PullRequestReviewConnection']>;
        latestReviews?: Maybe<ResolversTypes['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<ResolversTypes['Commit']>;
        mergedBy?: Maybe<ResolversTypes['Actor']>;
        milestone?: Maybe<ResolversTypes['Milestone']>;
        participants: ResolversTypes['UserConnection'];
        potentialMergeCommit?: Maybe<ResolversTypes['Commit']>;
        projectCards: ResolversTypes['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<ResolversTypes['ReactionGroup']>>;
        reactions: ResolversTypes['ReactionConnection'];
        repository: ResolversTypes['Repository'];
        reviewRequests?: Maybe<ResolversTypes['ReviewRequestConnection']>;
        reviewThreads: ResolversTypes['PullRequestReviewThreadConnection'];
        reviews?: Maybe<ResolversTypes['PullRequestReviewConnection']>;
        timeline: ResolversTypes['PullRequestTimelineConnection'];
        timelineItems: ResolversTypes['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<ResolversTypes['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<ResolversTypes['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<ResolversTypes['ReviewRequest']>;
    }>;
    PullRequestChangedFile: ResolverTypeWrapper<PullRequestChangedFile>;
    PullRequestChangedFileConnection: ResolverTypeWrapper<PullRequestChangedFileConnection>;
    PullRequestChangedFileEdge: ResolverTypeWrapper<PullRequestChangedFileEdge>;
    PullRequestCommit: ResolverTypeWrapper<Omit<PullRequestCommit, 'commit' | 'pullRequest'> & {
        commit: ResolversTypes['Commit'];
        pullRequest: ResolversTypes['PullRequest'];
    }>;
    PullRequestCommitCommentThread: ResolverTypeWrapper<Omit<PullRequestCommitCommentThread, 'comments' | 'commit' | 'pullRequest' | 'repository'> & {
        comments: ResolversTypes['CommitCommentConnection'];
        commit: ResolversTypes['Commit'];
        pullRequest: ResolversTypes['PullRequest'];
        repository: ResolversTypes['Repository'];
    }>;
    PullRequestCommitConnection: ResolverTypeWrapper<Omit<PullRequestCommitConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['PullRequestCommitEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['PullRequestCommit']>>>;
    }>;
    PullRequestCommitEdge: ResolverTypeWrapper<Omit<PullRequestCommitEdge, 'node'> & {
        node?: Maybe<ResolversTypes['PullRequestCommit']>;
    }>;
    PullRequestConnection: ResolverTypeWrapper<Omit<PullRequestConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['PullRequestEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['PullRequest']>>>;
    }>;
    PullRequestContributionsByRepository: ResolverTypeWrapper<Omit<PullRequestContributionsByRepository, 'contributions' | 'repository'> & {
        contributions: ResolversTypes['CreatedPullRequestContributionConnection'];
        repository: ResolversTypes['Repository'];
    }>;
    PullRequestEdge: ResolverTypeWrapper<Omit<PullRequestEdge, 'node'> & {
        node?: Maybe<ResolversTypes['PullRequest']>;
    }>;
    PullRequestMergeMethod: PullRequestMergeMethod;
    PullRequestOrder: PullRequestOrder;
    PullRequestOrderField: PullRequestOrderField;
    PullRequestReview: ResolverTypeWrapper<Omit<PullRequestReview, 'author' | 'comments' | 'commit' | 'editor' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<ResolversTypes['Actor']>;
        comments: ResolversTypes['PullRequestReviewCommentConnection'];
        commit?: Maybe<ResolversTypes['Commit']>;
        editor?: Maybe<ResolversTypes['Actor']>;
        pullRequest: ResolversTypes['PullRequest'];
        reactionGroups?: Maybe<Array<ResolversTypes['ReactionGroup']>>;
        reactions: ResolversTypes['ReactionConnection'];
        repository: ResolversTypes['Repository'];
        userContentEdits?: Maybe<ResolversTypes['UserContentEditConnection']>;
    }>;
    PullRequestReviewComment: ResolverTypeWrapper<Omit<PullRequestReviewComment, 'author' | 'commit' | 'editor' | 'originalCommit' | 'pullRequest' | 'pullRequestReview' | 'reactionGroups' | 'reactions' | 'replyTo' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<ResolversTypes['Actor']>;
        commit?: Maybe<ResolversTypes['Commit']>;
        editor?: Maybe<ResolversTypes['Actor']>;
        originalCommit?: Maybe<ResolversTypes['Commit']>;
        pullRequest: ResolversTypes['PullRequest'];
        pullRequestReview?: Maybe<ResolversTypes['PullRequestReview']>;
        reactionGroups?: Maybe<Array<ResolversTypes['ReactionGroup']>>;
        reactions: ResolversTypes['ReactionConnection'];
        replyTo?: Maybe<ResolversTypes['PullRequestReviewComment']>;
        repository: ResolversTypes['Repository'];
        userContentEdits?: Maybe<ResolversTypes['UserContentEditConnection']>;
    }>;
    PullRequestReviewCommentConnection: ResolverTypeWrapper<Omit<PullRequestReviewCommentConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['PullRequestReviewCommentEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['PullRequestReviewComment']>>>;
    }>;
    PullRequestReviewCommentEdge: ResolverTypeWrapper<Omit<PullRequestReviewCommentEdge, 'node'> & {
        node?: Maybe<ResolversTypes['PullRequestReviewComment']>;
    }>;
    PullRequestReviewCommentState: PullRequestReviewCommentState;
    PullRequestReviewConnection: ResolverTypeWrapper<Omit<PullRequestReviewConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['PullRequestReviewEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['PullRequestReview']>>>;
    }>;
    PullRequestReviewContributionsByRepository: ResolverTypeWrapper<Omit<PullRequestReviewContributionsByRepository, 'contributions' | 'repository'> & {
        contributions: ResolversTypes['CreatedPullRequestReviewContributionConnection'];
        repository: ResolversTypes['Repository'];
    }>;
    PullRequestReviewDecision: PullRequestReviewDecision;
    PullRequestReviewEdge: ResolverTypeWrapper<Omit<PullRequestReviewEdge, 'node'> & {
        node?: Maybe<ResolversTypes['PullRequestReview']>;
    }>;
    PullRequestReviewEvent: PullRequestReviewEvent;
    PullRequestReviewState: PullRequestReviewState;
    PullRequestReviewThread: ResolverTypeWrapper<Omit<PullRequestReviewThread, 'comments' | 'pullRequest' | 'repository' | 'resolvedBy'> & {
        comments: ResolversTypes['PullRequestReviewCommentConnection'];
        pullRequest: ResolversTypes['PullRequest'];
        repository: ResolversTypes['Repository'];
        resolvedBy?: Maybe<ResolversTypes['User']>;
    }>;
    PullRequestReviewThreadConnection: ResolverTypeWrapper<Omit<PullRequestReviewThreadConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['PullRequestReviewThreadEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['PullRequestReviewThread']>>>;
    }>;
    PullRequestReviewThreadEdge: ResolverTypeWrapper<Omit<PullRequestReviewThreadEdge, 'node'> & {
        node?: Maybe<ResolversTypes['PullRequestReviewThread']>;
    }>;
    PullRequestRevisionMarker: ResolverTypeWrapper<Omit<PullRequestRevisionMarker, 'lastSeenCommit' | 'pullRequest'> & {
        lastSeenCommit: ResolversTypes['Commit'];
        pullRequest: ResolversTypes['PullRequest'];
    }>;
    PullRequestState: PullRequestState;
    PullRequestTemplate: ResolverTypeWrapper<Omit<PullRequestTemplate, 'repository'> & {
        repository: ResolversTypes['Repository'];
    }>;
    PullRequestTimelineConnection: ResolverTypeWrapper<Omit<PullRequestTimelineConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['PullRequestTimelineItemEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['PullRequestTimelineItem']>>>;
    }>;
    PullRequestTimelineItem: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['PullRequestTimelineItem']>;
    PullRequestTimelineItemEdge: ResolverTypeWrapper<Omit<PullRequestTimelineItemEdge, 'node'> & {
        node?: Maybe<ResolversTypes['PullRequestTimelineItem']>;
    }>;
    PullRequestTimelineItems: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['PullRequestTimelineItems']>;
    PullRequestTimelineItemsConnection: ResolverTypeWrapper<Omit<PullRequestTimelineItemsConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['PullRequestTimelineItemsEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['PullRequestTimelineItems']>>>;
    }>;
    PullRequestTimelineItemsEdge: ResolverTypeWrapper<Omit<PullRequestTimelineItemsEdge, 'node'> & {
        node?: Maybe<ResolversTypes['PullRequestTimelineItems']>;
    }>;
    PullRequestTimelineItemsItemType: PullRequestTimelineItemsItemType;
    PullRequestUpdateState: PullRequestUpdateState;
    Push: ResolverTypeWrapper<Omit<Push, 'pusher' | 'repository'> & {
        pusher: ResolversTypes['User'];
        repository: ResolversTypes['Repository'];
    }>;
    PushAllowance: ResolverTypeWrapper<Omit<PushAllowance, 'actor' | 'branchProtectionRule'> & {
        actor?: Maybe<ResolversTypes['PushAllowanceActor']>;
        branchProtectionRule?: Maybe<ResolversTypes['BranchProtectionRule']>;
    }>;
    PushAllowanceActor: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['PushAllowanceActor']>;
    PushAllowanceConnection: ResolverTypeWrapper<Omit<PushAllowanceConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['PushAllowanceEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['PushAllowance']>>>;
    }>;
    PushAllowanceEdge: ResolverTypeWrapper<Omit<PushAllowanceEdge, 'node'> & {
        node?: Maybe<ResolversTypes['PushAllowance']>;
    }>;
    Query: ResolverTypeWrapper<{}>;
    RateLimit: ResolverTypeWrapper<RateLimit>;
    Reactable: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['Reactable']>;
    ReactingUserConnection: ResolverTypeWrapper<Omit<ReactingUserConnection, 'nodes'> & {
        nodes?: Maybe<Array<Maybe<ResolversTypes['User']>>>;
    }>;
    ReactingUserEdge: ResolverTypeWrapper<Omit<ReactingUserEdge, 'node'> & {
        node: ResolversTypes['User'];
    }>;
    Reaction: ResolverTypeWrapper<Omit<Reaction, 'reactable' | 'user'> & {
        reactable: ResolversTypes['Reactable'];
        user?: Maybe<ResolversTypes['User']>;
    }>;
    ReactionConnection: ResolverTypeWrapper<Omit<ReactionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['ReactionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Reaction']>>>;
    }>;
    ReactionContent: ReactionContent;
    ReactionEdge: ResolverTypeWrapper<Omit<ReactionEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Reaction']>;
    }>;
    ReactionGroup: ResolverTypeWrapper<Omit<ReactionGroup, 'reactors' | 'subject'> & {
        reactors: ResolversTypes['ReactorConnection'];
        subject: ResolversTypes['Reactable'];
    }>;
    ReactionOrder: ReactionOrder;
    ReactionOrderField: ReactionOrderField;
    Reactor: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['Reactor']>;
    ReactorConnection: ResolverTypeWrapper<Omit<ReactorConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['ReactorEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Reactor']>>>;
    }>;
    ReactorEdge: ResolverTypeWrapper<Omit<ReactorEdge, 'node'> & {
        node: ResolversTypes['Reactor'];
    }>;
    ReadyForReviewEvent: ResolverTypeWrapper<Omit<ReadyForReviewEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        pullRequest: ResolversTypes['PullRequest'];
    }>;
    Ref: ResolverTypeWrapper<Omit<Ref, 'associatedPullRequests' | 'branchProtectionRule' | 'repository' | 'target'> & {
        associatedPullRequests: ResolversTypes['PullRequestConnection'];
        branchProtectionRule?: Maybe<ResolversTypes['BranchProtectionRule']>;
        repository: ResolversTypes['Repository'];
        target?: Maybe<ResolversTypes['GitObject']>;
    }>;
    RefConnection: ResolverTypeWrapper<Omit<RefConnection, 'nodes'> & {
        nodes?: Maybe<Array<Maybe<ResolversTypes['Ref']>>>;
    }>;
    RefEdge: ResolverTypeWrapper<Omit<RefEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Ref']>;
    }>;
    RefOrder: RefOrder;
    RefOrderField: RefOrderField;
    RefUpdate: RefUpdate;
    RefUpdateRule: ResolverTypeWrapper<RefUpdateRule>;
    ReferencedEvent: ResolverTypeWrapper<Omit<ReferencedEvent, 'actor' | 'commit' | 'commitRepository' | 'subject'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        commit?: Maybe<ResolversTypes['Commit']>;
        commitRepository: ResolversTypes['Repository'];
        subject: ResolversTypes['ReferencedSubject'];
    }>;
    ReferencedSubject: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['ReferencedSubject']>;
    RegenerateVerifiableDomainTokenInput: RegenerateVerifiableDomainTokenInput;
    RegenerateVerifiableDomainTokenPayload: ResolverTypeWrapper<RegenerateVerifiableDomainTokenPayload>;
    RejectDeploymentsInput: RejectDeploymentsInput;
    RejectDeploymentsPayload: ResolverTypeWrapper<Omit<RejectDeploymentsPayload, 'deployments'> & {
        deployments?: Maybe<Array<ResolversTypes['Deployment']>>;
    }>;
    Release: ResolverTypeWrapper<Omit<Release, 'author' | 'mentions' | 'reactionGroups' | 'reactions' | 'releaseAssets' | 'repository' | 'tag' | 'tagCommit'> & {
        author?: Maybe<ResolversTypes['User']>;
        mentions?: Maybe<ResolversTypes['UserConnection']>;
        reactionGroups?: Maybe<Array<ResolversTypes['ReactionGroup']>>;
        reactions: ResolversTypes['ReactionConnection'];
        releaseAssets: ResolversTypes['ReleaseAssetConnection'];
        repository: ResolversTypes['Repository'];
        tag?: Maybe<ResolversTypes['Ref']>;
        tagCommit?: Maybe<ResolversTypes['Commit']>;
    }>;
    ReleaseAsset: ResolverTypeWrapper<Omit<ReleaseAsset, 'release' | 'uploadedBy'> & {
        release?: Maybe<ResolversTypes['Release']>;
        uploadedBy: ResolversTypes['User'];
    }>;
    ReleaseAssetConnection: ResolverTypeWrapper<Omit<ReleaseAssetConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['ReleaseAssetEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['ReleaseAsset']>>>;
    }>;
    ReleaseAssetEdge: ResolverTypeWrapper<Omit<ReleaseAssetEdge, 'node'> & {
        node?: Maybe<ResolversTypes['ReleaseAsset']>;
    }>;
    ReleaseConnection: ResolverTypeWrapper<Omit<ReleaseConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['ReleaseEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Release']>>>;
    }>;
    ReleaseEdge: ResolverTypeWrapper<Omit<ReleaseEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Release']>;
    }>;
    ReleaseOrder: ReleaseOrder;
    ReleaseOrderField: ReleaseOrderField;
    RemoveAssigneesFromAssignableInput: RemoveAssigneesFromAssignableInput;
    RemoveAssigneesFromAssignablePayload: ResolverTypeWrapper<Omit<RemoveAssigneesFromAssignablePayload, 'assignable'> & {
        assignable?: Maybe<ResolversTypes['Assignable']>;
    }>;
    RemoveEnterpriseAdminInput: RemoveEnterpriseAdminInput;
    RemoveEnterpriseAdminPayload: ResolverTypeWrapper<Omit<RemoveEnterpriseAdminPayload, 'admin' | 'enterprise' | 'viewer'> & {
        admin?: Maybe<ResolversTypes['User']>;
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
        viewer?: Maybe<ResolversTypes['User']>;
    }>;
    RemoveLabelsFromLabelableInput: RemoveLabelsFromLabelableInput;
    RemoveLabelsFromLabelablePayload: ResolverTypeWrapper<Omit<RemoveLabelsFromLabelablePayload, 'labelable'> & {
        labelable?: Maybe<ResolversTypes['Labelable']>;
    }>;
    RemoveOutsideCollaboratorInput: RemoveOutsideCollaboratorInput;
    RemoveOutsideCollaboratorPayload: ResolverTypeWrapper<Omit<RemoveOutsideCollaboratorPayload, 'removedUser'> & {
        removedUser?: Maybe<ResolversTypes['User']>;
    }>;
    RemoveReactionInput: RemoveReactionInput;
    RemoveReactionPayload: ResolverTypeWrapper<Omit<RemoveReactionPayload, 'reaction' | 'subject'> & {
        reaction?: Maybe<ResolversTypes['Reaction']>;
        subject?: Maybe<ResolversTypes['Reactable']>;
    }>;
    RemoveStarInput: RemoveStarInput;
    RemoveStarPayload: ResolverTypeWrapper<Omit<RemoveStarPayload, 'starrable'> & {
        starrable?: Maybe<ResolversTypes['Starrable']>;
    }>;
    RemoveUpvoteInput: RemoveUpvoteInput;
    RemoveUpvotePayload: ResolverTypeWrapper<Omit<RemoveUpvotePayload, 'subject'> & {
        subject?: Maybe<ResolversTypes['Votable']>;
    }>;
    RemovedFromProjectEvent: ResolverTypeWrapper<Omit<RemovedFromProjectEvent, 'actor' | 'project'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        project?: Maybe<ResolversTypes['Project']>;
    }>;
    RenamedTitleEvent: ResolverTypeWrapper<Omit<RenamedTitleEvent, 'actor' | 'subject'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        subject: ResolversTypes['RenamedTitleSubject'];
    }>;
    RenamedTitleSubject: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['RenamedTitleSubject']>;
    ReopenIssueInput: ReopenIssueInput;
    ReopenIssuePayload: ResolverTypeWrapper<Omit<ReopenIssuePayload, 'issue'> & {
        issue?: Maybe<ResolversTypes['Issue']>;
    }>;
    ReopenPullRequestInput: ReopenPullRequestInput;
    ReopenPullRequestPayload: ResolverTypeWrapper<Omit<ReopenPullRequestPayload, 'pullRequest'> & {
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
    }>;
    ReopenedEvent: ResolverTypeWrapper<Omit<ReopenedEvent, 'actor' | 'closable'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        closable: ResolversTypes['Closable'];
    }>;
    RepoAccessAuditEntry: ResolverTypeWrapper<Omit<RepoAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoAccessAuditEntryVisibility: RepoAccessAuditEntryVisibility;
    RepoAddMemberAuditEntry: ResolverTypeWrapper<Omit<RepoAddMemberAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoAddMemberAuditEntryVisibility: RepoAddMemberAuditEntryVisibility;
    RepoAddTopicAuditEntry: ResolverTypeWrapper<Omit<RepoAddTopicAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoArchivedAuditEntry: ResolverTypeWrapper<Omit<RepoArchivedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoArchivedAuditEntryVisibility: RepoArchivedAuditEntryVisibility;
    RepoChangeMergeSettingAuditEntry: ResolverTypeWrapper<Omit<RepoChangeMergeSettingAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoChangeMergeSettingAuditEntryMergeType: RepoChangeMergeSettingAuditEntryMergeType;
    RepoConfigDisableAnonymousGitAccessAuditEntry: ResolverTypeWrapper<Omit<RepoConfigDisableAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoConfigDisableCollaboratorsOnlyAuditEntry: ResolverTypeWrapper<Omit<RepoConfigDisableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoConfigDisableContributorsOnlyAuditEntry: ResolverTypeWrapper<Omit<RepoConfigDisableContributorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoConfigDisableSockpuppetDisallowedAuditEntry: ResolverTypeWrapper<Omit<RepoConfigDisableSockpuppetDisallowedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoConfigEnableAnonymousGitAccessAuditEntry: ResolverTypeWrapper<Omit<RepoConfigEnableAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoConfigEnableCollaboratorsOnlyAuditEntry: ResolverTypeWrapper<Omit<RepoConfigEnableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoConfigEnableContributorsOnlyAuditEntry: ResolverTypeWrapper<Omit<RepoConfigEnableContributorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoConfigEnableSockpuppetDisallowedAuditEntry: ResolverTypeWrapper<Omit<RepoConfigEnableSockpuppetDisallowedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoConfigLockAnonymousGitAccessAuditEntry: ResolverTypeWrapper<Omit<RepoConfigLockAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoConfigUnlockAnonymousGitAccessAuditEntry: ResolverTypeWrapper<Omit<RepoConfigUnlockAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoCreateAuditEntry: ResolverTypeWrapper<Omit<RepoCreateAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoCreateAuditEntryVisibility: RepoCreateAuditEntryVisibility;
    RepoDestroyAuditEntry: ResolverTypeWrapper<Omit<RepoDestroyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoDestroyAuditEntryVisibility: RepoDestroyAuditEntryVisibility;
    RepoRemoveMemberAuditEntry: ResolverTypeWrapper<Omit<RepoRemoveMemberAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepoRemoveMemberAuditEntryVisibility: RepoRemoveMemberAuditEntryVisibility;
    RepoRemoveTopicAuditEntry: ResolverTypeWrapper<Omit<RepoRemoveTopicAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    ReportedContentClassifiers: ReportedContentClassifiers;
    Repository: ResolverTypeWrapper<Omit<Repository, 'assignableUsers' | 'branchProtectionRules' | 'collaborators' | 'commitComments' | 'defaultBranchRef' | 'deployments' | 'discussion' | 'discussionCategories' | 'discussions' | 'environment' | 'environments' | 'forks' | 'issue' | 'issueOrPullRequest' | 'label' | 'labels' | 'latestRelease' | 'mentionableUsers' | 'milestone' | 'milestones' | 'object' | 'owner' | 'packages' | 'parent' | 'pinnedDiscussions' | 'pinnedIssues' | 'project' | 'projects' | 'pullRequest' | 'pullRequestTemplates' | 'pullRequests' | 'ref' | 'release' | 'releases' | 'templateRepository' | 'vulnerabilityAlerts' | 'watchers'> & {
        assignableUsers: ResolversTypes['UserConnection'];
        branchProtectionRules: ResolversTypes['BranchProtectionRuleConnection'];
        collaborators?: Maybe<ResolversTypes['RepositoryCollaboratorConnection']>;
        commitComments: ResolversTypes['CommitCommentConnection'];
        defaultBranchRef?: Maybe<ResolversTypes['Ref']>;
        deployments: ResolversTypes['DeploymentConnection'];
        discussion?: Maybe<ResolversTypes['Discussion']>;
        discussionCategories: ResolversTypes['DiscussionCategoryConnection'];
        discussions: ResolversTypes['DiscussionConnection'];
        environment?: Maybe<ResolversTypes['Environment']>;
        environments: ResolversTypes['EnvironmentConnection'];
        forks: ResolversTypes['RepositoryConnection'];
        issue?: Maybe<ResolversTypes['Issue']>;
        issueOrPullRequest?: Maybe<ResolversTypes['IssueOrPullRequest']>;
        label?: Maybe<ResolversTypes['Label']>;
        labels?: Maybe<ResolversTypes['LabelConnection']>;
        latestRelease?: Maybe<ResolversTypes['Release']>;
        mentionableUsers: ResolversTypes['UserConnection'];
        milestone?: Maybe<ResolversTypes['Milestone']>;
        milestones?: Maybe<ResolversTypes['MilestoneConnection']>;
        object?: Maybe<ResolversTypes['GitObject']>;
        owner: ResolversTypes['RepositoryOwner'];
        packages: ResolversTypes['PackageConnection'];
        parent?: Maybe<ResolversTypes['Repository']>;
        pinnedDiscussions: ResolversTypes['PinnedDiscussionConnection'];
        pinnedIssues?: Maybe<ResolversTypes['PinnedIssueConnection']>;
        project?: Maybe<ResolversTypes['Project']>;
        projects: ResolversTypes['ProjectConnection'];
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
        pullRequestTemplates?: Maybe<Array<ResolversTypes['PullRequestTemplate']>>;
        pullRequests: ResolversTypes['PullRequestConnection'];
        ref?: Maybe<ResolversTypes['Ref']>;
        release?: Maybe<ResolversTypes['Release']>;
        releases: ResolversTypes['ReleaseConnection'];
        templateRepository?: Maybe<ResolversTypes['Repository']>;
        vulnerabilityAlerts?: Maybe<ResolversTypes['RepositoryVulnerabilityAlertConnection']>;
        watchers: ResolversTypes['UserConnection'];
    }>;
    RepositoryAffiliation: RepositoryAffiliation;
    RepositoryAuditEntryData: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['RepositoryAuditEntryData']>;
    RepositoryCollaboratorConnection: ResolverTypeWrapper<Omit<RepositoryCollaboratorConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['RepositoryCollaboratorEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['User']>>>;
    }>;
    RepositoryCollaboratorEdge: ResolverTypeWrapper<Omit<RepositoryCollaboratorEdge, 'node' | 'permissionSources'> & {
        node: ResolversTypes['User'];
        permissionSources?: Maybe<Array<ResolversTypes['PermissionSource']>>;
    }>;
    RepositoryConnection: ResolverTypeWrapper<Omit<RepositoryConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['RepositoryEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Repository']>>>;
    }>;
    RepositoryContactLink: ResolverTypeWrapper<RepositoryContactLink>;
    RepositoryContributionType: RepositoryContributionType;
    RepositoryDiscussionAuthor: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['RepositoryDiscussionAuthor']>;
    RepositoryDiscussionCommentAuthor: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['RepositoryDiscussionCommentAuthor']>;
    RepositoryEdge: ResolverTypeWrapper<Omit<RepositoryEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Repository']>;
    }>;
    RepositoryInfo: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['RepositoryInfo']>;
    RepositoryInvitation: ResolverTypeWrapper<Omit<RepositoryInvitation, 'invitee' | 'inviter' | 'repository'> & {
        invitee?: Maybe<ResolversTypes['User']>;
        inviter: ResolversTypes['User'];
        repository?: Maybe<ResolversTypes['RepositoryInfo']>;
    }>;
    RepositoryInvitationConnection: ResolverTypeWrapper<Omit<RepositoryInvitationConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['RepositoryInvitationEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['RepositoryInvitation']>>>;
    }>;
    RepositoryInvitationEdge: ResolverTypeWrapper<Omit<RepositoryInvitationEdge, 'node'> & {
        node?: Maybe<ResolversTypes['RepositoryInvitation']>;
    }>;
    RepositoryInvitationOrder: RepositoryInvitationOrder;
    RepositoryInvitationOrderField: RepositoryInvitationOrderField;
    RepositoryLockReason: RepositoryLockReason;
    RepositoryNode: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['RepositoryNode']>;
    RepositoryOrder: RepositoryOrder;
    RepositoryOrderField: RepositoryOrderField;
    RepositoryOwner: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['RepositoryOwner']>;
    RepositoryPermission: RepositoryPermission;
    RepositoryPrivacy: RepositoryPrivacy;
    RepositoryTopic: ResolverTypeWrapper<RepositoryTopic>;
    RepositoryTopicConnection: ResolverTypeWrapper<RepositoryTopicConnection>;
    RepositoryTopicEdge: ResolverTypeWrapper<RepositoryTopicEdge>;
    RepositoryVisibility: RepositoryVisibility;
    RepositoryVisibilityChangeDisableAuditEntry: ResolverTypeWrapper<Omit<RepositoryVisibilityChangeDisableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepositoryVisibilityChangeEnableAuditEntry: ResolverTypeWrapper<Omit<RepositoryVisibilityChangeEnableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    RepositoryVulnerabilityAlert: ResolverTypeWrapper<Omit<RepositoryVulnerabilityAlert, 'dismisser' | 'repository'> & {
        dismisser?: Maybe<ResolversTypes['User']>;
        repository: ResolversTypes['Repository'];
    }>;
    RepositoryVulnerabilityAlertConnection: ResolverTypeWrapper<Omit<RepositoryVulnerabilityAlertConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['RepositoryVulnerabilityAlertEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['RepositoryVulnerabilityAlert']>>>;
    }>;
    RepositoryVulnerabilityAlertEdge: ResolverTypeWrapper<Omit<RepositoryVulnerabilityAlertEdge, 'node'> & {
        node?: Maybe<ResolversTypes['RepositoryVulnerabilityAlert']>;
    }>;
    RequestReviewsInput: RequestReviewsInput;
    RequestReviewsPayload: ResolverTypeWrapper<Omit<RequestReviewsPayload, 'actor' | 'pullRequest' | 'requestedReviewersEdge'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
        requestedReviewersEdge?: Maybe<ResolversTypes['UserEdge']>;
    }>;
    RequestableCheckStatusState: RequestableCheckStatusState;
    RequestedReviewer: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['RequestedReviewer']>;
    RequirableByPullRequest: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['RequirableByPullRequest']>;
    RerequestCheckSuiteInput: RerequestCheckSuiteInput;
    RerequestCheckSuitePayload: ResolverTypeWrapper<Omit<RerequestCheckSuitePayload, 'checkSuite'> & {
        checkSuite?: Maybe<ResolversTypes['CheckSuite']>;
    }>;
    ResolveReviewThreadInput: ResolveReviewThreadInput;
    ResolveReviewThreadPayload: ResolverTypeWrapper<Omit<ResolveReviewThreadPayload, 'thread'> & {
        thread?: Maybe<ResolversTypes['PullRequestReviewThread']>;
    }>;
    RestrictedContribution: ResolverTypeWrapper<Omit<RestrictedContribution, 'user'> & {
        user: ResolversTypes['User'];
    }>;
    ReviewDismissalAllowance: ResolverTypeWrapper<Omit<ReviewDismissalAllowance, 'actor' | 'branchProtectionRule'> & {
        actor?: Maybe<ResolversTypes['ReviewDismissalAllowanceActor']>;
        branchProtectionRule?: Maybe<ResolversTypes['BranchProtectionRule']>;
    }>;
    ReviewDismissalAllowanceActor: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['ReviewDismissalAllowanceActor']>;
    ReviewDismissalAllowanceConnection: ResolverTypeWrapper<Omit<ReviewDismissalAllowanceConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['ReviewDismissalAllowanceEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['ReviewDismissalAllowance']>>>;
    }>;
    ReviewDismissalAllowanceEdge: ResolverTypeWrapper<Omit<ReviewDismissalAllowanceEdge, 'node'> & {
        node?: Maybe<ResolversTypes['ReviewDismissalAllowance']>;
    }>;
    ReviewDismissedEvent: ResolverTypeWrapper<Omit<ReviewDismissedEvent, 'actor' | 'pullRequest' | 'pullRequestCommit' | 'review'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        pullRequest: ResolversTypes['PullRequest'];
        pullRequestCommit?: Maybe<ResolversTypes['PullRequestCommit']>;
        review?: Maybe<ResolversTypes['PullRequestReview']>;
    }>;
    ReviewRequest: ResolverTypeWrapper<Omit<ReviewRequest, 'pullRequest' | 'requestedReviewer'> & {
        pullRequest: ResolversTypes['PullRequest'];
        requestedReviewer?: Maybe<ResolversTypes['RequestedReviewer']>;
    }>;
    ReviewRequestConnection: ResolverTypeWrapper<Omit<ReviewRequestConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['ReviewRequestEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['ReviewRequest']>>>;
    }>;
    ReviewRequestEdge: ResolverTypeWrapper<Omit<ReviewRequestEdge, 'node'> & {
        node?: Maybe<ResolversTypes['ReviewRequest']>;
    }>;
    ReviewRequestRemovedEvent: ResolverTypeWrapper<Omit<ReviewRequestRemovedEvent, 'actor' | 'pullRequest' | 'requestedReviewer'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        pullRequest: ResolversTypes['PullRequest'];
        requestedReviewer?: Maybe<ResolversTypes['RequestedReviewer']>;
    }>;
    ReviewRequestedEvent: ResolverTypeWrapper<Omit<ReviewRequestedEvent, 'actor' | 'pullRequest' | 'requestedReviewer'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        pullRequest: ResolversTypes['PullRequest'];
        requestedReviewer?: Maybe<ResolversTypes['RequestedReviewer']>;
    }>;
    ReviewStatusHovercardContext: ResolverTypeWrapper<ReviewStatusHovercardContext>;
    SamlDigestAlgorithm: SamlDigestAlgorithm;
    SamlSignatureAlgorithm: SamlSignatureAlgorithm;
    SavedReply: ResolverTypeWrapper<Omit<SavedReply, 'user'> & {
        user?: Maybe<ResolversTypes['Actor']>;
    }>;
    SavedReplyConnection: ResolverTypeWrapper<Omit<SavedReplyConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['SavedReplyEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['SavedReply']>>>;
    }>;
    SavedReplyEdge: ResolverTypeWrapper<Omit<SavedReplyEdge, 'node'> & {
        node?: Maybe<ResolversTypes['SavedReply']>;
    }>;
    SavedReplyOrder: SavedReplyOrder;
    SavedReplyOrderField: SavedReplyOrderField;
    SearchResultItem: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['SearchResultItem']>;
    SearchResultItemConnection: ResolverTypeWrapper<Omit<SearchResultItemConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['SearchResultItemEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['SearchResultItem']>>>;
    }>;
    SearchResultItemEdge: ResolverTypeWrapper<Omit<SearchResultItemEdge, 'node'> & {
        node?: Maybe<ResolversTypes['SearchResultItem']>;
    }>;
    SearchType: SearchType;
    SecurityAdvisory: ResolverTypeWrapper<SecurityAdvisory>;
    SecurityAdvisoryConnection: ResolverTypeWrapper<SecurityAdvisoryConnection>;
    SecurityAdvisoryEcosystem: SecurityAdvisoryEcosystem;
    SecurityAdvisoryEdge: ResolverTypeWrapper<SecurityAdvisoryEdge>;
    SecurityAdvisoryIdentifier: ResolverTypeWrapper<SecurityAdvisoryIdentifier>;
    SecurityAdvisoryPackage: ResolverTypeWrapper<SecurityAdvisoryPackage>;
    SecurityAdvisoryPackageVersion: ResolverTypeWrapper<SecurityAdvisoryPackageVersion>;
    SecurityAdvisoryReference: ResolverTypeWrapper<SecurityAdvisoryReference>;
    SecurityAdvisorySeverity: SecurityAdvisorySeverity;
    SecurityVulnerability: ResolverTypeWrapper<SecurityVulnerability>;
    SecurityVulnerabilityConnection: ResolverTypeWrapper<SecurityVulnerabilityConnection>;
    SecurityVulnerabilityEdge: ResolverTypeWrapper<SecurityVulnerabilityEdge>;
    SmimeSignature: ResolverTypeWrapper<Omit<SmimeSignature, 'signer'> & {
        signer?: Maybe<ResolversTypes['User']>;
    }>;
    Sponsor: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['Sponsor']>;
    Sponsorable: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['Sponsorable']>;
    Sponsorship: ResolverTypeWrapper<Omit<Sponsorship, 'maintainer' | 'sponsor' | 'sponsorEntity' | 'sponsorable'> & {
        maintainer: ResolversTypes['User'];
        sponsor?: Maybe<ResolversTypes['User']>;
        sponsorEntity?: Maybe<ResolversTypes['Sponsor']>;
        sponsorable: ResolversTypes['Sponsorable'];
    }>;
    SponsorshipConnection: ResolverTypeWrapper<Omit<SponsorshipConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['SponsorshipEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Sponsorship']>>>;
    }>;
    SponsorshipEdge: ResolverTypeWrapper<Omit<SponsorshipEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Sponsorship']>;
    }>;
    SponsorshipOrder: SponsorshipOrder;
    SponsorshipPrivacy: SponsorshipPrivacy;
    StarOrder: StarOrder;
    StarOrderField: StarOrderField;
    StargazerConnection: ResolverTypeWrapper<Omit<StargazerConnection, 'nodes'> & {
        nodes?: Maybe<Array<Maybe<ResolversTypes['User']>>>;
    }>;
    StargazerEdge: ResolverTypeWrapper<Omit<StargazerEdge, 'node'> & {
        node: ResolversTypes['User'];
    }>;
    Starrable: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['Starrable']>;
    StarredRepositoryConnection: ResolverTypeWrapper<Omit<StarredRepositoryConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['StarredRepositoryEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Repository']>>>;
    }>;
    StarredRepositoryEdge: ResolverTypeWrapper<Omit<StarredRepositoryEdge, 'node'> & {
        node: ResolversTypes['Repository'];
    }>;
    Status: ResolverTypeWrapper<Omit<Status, 'combinedContexts' | 'commit' | 'context' | 'contexts'> & {
        combinedContexts: ResolversTypes['StatusCheckRollupContextConnection'];
        commit?: Maybe<ResolversTypes['Commit']>;
        context?: Maybe<ResolversTypes['StatusContext']>;
        contexts: Array<ResolversTypes['StatusContext']>;
    }>;
    StatusCheckRollup: ResolverTypeWrapper<Omit<StatusCheckRollup, 'commit' | 'contexts'> & {
        commit?: Maybe<ResolversTypes['Commit']>;
        contexts: ResolversTypes['StatusCheckRollupContextConnection'];
    }>;
    StatusCheckRollupContext: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['StatusCheckRollupContext']>;
    StatusCheckRollupContextConnection: ResolverTypeWrapper<Omit<StatusCheckRollupContextConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['StatusCheckRollupContextEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['StatusCheckRollupContext']>>>;
    }>;
    StatusCheckRollupContextEdge: ResolverTypeWrapper<Omit<StatusCheckRollupContextEdge, 'node'> & {
        node?: Maybe<ResolversTypes['StatusCheckRollupContext']>;
    }>;
    StatusContext: ResolverTypeWrapper<Omit<StatusContext, 'commit' | 'creator'> & {
        commit?: Maybe<ResolversTypes['Commit']>;
        creator?: Maybe<ResolversTypes['Actor']>;
    }>;
    StatusState: StatusState;
    String: ResolverTypeWrapper<Scalars['String']['output']>;
    SubmitPullRequestReviewInput: SubmitPullRequestReviewInput;
    SubmitPullRequestReviewPayload: ResolverTypeWrapper<Omit<SubmitPullRequestReviewPayload, 'pullRequestReview'> & {
        pullRequestReview?: Maybe<ResolversTypes['PullRequestReview']>;
    }>;
    Submodule: ResolverTypeWrapper<Submodule>;
    SubmoduleConnection: ResolverTypeWrapper<SubmoduleConnection>;
    SubmoduleEdge: ResolverTypeWrapper<SubmoduleEdge>;
    Subscribable: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['Subscribable']>;
    SubscribedEvent: ResolverTypeWrapper<Omit<SubscribedEvent, 'actor' | 'subscribable'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        subscribable: ResolversTypes['Subscribable'];
    }>;
    SubscriptionState: SubscriptionState;
    SuggestedReviewer: ResolverTypeWrapper<Omit<SuggestedReviewer, 'reviewer'> & {
        reviewer: ResolversTypes['User'];
    }>;
    Tag: ResolverTypeWrapper<Omit<Tag, 'repository' | 'target'> & {
        repository: ResolversTypes['Repository'];
        target: ResolversTypes['GitObject'];
    }>;
    Team: ResolverTypeWrapper<Omit<Team, 'discussion' | 'discussions' | 'invitations' | 'memberStatuses' | 'organization' | 'parentTeam' | 'repositories'> & {
        discussion?: Maybe<ResolversTypes['TeamDiscussion']>;
        discussions: ResolversTypes['TeamDiscussionConnection'];
        invitations?: Maybe<ResolversTypes['OrganizationInvitationConnection']>;
        memberStatuses: ResolversTypes['UserStatusConnection'];
        organization: ResolversTypes['Organization'];
        parentTeam?: Maybe<ResolversTypes['Team']>;
        repositories: ResolversTypes['TeamRepositoryConnection'];
    }>;
    TeamAddMemberAuditEntry: ResolverTypeWrapper<Omit<TeamAddMemberAuditEntry, 'actor' | 'organization' | 'team' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        team?: Maybe<ResolversTypes['Team']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    TeamAddRepositoryAuditEntry: ResolverTypeWrapper<Omit<TeamAddRepositoryAuditEntry, 'actor' | 'organization' | 'repository' | 'team' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        team?: Maybe<ResolversTypes['Team']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    TeamAuditEntryData: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['TeamAuditEntryData']>;
    TeamChangeParentTeamAuditEntry: ResolverTypeWrapper<Omit<TeamChangeParentTeamAuditEntry, 'actor' | 'organization' | 'parentTeam' | 'parentTeamWas' | 'team' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        parentTeam?: Maybe<ResolversTypes['Team']>;
        parentTeamWas?: Maybe<ResolversTypes['Team']>;
        team?: Maybe<ResolversTypes['Team']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    TeamConnection: ResolverTypeWrapper<Omit<TeamConnection, 'nodes'> & {
        nodes?: Maybe<Array<Maybe<ResolversTypes['Team']>>>;
    }>;
    TeamDiscussion: ResolverTypeWrapper<Omit<TeamDiscussion, 'author' | 'comments' | 'editor' | 'reactionGroups' | 'reactions' | 'team' | 'userContentEdits'> & {
        author?: Maybe<ResolversTypes['Actor']>;
        comments: ResolversTypes['TeamDiscussionCommentConnection'];
        editor?: Maybe<ResolversTypes['Actor']>;
        reactionGroups?: Maybe<Array<ResolversTypes['ReactionGroup']>>;
        reactions: ResolversTypes['ReactionConnection'];
        team: ResolversTypes['Team'];
        userContentEdits?: Maybe<ResolversTypes['UserContentEditConnection']>;
    }>;
    TeamDiscussionComment: ResolverTypeWrapper<Omit<TeamDiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'userContentEdits'> & {
        author?: Maybe<ResolversTypes['Actor']>;
        discussion: ResolversTypes['TeamDiscussion'];
        editor?: Maybe<ResolversTypes['Actor']>;
        reactionGroups?: Maybe<Array<ResolversTypes['ReactionGroup']>>;
        reactions: ResolversTypes['ReactionConnection'];
        userContentEdits?: Maybe<ResolversTypes['UserContentEditConnection']>;
    }>;
    TeamDiscussionCommentConnection: ResolverTypeWrapper<Omit<TeamDiscussionCommentConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['TeamDiscussionCommentEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['TeamDiscussionComment']>>>;
    }>;
    TeamDiscussionCommentEdge: ResolverTypeWrapper<Omit<TeamDiscussionCommentEdge, 'node'> & {
        node?: Maybe<ResolversTypes['TeamDiscussionComment']>;
    }>;
    TeamDiscussionCommentOrder: TeamDiscussionCommentOrder;
    TeamDiscussionCommentOrderField: TeamDiscussionCommentOrderField;
    TeamDiscussionConnection: ResolverTypeWrapper<Omit<TeamDiscussionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['TeamDiscussionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['TeamDiscussion']>>>;
    }>;
    TeamDiscussionEdge: ResolverTypeWrapper<Omit<TeamDiscussionEdge, 'node'> & {
        node?: Maybe<ResolversTypes['TeamDiscussion']>;
    }>;
    TeamDiscussionOrder: TeamDiscussionOrder;
    TeamDiscussionOrderField: TeamDiscussionOrderField;
    TeamEdge: ResolverTypeWrapper<Omit<TeamEdge, 'node'> & {
        node?: Maybe<ResolversTypes['Team']>;
    }>;
    TeamMemberConnection: ResolverTypeWrapper<Omit<TeamMemberConnection, 'nodes'> & {
        nodes?: Maybe<Array<Maybe<ResolversTypes['User']>>>;
    }>;
    TeamMemberEdge: ResolverTypeWrapper<Omit<TeamMemberEdge, 'node'> & {
        node: ResolversTypes['User'];
    }>;
    TeamMemberOrder: TeamMemberOrder;
    TeamMemberOrderField: TeamMemberOrderField;
    TeamMemberRole: TeamMemberRole;
    TeamMembershipType: TeamMembershipType;
    TeamOrder: TeamOrder;
    TeamOrderField: TeamOrderField;
    TeamPrivacy: TeamPrivacy;
    TeamRemoveMemberAuditEntry: ResolverTypeWrapper<Omit<TeamRemoveMemberAuditEntry, 'actor' | 'organization' | 'team' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        team?: Maybe<ResolversTypes['Team']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    TeamRemoveRepositoryAuditEntry: ResolverTypeWrapper<Omit<TeamRemoveRepositoryAuditEntry, 'actor' | 'organization' | 'repository' | 'team' | 'user'> & {
        actor?: Maybe<ResolversTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversTypes['Organization']>;
        repository?: Maybe<ResolversTypes['Repository']>;
        team?: Maybe<ResolversTypes['Team']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    TeamRepositoryConnection: ResolverTypeWrapper<Omit<TeamRepositoryConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['TeamRepositoryEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['Repository']>>>;
    }>;
    TeamRepositoryEdge: ResolverTypeWrapper<Omit<TeamRepositoryEdge, 'node'> & {
        node: ResolversTypes['Repository'];
    }>;
    TeamRepositoryOrder: TeamRepositoryOrder;
    TeamRepositoryOrderField: TeamRepositoryOrderField;
    TeamReviewAssignmentAlgorithm: TeamReviewAssignmentAlgorithm;
    TeamRole: TeamRole;
    TextMatch: ResolverTypeWrapper<TextMatch>;
    TextMatchHighlight: ResolverTypeWrapper<TextMatchHighlight>;
    Topic: ResolverTypeWrapper<Topic>;
    TopicAuditEntryData: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['TopicAuditEntryData']>;
    TransferIssueInput: TransferIssueInput;
    TransferIssuePayload: ResolverTypeWrapper<Omit<TransferIssuePayload, 'issue'> & {
        issue?: Maybe<ResolversTypes['Issue']>;
    }>;
    TransferredEvent: ResolverTypeWrapper<Omit<TransferredEvent, 'actor' | 'fromRepository' | 'issue'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        fromRepository?: Maybe<ResolversTypes['Repository']>;
        issue: ResolversTypes['Issue'];
    }>;
    Tree: ResolverTypeWrapper<Omit<Tree, 'entries' | 'repository'> & {
        entries?: Maybe<Array<ResolversTypes['TreeEntry']>>;
        repository: ResolversTypes['Repository'];
    }>;
    TreeEntry: ResolverTypeWrapper<Omit<TreeEntry, 'object' | 'repository'> & {
        object?: Maybe<ResolversTypes['GitObject']>;
        repository: ResolversTypes['Repository'];
    }>;
    URI: ResolverTypeWrapper<Scalars['URI']['output']>;
    UnarchiveRepositoryInput: UnarchiveRepositoryInput;
    UnarchiveRepositoryPayload: ResolverTypeWrapper<Omit<UnarchiveRepositoryPayload, 'repository'> & {
        repository?: Maybe<ResolversTypes['Repository']>;
    }>;
    UnassignedEvent: ResolverTypeWrapper<Omit<UnassignedEvent, 'actor' | 'assignable' | 'assignee' | 'user'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        assignable: ResolversTypes['Assignable'];
        assignee?: Maybe<ResolversTypes['Assignee']>;
        user?: Maybe<ResolversTypes['User']>;
    }>;
    UnfollowUserInput: UnfollowUserInput;
    UnfollowUserPayload: ResolverTypeWrapper<Omit<UnfollowUserPayload, 'user'> & {
        user?: Maybe<ResolversTypes['User']>;
    }>;
    UniformResourceLocatable: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['UniformResourceLocatable']>;
    UnknownSignature: ResolverTypeWrapper<Omit<UnknownSignature, 'signer'> & {
        signer?: Maybe<ResolversTypes['User']>;
    }>;
    UnlabeledEvent: ResolverTypeWrapper<Omit<UnlabeledEvent, 'actor' | 'label' | 'labelable'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        label: ResolversTypes['Label'];
        labelable: ResolversTypes['Labelable'];
    }>;
    UnlinkRepositoryFromProjectInput: UnlinkRepositoryFromProjectInput;
    UnlinkRepositoryFromProjectPayload: ResolverTypeWrapper<Omit<UnlinkRepositoryFromProjectPayload, 'project' | 'repository'> & {
        project?: Maybe<ResolversTypes['Project']>;
        repository?: Maybe<ResolversTypes['Repository']>;
    }>;
    UnlockLockableInput: UnlockLockableInput;
    UnlockLockablePayload: ResolverTypeWrapper<Omit<UnlockLockablePayload, 'actor' | 'unlockedRecord'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        unlockedRecord?: Maybe<ResolversTypes['Lockable']>;
    }>;
    UnlockedEvent: ResolverTypeWrapper<Omit<UnlockedEvent, 'actor' | 'lockable'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        lockable: ResolversTypes['Lockable'];
    }>;
    UnmarkDiscussionCommentAsAnswerInput: UnmarkDiscussionCommentAsAnswerInput;
    UnmarkDiscussionCommentAsAnswerPayload: ResolverTypeWrapper<Omit<UnmarkDiscussionCommentAsAnswerPayload, 'discussion'> & {
        discussion?: Maybe<ResolversTypes['Discussion']>;
    }>;
    UnmarkFileAsViewedInput: UnmarkFileAsViewedInput;
    UnmarkFileAsViewedPayload: ResolverTypeWrapper<Omit<UnmarkFileAsViewedPayload, 'pullRequest'> & {
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
    }>;
    UnmarkIssueAsDuplicateInput: UnmarkIssueAsDuplicateInput;
    UnmarkIssueAsDuplicatePayload: ResolverTypeWrapper<Omit<UnmarkIssueAsDuplicatePayload, 'duplicate'> & {
        duplicate?: Maybe<ResolversTypes['IssueOrPullRequest']>;
    }>;
    UnmarkedAsDuplicateEvent: ResolverTypeWrapper<Omit<UnmarkedAsDuplicateEvent, 'actor' | 'canonical' | 'duplicate'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        canonical?: Maybe<ResolversTypes['IssueOrPullRequest']>;
        duplicate?: Maybe<ResolversTypes['IssueOrPullRequest']>;
    }>;
    UnminimizeCommentInput: UnminimizeCommentInput;
    UnminimizeCommentPayload: ResolverTypeWrapper<Omit<UnminimizeCommentPayload, 'unminimizedComment'> & {
        unminimizedComment?: Maybe<ResolversTypes['Minimizable']>;
    }>;
    UnpinIssueInput: UnpinIssueInput;
    UnpinIssuePayload: ResolverTypeWrapper<Omit<UnpinIssuePayload, 'issue'> & {
        issue?: Maybe<ResolversTypes['Issue']>;
    }>;
    UnpinnedEvent: ResolverTypeWrapper<Omit<UnpinnedEvent, 'actor' | 'issue'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        issue: ResolversTypes['Issue'];
    }>;
    UnresolveReviewThreadInput: UnresolveReviewThreadInput;
    UnresolveReviewThreadPayload: ResolverTypeWrapper<Omit<UnresolveReviewThreadPayload, 'thread'> & {
        thread?: Maybe<ResolversTypes['PullRequestReviewThread']>;
    }>;
    UnsubscribedEvent: ResolverTypeWrapper<Omit<UnsubscribedEvent, 'actor' | 'subscribable'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        subscribable: ResolversTypes['Subscribable'];
    }>;
    Updatable: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['Updatable']>;
    UpdatableComment: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['UpdatableComment']>;
    UpdateBranchProtectionRuleInput: UpdateBranchProtectionRuleInput;
    UpdateBranchProtectionRulePayload: ResolverTypeWrapper<Omit<UpdateBranchProtectionRulePayload, 'branchProtectionRule'> & {
        branchProtectionRule?: Maybe<ResolversTypes['BranchProtectionRule']>;
    }>;
    UpdateCheckRunInput: UpdateCheckRunInput;
    UpdateCheckRunPayload: ResolverTypeWrapper<Omit<UpdateCheckRunPayload, 'checkRun'> & {
        checkRun?: Maybe<ResolversTypes['CheckRun']>;
    }>;
    UpdateCheckSuitePreferencesInput: UpdateCheckSuitePreferencesInput;
    UpdateCheckSuitePreferencesPayload: ResolverTypeWrapper<Omit<UpdateCheckSuitePreferencesPayload, 'repository'> & {
        repository?: Maybe<ResolversTypes['Repository']>;
    }>;
    UpdateDiscussionCommentInput: UpdateDiscussionCommentInput;
    UpdateDiscussionCommentPayload: ResolverTypeWrapper<Omit<UpdateDiscussionCommentPayload, 'comment'> & {
        comment?: Maybe<ResolversTypes['DiscussionComment']>;
    }>;
    UpdateDiscussionInput: UpdateDiscussionInput;
    UpdateDiscussionPayload: ResolverTypeWrapper<Omit<UpdateDiscussionPayload, 'discussion'> & {
        discussion?: Maybe<ResolversTypes['Discussion']>;
    }>;
    UpdateEnterpriseAllowPrivateRepositoryForkingSettingInput: UpdateEnterpriseAllowPrivateRepositoryForkingSettingInput;
    UpdateEnterpriseAllowPrivateRepositoryForkingSettingPayload: ResolverTypeWrapper<Omit<UpdateEnterpriseAllowPrivateRepositoryForkingSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
    }>;
    UpdateEnterpriseDefaultRepositoryPermissionSettingInput: UpdateEnterpriseDefaultRepositoryPermissionSettingInput;
    UpdateEnterpriseDefaultRepositoryPermissionSettingPayload: ResolverTypeWrapper<Omit<UpdateEnterpriseDefaultRepositoryPermissionSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
    }>;
    UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingInput: UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingInput;
    UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingPayload: ResolverTypeWrapper<Omit<UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
    }>;
    UpdateEnterpriseMembersCanCreateRepositoriesSettingInput: UpdateEnterpriseMembersCanCreateRepositoriesSettingInput;
    UpdateEnterpriseMembersCanCreateRepositoriesSettingPayload: ResolverTypeWrapper<Omit<UpdateEnterpriseMembersCanCreateRepositoriesSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
    }>;
    UpdateEnterpriseMembersCanDeleteIssuesSettingInput: UpdateEnterpriseMembersCanDeleteIssuesSettingInput;
    UpdateEnterpriseMembersCanDeleteIssuesSettingPayload: ResolverTypeWrapper<Omit<UpdateEnterpriseMembersCanDeleteIssuesSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
    }>;
    UpdateEnterpriseMembersCanDeleteRepositoriesSettingInput: UpdateEnterpriseMembersCanDeleteRepositoriesSettingInput;
    UpdateEnterpriseMembersCanDeleteRepositoriesSettingPayload: ResolverTypeWrapper<Omit<UpdateEnterpriseMembersCanDeleteRepositoriesSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
    }>;
    UpdateEnterpriseMembersCanInviteCollaboratorsSettingInput: UpdateEnterpriseMembersCanInviteCollaboratorsSettingInput;
    UpdateEnterpriseMembersCanInviteCollaboratorsSettingPayload: ResolverTypeWrapper<Omit<UpdateEnterpriseMembersCanInviteCollaboratorsSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
    }>;
    UpdateEnterpriseMembersCanMakePurchasesSettingInput: UpdateEnterpriseMembersCanMakePurchasesSettingInput;
    UpdateEnterpriseMembersCanMakePurchasesSettingPayload: ResolverTypeWrapper<Omit<UpdateEnterpriseMembersCanMakePurchasesSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
    }>;
    UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingInput: UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingInput;
    UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingPayload: ResolverTypeWrapper<Omit<UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
    }>;
    UpdateEnterpriseMembersCanViewDependencyInsightsSettingInput: UpdateEnterpriseMembersCanViewDependencyInsightsSettingInput;
    UpdateEnterpriseMembersCanViewDependencyInsightsSettingPayload: ResolverTypeWrapper<Omit<UpdateEnterpriseMembersCanViewDependencyInsightsSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
    }>;
    UpdateEnterpriseOrganizationProjectsSettingInput: UpdateEnterpriseOrganizationProjectsSettingInput;
    UpdateEnterpriseOrganizationProjectsSettingPayload: ResolverTypeWrapper<Omit<UpdateEnterpriseOrganizationProjectsSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
    }>;
    UpdateEnterpriseProfileInput: UpdateEnterpriseProfileInput;
    UpdateEnterpriseProfilePayload: ResolverTypeWrapper<Omit<UpdateEnterpriseProfilePayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
    }>;
    UpdateEnterpriseRepositoryProjectsSettingInput: UpdateEnterpriseRepositoryProjectsSettingInput;
    UpdateEnterpriseRepositoryProjectsSettingPayload: ResolverTypeWrapper<Omit<UpdateEnterpriseRepositoryProjectsSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
    }>;
    UpdateEnterpriseTeamDiscussionsSettingInput: UpdateEnterpriseTeamDiscussionsSettingInput;
    UpdateEnterpriseTeamDiscussionsSettingPayload: ResolverTypeWrapper<Omit<UpdateEnterpriseTeamDiscussionsSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
    }>;
    UpdateEnterpriseTwoFactorAuthenticationRequiredSettingInput: UpdateEnterpriseTwoFactorAuthenticationRequiredSettingInput;
    UpdateEnterpriseTwoFactorAuthenticationRequiredSettingPayload: ResolverTypeWrapper<Omit<UpdateEnterpriseTwoFactorAuthenticationRequiredSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversTypes['Enterprise']>;
    }>;
    UpdateEnvironmentInput: UpdateEnvironmentInput;
    UpdateEnvironmentPayload: ResolverTypeWrapper<Omit<UpdateEnvironmentPayload, 'environment'> & {
        environment?: Maybe<ResolversTypes['Environment']>;
    }>;
    UpdateIpAllowListEnabledSettingInput: UpdateIpAllowListEnabledSettingInput;
    UpdateIpAllowListEnabledSettingPayload: ResolverTypeWrapper<Omit<UpdateIpAllowListEnabledSettingPayload, 'owner'> & {
        owner?: Maybe<ResolversTypes['IpAllowListOwner']>;
    }>;
    UpdateIpAllowListEntryInput: UpdateIpAllowListEntryInput;
    UpdateIpAllowListEntryPayload: ResolverTypeWrapper<Omit<UpdateIpAllowListEntryPayload, 'ipAllowListEntry'> & {
        ipAllowListEntry?: Maybe<ResolversTypes['IpAllowListEntry']>;
    }>;
    UpdateIpAllowListForInstalledAppsEnabledSettingInput: UpdateIpAllowListForInstalledAppsEnabledSettingInput;
    UpdateIpAllowListForInstalledAppsEnabledSettingPayload: ResolverTypeWrapper<Omit<UpdateIpAllowListForInstalledAppsEnabledSettingPayload, 'owner'> & {
        owner?: Maybe<ResolversTypes['IpAllowListOwner']>;
    }>;
    UpdateIssueCommentInput: UpdateIssueCommentInput;
    UpdateIssueCommentPayload: ResolverTypeWrapper<Omit<UpdateIssueCommentPayload, 'issueComment'> & {
        issueComment?: Maybe<ResolversTypes['IssueComment']>;
    }>;
    UpdateIssueInput: UpdateIssueInput;
    UpdateIssuePayload: ResolverTypeWrapper<Omit<UpdateIssuePayload, 'actor' | 'issue'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        issue?: Maybe<ResolversTypes['Issue']>;
    }>;
    UpdateLabelInput: UpdateLabelInput;
    UpdateLabelPayload: ResolverTypeWrapper<Omit<UpdateLabelPayload, 'label'> & {
        label?: Maybe<ResolversTypes['Label']>;
    }>;
    UpdateNotificationRestrictionSettingInput: UpdateNotificationRestrictionSettingInput;
    UpdateNotificationRestrictionSettingPayload: ResolverTypeWrapper<Omit<UpdateNotificationRestrictionSettingPayload, 'owner'> & {
        owner?: Maybe<ResolversTypes['VerifiableDomainOwner']>;
    }>;
    UpdateProjectCardInput: UpdateProjectCardInput;
    UpdateProjectCardPayload: ResolverTypeWrapper<Omit<UpdateProjectCardPayload, 'projectCard'> & {
        projectCard?: Maybe<ResolversTypes['ProjectCard']>;
    }>;
    UpdateProjectColumnInput: UpdateProjectColumnInput;
    UpdateProjectColumnPayload: ResolverTypeWrapper<Omit<UpdateProjectColumnPayload, 'projectColumn'> & {
        projectColumn?: Maybe<ResolversTypes['ProjectColumn']>;
    }>;
    UpdateProjectInput: UpdateProjectInput;
    UpdateProjectPayload: ResolverTypeWrapper<Omit<UpdateProjectPayload, 'project'> & {
        project?: Maybe<ResolversTypes['Project']>;
    }>;
    UpdatePullRequestInput: UpdatePullRequestInput;
    UpdatePullRequestPayload: ResolverTypeWrapper<Omit<UpdatePullRequestPayload, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        pullRequest?: Maybe<ResolversTypes['PullRequest']>;
    }>;
    UpdatePullRequestReviewCommentInput: UpdatePullRequestReviewCommentInput;
    UpdatePullRequestReviewCommentPayload: ResolverTypeWrapper<Omit<UpdatePullRequestReviewCommentPayload, 'pullRequestReviewComment'> & {
        pullRequestReviewComment?: Maybe<ResolversTypes['PullRequestReviewComment']>;
    }>;
    UpdatePullRequestReviewInput: UpdatePullRequestReviewInput;
    UpdatePullRequestReviewPayload: ResolverTypeWrapper<Omit<UpdatePullRequestReviewPayload, 'pullRequestReview'> & {
        pullRequestReview?: Maybe<ResolversTypes['PullRequestReview']>;
    }>;
    UpdateRefInput: UpdateRefInput;
    UpdateRefPayload: ResolverTypeWrapper<Omit<UpdateRefPayload, 'ref'> & {
        ref?: Maybe<ResolversTypes['Ref']>;
    }>;
    UpdateRefsInput: UpdateRefsInput;
    UpdateRefsPayload: ResolverTypeWrapper<UpdateRefsPayload>;
    UpdateRepositoryInput: UpdateRepositoryInput;
    UpdateRepositoryPayload: ResolverTypeWrapper<Omit<UpdateRepositoryPayload, 'repository'> & {
        repository?: Maybe<ResolversTypes['Repository']>;
    }>;
    UpdateSubscriptionInput: UpdateSubscriptionInput;
    UpdateSubscriptionPayload: ResolverTypeWrapper<Omit<UpdateSubscriptionPayload, 'subscribable'> & {
        subscribable?: Maybe<ResolversTypes['Subscribable']>;
    }>;
    UpdateTeamDiscussionCommentInput: UpdateTeamDiscussionCommentInput;
    UpdateTeamDiscussionCommentPayload: ResolverTypeWrapper<Omit<UpdateTeamDiscussionCommentPayload, 'teamDiscussionComment'> & {
        teamDiscussionComment?: Maybe<ResolversTypes['TeamDiscussionComment']>;
    }>;
    UpdateTeamDiscussionInput: UpdateTeamDiscussionInput;
    UpdateTeamDiscussionPayload: ResolverTypeWrapper<Omit<UpdateTeamDiscussionPayload, 'teamDiscussion'> & {
        teamDiscussion?: Maybe<ResolversTypes['TeamDiscussion']>;
    }>;
    UpdateTeamReviewAssignmentInput: UpdateTeamReviewAssignmentInput;
    UpdateTeamReviewAssignmentPayload: ResolverTypeWrapper<Omit<UpdateTeamReviewAssignmentPayload, 'team'> & {
        team?: Maybe<ResolversTypes['Team']>;
    }>;
    UpdateTopicsInput: UpdateTopicsInput;
    UpdateTopicsPayload: ResolverTypeWrapper<Omit<UpdateTopicsPayload, 'repository'> & {
        repository?: Maybe<ResolversTypes['Repository']>;
    }>;
    User: ResolverTypeWrapper<Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: ResolversTypes['CommitCommentConnection'];
        contributionsCollection: ResolversTypes['ContributionsCollection'];
        followers: ResolversTypes['FollowerConnection'];
        following: ResolversTypes['FollowingConnection'];
        gist?: Maybe<ResolversTypes['Gist']>;
        gistComments: ResolversTypes['GistCommentConnection'];
        gists: ResolversTypes['GistConnection'];
        hovercard: ResolversTypes['Hovercard'];
        issueComments: ResolversTypes['IssueCommentConnection'];
        itemShowcase: ResolversTypes['ProfileItemShowcase'];
        organization?: Maybe<ResolversTypes['Organization']>;
        organizations: ResolversTypes['OrganizationConnection'];
        packages: ResolversTypes['PackageConnection'];
        pinnableItems: ResolversTypes['PinnableItemConnection'];
        pinnedItems: ResolversTypes['PinnableItemConnection'];
        project?: Maybe<ResolversTypes['Project']>;
        projects: ResolversTypes['ProjectConnection'];
        pullRequests: ResolversTypes['PullRequestConnection'];
        repositories: ResolversTypes['RepositoryConnection'];
        repositoriesContributedTo: ResolversTypes['RepositoryConnection'];
        repository?: Maybe<ResolversTypes['Repository']>;
        repositoryDiscussionComments: ResolversTypes['DiscussionCommentConnection'];
        repositoryDiscussions: ResolversTypes['DiscussionConnection'];
        savedReplies?: Maybe<ResolversTypes['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: ResolversTypes['SponsorshipConnection'];
        sponsorshipsAsSponsor: ResolversTypes['SponsorshipConnection'];
        starredRepositories: ResolversTypes['StarredRepositoryConnection'];
        status?: Maybe<ResolversTypes['UserStatus']>;
        topRepositories: ResolversTypes['RepositoryConnection'];
        watching: ResolversTypes['RepositoryConnection'];
    }>;
    UserBlockDuration: UserBlockDuration;
    UserBlockedEvent: ResolverTypeWrapper<Omit<UserBlockedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<ResolversTypes['Actor']>;
        subject?: Maybe<ResolversTypes['User']>;
    }>;
    UserConnection: ResolverTypeWrapper<Omit<UserConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['UserEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['User']>>>;
    }>;
    UserContentEdit: ResolverTypeWrapper<Omit<UserContentEdit, 'deletedBy' | 'editor'> & {
        deletedBy?: Maybe<ResolversTypes['Actor']>;
        editor?: Maybe<ResolversTypes['Actor']>;
    }>;
    UserContentEditConnection: ResolverTypeWrapper<Omit<UserContentEditConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['UserContentEditEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['UserContentEdit']>>>;
    }>;
    UserContentEditEdge: ResolverTypeWrapper<Omit<UserContentEditEdge, 'node'> & {
        node?: Maybe<ResolversTypes['UserContentEdit']>;
    }>;
    UserEdge: ResolverTypeWrapper<Omit<UserEdge, 'node'> & {
        node?: Maybe<ResolversTypes['User']>;
    }>;
    UserEmailMetadata: ResolverTypeWrapper<UserEmailMetadata>;
    UserStatus: ResolverTypeWrapper<Omit<UserStatus, 'organization' | 'user'> & {
        organization?: Maybe<ResolversTypes['Organization']>;
        user: ResolversTypes['User'];
    }>;
    UserStatusConnection: ResolverTypeWrapper<Omit<UserStatusConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['UserStatusEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['UserStatus']>>>;
    }>;
    UserStatusEdge: ResolverTypeWrapper<Omit<UserStatusEdge, 'node'> & {
        node?: Maybe<ResolversTypes['UserStatus']>;
    }>;
    UserStatusOrder: UserStatusOrder;
    UserStatusOrderField: UserStatusOrderField;
    VerifiableDomain: ResolverTypeWrapper<Omit<VerifiableDomain, 'owner'> & {
        owner: ResolversTypes['VerifiableDomainOwner'];
    }>;
    VerifiableDomainConnection: ResolverTypeWrapper<Omit<VerifiableDomainConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversTypes['VerifiableDomainEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversTypes['VerifiableDomain']>>>;
    }>;
    VerifiableDomainEdge: ResolverTypeWrapper<Omit<VerifiableDomainEdge, 'node'> & {
        node?: Maybe<ResolversTypes['VerifiableDomain']>;
    }>;
    VerifiableDomainOrder: VerifiableDomainOrder;
    VerifiableDomainOrderField: VerifiableDomainOrderField;
    VerifiableDomainOwner: ResolverTypeWrapper<ResolversUnionTypes<ResolversTypes>['VerifiableDomainOwner']>;
    VerifyVerifiableDomainInput: VerifyVerifiableDomainInput;
    VerifyVerifiableDomainPayload: ResolverTypeWrapper<Omit<VerifyVerifiableDomainPayload, 'domain'> & {
        domain?: Maybe<ResolversTypes['VerifiableDomain']>;
    }>;
    ViewerHovercardContext: ResolverTypeWrapper<Omit<ViewerHovercardContext, 'viewer'> & {
        viewer: ResolversTypes['User'];
    }>;
    Votable: ResolverTypeWrapper<ResolversInterfaceTypes<ResolversTypes>['Votable']>;
    Workflow: ResolverTypeWrapper<Workflow>;
    WorkflowRun: ResolverTypeWrapper<Omit<WorkflowRun, 'checkSuite' | 'deploymentReviews' | 'pendingDeploymentRequests'> & {
        checkSuite: ResolversTypes['CheckSuite'];
        deploymentReviews: ResolversTypes['DeploymentReviewConnection'];
        pendingDeploymentRequests: ResolversTypes['DeploymentRequestConnection'];
    }>;
    X509Certificate: ResolverTypeWrapper<Scalars['X509Certificate']['output']>;
};
/** Mapping between all available schema types and the resolvers parents */
export type ResolversParentTypes = {
    Actor: ResolversInterfaceTypes<ResolversParentTypes>['Actor'];
    ActorLocation: ActorLocation;
    AddAssigneesToAssignableInput: AddAssigneesToAssignableInput;
    AddAssigneesToAssignablePayload: Omit<AddAssigneesToAssignablePayload, 'assignable'> & {
        assignable?: Maybe<ResolversParentTypes['Assignable']>;
    };
    AddCommentInput: AddCommentInput;
    AddCommentPayload: Omit<AddCommentPayload, 'commentEdge' | 'subject' | 'timelineEdge'> & {
        commentEdge?: Maybe<ResolversParentTypes['IssueCommentEdge']>;
        subject?: Maybe<ResolversParentTypes['Node']>;
        timelineEdge?: Maybe<ResolversParentTypes['IssueTimelineItemEdge']>;
    };
    AddDiscussionCommentInput: AddDiscussionCommentInput;
    AddDiscussionCommentPayload: Omit<AddDiscussionCommentPayload, 'comment'> & {
        comment?: Maybe<ResolversParentTypes['DiscussionComment']>;
    };
    AddEnterpriseAdminInput: AddEnterpriseAdminInput;
    AddEnterpriseAdminPayload: Omit<AddEnterpriseAdminPayload, 'admin' | 'enterprise' | 'viewer'> & {
        admin?: Maybe<ResolversParentTypes['User']>;
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
        viewer?: Maybe<ResolversParentTypes['User']>;
    };
    AddLabelsToLabelableInput: AddLabelsToLabelableInput;
    AddLabelsToLabelablePayload: Omit<AddLabelsToLabelablePayload, 'labelable'> & {
        labelable?: Maybe<ResolversParentTypes['Labelable']>;
    };
    AddProjectCardInput: AddProjectCardInput;
    AddProjectCardPayload: Omit<AddProjectCardPayload, 'cardEdge' | 'projectColumn'> & {
        cardEdge?: Maybe<ResolversParentTypes['ProjectCardEdge']>;
        projectColumn?: Maybe<ResolversParentTypes['ProjectColumn']>;
    };
    AddProjectColumnInput: AddProjectColumnInput;
    AddProjectColumnPayload: Omit<AddProjectColumnPayload, 'columnEdge' | 'project'> & {
        columnEdge?: Maybe<ResolversParentTypes['ProjectColumnEdge']>;
        project?: Maybe<ResolversParentTypes['Project']>;
    };
    AddPullRequestReviewCommentInput: AddPullRequestReviewCommentInput;
    AddPullRequestReviewCommentPayload: Omit<AddPullRequestReviewCommentPayload, 'comment' | 'commentEdge'> & {
        comment?: Maybe<ResolversParentTypes['PullRequestReviewComment']>;
        commentEdge?: Maybe<ResolversParentTypes['PullRequestReviewCommentEdge']>;
    };
    AddPullRequestReviewInput: AddPullRequestReviewInput;
    AddPullRequestReviewPayload: Omit<AddPullRequestReviewPayload, 'pullRequestReview' | 'reviewEdge'> & {
        pullRequestReview?: Maybe<ResolversParentTypes['PullRequestReview']>;
        reviewEdge?: Maybe<ResolversParentTypes['PullRequestReviewEdge']>;
    };
    AddPullRequestReviewThreadInput: AddPullRequestReviewThreadInput;
    AddPullRequestReviewThreadPayload: Omit<AddPullRequestReviewThreadPayload, 'thread'> & {
        thread?: Maybe<ResolversParentTypes['PullRequestReviewThread']>;
    };
    AddReactionInput: AddReactionInput;
    AddReactionPayload: Omit<AddReactionPayload, 'reaction' | 'subject'> & {
        reaction?: Maybe<ResolversParentTypes['Reaction']>;
        subject?: Maybe<ResolversParentTypes['Reactable']>;
    };
    AddStarInput: AddStarInput;
    AddStarPayload: Omit<AddStarPayload, 'starrable'> & {
        starrable?: Maybe<ResolversParentTypes['Starrable']>;
    };
    AddUpvoteInput: AddUpvoteInput;
    AddUpvotePayload: Omit<AddUpvotePayload, 'subject'> & {
        subject?: Maybe<ResolversParentTypes['Votable']>;
    };
    AddVerifiableDomainInput: AddVerifiableDomainInput;
    AddVerifiableDomainPayload: Omit<AddVerifiableDomainPayload, 'domain'> & {
        domain?: Maybe<ResolversParentTypes['VerifiableDomain']>;
    };
    AddedToProjectEvent: Omit<AddedToProjectEvent, 'actor' | 'project' | 'projectCard'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        project?: Maybe<ResolversParentTypes['Project']>;
        projectCard?: Maybe<ResolversParentTypes['ProjectCard']>;
    };
    App: Omit<App, 'ipAllowListEntries'> & {
        ipAllowListEntries: ResolversParentTypes['IpAllowListEntryConnection'];
    };
    ApproveDeploymentsInput: ApproveDeploymentsInput;
    ApproveDeploymentsPayload: Omit<ApproveDeploymentsPayload, 'deployments'> & {
        deployments?: Maybe<Array<ResolversParentTypes['Deployment']>>;
    };
    ApproveVerifiableDomainInput: ApproveVerifiableDomainInput;
    ApproveVerifiableDomainPayload: Omit<ApproveVerifiableDomainPayload, 'domain'> & {
        domain?: Maybe<ResolversParentTypes['VerifiableDomain']>;
    };
    ArchiveRepositoryInput: ArchiveRepositoryInput;
    ArchiveRepositoryPayload: Omit<ArchiveRepositoryPayload, 'repository'> & {
        repository?: Maybe<ResolversParentTypes['Repository']>;
    };
    Assignable: ResolversInterfaceTypes<ResolversParentTypes>['Assignable'];
    AssignedEvent: Omit<AssignedEvent, 'actor' | 'assignable' | 'assignee' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        assignable: ResolversParentTypes['Assignable'];
        assignee?: Maybe<ResolversParentTypes['Assignee']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    Assignee: ResolversUnionTypes<ResolversParentTypes>['Assignee'];
    AuditEntry: ResolversInterfaceTypes<ResolversParentTypes>['AuditEntry'];
    AuditEntryActor: ResolversUnionTypes<ResolversParentTypes>['AuditEntryActor'];
    AuditLogOrder: AuditLogOrder;
    AutoMergeDisabledEvent: Omit<AutoMergeDisabledEvent, 'actor' | 'disabler' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        disabler?: Maybe<ResolversParentTypes['User']>;
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
    };
    AutoMergeEnabledEvent: Omit<AutoMergeEnabledEvent, 'actor' | 'enabler' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        enabler?: Maybe<ResolversParentTypes['User']>;
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
    };
    AutoMergeRequest: Omit<AutoMergeRequest, 'enabledBy' | 'pullRequest'> & {
        enabledBy?: Maybe<ResolversParentTypes['Actor']>;
        pullRequest: ResolversParentTypes['PullRequest'];
    };
    AutoRebaseEnabledEvent: Omit<AutoRebaseEnabledEvent, 'actor' | 'enabler' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        enabler?: Maybe<ResolversParentTypes['User']>;
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
    };
    AutoSquashEnabledEvent: Omit<AutoSquashEnabledEvent, 'actor' | 'enabler' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        enabler?: Maybe<ResolversParentTypes['User']>;
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
    };
    AutomaticBaseChangeFailedEvent: Omit<AutomaticBaseChangeFailedEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        pullRequest: ResolversParentTypes['PullRequest'];
    };
    AutomaticBaseChangeSucceededEvent: Omit<AutomaticBaseChangeSucceededEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        pullRequest: ResolversParentTypes['PullRequest'];
    };
    BaseRefChangedEvent: Omit<BaseRefChangedEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        pullRequest: ResolversParentTypes['PullRequest'];
    };
    BaseRefDeletedEvent: Omit<BaseRefDeletedEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
    };
    BaseRefForcePushedEvent: Omit<BaseRefForcePushedEvent, 'actor' | 'afterCommit' | 'beforeCommit' | 'pullRequest' | 'ref'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        afterCommit?: Maybe<ResolversParentTypes['Commit']>;
        beforeCommit?: Maybe<ResolversParentTypes['Commit']>;
        pullRequest: ResolversParentTypes['PullRequest'];
        ref?: Maybe<ResolversParentTypes['Ref']>;
    };
    Blame: Omit<Blame, 'ranges'> & {
        ranges: Array<ResolversParentTypes['BlameRange']>;
    };
    BlameRange: Omit<BlameRange, 'commit'> & {
        commit: ResolversParentTypes['Commit'];
    };
    Blob: Omit<Blob, 'repository'> & {
        repository: ResolversParentTypes['Repository'];
    };
    Boolean: Scalars['Boolean']['output'];
    Bot: Bot;
    BranchProtectionRule: Omit<BranchProtectionRule, 'creator' | 'pushAllowances' | 'repository' | 'reviewDismissalAllowances'> & {
        creator?: Maybe<ResolversParentTypes['Actor']>;
        pushAllowances: ResolversParentTypes['PushAllowanceConnection'];
        repository?: Maybe<ResolversParentTypes['Repository']>;
        reviewDismissalAllowances: ResolversParentTypes['ReviewDismissalAllowanceConnection'];
    };
    BranchProtectionRuleConflict: Omit<BranchProtectionRuleConflict, 'branchProtectionRule' | 'conflictingBranchProtectionRule' | 'ref'> & {
        branchProtectionRule?: Maybe<ResolversParentTypes['BranchProtectionRule']>;
        conflictingBranchProtectionRule?: Maybe<ResolversParentTypes['BranchProtectionRule']>;
        ref?: Maybe<ResolversParentTypes['Ref']>;
    };
    BranchProtectionRuleConflictConnection: BranchProtectionRuleConflictConnection;
    BranchProtectionRuleConflictEdge: BranchProtectionRuleConflictEdge;
    BranchProtectionRuleConnection: Omit<BranchProtectionRuleConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['BranchProtectionRuleEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['BranchProtectionRule']>>>;
    };
    BranchProtectionRuleEdge: Omit<BranchProtectionRuleEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['BranchProtectionRule']>;
    };
    CVSS: Cvss;
    CWE: Cwe;
    CWEConnection: CweConnection;
    CWEEdge: CweEdge;
    ChangeUserStatusInput: ChangeUserStatusInput;
    ChangeUserStatusPayload: Omit<ChangeUserStatusPayload, 'status'> & {
        status?: Maybe<ResolversParentTypes['UserStatus']>;
    };
    CheckAnnotation: CheckAnnotation;
    CheckAnnotationConnection: CheckAnnotationConnection;
    CheckAnnotationData: CheckAnnotationData;
    CheckAnnotationEdge: CheckAnnotationEdge;
    CheckAnnotationPosition: CheckAnnotationPosition;
    CheckAnnotationRange: CheckAnnotationRange;
    CheckAnnotationSpan: CheckAnnotationSpan;
    CheckRun: Omit<CheckRun, 'checkSuite' | 'deployment' | 'pendingDeploymentRequest' | 'repository'> & {
        checkSuite: ResolversParentTypes['CheckSuite'];
        deployment?: Maybe<ResolversParentTypes['Deployment']>;
        pendingDeploymentRequest?: Maybe<ResolversParentTypes['DeploymentRequest']>;
        repository: ResolversParentTypes['Repository'];
    };
    CheckRunAction: CheckRunAction;
    CheckRunConnection: Omit<CheckRunConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['CheckRunEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['CheckRun']>>>;
    };
    CheckRunEdge: Omit<CheckRunEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['CheckRun']>;
    };
    CheckRunFilter: CheckRunFilter;
    CheckRunOutput: CheckRunOutput;
    CheckRunOutputImage: CheckRunOutputImage;
    CheckStep: CheckStep;
    CheckStepConnection: CheckStepConnection;
    CheckStepEdge: CheckStepEdge;
    CheckSuite: Omit<CheckSuite, 'app' | 'branch' | 'checkRuns' | 'commit' | 'creator' | 'matchingPullRequests' | 'push' | 'repository' | 'workflowRun'> & {
        app?: Maybe<ResolversParentTypes['App']>;
        branch?: Maybe<ResolversParentTypes['Ref']>;
        checkRuns?: Maybe<ResolversParentTypes['CheckRunConnection']>;
        commit: ResolversParentTypes['Commit'];
        creator?: Maybe<ResolversParentTypes['User']>;
        matchingPullRequests?: Maybe<ResolversParentTypes['PullRequestConnection']>;
        push?: Maybe<ResolversParentTypes['Push']>;
        repository: ResolversParentTypes['Repository'];
        workflowRun?: Maybe<ResolversParentTypes['WorkflowRun']>;
    };
    CheckSuiteAutoTriggerPreference: CheckSuiteAutoTriggerPreference;
    CheckSuiteConnection: Omit<CheckSuiteConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['CheckSuiteEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['CheckSuite']>>>;
    };
    CheckSuiteEdge: Omit<CheckSuiteEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['CheckSuite']>;
    };
    CheckSuiteFilter: CheckSuiteFilter;
    ClearLabelsFromLabelableInput: ClearLabelsFromLabelableInput;
    ClearLabelsFromLabelablePayload: Omit<ClearLabelsFromLabelablePayload, 'labelable'> & {
        labelable?: Maybe<ResolversParentTypes['Labelable']>;
    };
    CloneProjectInput: CloneProjectInput;
    CloneProjectPayload: Omit<CloneProjectPayload, 'project'> & {
        project?: Maybe<ResolversParentTypes['Project']>;
    };
    CloneTemplateRepositoryInput: CloneTemplateRepositoryInput;
    CloneTemplateRepositoryPayload: Omit<CloneTemplateRepositoryPayload, 'repository'> & {
        repository?: Maybe<ResolversParentTypes['Repository']>;
    };
    Closable: ResolversInterfaceTypes<ResolversParentTypes>['Closable'];
    CloseIssueInput: CloseIssueInput;
    CloseIssuePayload: Omit<CloseIssuePayload, 'issue'> & {
        issue?: Maybe<ResolversParentTypes['Issue']>;
    };
    ClosePullRequestInput: ClosePullRequestInput;
    ClosePullRequestPayload: Omit<ClosePullRequestPayload, 'pullRequest'> & {
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
    };
    ClosedEvent: Omit<ClosedEvent, 'actor' | 'closable' | 'closer'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        closable: ResolversParentTypes['Closable'];
        closer?: Maybe<ResolversParentTypes['Closer']>;
    };
    Closer: ResolversUnionTypes<ResolversParentTypes>['Closer'];
    CodeOfConduct: CodeOfConduct;
    Comment: ResolversInterfaceTypes<ResolversParentTypes>['Comment'];
    CommentDeletedEvent: Omit<CommentDeletedEvent, 'actor' | 'deletedCommentAuthor'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        deletedCommentAuthor?: Maybe<ResolversParentTypes['Actor']>;
    };
    Commit: Omit<Commit, 'associatedPullRequests' | 'blame' | 'checkSuites' | 'comments' | 'deployments' | 'file' | 'history' | 'onBehalfOf' | 'parents' | 'repository' | 'signature' | 'status' | 'statusCheckRollup' | 'tree'> & {
        associatedPullRequests?: Maybe<ResolversParentTypes['PullRequestConnection']>;
        blame: ResolversParentTypes['Blame'];
        checkSuites?: Maybe<ResolversParentTypes['CheckSuiteConnection']>;
        comments: ResolversParentTypes['CommitCommentConnection'];
        deployments?: Maybe<ResolversParentTypes['DeploymentConnection']>;
        file?: Maybe<ResolversParentTypes['TreeEntry']>;
        history: ResolversParentTypes['CommitHistoryConnection'];
        onBehalfOf?: Maybe<ResolversParentTypes['Organization']>;
        parents: ResolversParentTypes['CommitConnection'];
        repository: ResolversParentTypes['Repository'];
        signature?: Maybe<ResolversParentTypes['GitSignature']>;
        status?: Maybe<ResolversParentTypes['Status']>;
        statusCheckRollup?: Maybe<ResolversParentTypes['StatusCheckRollup']>;
        tree: ResolversParentTypes['Tree'];
    };
    CommitAuthor: CommitAuthor;
    CommitComment: Omit<CommitComment, 'author' | 'commit' | 'editor' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<ResolversParentTypes['Actor']>;
        commit?: Maybe<ResolversParentTypes['Commit']>;
        editor?: Maybe<ResolversParentTypes['Actor']>;
        reactionGroups?: Maybe<Array<ResolversParentTypes['ReactionGroup']>>;
        reactions: ResolversParentTypes['ReactionConnection'];
        repository: ResolversParentTypes['Repository'];
        userContentEdits?: Maybe<ResolversParentTypes['UserContentEditConnection']>;
    };
    CommitCommentConnection: Omit<CommitCommentConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['CommitCommentEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['CommitComment']>>>;
    };
    CommitCommentEdge: Omit<CommitCommentEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['CommitComment']>;
    };
    CommitCommentThread: Omit<CommitCommentThread, 'comments' | 'commit' | 'repository'> & {
        comments: ResolversParentTypes['CommitCommentConnection'];
        commit?: Maybe<ResolversParentTypes['Commit']>;
        repository: ResolversParentTypes['Repository'];
    };
    CommitConnection: Omit<CommitConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['CommitEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Commit']>>>;
    };
    CommitContributionOrder: CommitContributionOrder;
    CommitContributionsByRepository: Omit<CommitContributionsByRepository, 'contributions' | 'repository'> & {
        contributions: ResolversParentTypes['CreatedCommitContributionConnection'];
        repository: ResolversParentTypes['Repository'];
    };
    CommitEdge: Omit<CommitEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Commit']>;
    };
    CommitHistoryConnection: Omit<CommitHistoryConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['CommitEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Commit']>>>;
    };
    ConnectedEvent: Omit<ConnectedEvent, 'actor' | 'source' | 'subject'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        source: ResolversParentTypes['ReferencedSubject'];
        subject: ResolversParentTypes['ReferencedSubject'];
    };
    ContentAttachment: ContentAttachment;
    ContentReference: ContentReference;
    Contribution: ResolversInterfaceTypes<ResolversParentTypes>['Contribution'];
    ContributionCalendar: ContributionCalendar;
    ContributionCalendarDay: ContributionCalendarDay;
    ContributionCalendarMonth: ContributionCalendarMonth;
    ContributionCalendarWeek: ContributionCalendarWeek;
    ContributionOrder: ContributionOrder;
    ContributionsCollection: Omit<ContributionsCollection, 'commitContributionsByRepository' | 'firstIssueContribution' | 'firstPullRequestContribution' | 'firstRepositoryContribution' | 'issueContributions' | 'issueContributionsByRepository' | 'joinedGitHubContribution' | 'mostRecentCollectionWithActivity' | 'mostRecentCollectionWithoutActivity' | 'popularIssueContribution' | 'popularPullRequestContribution' | 'pullRequestContributions' | 'pullRequestContributionsByRepository' | 'pullRequestReviewContributions' | 'pullRequestReviewContributionsByRepository' | 'repositoryContributions' | 'user'> & {
        commitContributionsByRepository: Array<ResolversParentTypes['CommitContributionsByRepository']>;
        firstIssueContribution?: Maybe<ResolversParentTypes['CreatedIssueOrRestrictedContribution']>;
        firstPullRequestContribution?: Maybe<ResolversParentTypes['CreatedPullRequestOrRestrictedContribution']>;
        firstRepositoryContribution?: Maybe<ResolversParentTypes['CreatedRepositoryOrRestrictedContribution']>;
        issueContributions: ResolversParentTypes['CreatedIssueContributionConnection'];
        issueContributionsByRepository: Array<ResolversParentTypes['IssueContributionsByRepository']>;
        joinedGitHubContribution?: Maybe<ResolversParentTypes['JoinedGitHubContribution']>;
        mostRecentCollectionWithActivity?: Maybe<ResolversParentTypes['ContributionsCollection']>;
        mostRecentCollectionWithoutActivity?: Maybe<ResolversParentTypes['ContributionsCollection']>;
        popularIssueContribution?: Maybe<ResolversParentTypes['CreatedIssueContribution']>;
        popularPullRequestContribution?: Maybe<ResolversParentTypes['CreatedPullRequestContribution']>;
        pullRequestContributions: ResolversParentTypes['CreatedPullRequestContributionConnection'];
        pullRequestContributionsByRepository: Array<ResolversParentTypes['PullRequestContributionsByRepository']>;
        pullRequestReviewContributions: ResolversParentTypes['CreatedPullRequestReviewContributionConnection'];
        pullRequestReviewContributionsByRepository: Array<ResolversParentTypes['PullRequestReviewContributionsByRepository']>;
        repositoryContributions: ResolversParentTypes['CreatedRepositoryContributionConnection'];
        user: ResolversParentTypes['User'];
    };
    ConvertProjectCardNoteToIssueInput: ConvertProjectCardNoteToIssueInput;
    ConvertProjectCardNoteToIssuePayload: Omit<ConvertProjectCardNoteToIssuePayload, 'projectCard'> & {
        projectCard?: Maybe<ResolversParentTypes['ProjectCard']>;
    };
    ConvertPullRequestToDraftInput: ConvertPullRequestToDraftInput;
    ConvertPullRequestToDraftPayload: Omit<ConvertPullRequestToDraftPayload, 'pullRequest'> & {
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
    };
    ConvertToDraftEvent: Omit<ConvertToDraftEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        pullRequest: ResolversParentTypes['PullRequest'];
    };
    ConvertedNoteToIssueEvent: Omit<ConvertedNoteToIssueEvent, 'actor' | 'project' | 'projectCard'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        project?: Maybe<ResolversParentTypes['Project']>;
        projectCard?: Maybe<ResolversParentTypes['ProjectCard']>;
    };
    CreateBranchProtectionRuleInput: CreateBranchProtectionRuleInput;
    CreateBranchProtectionRulePayload: Omit<CreateBranchProtectionRulePayload, 'branchProtectionRule'> & {
        branchProtectionRule?: Maybe<ResolversParentTypes['BranchProtectionRule']>;
    };
    CreateCheckRunInput: CreateCheckRunInput;
    CreateCheckRunPayload: Omit<CreateCheckRunPayload, 'checkRun'> & {
        checkRun?: Maybe<ResolversParentTypes['CheckRun']>;
    };
    CreateCheckSuiteInput: CreateCheckSuiteInput;
    CreateCheckSuitePayload: Omit<CreateCheckSuitePayload, 'checkSuite'> & {
        checkSuite?: Maybe<ResolversParentTypes['CheckSuite']>;
    };
    CreateContentAttachmentInput: CreateContentAttachmentInput;
    CreateContentAttachmentPayload: CreateContentAttachmentPayload;
    CreateDeploymentInput: CreateDeploymentInput;
    CreateDeploymentPayload: Omit<CreateDeploymentPayload, 'deployment'> & {
        deployment?: Maybe<ResolversParentTypes['Deployment']>;
    };
    CreateDeploymentStatusInput: CreateDeploymentStatusInput;
    CreateDeploymentStatusPayload: Omit<CreateDeploymentStatusPayload, 'deploymentStatus'> & {
        deploymentStatus?: Maybe<ResolversParentTypes['DeploymentStatus']>;
    };
    CreateDiscussionInput: CreateDiscussionInput;
    CreateDiscussionPayload: Omit<CreateDiscussionPayload, 'discussion'> & {
        discussion?: Maybe<ResolversParentTypes['Discussion']>;
    };
    CreateEnterpriseOrganizationInput: CreateEnterpriseOrganizationInput;
    CreateEnterpriseOrganizationPayload: Omit<CreateEnterpriseOrganizationPayload, 'enterprise' | 'organization'> & {
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
    };
    CreateEnvironmentInput: CreateEnvironmentInput;
    CreateEnvironmentPayload: Omit<CreateEnvironmentPayload, 'environment'> & {
        environment?: Maybe<ResolversParentTypes['Environment']>;
    };
    CreateIpAllowListEntryInput: CreateIpAllowListEntryInput;
    CreateIpAllowListEntryPayload: Omit<CreateIpAllowListEntryPayload, 'ipAllowListEntry'> & {
        ipAllowListEntry?: Maybe<ResolversParentTypes['IpAllowListEntry']>;
    };
    CreateIssueInput: CreateIssueInput;
    CreateIssuePayload: Omit<CreateIssuePayload, 'issue'> & {
        issue?: Maybe<ResolversParentTypes['Issue']>;
    };
    CreateLabelInput: CreateLabelInput;
    CreateLabelPayload: Omit<CreateLabelPayload, 'label'> & {
        label?: Maybe<ResolversParentTypes['Label']>;
    };
    CreateProjectInput: CreateProjectInput;
    CreateProjectPayload: Omit<CreateProjectPayload, 'project'> & {
        project?: Maybe<ResolversParentTypes['Project']>;
    };
    CreatePullRequestInput: CreatePullRequestInput;
    CreatePullRequestPayload: Omit<CreatePullRequestPayload, 'pullRequest'> & {
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
    };
    CreateRefInput: CreateRefInput;
    CreateRefPayload: Omit<CreateRefPayload, 'ref'> & {
        ref?: Maybe<ResolversParentTypes['Ref']>;
    };
    CreateRepositoryInput: CreateRepositoryInput;
    CreateRepositoryPayload: Omit<CreateRepositoryPayload, 'repository'> & {
        repository?: Maybe<ResolversParentTypes['Repository']>;
    };
    CreateTeamDiscussionCommentInput: CreateTeamDiscussionCommentInput;
    CreateTeamDiscussionCommentPayload: Omit<CreateTeamDiscussionCommentPayload, 'teamDiscussionComment'> & {
        teamDiscussionComment?: Maybe<ResolversParentTypes['TeamDiscussionComment']>;
    };
    CreateTeamDiscussionInput: CreateTeamDiscussionInput;
    CreateTeamDiscussionPayload: Omit<CreateTeamDiscussionPayload, 'teamDiscussion'> & {
        teamDiscussion?: Maybe<ResolversParentTypes['TeamDiscussion']>;
    };
    CreatedCommitContribution: Omit<CreatedCommitContribution, 'repository' | 'user'> & {
        repository: ResolversParentTypes['Repository'];
        user: ResolversParentTypes['User'];
    };
    CreatedCommitContributionConnection: Omit<CreatedCommitContributionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['CreatedCommitContributionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['CreatedCommitContribution']>>>;
    };
    CreatedCommitContributionEdge: Omit<CreatedCommitContributionEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['CreatedCommitContribution']>;
    };
    CreatedIssueContribution: Omit<CreatedIssueContribution, 'issue' | 'user'> & {
        issue: ResolversParentTypes['Issue'];
        user: ResolversParentTypes['User'];
    };
    CreatedIssueContributionConnection: Omit<CreatedIssueContributionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['CreatedIssueContributionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['CreatedIssueContribution']>>>;
    };
    CreatedIssueContributionEdge: Omit<CreatedIssueContributionEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['CreatedIssueContribution']>;
    };
    CreatedIssueOrRestrictedContribution: ResolversUnionTypes<ResolversParentTypes>['CreatedIssueOrRestrictedContribution'];
    CreatedPullRequestContribution: Omit<CreatedPullRequestContribution, 'pullRequest' | 'user'> & {
        pullRequest: ResolversParentTypes['PullRequest'];
        user: ResolversParentTypes['User'];
    };
    CreatedPullRequestContributionConnection: Omit<CreatedPullRequestContributionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['CreatedPullRequestContributionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['CreatedPullRequestContribution']>>>;
    };
    CreatedPullRequestContributionEdge: Omit<CreatedPullRequestContributionEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['CreatedPullRequestContribution']>;
    };
    CreatedPullRequestOrRestrictedContribution: ResolversUnionTypes<ResolversParentTypes>['CreatedPullRequestOrRestrictedContribution'];
    CreatedPullRequestReviewContribution: Omit<CreatedPullRequestReviewContribution, 'pullRequest' | 'pullRequestReview' | 'repository' | 'user'> & {
        pullRequest: ResolversParentTypes['PullRequest'];
        pullRequestReview: ResolversParentTypes['PullRequestReview'];
        repository: ResolversParentTypes['Repository'];
        user: ResolversParentTypes['User'];
    };
    CreatedPullRequestReviewContributionConnection: Omit<CreatedPullRequestReviewContributionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['CreatedPullRequestReviewContributionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['CreatedPullRequestReviewContribution']>>>;
    };
    CreatedPullRequestReviewContributionEdge: Omit<CreatedPullRequestReviewContributionEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['CreatedPullRequestReviewContribution']>;
    };
    CreatedRepositoryContribution: Omit<CreatedRepositoryContribution, 'repository' | 'user'> & {
        repository: ResolversParentTypes['Repository'];
        user: ResolversParentTypes['User'];
    };
    CreatedRepositoryContributionConnection: Omit<CreatedRepositoryContributionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['CreatedRepositoryContributionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['CreatedRepositoryContribution']>>>;
    };
    CreatedRepositoryContributionEdge: Omit<CreatedRepositoryContributionEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['CreatedRepositoryContribution']>;
    };
    CreatedRepositoryOrRestrictedContribution: ResolversUnionTypes<ResolversParentTypes>['CreatedRepositoryOrRestrictedContribution'];
    CrossReferencedEvent: Omit<CrossReferencedEvent, 'actor' | 'source' | 'target'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        source: ResolversParentTypes['ReferencedSubject'];
        target: ResolversParentTypes['ReferencedSubject'];
    };
    Date: Scalars['Date']['output'];
    DateTime: Scalars['DateTime']['output'];
    Deletable: ResolversInterfaceTypes<ResolversParentTypes>['Deletable'];
    DeleteBranchProtectionRuleInput: DeleteBranchProtectionRuleInput;
    DeleteBranchProtectionRulePayload: DeleteBranchProtectionRulePayload;
    DeleteDeploymentInput: DeleteDeploymentInput;
    DeleteDeploymentPayload: DeleteDeploymentPayload;
    DeleteDiscussionCommentInput: DeleteDiscussionCommentInput;
    DeleteDiscussionCommentPayload: Omit<DeleteDiscussionCommentPayload, 'comment'> & {
        comment?: Maybe<ResolversParentTypes['DiscussionComment']>;
    };
    DeleteDiscussionInput: DeleteDiscussionInput;
    DeleteDiscussionPayload: Omit<DeleteDiscussionPayload, 'discussion'> & {
        discussion?: Maybe<ResolversParentTypes['Discussion']>;
    };
    DeleteEnvironmentInput: DeleteEnvironmentInput;
    DeleteEnvironmentPayload: DeleteEnvironmentPayload;
    DeleteIpAllowListEntryInput: DeleteIpAllowListEntryInput;
    DeleteIpAllowListEntryPayload: Omit<DeleteIpAllowListEntryPayload, 'ipAllowListEntry'> & {
        ipAllowListEntry?: Maybe<ResolversParentTypes['IpAllowListEntry']>;
    };
    DeleteIssueCommentInput: DeleteIssueCommentInput;
    DeleteIssueCommentPayload: DeleteIssueCommentPayload;
    DeleteIssueInput: DeleteIssueInput;
    DeleteIssuePayload: Omit<DeleteIssuePayload, 'repository'> & {
        repository?: Maybe<ResolversParentTypes['Repository']>;
    };
    DeleteLabelInput: DeleteLabelInput;
    DeleteLabelPayload: DeleteLabelPayload;
    DeletePackageVersionInput: DeletePackageVersionInput;
    DeletePackageVersionPayload: DeletePackageVersionPayload;
    DeleteProjectCardInput: DeleteProjectCardInput;
    DeleteProjectCardPayload: Omit<DeleteProjectCardPayload, 'column'> & {
        column?: Maybe<ResolversParentTypes['ProjectColumn']>;
    };
    DeleteProjectColumnInput: DeleteProjectColumnInput;
    DeleteProjectColumnPayload: Omit<DeleteProjectColumnPayload, 'project'> & {
        project?: Maybe<ResolversParentTypes['Project']>;
    };
    DeleteProjectInput: DeleteProjectInput;
    DeleteProjectPayload: Omit<DeleteProjectPayload, 'owner'> & {
        owner?: Maybe<ResolversParentTypes['ProjectOwner']>;
    };
    DeletePullRequestReviewCommentInput: DeletePullRequestReviewCommentInput;
    DeletePullRequestReviewCommentPayload: Omit<DeletePullRequestReviewCommentPayload, 'pullRequestReview'> & {
        pullRequestReview?: Maybe<ResolversParentTypes['PullRequestReview']>;
    };
    DeletePullRequestReviewInput: DeletePullRequestReviewInput;
    DeletePullRequestReviewPayload: Omit<DeletePullRequestReviewPayload, 'pullRequestReview'> & {
        pullRequestReview?: Maybe<ResolversParentTypes['PullRequestReview']>;
    };
    DeleteRefInput: DeleteRefInput;
    DeleteRefPayload: DeleteRefPayload;
    DeleteTeamDiscussionCommentInput: DeleteTeamDiscussionCommentInput;
    DeleteTeamDiscussionCommentPayload: DeleteTeamDiscussionCommentPayload;
    DeleteTeamDiscussionInput: DeleteTeamDiscussionInput;
    DeleteTeamDiscussionPayload: DeleteTeamDiscussionPayload;
    DeleteVerifiableDomainInput: DeleteVerifiableDomainInput;
    DeleteVerifiableDomainPayload: Omit<DeleteVerifiableDomainPayload, 'owner'> & {
        owner?: Maybe<ResolversParentTypes['VerifiableDomainOwner']>;
    };
    DemilestonedEvent: Omit<DemilestonedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        subject: ResolversParentTypes['MilestoneItem'];
    };
    DeployKey: DeployKey;
    DeployKeyConnection: DeployKeyConnection;
    DeployKeyEdge: DeployKeyEdge;
    DeployedEvent: Omit<DeployedEvent, 'actor' | 'deployment' | 'pullRequest' | 'ref'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        deployment: ResolversParentTypes['Deployment'];
        pullRequest: ResolversParentTypes['PullRequest'];
        ref?: Maybe<ResolversParentTypes['Ref']>;
    };
    Deployment: Omit<Deployment, 'commit' | 'creator' | 'latestStatus' | 'ref' | 'repository' | 'statuses'> & {
        commit?: Maybe<ResolversParentTypes['Commit']>;
        creator: ResolversParentTypes['Actor'];
        latestStatus?: Maybe<ResolversParentTypes['DeploymentStatus']>;
        ref?: Maybe<ResolversParentTypes['Ref']>;
        repository: ResolversParentTypes['Repository'];
        statuses?: Maybe<ResolversParentTypes['DeploymentStatusConnection']>;
    };
    DeploymentConnection: Omit<DeploymentConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['DeploymentEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Deployment']>>>;
    };
    DeploymentEdge: Omit<DeploymentEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Deployment']>;
    };
    DeploymentEnvironmentChangedEvent: Omit<DeploymentEnvironmentChangedEvent, 'actor' | 'deploymentStatus' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        deploymentStatus: ResolversParentTypes['DeploymentStatus'];
        pullRequest: ResolversParentTypes['PullRequest'];
    };
    DeploymentOrder: DeploymentOrder;
    DeploymentProtectionRule: Omit<DeploymentProtectionRule, 'reviewers'> & {
        reviewers: ResolversParentTypes['DeploymentReviewerConnection'];
    };
    DeploymentProtectionRuleConnection: Omit<DeploymentProtectionRuleConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['DeploymentProtectionRuleEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['DeploymentProtectionRule']>>>;
    };
    DeploymentProtectionRuleEdge: Omit<DeploymentProtectionRuleEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['DeploymentProtectionRule']>;
    };
    DeploymentRequest: Omit<DeploymentRequest, 'environment' | 'reviewers'> & {
        environment: ResolversParentTypes['Environment'];
        reviewers: ResolversParentTypes['DeploymentReviewerConnection'];
    };
    DeploymentRequestConnection: Omit<DeploymentRequestConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['DeploymentRequestEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['DeploymentRequest']>>>;
    };
    DeploymentRequestEdge: Omit<DeploymentRequestEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['DeploymentRequest']>;
    };
    DeploymentReview: Omit<DeploymentReview, 'environments' | 'user'> & {
        environments: ResolversParentTypes['EnvironmentConnection'];
        user: ResolversParentTypes['User'];
    };
    DeploymentReviewConnection: Omit<DeploymentReviewConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['DeploymentReviewEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['DeploymentReview']>>>;
    };
    DeploymentReviewEdge: Omit<DeploymentReviewEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['DeploymentReview']>;
    };
    DeploymentReviewer: ResolversUnionTypes<ResolversParentTypes>['DeploymentReviewer'];
    DeploymentReviewerConnection: Omit<DeploymentReviewerConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['DeploymentReviewerEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['DeploymentReviewer']>>>;
    };
    DeploymentReviewerEdge: Omit<DeploymentReviewerEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['DeploymentReviewer']>;
    };
    DeploymentStatus: Omit<DeploymentStatus, 'creator' | 'deployment'> & {
        creator: ResolversParentTypes['Actor'];
        deployment: ResolversParentTypes['Deployment'];
    };
    DeploymentStatusConnection: Omit<DeploymentStatusConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['DeploymentStatusEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['DeploymentStatus']>>>;
    };
    DeploymentStatusEdge: Omit<DeploymentStatusEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['DeploymentStatus']>;
    };
    DisablePullRequestAutoMergeInput: DisablePullRequestAutoMergeInput;
    DisablePullRequestAutoMergePayload: Omit<DisablePullRequestAutoMergePayload, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
    };
    DisconnectedEvent: Omit<DisconnectedEvent, 'actor' | 'source' | 'subject'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        source: ResolversParentTypes['ReferencedSubject'];
        subject: ResolversParentTypes['ReferencedSubject'];
    };
    Discussion: Omit<Discussion, 'answer' | 'answerChosenBy' | 'author' | 'category' | 'comments' | 'editor' | 'labels' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        answer?: Maybe<ResolversParentTypes['DiscussionComment']>;
        answerChosenBy?: Maybe<ResolversParentTypes['Actor']>;
        author?: Maybe<ResolversParentTypes['Actor']>;
        category: ResolversParentTypes['DiscussionCategory'];
        comments: ResolversParentTypes['DiscussionCommentConnection'];
        editor?: Maybe<ResolversParentTypes['Actor']>;
        labels?: Maybe<ResolversParentTypes['LabelConnection']>;
        reactionGroups?: Maybe<Array<ResolversParentTypes['ReactionGroup']>>;
        reactions: ResolversParentTypes['ReactionConnection'];
        repository: ResolversParentTypes['Repository'];
        userContentEdits?: Maybe<ResolversParentTypes['UserContentEditConnection']>;
    };
    DiscussionCategory: Omit<DiscussionCategory, 'repository'> & {
        repository: ResolversParentTypes['Repository'];
    };
    DiscussionCategoryConnection: Omit<DiscussionCategoryConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['DiscussionCategoryEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['DiscussionCategory']>>>;
    };
    DiscussionCategoryEdge: Omit<DiscussionCategoryEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['DiscussionCategory']>;
    };
    DiscussionComment: Omit<DiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'replies' | 'replyTo' | 'userContentEdits'> & {
        author?: Maybe<ResolversParentTypes['Actor']>;
        discussion?: Maybe<ResolversParentTypes['Discussion']>;
        editor?: Maybe<ResolversParentTypes['Actor']>;
        reactionGroups?: Maybe<Array<ResolversParentTypes['ReactionGroup']>>;
        reactions: ResolversParentTypes['ReactionConnection'];
        replies: ResolversParentTypes['DiscussionCommentConnection'];
        replyTo?: Maybe<ResolversParentTypes['DiscussionComment']>;
        userContentEdits?: Maybe<ResolversParentTypes['UserContentEditConnection']>;
    };
    DiscussionCommentConnection: Omit<DiscussionCommentConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['DiscussionCommentEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['DiscussionComment']>>>;
    };
    DiscussionCommentEdge: Omit<DiscussionCommentEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['DiscussionComment']>;
    };
    DiscussionConnection: Omit<DiscussionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['DiscussionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Discussion']>>>;
    };
    DiscussionEdge: Omit<DiscussionEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Discussion']>;
    };
    DiscussionOrder: DiscussionOrder;
    DismissPullRequestReviewInput: DismissPullRequestReviewInput;
    DismissPullRequestReviewPayload: Omit<DismissPullRequestReviewPayload, 'pullRequestReview'> & {
        pullRequestReview?: Maybe<ResolversParentTypes['PullRequestReview']>;
    };
    DraftPullRequestReviewComment: DraftPullRequestReviewComment;
    DraftPullRequestReviewThread: DraftPullRequestReviewThread;
    EnablePullRequestAutoMergeInput: EnablePullRequestAutoMergeInput;
    EnablePullRequestAutoMergePayload: Omit<EnablePullRequestAutoMergePayload, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
    };
    Enterprise: Omit<Enterprise, 'billingInfo' | 'members' | 'organizations' | 'ownerInfo' | 'userAccounts'> & {
        billingInfo?: Maybe<ResolversParentTypes['EnterpriseBillingInfo']>;
        members: ResolversParentTypes['EnterpriseMemberConnection'];
        organizations: ResolversParentTypes['OrganizationConnection'];
        ownerInfo?: Maybe<ResolversParentTypes['EnterpriseOwnerInfo']>;
        userAccounts: ResolversParentTypes['EnterpriseUserAccountConnection'];
    };
    EnterpriseAdministratorConnection: Omit<EnterpriseAdministratorConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['EnterpriseAdministratorEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['User']>>>;
    };
    EnterpriseAdministratorEdge: Omit<EnterpriseAdministratorEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['User']>;
    };
    EnterpriseAdministratorInvitation: Omit<EnterpriseAdministratorInvitation, 'enterprise' | 'invitee' | 'inviter'> & {
        enterprise: ResolversParentTypes['Enterprise'];
        invitee?: Maybe<ResolversParentTypes['User']>;
        inviter?: Maybe<ResolversParentTypes['User']>;
    };
    EnterpriseAdministratorInvitationConnection: Omit<EnterpriseAdministratorInvitationConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['EnterpriseAdministratorInvitationEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['EnterpriseAdministratorInvitation']>>>;
    };
    EnterpriseAdministratorInvitationEdge: Omit<EnterpriseAdministratorInvitationEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['EnterpriseAdministratorInvitation']>;
    };
    EnterpriseAdministratorInvitationOrder: EnterpriseAdministratorInvitationOrder;
    EnterpriseAuditEntryData: ResolversInterfaceTypes<ResolversParentTypes>['EnterpriseAuditEntryData'];
    EnterpriseBillingInfo: EnterpriseBillingInfo;
    EnterpriseIdentityProvider: Omit<EnterpriseIdentityProvider, 'enterprise' | 'externalIdentities'> & {
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
        externalIdentities: ResolversParentTypes['ExternalIdentityConnection'];
    };
    EnterpriseMember: ResolversUnionTypes<ResolversParentTypes>['EnterpriseMember'];
    EnterpriseMemberConnection: Omit<EnterpriseMemberConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['EnterpriseMemberEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['EnterpriseMember']>>>;
    };
    EnterpriseMemberEdge: Omit<EnterpriseMemberEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['EnterpriseMember']>;
    };
    EnterpriseMemberOrder: EnterpriseMemberOrder;
    EnterpriseOrganizationMembershipConnection: Omit<EnterpriseOrganizationMembershipConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['EnterpriseOrganizationMembershipEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Organization']>>>;
    };
    EnterpriseOrganizationMembershipEdge: Omit<EnterpriseOrganizationMembershipEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Organization']>;
    };
    EnterpriseOutsideCollaboratorConnection: Omit<EnterpriseOutsideCollaboratorConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['EnterpriseOutsideCollaboratorEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['User']>>>;
    };
    EnterpriseOutsideCollaboratorEdge: Omit<EnterpriseOutsideCollaboratorEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['User']>;
    };
    EnterpriseOwnerInfo: Omit<EnterpriseOwnerInfo, 'admins' | 'affiliatedUsersWithTwoFactorDisabled' | 'allowPrivateRepositoryForkingSettingOrganizations' | 'defaultRepositoryPermissionSettingOrganizations' | 'domains' | 'ipAllowListEntries' | 'membersCanChangeRepositoryVisibilitySettingOrganizations' | 'membersCanCreateRepositoriesSettingOrganizations' | 'membersCanDeleteIssuesSettingOrganizations' | 'membersCanDeleteRepositoriesSettingOrganizations' | 'membersCanInviteCollaboratorsSettingOrganizations' | 'membersCanUpdateProtectedBranchesSettingOrganizations' | 'membersCanViewDependencyInsightsSettingOrganizations' | 'organizationProjectsSettingOrganizations' | 'outsideCollaborators' | 'pendingAdminInvitations' | 'pendingCollaboratorInvitations' | 'pendingCollaborators' | 'pendingMemberInvitations' | 'repositoryProjectsSettingOrganizations' | 'samlIdentityProvider' | 'samlIdentityProviderSettingOrganizations' | 'teamDiscussionsSettingOrganizations' | 'twoFactorRequiredSettingOrganizations'> & {
        admins: ResolversParentTypes['EnterpriseAdministratorConnection'];
        affiliatedUsersWithTwoFactorDisabled: ResolversParentTypes['UserConnection'];
        allowPrivateRepositoryForkingSettingOrganizations: ResolversParentTypes['OrganizationConnection'];
        defaultRepositoryPermissionSettingOrganizations: ResolversParentTypes['OrganizationConnection'];
        domains: ResolversParentTypes['VerifiableDomainConnection'];
        ipAllowListEntries: ResolversParentTypes['IpAllowListEntryConnection'];
        membersCanChangeRepositoryVisibilitySettingOrganizations: ResolversParentTypes['OrganizationConnection'];
        membersCanCreateRepositoriesSettingOrganizations: ResolversParentTypes['OrganizationConnection'];
        membersCanDeleteIssuesSettingOrganizations: ResolversParentTypes['OrganizationConnection'];
        membersCanDeleteRepositoriesSettingOrganizations: ResolversParentTypes['OrganizationConnection'];
        membersCanInviteCollaboratorsSettingOrganizations: ResolversParentTypes['OrganizationConnection'];
        membersCanUpdateProtectedBranchesSettingOrganizations: ResolversParentTypes['OrganizationConnection'];
        membersCanViewDependencyInsightsSettingOrganizations: ResolversParentTypes['OrganizationConnection'];
        organizationProjectsSettingOrganizations: ResolversParentTypes['OrganizationConnection'];
        outsideCollaborators: ResolversParentTypes['EnterpriseOutsideCollaboratorConnection'];
        pendingAdminInvitations: ResolversParentTypes['EnterpriseAdministratorInvitationConnection'];
        pendingCollaboratorInvitations: ResolversParentTypes['RepositoryInvitationConnection'];
        pendingCollaborators: ResolversParentTypes['EnterprisePendingCollaboratorConnection'];
        pendingMemberInvitations: ResolversParentTypes['EnterprisePendingMemberInvitationConnection'];
        repositoryProjectsSettingOrganizations: ResolversParentTypes['OrganizationConnection'];
        samlIdentityProvider?: Maybe<ResolversParentTypes['EnterpriseIdentityProvider']>;
        samlIdentityProviderSettingOrganizations: ResolversParentTypes['OrganizationConnection'];
        teamDiscussionsSettingOrganizations: ResolversParentTypes['OrganizationConnection'];
        twoFactorRequiredSettingOrganizations: ResolversParentTypes['OrganizationConnection'];
    };
    EnterprisePendingCollaboratorConnection: Omit<EnterprisePendingCollaboratorConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['EnterprisePendingCollaboratorEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['User']>>>;
    };
    EnterprisePendingCollaboratorEdge: Omit<EnterprisePendingCollaboratorEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['User']>;
    };
    EnterprisePendingMemberInvitationConnection: Omit<EnterprisePendingMemberInvitationConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['EnterprisePendingMemberInvitationEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['OrganizationInvitation']>>>;
    };
    EnterprisePendingMemberInvitationEdge: Omit<EnterprisePendingMemberInvitationEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['OrganizationInvitation']>;
    };
    EnterpriseRepositoryInfo: EnterpriseRepositoryInfo;
    EnterpriseRepositoryInfoConnection: EnterpriseRepositoryInfoConnection;
    EnterpriseRepositoryInfoEdge: EnterpriseRepositoryInfoEdge;
    EnterpriseServerInstallation: Omit<EnterpriseServerInstallation, 'userAccounts' | 'userAccountsUploads'> & {
        userAccounts: ResolversParentTypes['EnterpriseServerUserAccountConnection'];
        userAccountsUploads: ResolversParentTypes['EnterpriseServerUserAccountsUploadConnection'];
    };
    EnterpriseServerUserAccount: Omit<EnterpriseServerUserAccount, 'enterpriseServerInstallation'> & {
        enterpriseServerInstallation: ResolversParentTypes['EnterpriseServerInstallation'];
    };
    EnterpriseServerUserAccountConnection: Omit<EnterpriseServerUserAccountConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['EnterpriseServerUserAccountEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['EnterpriseServerUserAccount']>>>;
    };
    EnterpriseServerUserAccountEdge: Omit<EnterpriseServerUserAccountEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['EnterpriseServerUserAccount']>;
    };
    EnterpriseServerUserAccountEmail: Omit<EnterpriseServerUserAccountEmail, 'userAccount'> & {
        userAccount: ResolversParentTypes['EnterpriseServerUserAccount'];
    };
    EnterpriseServerUserAccountEmailConnection: EnterpriseServerUserAccountEmailConnection;
    EnterpriseServerUserAccountEmailEdge: EnterpriseServerUserAccountEmailEdge;
    EnterpriseServerUserAccountEmailOrder: EnterpriseServerUserAccountEmailOrder;
    EnterpriseServerUserAccountOrder: EnterpriseServerUserAccountOrder;
    EnterpriseServerUserAccountsUpload: Omit<EnterpriseServerUserAccountsUpload, 'enterprise' | 'enterpriseServerInstallation'> & {
        enterprise: ResolversParentTypes['Enterprise'];
        enterpriseServerInstallation: ResolversParentTypes['EnterpriseServerInstallation'];
    };
    EnterpriseServerUserAccountsUploadConnection: Omit<EnterpriseServerUserAccountsUploadConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['EnterpriseServerUserAccountsUploadEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['EnterpriseServerUserAccountsUpload']>>>;
    };
    EnterpriseServerUserAccountsUploadEdge: Omit<EnterpriseServerUserAccountsUploadEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['EnterpriseServerUserAccountsUpload']>;
    };
    EnterpriseServerUserAccountsUploadOrder: EnterpriseServerUserAccountsUploadOrder;
    EnterpriseUserAccount: Omit<EnterpriseUserAccount, 'enterprise' | 'organizations' | 'user'> & {
        enterprise: ResolversParentTypes['Enterprise'];
        organizations: ResolversParentTypes['EnterpriseOrganizationMembershipConnection'];
        user?: Maybe<ResolversParentTypes['User']>;
    };
    EnterpriseUserAccountConnection: Omit<EnterpriseUserAccountConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['EnterpriseUserAccountEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['EnterpriseUserAccount']>>>;
    };
    EnterpriseUserAccountEdge: Omit<EnterpriseUserAccountEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['EnterpriseUserAccount']>;
    };
    Environment: Omit<Environment, 'protectionRules'> & {
        protectionRules: ResolversParentTypes['DeploymentProtectionRuleConnection'];
    };
    EnvironmentConnection: Omit<EnvironmentConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['EnvironmentEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Environment']>>>;
    };
    EnvironmentEdge: Omit<EnvironmentEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Environment']>;
    };
    ExternalIdentity: Omit<ExternalIdentity, 'organizationInvitation' | 'user'> & {
        organizationInvitation?: Maybe<ResolversParentTypes['OrganizationInvitation']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    ExternalIdentityConnection: Omit<ExternalIdentityConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['ExternalIdentityEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['ExternalIdentity']>>>;
    };
    ExternalIdentityEdge: Omit<ExternalIdentityEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['ExternalIdentity']>;
    };
    ExternalIdentitySamlAttributes: ExternalIdentitySamlAttributes;
    ExternalIdentityScimAttributes: ExternalIdentityScimAttributes;
    Float: Scalars['Float']['output'];
    FollowUserInput: FollowUserInput;
    FollowUserPayload: Omit<FollowUserPayload, 'user'> & {
        user?: Maybe<ResolversParentTypes['User']>;
    };
    FollowerConnection: Omit<FollowerConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['UserEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['User']>>>;
    };
    FollowingConnection: Omit<FollowingConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['UserEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['User']>>>;
    };
    GenericHovercardContext: GenericHovercardContext;
    Gist: Omit<Gist, 'comments' | 'forks' | 'owner'> & {
        comments: ResolversParentTypes['GistCommentConnection'];
        forks: ResolversParentTypes['GistConnection'];
        owner?: Maybe<ResolversParentTypes['RepositoryOwner']>;
    };
    GistComment: Omit<GistComment, 'author' | 'editor' | 'gist' | 'userContentEdits'> & {
        author?: Maybe<ResolversParentTypes['Actor']>;
        editor?: Maybe<ResolversParentTypes['Actor']>;
        gist: ResolversParentTypes['Gist'];
        userContentEdits?: Maybe<ResolversParentTypes['UserContentEditConnection']>;
    };
    GistCommentConnection: Omit<GistCommentConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['GistCommentEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['GistComment']>>>;
    };
    GistCommentEdge: Omit<GistCommentEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['GistComment']>;
    };
    GistConnection: Omit<GistConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['GistEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Gist']>>>;
    };
    GistEdge: Omit<GistEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Gist']>;
    };
    GistFile: GistFile;
    GistOrder: GistOrder;
    GitActor: Omit<GitActor, 'user'> & {
        user?: Maybe<ResolversParentTypes['User']>;
    };
    GitActorConnection: GitActorConnection;
    GitActorEdge: GitActorEdge;
    GitHubMetadata: GitHubMetadata;
    GitObject: ResolversInterfaceTypes<ResolversParentTypes>['GitObject'];
    GitObjectID: Scalars['GitObjectID']['output'];
    GitRefname: Scalars['GitRefname']['output'];
    GitSSHRemote: Scalars['GitSSHRemote']['output'];
    GitSignature: ResolversInterfaceTypes<ResolversParentTypes>['GitSignature'];
    GitTimestamp: Scalars['GitTimestamp']['output'];
    GpgSignature: Omit<GpgSignature, 'signer'> & {
        signer?: Maybe<ResolversParentTypes['User']>;
    };
    HTML: Scalars['HTML']['output'];
    HeadRefDeletedEvent: Omit<HeadRefDeletedEvent, 'actor' | 'headRef' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        headRef?: Maybe<ResolversParentTypes['Ref']>;
        pullRequest: ResolversParentTypes['PullRequest'];
    };
    HeadRefForcePushedEvent: Omit<HeadRefForcePushedEvent, 'actor' | 'afterCommit' | 'beforeCommit' | 'pullRequest' | 'ref'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        afterCommit?: Maybe<ResolversParentTypes['Commit']>;
        beforeCommit?: Maybe<ResolversParentTypes['Commit']>;
        pullRequest: ResolversParentTypes['PullRequest'];
        ref?: Maybe<ResolversParentTypes['Ref']>;
    };
    HeadRefRestoredEvent: Omit<HeadRefRestoredEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        pullRequest: ResolversParentTypes['PullRequest'];
    };
    Hovercard: Omit<Hovercard, 'contexts'> & {
        contexts: Array<ResolversParentTypes['HovercardContext']>;
    };
    HovercardContext: ResolversInterfaceTypes<ResolversParentTypes>['HovercardContext'];
    ID: Scalars['ID']['output'];
    ImportProjectInput: ImportProjectInput;
    ImportProjectPayload: Omit<ImportProjectPayload, 'project'> & {
        project?: Maybe<ResolversParentTypes['Project']>;
    };
    Int: Scalars['Int']['output'];
    IpAllowListEntry: Omit<IpAllowListEntry, 'owner'> & {
        owner: ResolversParentTypes['IpAllowListOwner'];
    };
    IpAllowListEntryConnection: Omit<IpAllowListEntryConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['IpAllowListEntryEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['IpAllowListEntry']>>>;
    };
    IpAllowListEntryEdge: Omit<IpAllowListEntryEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['IpAllowListEntry']>;
    };
    IpAllowListEntryOrder: IpAllowListEntryOrder;
    IpAllowListOwner: ResolversUnionTypes<ResolversParentTypes>['IpAllowListOwner'];
    Issue: Omit<Issue, 'assignees' | 'author' | 'comments' | 'editor' | 'hovercard' | 'labels' | 'milestone' | 'participants' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'timeline' | 'timelineItems' | 'userContentEdits'> & {
        assignees: ResolversParentTypes['UserConnection'];
        author?: Maybe<ResolversParentTypes['Actor']>;
        comments: ResolversParentTypes['IssueCommentConnection'];
        editor?: Maybe<ResolversParentTypes['Actor']>;
        hovercard: ResolversParentTypes['Hovercard'];
        labels?: Maybe<ResolversParentTypes['LabelConnection']>;
        milestone?: Maybe<ResolversParentTypes['Milestone']>;
        participants: ResolversParentTypes['UserConnection'];
        projectCards: ResolversParentTypes['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<ResolversParentTypes['ReactionGroup']>>;
        reactions: ResolversParentTypes['ReactionConnection'];
        repository: ResolversParentTypes['Repository'];
        timeline: ResolversParentTypes['IssueTimelineConnection'];
        timelineItems: ResolversParentTypes['IssueTimelineItemsConnection'];
        userContentEdits?: Maybe<ResolversParentTypes['UserContentEditConnection']>;
    };
    IssueComment: Omit<IssueComment, 'author' | 'editor' | 'issue' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<ResolversParentTypes['Actor']>;
        editor?: Maybe<ResolversParentTypes['Actor']>;
        issue: ResolversParentTypes['Issue'];
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
        reactionGroups?: Maybe<Array<ResolversParentTypes['ReactionGroup']>>;
        reactions: ResolversParentTypes['ReactionConnection'];
        repository: ResolversParentTypes['Repository'];
        userContentEdits?: Maybe<ResolversParentTypes['UserContentEditConnection']>;
    };
    IssueCommentConnection: Omit<IssueCommentConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['IssueCommentEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['IssueComment']>>>;
    };
    IssueCommentEdge: Omit<IssueCommentEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['IssueComment']>;
    };
    IssueCommentOrder: IssueCommentOrder;
    IssueConnection: Omit<IssueConnection, 'nodes'> & {
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Issue']>>>;
    };
    IssueContributionsByRepository: Omit<IssueContributionsByRepository, 'contributions' | 'repository'> & {
        contributions: ResolversParentTypes['CreatedIssueContributionConnection'];
        repository: ResolversParentTypes['Repository'];
    };
    IssueEdge: Omit<IssueEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Issue']>;
    };
    IssueFilters: IssueFilters;
    IssueOrPullRequest: ResolversUnionTypes<ResolversParentTypes>['IssueOrPullRequest'];
    IssueOrder: IssueOrder;
    IssueTemplate: IssueTemplate;
    IssueTimelineConnection: Omit<IssueTimelineConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['IssueTimelineItemEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['IssueTimelineItem']>>>;
    };
    IssueTimelineItem: ResolversUnionTypes<ResolversParentTypes>['IssueTimelineItem'];
    IssueTimelineItemEdge: Omit<IssueTimelineItemEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['IssueTimelineItem']>;
    };
    IssueTimelineItems: ResolversUnionTypes<ResolversParentTypes>['IssueTimelineItems'];
    IssueTimelineItemsConnection: Omit<IssueTimelineItemsConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['IssueTimelineItemsEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['IssueTimelineItems']>>>;
    };
    IssueTimelineItemsEdge: Omit<IssueTimelineItemsEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['IssueTimelineItems']>;
    };
    JoinedGitHubContribution: Omit<JoinedGitHubContribution, 'user'> & {
        user: ResolversParentTypes['User'];
    };
    Label: Omit<Label, 'pullRequests' | 'repository'> & {
        pullRequests: ResolversParentTypes['PullRequestConnection'];
        repository: ResolversParentTypes['Repository'];
    };
    LabelConnection: Omit<LabelConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['LabelEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Label']>>>;
    };
    LabelEdge: Omit<LabelEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Label']>;
    };
    LabelOrder: LabelOrder;
    Labelable: ResolversInterfaceTypes<ResolversParentTypes>['Labelable'];
    LabeledEvent: Omit<LabeledEvent, 'actor' | 'label' | 'labelable'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        label: ResolversParentTypes['Label'];
        labelable: ResolversParentTypes['Labelable'];
    };
    Language: Language;
    LanguageConnection: LanguageConnection;
    LanguageEdge: LanguageEdge;
    LanguageOrder: LanguageOrder;
    License: License;
    LicenseRule: LicenseRule;
    LinkRepositoryToProjectInput: LinkRepositoryToProjectInput;
    LinkRepositoryToProjectPayload: Omit<LinkRepositoryToProjectPayload, 'project' | 'repository'> & {
        project?: Maybe<ResolversParentTypes['Project']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
    };
    LockLockableInput: LockLockableInput;
    LockLockablePayload: Omit<LockLockablePayload, 'actor' | 'lockedRecord'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        lockedRecord?: Maybe<ResolversParentTypes['Lockable']>;
    };
    Lockable: ResolversInterfaceTypes<ResolversParentTypes>['Lockable'];
    LockedEvent: Omit<LockedEvent, 'actor' | 'lockable'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        lockable: ResolversParentTypes['Lockable'];
    };
    Mannequin: Omit<Mannequin, 'claimant'> & {
        claimant?: Maybe<ResolversParentTypes['User']>;
    };
    MarkDiscussionCommentAsAnswerInput: MarkDiscussionCommentAsAnswerInput;
    MarkDiscussionCommentAsAnswerPayload: Omit<MarkDiscussionCommentAsAnswerPayload, 'discussion'> & {
        discussion?: Maybe<ResolversParentTypes['Discussion']>;
    };
    MarkFileAsViewedInput: MarkFileAsViewedInput;
    MarkFileAsViewedPayload: Omit<MarkFileAsViewedPayload, 'pullRequest'> & {
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
    };
    MarkPullRequestReadyForReviewInput: MarkPullRequestReadyForReviewInput;
    MarkPullRequestReadyForReviewPayload: Omit<MarkPullRequestReadyForReviewPayload, 'pullRequest'> & {
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
    };
    MarkedAsDuplicateEvent: Omit<MarkedAsDuplicateEvent, 'actor' | 'canonical' | 'duplicate'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        canonical?: Maybe<ResolversParentTypes['IssueOrPullRequest']>;
        duplicate?: Maybe<ResolversParentTypes['IssueOrPullRequest']>;
    };
    MemberStatusable: ResolversInterfaceTypes<ResolversParentTypes>['MemberStatusable'];
    MembersCanDeleteReposClearAuditEntry: Omit<MembersCanDeleteReposClearAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    MembersCanDeleteReposDisableAuditEntry: Omit<MembersCanDeleteReposDisableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    MembersCanDeleteReposEnableAuditEntry: Omit<MembersCanDeleteReposEnableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    MentionedEvent: Omit<MentionedEvent, 'actor'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
    };
    MergeBranchInput: MergeBranchInput;
    MergeBranchPayload: Omit<MergeBranchPayload, 'mergeCommit'> & {
        mergeCommit?: Maybe<ResolversParentTypes['Commit']>;
    };
    MergePullRequestInput: MergePullRequestInput;
    MergePullRequestPayload: Omit<MergePullRequestPayload, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
    };
    MergedEvent: Omit<MergedEvent, 'actor' | 'commit' | 'mergeRef' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        commit?: Maybe<ResolversParentTypes['Commit']>;
        mergeRef?: Maybe<ResolversParentTypes['Ref']>;
        pullRequest: ResolversParentTypes['PullRequest'];
    };
    Milestone: Omit<Milestone, 'creator' | 'pullRequests' | 'repository'> & {
        creator?: Maybe<ResolversParentTypes['Actor']>;
        pullRequests: ResolversParentTypes['PullRequestConnection'];
        repository: ResolversParentTypes['Repository'];
    };
    MilestoneConnection: Omit<MilestoneConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['MilestoneEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Milestone']>>>;
    };
    MilestoneEdge: Omit<MilestoneEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Milestone']>;
    };
    MilestoneItem: ResolversUnionTypes<ResolversParentTypes>['MilestoneItem'];
    MilestoneOrder: MilestoneOrder;
    MilestonedEvent: Omit<MilestonedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        subject: ResolversParentTypes['MilestoneItem'];
    };
    Minimizable: ResolversInterfaceTypes<ResolversParentTypes>['Minimizable'];
    MinimizeCommentInput: MinimizeCommentInput;
    MinimizeCommentPayload: Omit<MinimizeCommentPayload, 'minimizedComment'> & {
        minimizedComment?: Maybe<ResolversParentTypes['Minimizable']>;
    };
    MoveProjectCardInput: MoveProjectCardInput;
    MoveProjectCardPayload: Omit<MoveProjectCardPayload, 'cardEdge'> & {
        cardEdge?: Maybe<ResolversParentTypes['ProjectCardEdge']>;
    };
    MoveProjectColumnInput: MoveProjectColumnInput;
    MoveProjectColumnPayload: Omit<MoveProjectColumnPayload, 'columnEdge'> & {
        columnEdge?: Maybe<ResolversParentTypes['ProjectColumnEdge']>;
    };
    MovedColumnsInProjectEvent: Omit<MovedColumnsInProjectEvent, 'actor' | 'project' | 'projectCard'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        project?: Maybe<ResolversParentTypes['Project']>;
        projectCard?: Maybe<ResolversParentTypes['ProjectCard']>;
    };
    Mutation: {};
    Node: ResolversInterfaceTypes<ResolversParentTypes>['Node'];
    OauthApplicationAuditEntryData: ResolversInterfaceTypes<ResolversParentTypes>['OauthApplicationAuditEntryData'];
    OauthApplicationCreateAuditEntry: Omit<OauthApplicationCreateAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgAddBillingManagerAuditEntry: Omit<OrgAddBillingManagerAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgAddMemberAuditEntry: Omit<OrgAddMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgBlockUserAuditEntry: Omit<OrgBlockUserAuditEntry, 'actor' | 'blockedUser' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        blockedUser?: Maybe<ResolversParentTypes['User']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgConfigDisableCollaboratorsOnlyAuditEntry: Omit<OrgConfigDisableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgConfigEnableCollaboratorsOnlyAuditEntry: Omit<OrgConfigEnableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgCreateAuditEntry: Omit<OrgCreateAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgDisableOauthAppRestrictionsAuditEntry: Omit<OrgDisableOauthAppRestrictionsAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgDisableSamlAuditEntry: Omit<OrgDisableSamlAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgDisableTwoFactorRequirementAuditEntry: Omit<OrgDisableTwoFactorRequirementAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgEnableOauthAppRestrictionsAuditEntry: Omit<OrgEnableOauthAppRestrictionsAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgEnableSamlAuditEntry: Omit<OrgEnableSamlAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgEnableTwoFactorRequirementAuditEntry: Omit<OrgEnableTwoFactorRequirementAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgInviteMemberAuditEntry: Omit<OrgInviteMemberAuditEntry, 'actor' | 'organization' | 'organizationInvitation' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        organizationInvitation?: Maybe<ResolversParentTypes['OrganizationInvitation']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgInviteToBusinessAuditEntry: Omit<OrgInviteToBusinessAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgOauthAppAccessApprovedAuditEntry: Omit<OrgOauthAppAccessApprovedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgOauthAppAccessDeniedAuditEntry: Omit<OrgOauthAppAccessDeniedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgOauthAppAccessRequestedAuditEntry: Omit<OrgOauthAppAccessRequestedAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgRemoveBillingManagerAuditEntry: Omit<OrgRemoveBillingManagerAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgRemoveMemberAuditEntry: Omit<OrgRemoveMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgRemoveOutsideCollaboratorAuditEntry: Omit<OrgRemoveOutsideCollaboratorAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgRestoreMemberAuditEntry: Omit<OrgRestoreMemberAuditEntry, 'actor' | 'organization' | 'restoredMemberships' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        restoredMemberships?: Maybe<Array<ResolversParentTypes['OrgRestoreMemberAuditEntryMembership']>>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgRestoreMemberAuditEntryMembership: ResolversUnionTypes<ResolversParentTypes>['OrgRestoreMemberAuditEntryMembership'];
    OrgRestoreMemberMembershipOrganizationAuditEntryData: Omit<OrgRestoreMemberMembershipOrganizationAuditEntryData, 'organization'> & {
        organization?: Maybe<ResolversParentTypes['Organization']>;
    };
    OrgRestoreMemberMembershipRepositoryAuditEntryData: Omit<OrgRestoreMemberMembershipRepositoryAuditEntryData, 'repository'> & {
        repository?: Maybe<ResolversParentTypes['Repository']>;
    };
    OrgRestoreMemberMembershipTeamAuditEntryData: Omit<OrgRestoreMemberMembershipTeamAuditEntryData, 'team'> & {
        team?: Maybe<ResolversParentTypes['Team']>;
    };
    OrgUnblockUserAuditEntry: Omit<OrgUnblockUserAuditEntry, 'actor' | 'blockedUser' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        blockedUser?: Maybe<ResolversParentTypes['User']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgUpdateDefaultRepositoryPermissionAuditEntry: Omit<OrgUpdateDefaultRepositoryPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgUpdateMemberAuditEntry: Omit<OrgUpdateMemberAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgUpdateMemberRepositoryCreationPermissionAuditEntry: Omit<OrgUpdateMemberRepositoryCreationPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    OrgUpdateMemberRepositoryInvitationPermissionAuditEntry: Omit<OrgUpdateMemberRepositoryInvitationPermissionAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    Organization: Omit<Organization, 'auditLog' | 'domains' | 'ipAllowListEntries' | 'itemShowcase' | 'memberStatuses' | 'packages' | 'pendingMembers' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'repositories' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'samlIdentityProvider' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'team'> & {
        auditLog: ResolversParentTypes['OrganizationAuditEntryConnection'];
        domains?: Maybe<ResolversParentTypes['VerifiableDomainConnection']>;
        ipAllowListEntries: ResolversParentTypes['IpAllowListEntryConnection'];
        itemShowcase: ResolversParentTypes['ProfileItemShowcase'];
        memberStatuses: ResolversParentTypes['UserStatusConnection'];
        packages: ResolversParentTypes['PackageConnection'];
        pendingMembers: ResolversParentTypes['UserConnection'];
        pinnableItems: ResolversParentTypes['PinnableItemConnection'];
        pinnedItems: ResolversParentTypes['PinnableItemConnection'];
        project?: Maybe<ResolversParentTypes['Project']>;
        projects: ResolversParentTypes['ProjectConnection'];
        repositories: ResolversParentTypes['RepositoryConnection'];
        repository?: Maybe<ResolversParentTypes['Repository']>;
        repositoryDiscussionComments: ResolversParentTypes['DiscussionCommentConnection'];
        repositoryDiscussions: ResolversParentTypes['DiscussionConnection'];
        samlIdentityProvider?: Maybe<ResolversParentTypes['OrganizationIdentityProvider']>;
        sponsorshipsAsMaintainer: ResolversParentTypes['SponsorshipConnection'];
        sponsorshipsAsSponsor: ResolversParentTypes['SponsorshipConnection'];
        team?: Maybe<ResolversParentTypes['Team']>;
    };
    OrganizationAuditEntry: ResolversUnionTypes<ResolversParentTypes>['OrganizationAuditEntry'];
    OrganizationAuditEntryConnection: Omit<OrganizationAuditEntryConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['OrganizationAuditEntryEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['OrganizationAuditEntry']>>>;
    };
    OrganizationAuditEntryData: ResolversInterfaceTypes<ResolversParentTypes>['OrganizationAuditEntryData'];
    OrganizationAuditEntryEdge: Omit<OrganizationAuditEntryEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['OrganizationAuditEntry']>;
    };
    OrganizationConnection: Omit<OrganizationConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['OrganizationEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Organization']>>>;
    };
    OrganizationEdge: Omit<OrganizationEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Organization']>;
    };
    OrganizationIdentityProvider: Omit<OrganizationIdentityProvider, 'externalIdentities' | 'organization'> & {
        externalIdentities: ResolversParentTypes['ExternalIdentityConnection'];
        organization?: Maybe<ResolversParentTypes['Organization']>;
    };
    OrganizationInvitation: Omit<OrganizationInvitation, 'invitee' | 'inviter' | 'organization'> & {
        invitee?: Maybe<ResolversParentTypes['User']>;
        inviter: ResolversParentTypes['User'];
        organization: ResolversParentTypes['Organization'];
    };
    OrganizationInvitationConnection: Omit<OrganizationInvitationConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['OrganizationInvitationEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['OrganizationInvitation']>>>;
    };
    OrganizationInvitationEdge: Omit<OrganizationInvitationEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['OrganizationInvitation']>;
    };
    OrganizationMemberConnection: Omit<OrganizationMemberConnection, 'nodes'> & {
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['User']>>>;
    };
    OrganizationMemberEdge: Omit<OrganizationMemberEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['User']>;
    };
    OrganizationOrder: OrganizationOrder;
    OrganizationTeamsHovercardContext: OrganizationTeamsHovercardContext;
    OrganizationsHovercardContext: Omit<OrganizationsHovercardContext, 'relevantOrganizations'> & {
        relevantOrganizations: ResolversParentTypes['OrganizationConnection'];
    };
    Package: Omit<Package, 'latestVersion' | 'repository' | 'version' | 'versions'> & {
        latestVersion?: Maybe<ResolversParentTypes['PackageVersion']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        version?: Maybe<ResolversParentTypes['PackageVersion']>;
        versions: ResolversParentTypes['PackageVersionConnection'];
    };
    PackageConnection: Omit<PackageConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['PackageEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Package']>>>;
    };
    PackageEdge: Omit<PackageEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Package']>;
    };
    PackageFile: Omit<PackageFile, 'packageVersion'> & {
        packageVersion?: Maybe<ResolversParentTypes['PackageVersion']>;
    };
    PackageFileConnection: PackageFileConnection;
    PackageFileEdge: PackageFileEdge;
    PackageFileOrder: PackageFileOrder;
    PackageOrder: PackageOrder;
    PackageOwner: ResolversInterfaceTypes<ResolversParentTypes>['PackageOwner'];
    PackageStatistics: PackageStatistics;
    PackageTag: Omit<PackageTag, 'version'> & {
        version?: Maybe<ResolversParentTypes['PackageVersion']>;
    };
    PackageVersion: Omit<PackageVersion, 'package' | 'release'> & {
        package?: Maybe<ResolversParentTypes['Package']>;
        release?: Maybe<ResolversParentTypes['Release']>;
    };
    PackageVersionConnection: Omit<PackageVersionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['PackageVersionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['PackageVersion']>>>;
    };
    PackageVersionEdge: Omit<PackageVersionEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['PackageVersion']>;
    };
    PackageVersionOrder: PackageVersionOrder;
    PackageVersionStatistics: PackageVersionStatistics;
    PageInfo: PageInfo;
    PermissionGranter: ResolversUnionTypes<ResolversParentTypes>['PermissionGranter'];
    PermissionSource: Omit<PermissionSource, 'organization' | 'source'> & {
        organization: ResolversParentTypes['Organization'];
        source: ResolversParentTypes['PermissionGranter'];
    };
    PinIssueInput: PinIssueInput;
    PinIssuePayload: Omit<PinIssuePayload, 'issue'> & {
        issue?: Maybe<ResolversParentTypes['Issue']>;
    };
    PinnableItem: ResolversUnionTypes<ResolversParentTypes>['PinnableItem'];
    PinnableItemConnection: Omit<PinnableItemConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['PinnableItemEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['PinnableItem']>>>;
    };
    PinnableItemEdge: Omit<PinnableItemEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['PinnableItem']>;
    };
    PinnedDiscussion: Omit<PinnedDiscussion, 'discussion' | 'pinnedBy' | 'repository'> & {
        discussion: ResolversParentTypes['Discussion'];
        pinnedBy: ResolversParentTypes['Actor'];
        repository: ResolversParentTypes['Repository'];
    };
    PinnedDiscussionConnection: Omit<PinnedDiscussionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['PinnedDiscussionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['PinnedDiscussion']>>>;
    };
    PinnedDiscussionEdge: Omit<PinnedDiscussionEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['PinnedDiscussion']>;
    };
    PinnedEvent: Omit<PinnedEvent, 'actor' | 'issue'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        issue: ResolversParentTypes['Issue'];
    };
    PinnedIssue: Omit<PinnedIssue, 'issue' | 'pinnedBy' | 'repository'> & {
        issue: ResolversParentTypes['Issue'];
        pinnedBy: ResolversParentTypes['Actor'];
        repository: ResolversParentTypes['Repository'];
    };
    PinnedIssueConnection: Omit<PinnedIssueConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['PinnedIssueEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['PinnedIssue']>>>;
    };
    PinnedIssueEdge: Omit<PinnedIssueEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['PinnedIssue']>;
    };
    PreciseDateTime: Scalars['PreciseDateTime']['output'];
    PrivateRepositoryForkingDisableAuditEntry: Omit<PrivateRepositoryForkingDisableAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    PrivateRepositoryForkingEnableAuditEntry: Omit<PrivateRepositoryForkingEnableAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    ProfileItemShowcase: Omit<ProfileItemShowcase, 'items'> & {
        items: ResolversParentTypes['PinnableItemConnection'];
    };
    ProfileOwner: ResolversInterfaceTypes<ResolversParentTypes>['ProfileOwner'];
    Project: Omit<Project, 'columns' | 'creator' | 'owner' | 'pendingCards'> & {
        columns: ResolversParentTypes['ProjectColumnConnection'];
        creator?: Maybe<ResolversParentTypes['Actor']>;
        owner: ResolversParentTypes['ProjectOwner'];
        pendingCards: ResolversParentTypes['ProjectCardConnection'];
    };
    ProjectCard: Omit<ProjectCard, 'column' | 'content' | 'creator' | 'project'> & {
        column?: Maybe<ResolversParentTypes['ProjectColumn']>;
        content?: Maybe<ResolversParentTypes['ProjectCardItem']>;
        creator?: Maybe<ResolversParentTypes['Actor']>;
        project: ResolversParentTypes['Project'];
    };
    ProjectCardConnection: Omit<ProjectCardConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['ProjectCardEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['ProjectCard']>>>;
    };
    ProjectCardEdge: Omit<ProjectCardEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['ProjectCard']>;
    };
    ProjectCardImport: ProjectCardImport;
    ProjectCardItem: ResolversUnionTypes<ResolversParentTypes>['ProjectCardItem'];
    ProjectColumn: Omit<ProjectColumn, 'cards' | 'project'> & {
        cards: ResolversParentTypes['ProjectCardConnection'];
        project: ResolversParentTypes['Project'];
    };
    ProjectColumnConnection: Omit<ProjectColumnConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['ProjectColumnEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['ProjectColumn']>>>;
    };
    ProjectColumnEdge: Omit<ProjectColumnEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['ProjectColumn']>;
    };
    ProjectColumnImport: ProjectColumnImport;
    ProjectConnection: Omit<ProjectConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['ProjectEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Project']>>>;
    };
    ProjectEdge: Omit<ProjectEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Project']>;
    };
    ProjectOrder: ProjectOrder;
    ProjectOwner: ResolversInterfaceTypes<ResolversParentTypes>['ProjectOwner'];
    ProjectProgress: ProjectProgress;
    PublicKey: PublicKey;
    PublicKeyConnection: PublicKeyConnection;
    PublicKeyEdge: PublicKeyEdge;
    PullRequest: Omit<PullRequest, 'assignees' | 'author' | 'autoMergeRequest' | 'baseRef' | 'baseRepository' | 'comments' | 'commits' | 'editor' | 'headRef' | 'headRepository' | 'headRepositoryOwner' | 'hovercard' | 'labels' | 'latestOpinionatedReviews' | 'latestReviews' | 'mergeCommit' | 'mergedBy' | 'milestone' | 'participants' | 'potentialMergeCommit' | 'projectCards' | 'reactionGroups' | 'reactions' | 'repository' | 'reviewRequests' | 'reviewThreads' | 'reviews' | 'timeline' | 'timelineItems' | 'userContentEdits' | 'viewerLatestReview' | 'viewerLatestReviewRequest'> & {
        assignees: ResolversParentTypes['UserConnection'];
        author?: Maybe<ResolversParentTypes['Actor']>;
        autoMergeRequest?: Maybe<ResolversParentTypes['AutoMergeRequest']>;
        baseRef?: Maybe<ResolversParentTypes['Ref']>;
        baseRepository?: Maybe<ResolversParentTypes['Repository']>;
        comments: ResolversParentTypes['IssueCommentConnection'];
        commits: ResolversParentTypes['PullRequestCommitConnection'];
        editor?: Maybe<ResolversParentTypes['Actor']>;
        headRef?: Maybe<ResolversParentTypes['Ref']>;
        headRepository?: Maybe<ResolversParentTypes['Repository']>;
        headRepositoryOwner?: Maybe<ResolversParentTypes['RepositoryOwner']>;
        hovercard: ResolversParentTypes['Hovercard'];
        labels?: Maybe<ResolversParentTypes['LabelConnection']>;
        latestOpinionatedReviews?: Maybe<ResolversParentTypes['PullRequestReviewConnection']>;
        latestReviews?: Maybe<ResolversParentTypes['PullRequestReviewConnection']>;
        mergeCommit?: Maybe<ResolversParentTypes['Commit']>;
        mergedBy?: Maybe<ResolversParentTypes['Actor']>;
        milestone?: Maybe<ResolversParentTypes['Milestone']>;
        participants: ResolversParentTypes['UserConnection'];
        potentialMergeCommit?: Maybe<ResolversParentTypes['Commit']>;
        projectCards: ResolversParentTypes['ProjectCardConnection'];
        reactionGroups?: Maybe<Array<ResolversParentTypes['ReactionGroup']>>;
        reactions: ResolversParentTypes['ReactionConnection'];
        repository: ResolversParentTypes['Repository'];
        reviewRequests?: Maybe<ResolversParentTypes['ReviewRequestConnection']>;
        reviewThreads: ResolversParentTypes['PullRequestReviewThreadConnection'];
        reviews?: Maybe<ResolversParentTypes['PullRequestReviewConnection']>;
        timeline: ResolversParentTypes['PullRequestTimelineConnection'];
        timelineItems: ResolversParentTypes['PullRequestTimelineItemsConnection'];
        userContentEdits?: Maybe<ResolversParentTypes['UserContentEditConnection']>;
        viewerLatestReview?: Maybe<ResolversParentTypes['PullRequestReview']>;
        viewerLatestReviewRequest?: Maybe<ResolversParentTypes['ReviewRequest']>;
    };
    PullRequestChangedFile: PullRequestChangedFile;
    PullRequestChangedFileConnection: PullRequestChangedFileConnection;
    PullRequestChangedFileEdge: PullRequestChangedFileEdge;
    PullRequestCommit: Omit<PullRequestCommit, 'commit' | 'pullRequest'> & {
        commit: ResolversParentTypes['Commit'];
        pullRequest: ResolversParentTypes['PullRequest'];
    };
    PullRequestCommitCommentThread: Omit<PullRequestCommitCommentThread, 'comments' | 'commit' | 'pullRequest' | 'repository'> & {
        comments: ResolversParentTypes['CommitCommentConnection'];
        commit: ResolversParentTypes['Commit'];
        pullRequest: ResolversParentTypes['PullRequest'];
        repository: ResolversParentTypes['Repository'];
    };
    PullRequestCommitConnection: Omit<PullRequestCommitConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['PullRequestCommitEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['PullRequestCommit']>>>;
    };
    PullRequestCommitEdge: Omit<PullRequestCommitEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['PullRequestCommit']>;
    };
    PullRequestConnection: Omit<PullRequestConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['PullRequestEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['PullRequest']>>>;
    };
    PullRequestContributionsByRepository: Omit<PullRequestContributionsByRepository, 'contributions' | 'repository'> & {
        contributions: ResolversParentTypes['CreatedPullRequestContributionConnection'];
        repository: ResolversParentTypes['Repository'];
    };
    PullRequestEdge: Omit<PullRequestEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['PullRequest']>;
    };
    PullRequestOrder: PullRequestOrder;
    PullRequestReview: Omit<PullRequestReview, 'author' | 'comments' | 'commit' | 'editor' | 'pullRequest' | 'reactionGroups' | 'reactions' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<ResolversParentTypes['Actor']>;
        comments: ResolversParentTypes['PullRequestReviewCommentConnection'];
        commit?: Maybe<ResolversParentTypes['Commit']>;
        editor?: Maybe<ResolversParentTypes['Actor']>;
        pullRequest: ResolversParentTypes['PullRequest'];
        reactionGroups?: Maybe<Array<ResolversParentTypes['ReactionGroup']>>;
        reactions: ResolversParentTypes['ReactionConnection'];
        repository: ResolversParentTypes['Repository'];
        userContentEdits?: Maybe<ResolversParentTypes['UserContentEditConnection']>;
    };
    PullRequestReviewComment: Omit<PullRequestReviewComment, 'author' | 'commit' | 'editor' | 'originalCommit' | 'pullRequest' | 'pullRequestReview' | 'reactionGroups' | 'reactions' | 'replyTo' | 'repository' | 'userContentEdits'> & {
        author?: Maybe<ResolversParentTypes['Actor']>;
        commit?: Maybe<ResolversParentTypes['Commit']>;
        editor?: Maybe<ResolversParentTypes['Actor']>;
        originalCommit?: Maybe<ResolversParentTypes['Commit']>;
        pullRequest: ResolversParentTypes['PullRequest'];
        pullRequestReview?: Maybe<ResolversParentTypes['PullRequestReview']>;
        reactionGroups?: Maybe<Array<ResolversParentTypes['ReactionGroup']>>;
        reactions: ResolversParentTypes['ReactionConnection'];
        replyTo?: Maybe<ResolversParentTypes['PullRequestReviewComment']>;
        repository: ResolversParentTypes['Repository'];
        userContentEdits?: Maybe<ResolversParentTypes['UserContentEditConnection']>;
    };
    PullRequestReviewCommentConnection: Omit<PullRequestReviewCommentConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['PullRequestReviewCommentEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['PullRequestReviewComment']>>>;
    };
    PullRequestReviewCommentEdge: Omit<PullRequestReviewCommentEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['PullRequestReviewComment']>;
    };
    PullRequestReviewConnection: Omit<PullRequestReviewConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['PullRequestReviewEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['PullRequestReview']>>>;
    };
    PullRequestReviewContributionsByRepository: Omit<PullRequestReviewContributionsByRepository, 'contributions' | 'repository'> & {
        contributions: ResolversParentTypes['CreatedPullRequestReviewContributionConnection'];
        repository: ResolversParentTypes['Repository'];
    };
    PullRequestReviewEdge: Omit<PullRequestReviewEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['PullRequestReview']>;
    };
    PullRequestReviewThread: Omit<PullRequestReviewThread, 'comments' | 'pullRequest' | 'repository' | 'resolvedBy'> & {
        comments: ResolversParentTypes['PullRequestReviewCommentConnection'];
        pullRequest: ResolversParentTypes['PullRequest'];
        repository: ResolversParentTypes['Repository'];
        resolvedBy?: Maybe<ResolversParentTypes['User']>;
    };
    PullRequestReviewThreadConnection: Omit<PullRequestReviewThreadConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['PullRequestReviewThreadEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['PullRequestReviewThread']>>>;
    };
    PullRequestReviewThreadEdge: Omit<PullRequestReviewThreadEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['PullRequestReviewThread']>;
    };
    PullRequestRevisionMarker: Omit<PullRequestRevisionMarker, 'lastSeenCommit' | 'pullRequest'> & {
        lastSeenCommit: ResolversParentTypes['Commit'];
        pullRequest: ResolversParentTypes['PullRequest'];
    };
    PullRequestTemplate: Omit<PullRequestTemplate, 'repository'> & {
        repository: ResolversParentTypes['Repository'];
    };
    PullRequestTimelineConnection: Omit<PullRequestTimelineConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['PullRequestTimelineItemEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['PullRequestTimelineItem']>>>;
    };
    PullRequestTimelineItem: ResolversUnionTypes<ResolversParentTypes>['PullRequestTimelineItem'];
    PullRequestTimelineItemEdge: Omit<PullRequestTimelineItemEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['PullRequestTimelineItem']>;
    };
    PullRequestTimelineItems: ResolversUnionTypes<ResolversParentTypes>['PullRequestTimelineItems'];
    PullRequestTimelineItemsConnection: Omit<PullRequestTimelineItemsConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['PullRequestTimelineItemsEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['PullRequestTimelineItems']>>>;
    };
    PullRequestTimelineItemsEdge: Omit<PullRequestTimelineItemsEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['PullRequestTimelineItems']>;
    };
    Push: Omit<Push, 'pusher' | 'repository'> & {
        pusher: ResolversParentTypes['User'];
        repository: ResolversParentTypes['Repository'];
    };
    PushAllowance: Omit<PushAllowance, 'actor' | 'branchProtectionRule'> & {
        actor?: Maybe<ResolversParentTypes['PushAllowanceActor']>;
        branchProtectionRule?: Maybe<ResolversParentTypes['BranchProtectionRule']>;
    };
    PushAllowanceActor: ResolversUnionTypes<ResolversParentTypes>['PushAllowanceActor'];
    PushAllowanceConnection: Omit<PushAllowanceConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['PushAllowanceEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['PushAllowance']>>>;
    };
    PushAllowanceEdge: Omit<PushAllowanceEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['PushAllowance']>;
    };
    Query: {};
    RateLimit: RateLimit;
    Reactable: ResolversInterfaceTypes<ResolversParentTypes>['Reactable'];
    ReactingUserConnection: Omit<ReactingUserConnection, 'nodes'> & {
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['User']>>>;
    };
    ReactingUserEdge: Omit<ReactingUserEdge, 'node'> & {
        node: ResolversParentTypes['User'];
    };
    Reaction: Omit<Reaction, 'reactable' | 'user'> & {
        reactable: ResolversParentTypes['Reactable'];
        user?: Maybe<ResolversParentTypes['User']>;
    };
    ReactionConnection: Omit<ReactionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['ReactionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Reaction']>>>;
    };
    ReactionEdge: Omit<ReactionEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Reaction']>;
    };
    ReactionGroup: Omit<ReactionGroup, 'reactors' | 'subject'> & {
        reactors: ResolversParentTypes['ReactorConnection'];
        subject: ResolversParentTypes['Reactable'];
    };
    ReactionOrder: ReactionOrder;
    Reactor: ResolversUnionTypes<ResolversParentTypes>['Reactor'];
    ReactorConnection: Omit<ReactorConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['ReactorEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Reactor']>>>;
    };
    ReactorEdge: Omit<ReactorEdge, 'node'> & {
        node: ResolversParentTypes['Reactor'];
    };
    ReadyForReviewEvent: Omit<ReadyForReviewEvent, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        pullRequest: ResolversParentTypes['PullRequest'];
    };
    Ref: Omit<Ref, 'associatedPullRequests' | 'branchProtectionRule' | 'repository' | 'target'> & {
        associatedPullRequests: ResolversParentTypes['PullRequestConnection'];
        branchProtectionRule?: Maybe<ResolversParentTypes['BranchProtectionRule']>;
        repository: ResolversParentTypes['Repository'];
        target?: Maybe<ResolversParentTypes['GitObject']>;
    };
    RefConnection: Omit<RefConnection, 'nodes'> & {
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Ref']>>>;
    };
    RefEdge: Omit<RefEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Ref']>;
    };
    RefOrder: RefOrder;
    RefUpdate: RefUpdate;
    RefUpdateRule: RefUpdateRule;
    ReferencedEvent: Omit<ReferencedEvent, 'actor' | 'commit' | 'commitRepository' | 'subject'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        commit?: Maybe<ResolversParentTypes['Commit']>;
        commitRepository: ResolversParentTypes['Repository'];
        subject: ResolversParentTypes['ReferencedSubject'];
    };
    ReferencedSubject: ResolversUnionTypes<ResolversParentTypes>['ReferencedSubject'];
    RegenerateVerifiableDomainTokenInput: RegenerateVerifiableDomainTokenInput;
    RegenerateVerifiableDomainTokenPayload: RegenerateVerifiableDomainTokenPayload;
    RejectDeploymentsInput: RejectDeploymentsInput;
    RejectDeploymentsPayload: Omit<RejectDeploymentsPayload, 'deployments'> & {
        deployments?: Maybe<Array<ResolversParentTypes['Deployment']>>;
    };
    Release: Omit<Release, 'author' | 'mentions' | 'reactionGroups' | 'reactions' | 'releaseAssets' | 'repository' | 'tag' | 'tagCommit'> & {
        author?: Maybe<ResolversParentTypes['User']>;
        mentions?: Maybe<ResolversParentTypes['UserConnection']>;
        reactionGroups?: Maybe<Array<ResolversParentTypes['ReactionGroup']>>;
        reactions: ResolversParentTypes['ReactionConnection'];
        releaseAssets: ResolversParentTypes['ReleaseAssetConnection'];
        repository: ResolversParentTypes['Repository'];
        tag?: Maybe<ResolversParentTypes['Ref']>;
        tagCommit?: Maybe<ResolversParentTypes['Commit']>;
    };
    ReleaseAsset: Omit<ReleaseAsset, 'release' | 'uploadedBy'> & {
        release?: Maybe<ResolversParentTypes['Release']>;
        uploadedBy: ResolversParentTypes['User'];
    };
    ReleaseAssetConnection: Omit<ReleaseAssetConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['ReleaseAssetEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['ReleaseAsset']>>>;
    };
    ReleaseAssetEdge: Omit<ReleaseAssetEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['ReleaseAsset']>;
    };
    ReleaseConnection: Omit<ReleaseConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['ReleaseEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Release']>>>;
    };
    ReleaseEdge: Omit<ReleaseEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Release']>;
    };
    ReleaseOrder: ReleaseOrder;
    RemoveAssigneesFromAssignableInput: RemoveAssigneesFromAssignableInput;
    RemoveAssigneesFromAssignablePayload: Omit<RemoveAssigneesFromAssignablePayload, 'assignable'> & {
        assignable?: Maybe<ResolversParentTypes['Assignable']>;
    };
    RemoveEnterpriseAdminInput: RemoveEnterpriseAdminInput;
    RemoveEnterpriseAdminPayload: Omit<RemoveEnterpriseAdminPayload, 'admin' | 'enterprise' | 'viewer'> & {
        admin?: Maybe<ResolversParentTypes['User']>;
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
        viewer?: Maybe<ResolversParentTypes['User']>;
    };
    RemoveLabelsFromLabelableInput: RemoveLabelsFromLabelableInput;
    RemoveLabelsFromLabelablePayload: Omit<RemoveLabelsFromLabelablePayload, 'labelable'> & {
        labelable?: Maybe<ResolversParentTypes['Labelable']>;
    };
    RemoveOutsideCollaboratorInput: RemoveOutsideCollaboratorInput;
    RemoveOutsideCollaboratorPayload: Omit<RemoveOutsideCollaboratorPayload, 'removedUser'> & {
        removedUser?: Maybe<ResolversParentTypes['User']>;
    };
    RemoveReactionInput: RemoveReactionInput;
    RemoveReactionPayload: Omit<RemoveReactionPayload, 'reaction' | 'subject'> & {
        reaction?: Maybe<ResolversParentTypes['Reaction']>;
        subject?: Maybe<ResolversParentTypes['Reactable']>;
    };
    RemoveStarInput: RemoveStarInput;
    RemoveStarPayload: Omit<RemoveStarPayload, 'starrable'> & {
        starrable?: Maybe<ResolversParentTypes['Starrable']>;
    };
    RemoveUpvoteInput: RemoveUpvoteInput;
    RemoveUpvotePayload: Omit<RemoveUpvotePayload, 'subject'> & {
        subject?: Maybe<ResolversParentTypes['Votable']>;
    };
    RemovedFromProjectEvent: Omit<RemovedFromProjectEvent, 'actor' | 'project'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        project?: Maybe<ResolversParentTypes['Project']>;
    };
    RenamedTitleEvent: Omit<RenamedTitleEvent, 'actor' | 'subject'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        subject: ResolversParentTypes['RenamedTitleSubject'];
    };
    RenamedTitleSubject: ResolversUnionTypes<ResolversParentTypes>['RenamedTitleSubject'];
    ReopenIssueInput: ReopenIssueInput;
    ReopenIssuePayload: Omit<ReopenIssuePayload, 'issue'> & {
        issue?: Maybe<ResolversParentTypes['Issue']>;
    };
    ReopenPullRequestInput: ReopenPullRequestInput;
    ReopenPullRequestPayload: Omit<ReopenPullRequestPayload, 'pullRequest'> & {
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
    };
    ReopenedEvent: Omit<ReopenedEvent, 'actor' | 'closable'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        closable: ResolversParentTypes['Closable'];
    };
    RepoAccessAuditEntry: Omit<RepoAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoAddMemberAuditEntry: Omit<RepoAddMemberAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoAddTopicAuditEntry: Omit<RepoAddTopicAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoArchivedAuditEntry: Omit<RepoArchivedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoChangeMergeSettingAuditEntry: Omit<RepoChangeMergeSettingAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoConfigDisableAnonymousGitAccessAuditEntry: Omit<RepoConfigDisableAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoConfigDisableCollaboratorsOnlyAuditEntry: Omit<RepoConfigDisableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoConfigDisableContributorsOnlyAuditEntry: Omit<RepoConfigDisableContributorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoConfigDisableSockpuppetDisallowedAuditEntry: Omit<RepoConfigDisableSockpuppetDisallowedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoConfigEnableAnonymousGitAccessAuditEntry: Omit<RepoConfigEnableAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoConfigEnableCollaboratorsOnlyAuditEntry: Omit<RepoConfigEnableCollaboratorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoConfigEnableContributorsOnlyAuditEntry: Omit<RepoConfigEnableContributorsOnlyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoConfigEnableSockpuppetDisallowedAuditEntry: Omit<RepoConfigEnableSockpuppetDisallowedAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoConfigLockAnonymousGitAccessAuditEntry: Omit<RepoConfigLockAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoConfigUnlockAnonymousGitAccessAuditEntry: Omit<RepoConfigUnlockAnonymousGitAccessAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoCreateAuditEntry: Omit<RepoCreateAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoDestroyAuditEntry: Omit<RepoDestroyAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoRemoveMemberAuditEntry: Omit<RepoRemoveMemberAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepoRemoveTopicAuditEntry: Omit<RepoRemoveTopicAuditEntry, 'actor' | 'organization' | 'repository' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    Repository: Omit<Repository, 'assignableUsers' | 'branchProtectionRules' | 'collaborators' | 'commitComments' | 'defaultBranchRef' | 'deployments' | 'discussion' | 'discussionCategories' | 'discussions' | 'environment' | 'environments' | 'forks' | 'issue' | 'issueOrPullRequest' | 'label' | 'labels' | 'latestRelease' | 'mentionableUsers' | 'milestone' | 'milestones' | 'object' | 'owner' | 'packages' | 'parent' | 'pinnedDiscussions' | 'pinnedIssues' | 'project' | 'projects' | 'pullRequest' | 'pullRequestTemplates' | 'pullRequests' | 'ref' | 'release' | 'releases' | 'templateRepository' | 'vulnerabilityAlerts' | 'watchers'> & {
        assignableUsers: ResolversParentTypes['UserConnection'];
        branchProtectionRules: ResolversParentTypes['BranchProtectionRuleConnection'];
        collaborators?: Maybe<ResolversParentTypes['RepositoryCollaboratorConnection']>;
        commitComments: ResolversParentTypes['CommitCommentConnection'];
        defaultBranchRef?: Maybe<ResolversParentTypes['Ref']>;
        deployments: ResolversParentTypes['DeploymentConnection'];
        discussion?: Maybe<ResolversParentTypes['Discussion']>;
        discussionCategories: ResolversParentTypes['DiscussionCategoryConnection'];
        discussions: ResolversParentTypes['DiscussionConnection'];
        environment?: Maybe<ResolversParentTypes['Environment']>;
        environments: ResolversParentTypes['EnvironmentConnection'];
        forks: ResolversParentTypes['RepositoryConnection'];
        issue?: Maybe<ResolversParentTypes['Issue']>;
        issueOrPullRequest?: Maybe<ResolversParentTypes['IssueOrPullRequest']>;
        label?: Maybe<ResolversParentTypes['Label']>;
        labels?: Maybe<ResolversParentTypes['LabelConnection']>;
        latestRelease?: Maybe<ResolversParentTypes['Release']>;
        mentionableUsers: ResolversParentTypes['UserConnection'];
        milestone?: Maybe<ResolversParentTypes['Milestone']>;
        milestones?: Maybe<ResolversParentTypes['MilestoneConnection']>;
        object?: Maybe<ResolversParentTypes['GitObject']>;
        owner: ResolversParentTypes['RepositoryOwner'];
        packages: ResolversParentTypes['PackageConnection'];
        parent?: Maybe<ResolversParentTypes['Repository']>;
        pinnedDiscussions: ResolversParentTypes['PinnedDiscussionConnection'];
        pinnedIssues?: Maybe<ResolversParentTypes['PinnedIssueConnection']>;
        project?: Maybe<ResolversParentTypes['Project']>;
        projects: ResolversParentTypes['ProjectConnection'];
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
        pullRequestTemplates?: Maybe<Array<ResolversParentTypes['PullRequestTemplate']>>;
        pullRequests: ResolversParentTypes['PullRequestConnection'];
        ref?: Maybe<ResolversParentTypes['Ref']>;
        release?: Maybe<ResolversParentTypes['Release']>;
        releases: ResolversParentTypes['ReleaseConnection'];
        templateRepository?: Maybe<ResolversParentTypes['Repository']>;
        vulnerabilityAlerts?: Maybe<ResolversParentTypes['RepositoryVulnerabilityAlertConnection']>;
        watchers: ResolversParentTypes['UserConnection'];
    };
    RepositoryAuditEntryData: ResolversInterfaceTypes<ResolversParentTypes>['RepositoryAuditEntryData'];
    RepositoryCollaboratorConnection: Omit<RepositoryCollaboratorConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['RepositoryCollaboratorEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['User']>>>;
    };
    RepositoryCollaboratorEdge: Omit<RepositoryCollaboratorEdge, 'node' | 'permissionSources'> & {
        node: ResolversParentTypes['User'];
        permissionSources?: Maybe<Array<ResolversParentTypes['PermissionSource']>>;
    };
    RepositoryConnection: Omit<RepositoryConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['RepositoryEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Repository']>>>;
    };
    RepositoryContactLink: RepositoryContactLink;
    RepositoryDiscussionAuthor: ResolversInterfaceTypes<ResolversParentTypes>['RepositoryDiscussionAuthor'];
    RepositoryDiscussionCommentAuthor: ResolversInterfaceTypes<ResolversParentTypes>['RepositoryDiscussionCommentAuthor'];
    RepositoryEdge: Omit<RepositoryEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Repository']>;
    };
    RepositoryInfo: ResolversInterfaceTypes<ResolversParentTypes>['RepositoryInfo'];
    RepositoryInvitation: Omit<RepositoryInvitation, 'invitee' | 'inviter' | 'repository'> & {
        invitee?: Maybe<ResolversParentTypes['User']>;
        inviter: ResolversParentTypes['User'];
        repository?: Maybe<ResolversParentTypes['RepositoryInfo']>;
    };
    RepositoryInvitationConnection: Omit<RepositoryInvitationConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['RepositoryInvitationEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['RepositoryInvitation']>>>;
    };
    RepositoryInvitationEdge: Omit<RepositoryInvitationEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['RepositoryInvitation']>;
    };
    RepositoryInvitationOrder: RepositoryInvitationOrder;
    RepositoryNode: ResolversInterfaceTypes<ResolversParentTypes>['RepositoryNode'];
    RepositoryOrder: RepositoryOrder;
    RepositoryOwner: ResolversInterfaceTypes<ResolversParentTypes>['RepositoryOwner'];
    RepositoryTopic: RepositoryTopic;
    RepositoryTopicConnection: RepositoryTopicConnection;
    RepositoryTopicEdge: RepositoryTopicEdge;
    RepositoryVisibilityChangeDisableAuditEntry: Omit<RepositoryVisibilityChangeDisableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepositoryVisibilityChangeEnableAuditEntry: Omit<RepositoryVisibilityChangeEnableAuditEntry, 'actor' | 'organization' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    RepositoryVulnerabilityAlert: Omit<RepositoryVulnerabilityAlert, 'dismisser' | 'repository'> & {
        dismisser?: Maybe<ResolversParentTypes['User']>;
        repository: ResolversParentTypes['Repository'];
    };
    RepositoryVulnerabilityAlertConnection: Omit<RepositoryVulnerabilityAlertConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['RepositoryVulnerabilityAlertEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['RepositoryVulnerabilityAlert']>>>;
    };
    RepositoryVulnerabilityAlertEdge: Omit<RepositoryVulnerabilityAlertEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['RepositoryVulnerabilityAlert']>;
    };
    RequestReviewsInput: RequestReviewsInput;
    RequestReviewsPayload: Omit<RequestReviewsPayload, 'actor' | 'pullRequest' | 'requestedReviewersEdge'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
        requestedReviewersEdge?: Maybe<ResolversParentTypes['UserEdge']>;
    };
    RequestedReviewer: ResolversUnionTypes<ResolversParentTypes>['RequestedReviewer'];
    RequirableByPullRequest: ResolversInterfaceTypes<ResolversParentTypes>['RequirableByPullRequest'];
    RerequestCheckSuiteInput: RerequestCheckSuiteInput;
    RerequestCheckSuitePayload: Omit<RerequestCheckSuitePayload, 'checkSuite'> & {
        checkSuite?: Maybe<ResolversParentTypes['CheckSuite']>;
    };
    ResolveReviewThreadInput: ResolveReviewThreadInput;
    ResolveReviewThreadPayload: Omit<ResolveReviewThreadPayload, 'thread'> & {
        thread?: Maybe<ResolversParentTypes['PullRequestReviewThread']>;
    };
    RestrictedContribution: Omit<RestrictedContribution, 'user'> & {
        user: ResolversParentTypes['User'];
    };
    ReviewDismissalAllowance: Omit<ReviewDismissalAllowance, 'actor' | 'branchProtectionRule'> & {
        actor?: Maybe<ResolversParentTypes['ReviewDismissalAllowanceActor']>;
        branchProtectionRule?: Maybe<ResolversParentTypes['BranchProtectionRule']>;
    };
    ReviewDismissalAllowanceActor: ResolversUnionTypes<ResolversParentTypes>['ReviewDismissalAllowanceActor'];
    ReviewDismissalAllowanceConnection: Omit<ReviewDismissalAllowanceConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['ReviewDismissalAllowanceEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['ReviewDismissalAllowance']>>>;
    };
    ReviewDismissalAllowanceEdge: Omit<ReviewDismissalAllowanceEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['ReviewDismissalAllowance']>;
    };
    ReviewDismissedEvent: Omit<ReviewDismissedEvent, 'actor' | 'pullRequest' | 'pullRequestCommit' | 'review'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        pullRequest: ResolversParentTypes['PullRequest'];
        pullRequestCommit?: Maybe<ResolversParentTypes['PullRequestCommit']>;
        review?: Maybe<ResolversParentTypes['PullRequestReview']>;
    };
    ReviewRequest: Omit<ReviewRequest, 'pullRequest' | 'requestedReviewer'> & {
        pullRequest: ResolversParentTypes['PullRequest'];
        requestedReviewer?: Maybe<ResolversParentTypes['RequestedReviewer']>;
    };
    ReviewRequestConnection: Omit<ReviewRequestConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['ReviewRequestEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['ReviewRequest']>>>;
    };
    ReviewRequestEdge: Omit<ReviewRequestEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['ReviewRequest']>;
    };
    ReviewRequestRemovedEvent: Omit<ReviewRequestRemovedEvent, 'actor' | 'pullRequest' | 'requestedReviewer'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        pullRequest: ResolversParentTypes['PullRequest'];
        requestedReviewer?: Maybe<ResolversParentTypes['RequestedReviewer']>;
    };
    ReviewRequestedEvent: Omit<ReviewRequestedEvent, 'actor' | 'pullRequest' | 'requestedReviewer'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        pullRequest: ResolversParentTypes['PullRequest'];
        requestedReviewer?: Maybe<ResolversParentTypes['RequestedReviewer']>;
    };
    ReviewStatusHovercardContext: ReviewStatusHovercardContext;
    SavedReply: Omit<SavedReply, 'user'> & {
        user?: Maybe<ResolversParentTypes['Actor']>;
    };
    SavedReplyConnection: Omit<SavedReplyConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['SavedReplyEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['SavedReply']>>>;
    };
    SavedReplyEdge: Omit<SavedReplyEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['SavedReply']>;
    };
    SavedReplyOrder: SavedReplyOrder;
    SearchResultItem: ResolversUnionTypes<ResolversParentTypes>['SearchResultItem'];
    SearchResultItemConnection: Omit<SearchResultItemConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['SearchResultItemEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['SearchResultItem']>>>;
    };
    SearchResultItemEdge: Omit<SearchResultItemEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['SearchResultItem']>;
    };
    SecurityAdvisory: SecurityAdvisory;
    SecurityAdvisoryConnection: SecurityAdvisoryConnection;
    SecurityAdvisoryEdge: SecurityAdvisoryEdge;
    SecurityAdvisoryIdentifier: SecurityAdvisoryIdentifier;
    SecurityAdvisoryPackage: SecurityAdvisoryPackage;
    SecurityAdvisoryPackageVersion: SecurityAdvisoryPackageVersion;
    SecurityAdvisoryReference: SecurityAdvisoryReference;
    SecurityVulnerability: SecurityVulnerability;
    SecurityVulnerabilityConnection: SecurityVulnerabilityConnection;
    SecurityVulnerabilityEdge: SecurityVulnerabilityEdge;
    SmimeSignature: Omit<SmimeSignature, 'signer'> & {
        signer?: Maybe<ResolversParentTypes['User']>;
    };
    Sponsor: ResolversUnionTypes<ResolversParentTypes>['Sponsor'];
    Sponsorable: ResolversInterfaceTypes<ResolversParentTypes>['Sponsorable'];
    Sponsorship: Omit<Sponsorship, 'maintainer' | 'sponsor' | 'sponsorEntity' | 'sponsorable'> & {
        maintainer: ResolversParentTypes['User'];
        sponsor?: Maybe<ResolversParentTypes['User']>;
        sponsorEntity?: Maybe<ResolversParentTypes['Sponsor']>;
        sponsorable: ResolversParentTypes['Sponsorable'];
    };
    SponsorshipConnection: Omit<SponsorshipConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['SponsorshipEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Sponsorship']>>>;
    };
    SponsorshipEdge: Omit<SponsorshipEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Sponsorship']>;
    };
    SponsorshipOrder: SponsorshipOrder;
    StarOrder: StarOrder;
    StargazerConnection: Omit<StargazerConnection, 'nodes'> & {
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['User']>>>;
    };
    StargazerEdge: Omit<StargazerEdge, 'node'> & {
        node: ResolversParentTypes['User'];
    };
    Starrable: ResolversInterfaceTypes<ResolversParentTypes>['Starrable'];
    StarredRepositoryConnection: Omit<StarredRepositoryConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['StarredRepositoryEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Repository']>>>;
    };
    StarredRepositoryEdge: Omit<StarredRepositoryEdge, 'node'> & {
        node: ResolversParentTypes['Repository'];
    };
    Status: Omit<Status, 'combinedContexts' | 'commit' | 'context' | 'contexts'> & {
        combinedContexts: ResolversParentTypes['StatusCheckRollupContextConnection'];
        commit?: Maybe<ResolversParentTypes['Commit']>;
        context?: Maybe<ResolversParentTypes['StatusContext']>;
        contexts: Array<ResolversParentTypes['StatusContext']>;
    };
    StatusCheckRollup: Omit<StatusCheckRollup, 'commit' | 'contexts'> & {
        commit?: Maybe<ResolversParentTypes['Commit']>;
        contexts: ResolversParentTypes['StatusCheckRollupContextConnection'];
    };
    StatusCheckRollupContext: ResolversUnionTypes<ResolversParentTypes>['StatusCheckRollupContext'];
    StatusCheckRollupContextConnection: Omit<StatusCheckRollupContextConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['StatusCheckRollupContextEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['StatusCheckRollupContext']>>>;
    };
    StatusCheckRollupContextEdge: Omit<StatusCheckRollupContextEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['StatusCheckRollupContext']>;
    };
    StatusContext: Omit<StatusContext, 'commit' | 'creator'> & {
        commit?: Maybe<ResolversParentTypes['Commit']>;
        creator?: Maybe<ResolversParentTypes['Actor']>;
    };
    String: Scalars['String']['output'];
    SubmitPullRequestReviewInput: SubmitPullRequestReviewInput;
    SubmitPullRequestReviewPayload: Omit<SubmitPullRequestReviewPayload, 'pullRequestReview'> & {
        pullRequestReview?: Maybe<ResolversParentTypes['PullRequestReview']>;
    };
    Submodule: Submodule;
    SubmoduleConnection: SubmoduleConnection;
    SubmoduleEdge: SubmoduleEdge;
    Subscribable: ResolversInterfaceTypes<ResolversParentTypes>['Subscribable'];
    SubscribedEvent: Omit<SubscribedEvent, 'actor' | 'subscribable'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        subscribable: ResolversParentTypes['Subscribable'];
    };
    SuggestedReviewer: Omit<SuggestedReviewer, 'reviewer'> & {
        reviewer: ResolversParentTypes['User'];
    };
    Tag: Omit<Tag, 'repository' | 'target'> & {
        repository: ResolversParentTypes['Repository'];
        target: ResolversParentTypes['GitObject'];
    };
    Team: Omit<Team, 'discussion' | 'discussions' | 'invitations' | 'memberStatuses' | 'organization' | 'parentTeam' | 'repositories'> & {
        discussion?: Maybe<ResolversParentTypes['TeamDiscussion']>;
        discussions: ResolversParentTypes['TeamDiscussionConnection'];
        invitations?: Maybe<ResolversParentTypes['OrganizationInvitationConnection']>;
        memberStatuses: ResolversParentTypes['UserStatusConnection'];
        organization: ResolversParentTypes['Organization'];
        parentTeam?: Maybe<ResolversParentTypes['Team']>;
        repositories: ResolversParentTypes['TeamRepositoryConnection'];
    };
    TeamAddMemberAuditEntry: Omit<TeamAddMemberAuditEntry, 'actor' | 'organization' | 'team' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        team?: Maybe<ResolversParentTypes['Team']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    TeamAddRepositoryAuditEntry: Omit<TeamAddRepositoryAuditEntry, 'actor' | 'organization' | 'repository' | 'team' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        team?: Maybe<ResolversParentTypes['Team']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    TeamAuditEntryData: ResolversInterfaceTypes<ResolversParentTypes>['TeamAuditEntryData'];
    TeamChangeParentTeamAuditEntry: Omit<TeamChangeParentTeamAuditEntry, 'actor' | 'organization' | 'parentTeam' | 'parentTeamWas' | 'team' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        parentTeam?: Maybe<ResolversParentTypes['Team']>;
        parentTeamWas?: Maybe<ResolversParentTypes['Team']>;
        team?: Maybe<ResolversParentTypes['Team']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    TeamConnection: Omit<TeamConnection, 'nodes'> & {
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Team']>>>;
    };
    TeamDiscussion: Omit<TeamDiscussion, 'author' | 'comments' | 'editor' | 'reactionGroups' | 'reactions' | 'team' | 'userContentEdits'> & {
        author?: Maybe<ResolversParentTypes['Actor']>;
        comments: ResolversParentTypes['TeamDiscussionCommentConnection'];
        editor?: Maybe<ResolversParentTypes['Actor']>;
        reactionGroups?: Maybe<Array<ResolversParentTypes['ReactionGroup']>>;
        reactions: ResolversParentTypes['ReactionConnection'];
        team: ResolversParentTypes['Team'];
        userContentEdits?: Maybe<ResolversParentTypes['UserContentEditConnection']>;
    };
    TeamDiscussionComment: Omit<TeamDiscussionComment, 'author' | 'discussion' | 'editor' | 'reactionGroups' | 'reactions' | 'userContentEdits'> & {
        author?: Maybe<ResolversParentTypes['Actor']>;
        discussion: ResolversParentTypes['TeamDiscussion'];
        editor?: Maybe<ResolversParentTypes['Actor']>;
        reactionGroups?: Maybe<Array<ResolversParentTypes['ReactionGroup']>>;
        reactions: ResolversParentTypes['ReactionConnection'];
        userContentEdits?: Maybe<ResolversParentTypes['UserContentEditConnection']>;
    };
    TeamDiscussionCommentConnection: Omit<TeamDiscussionCommentConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['TeamDiscussionCommentEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['TeamDiscussionComment']>>>;
    };
    TeamDiscussionCommentEdge: Omit<TeamDiscussionCommentEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['TeamDiscussionComment']>;
    };
    TeamDiscussionCommentOrder: TeamDiscussionCommentOrder;
    TeamDiscussionConnection: Omit<TeamDiscussionConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['TeamDiscussionEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['TeamDiscussion']>>>;
    };
    TeamDiscussionEdge: Omit<TeamDiscussionEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['TeamDiscussion']>;
    };
    TeamDiscussionOrder: TeamDiscussionOrder;
    TeamEdge: Omit<TeamEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['Team']>;
    };
    TeamMemberConnection: Omit<TeamMemberConnection, 'nodes'> & {
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['User']>>>;
    };
    TeamMemberEdge: Omit<TeamMemberEdge, 'node'> & {
        node: ResolversParentTypes['User'];
    };
    TeamMemberOrder: TeamMemberOrder;
    TeamOrder: TeamOrder;
    TeamRemoveMemberAuditEntry: Omit<TeamRemoveMemberAuditEntry, 'actor' | 'organization' | 'team' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        team?: Maybe<ResolversParentTypes['Team']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    TeamRemoveRepositoryAuditEntry: Omit<TeamRemoveRepositoryAuditEntry, 'actor' | 'organization' | 'repository' | 'team' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['AuditEntryActor']>;
        organization?: Maybe<ResolversParentTypes['Organization']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
        team?: Maybe<ResolversParentTypes['Team']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    TeamRepositoryConnection: Omit<TeamRepositoryConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['TeamRepositoryEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['Repository']>>>;
    };
    TeamRepositoryEdge: Omit<TeamRepositoryEdge, 'node'> & {
        node: ResolversParentTypes['Repository'];
    };
    TeamRepositoryOrder: TeamRepositoryOrder;
    TextMatch: TextMatch;
    TextMatchHighlight: TextMatchHighlight;
    Topic: Topic;
    TopicAuditEntryData: ResolversInterfaceTypes<ResolversParentTypes>['TopicAuditEntryData'];
    TransferIssueInput: TransferIssueInput;
    TransferIssuePayload: Omit<TransferIssuePayload, 'issue'> & {
        issue?: Maybe<ResolversParentTypes['Issue']>;
    };
    TransferredEvent: Omit<TransferredEvent, 'actor' | 'fromRepository' | 'issue'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        fromRepository?: Maybe<ResolversParentTypes['Repository']>;
        issue: ResolversParentTypes['Issue'];
    };
    Tree: Omit<Tree, 'entries' | 'repository'> & {
        entries?: Maybe<Array<ResolversParentTypes['TreeEntry']>>;
        repository: ResolversParentTypes['Repository'];
    };
    TreeEntry: Omit<TreeEntry, 'object' | 'repository'> & {
        object?: Maybe<ResolversParentTypes['GitObject']>;
        repository: ResolversParentTypes['Repository'];
    };
    URI: Scalars['URI']['output'];
    UnarchiveRepositoryInput: UnarchiveRepositoryInput;
    UnarchiveRepositoryPayload: Omit<UnarchiveRepositoryPayload, 'repository'> & {
        repository?: Maybe<ResolversParentTypes['Repository']>;
    };
    UnassignedEvent: Omit<UnassignedEvent, 'actor' | 'assignable' | 'assignee' | 'user'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        assignable: ResolversParentTypes['Assignable'];
        assignee?: Maybe<ResolversParentTypes['Assignee']>;
        user?: Maybe<ResolversParentTypes['User']>;
    };
    UnfollowUserInput: UnfollowUserInput;
    UnfollowUserPayload: Omit<UnfollowUserPayload, 'user'> & {
        user?: Maybe<ResolversParentTypes['User']>;
    };
    UniformResourceLocatable: ResolversInterfaceTypes<ResolversParentTypes>['UniformResourceLocatable'];
    UnknownSignature: Omit<UnknownSignature, 'signer'> & {
        signer?: Maybe<ResolversParentTypes['User']>;
    };
    UnlabeledEvent: Omit<UnlabeledEvent, 'actor' | 'label' | 'labelable'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        label: ResolversParentTypes['Label'];
        labelable: ResolversParentTypes['Labelable'];
    };
    UnlinkRepositoryFromProjectInput: UnlinkRepositoryFromProjectInput;
    UnlinkRepositoryFromProjectPayload: Omit<UnlinkRepositoryFromProjectPayload, 'project' | 'repository'> & {
        project?: Maybe<ResolversParentTypes['Project']>;
        repository?: Maybe<ResolversParentTypes['Repository']>;
    };
    UnlockLockableInput: UnlockLockableInput;
    UnlockLockablePayload: Omit<UnlockLockablePayload, 'actor' | 'unlockedRecord'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        unlockedRecord?: Maybe<ResolversParentTypes['Lockable']>;
    };
    UnlockedEvent: Omit<UnlockedEvent, 'actor' | 'lockable'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        lockable: ResolversParentTypes['Lockable'];
    };
    UnmarkDiscussionCommentAsAnswerInput: UnmarkDiscussionCommentAsAnswerInput;
    UnmarkDiscussionCommentAsAnswerPayload: Omit<UnmarkDiscussionCommentAsAnswerPayload, 'discussion'> & {
        discussion?: Maybe<ResolversParentTypes['Discussion']>;
    };
    UnmarkFileAsViewedInput: UnmarkFileAsViewedInput;
    UnmarkFileAsViewedPayload: Omit<UnmarkFileAsViewedPayload, 'pullRequest'> & {
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
    };
    UnmarkIssueAsDuplicateInput: UnmarkIssueAsDuplicateInput;
    UnmarkIssueAsDuplicatePayload: Omit<UnmarkIssueAsDuplicatePayload, 'duplicate'> & {
        duplicate?: Maybe<ResolversParentTypes['IssueOrPullRequest']>;
    };
    UnmarkedAsDuplicateEvent: Omit<UnmarkedAsDuplicateEvent, 'actor' | 'canonical' | 'duplicate'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        canonical?: Maybe<ResolversParentTypes['IssueOrPullRequest']>;
        duplicate?: Maybe<ResolversParentTypes['IssueOrPullRequest']>;
    };
    UnminimizeCommentInput: UnminimizeCommentInput;
    UnminimizeCommentPayload: Omit<UnminimizeCommentPayload, 'unminimizedComment'> & {
        unminimizedComment?: Maybe<ResolversParentTypes['Minimizable']>;
    };
    UnpinIssueInput: UnpinIssueInput;
    UnpinIssuePayload: Omit<UnpinIssuePayload, 'issue'> & {
        issue?: Maybe<ResolversParentTypes['Issue']>;
    };
    UnpinnedEvent: Omit<UnpinnedEvent, 'actor' | 'issue'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        issue: ResolversParentTypes['Issue'];
    };
    UnresolveReviewThreadInput: UnresolveReviewThreadInput;
    UnresolveReviewThreadPayload: Omit<UnresolveReviewThreadPayload, 'thread'> & {
        thread?: Maybe<ResolversParentTypes['PullRequestReviewThread']>;
    };
    UnsubscribedEvent: Omit<UnsubscribedEvent, 'actor' | 'subscribable'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        subscribable: ResolversParentTypes['Subscribable'];
    };
    Updatable: ResolversInterfaceTypes<ResolversParentTypes>['Updatable'];
    UpdatableComment: ResolversInterfaceTypes<ResolversParentTypes>['UpdatableComment'];
    UpdateBranchProtectionRuleInput: UpdateBranchProtectionRuleInput;
    UpdateBranchProtectionRulePayload: Omit<UpdateBranchProtectionRulePayload, 'branchProtectionRule'> & {
        branchProtectionRule?: Maybe<ResolversParentTypes['BranchProtectionRule']>;
    };
    UpdateCheckRunInput: UpdateCheckRunInput;
    UpdateCheckRunPayload: Omit<UpdateCheckRunPayload, 'checkRun'> & {
        checkRun?: Maybe<ResolversParentTypes['CheckRun']>;
    };
    UpdateCheckSuitePreferencesInput: UpdateCheckSuitePreferencesInput;
    UpdateCheckSuitePreferencesPayload: Omit<UpdateCheckSuitePreferencesPayload, 'repository'> & {
        repository?: Maybe<ResolversParentTypes['Repository']>;
    };
    UpdateDiscussionCommentInput: UpdateDiscussionCommentInput;
    UpdateDiscussionCommentPayload: Omit<UpdateDiscussionCommentPayload, 'comment'> & {
        comment?: Maybe<ResolversParentTypes['DiscussionComment']>;
    };
    UpdateDiscussionInput: UpdateDiscussionInput;
    UpdateDiscussionPayload: Omit<UpdateDiscussionPayload, 'discussion'> & {
        discussion?: Maybe<ResolversParentTypes['Discussion']>;
    };
    UpdateEnterpriseAllowPrivateRepositoryForkingSettingInput: UpdateEnterpriseAllowPrivateRepositoryForkingSettingInput;
    UpdateEnterpriseAllowPrivateRepositoryForkingSettingPayload: Omit<UpdateEnterpriseAllowPrivateRepositoryForkingSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
    };
    UpdateEnterpriseDefaultRepositoryPermissionSettingInput: UpdateEnterpriseDefaultRepositoryPermissionSettingInput;
    UpdateEnterpriseDefaultRepositoryPermissionSettingPayload: Omit<UpdateEnterpriseDefaultRepositoryPermissionSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
    };
    UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingInput: UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingInput;
    UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingPayload: Omit<UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
    };
    UpdateEnterpriseMembersCanCreateRepositoriesSettingInput: UpdateEnterpriseMembersCanCreateRepositoriesSettingInput;
    UpdateEnterpriseMembersCanCreateRepositoriesSettingPayload: Omit<UpdateEnterpriseMembersCanCreateRepositoriesSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
    };
    UpdateEnterpriseMembersCanDeleteIssuesSettingInput: UpdateEnterpriseMembersCanDeleteIssuesSettingInput;
    UpdateEnterpriseMembersCanDeleteIssuesSettingPayload: Omit<UpdateEnterpriseMembersCanDeleteIssuesSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
    };
    UpdateEnterpriseMembersCanDeleteRepositoriesSettingInput: UpdateEnterpriseMembersCanDeleteRepositoriesSettingInput;
    UpdateEnterpriseMembersCanDeleteRepositoriesSettingPayload: Omit<UpdateEnterpriseMembersCanDeleteRepositoriesSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
    };
    UpdateEnterpriseMembersCanInviteCollaboratorsSettingInput: UpdateEnterpriseMembersCanInviteCollaboratorsSettingInput;
    UpdateEnterpriseMembersCanInviteCollaboratorsSettingPayload: Omit<UpdateEnterpriseMembersCanInviteCollaboratorsSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
    };
    UpdateEnterpriseMembersCanMakePurchasesSettingInput: UpdateEnterpriseMembersCanMakePurchasesSettingInput;
    UpdateEnterpriseMembersCanMakePurchasesSettingPayload: Omit<UpdateEnterpriseMembersCanMakePurchasesSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
    };
    UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingInput: UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingInput;
    UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingPayload: Omit<UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
    };
    UpdateEnterpriseMembersCanViewDependencyInsightsSettingInput: UpdateEnterpriseMembersCanViewDependencyInsightsSettingInput;
    UpdateEnterpriseMembersCanViewDependencyInsightsSettingPayload: Omit<UpdateEnterpriseMembersCanViewDependencyInsightsSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
    };
    UpdateEnterpriseOrganizationProjectsSettingInput: UpdateEnterpriseOrganizationProjectsSettingInput;
    UpdateEnterpriseOrganizationProjectsSettingPayload: Omit<UpdateEnterpriseOrganizationProjectsSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
    };
    UpdateEnterpriseProfileInput: UpdateEnterpriseProfileInput;
    UpdateEnterpriseProfilePayload: Omit<UpdateEnterpriseProfilePayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
    };
    UpdateEnterpriseRepositoryProjectsSettingInput: UpdateEnterpriseRepositoryProjectsSettingInput;
    UpdateEnterpriseRepositoryProjectsSettingPayload: Omit<UpdateEnterpriseRepositoryProjectsSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
    };
    UpdateEnterpriseTeamDiscussionsSettingInput: UpdateEnterpriseTeamDiscussionsSettingInput;
    UpdateEnterpriseTeamDiscussionsSettingPayload: Omit<UpdateEnterpriseTeamDiscussionsSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
    };
    UpdateEnterpriseTwoFactorAuthenticationRequiredSettingInput: UpdateEnterpriseTwoFactorAuthenticationRequiredSettingInput;
    UpdateEnterpriseTwoFactorAuthenticationRequiredSettingPayload: Omit<UpdateEnterpriseTwoFactorAuthenticationRequiredSettingPayload, 'enterprise'> & {
        enterprise?: Maybe<ResolversParentTypes['Enterprise']>;
    };
    UpdateEnvironmentInput: UpdateEnvironmentInput;
    UpdateEnvironmentPayload: Omit<UpdateEnvironmentPayload, 'environment'> & {
        environment?: Maybe<ResolversParentTypes['Environment']>;
    };
    UpdateIpAllowListEnabledSettingInput: UpdateIpAllowListEnabledSettingInput;
    UpdateIpAllowListEnabledSettingPayload: Omit<UpdateIpAllowListEnabledSettingPayload, 'owner'> & {
        owner?: Maybe<ResolversParentTypes['IpAllowListOwner']>;
    };
    UpdateIpAllowListEntryInput: UpdateIpAllowListEntryInput;
    UpdateIpAllowListEntryPayload: Omit<UpdateIpAllowListEntryPayload, 'ipAllowListEntry'> & {
        ipAllowListEntry?: Maybe<ResolversParentTypes['IpAllowListEntry']>;
    };
    UpdateIpAllowListForInstalledAppsEnabledSettingInput: UpdateIpAllowListForInstalledAppsEnabledSettingInput;
    UpdateIpAllowListForInstalledAppsEnabledSettingPayload: Omit<UpdateIpAllowListForInstalledAppsEnabledSettingPayload, 'owner'> & {
        owner?: Maybe<ResolversParentTypes['IpAllowListOwner']>;
    };
    UpdateIssueCommentInput: UpdateIssueCommentInput;
    UpdateIssueCommentPayload: Omit<UpdateIssueCommentPayload, 'issueComment'> & {
        issueComment?: Maybe<ResolversParentTypes['IssueComment']>;
    };
    UpdateIssueInput: UpdateIssueInput;
    UpdateIssuePayload: Omit<UpdateIssuePayload, 'actor' | 'issue'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        issue?: Maybe<ResolversParentTypes['Issue']>;
    };
    UpdateLabelInput: UpdateLabelInput;
    UpdateLabelPayload: Omit<UpdateLabelPayload, 'label'> & {
        label?: Maybe<ResolversParentTypes['Label']>;
    };
    UpdateNotificationRestrictionSettingInput: UpdateNotificationRestrictionSettingInput;
    UpdateNotificationRestrictionSettingPayload: Omit<UpdateNotificationRestrictionSettingPayload, 'owner'> & {
        owner?: Maybe<ResolversParentTypes['VerifiableDomainOwner']>;
    };
    UpdateProjectCardInput: UpdateProjectCardInput;
    UpdateProjectCardPayload: Omit<UpdateProjectCardPayload, 'projectCard'> & {
        projectCard?: Maybe<ResolversParentTypes['ProjectCard']>;
    };
    UpdateProjectColumnInput: UpdateProjectColumnInput;
    UpdateProjectColumnPayload: Omit<UpdateProjectColumnPayload, 'projectColumn'> & {
        projectColumn?: Maybe<ResolversParentTypes['ProjectColumn']>;
    };
    UpdateProjectInput: UpdateProjectInput;
    UpdateProjectPayload: Omit<UpdateProjectPayload, 'project'> & {
        project?: Maybe<ResolversParentTypes['Project']>;
    };
    UpdatePullRequestInput: UpdatePullRequestInput;
    UpdatePullRequestPayload: Omit<UpdatePullRequestPayload, 'actor' | 'pullRequest'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        pullRequest?: Maybe<ResolversParentTypes['PullRequest']>;
    };
    UpdatePullRequestReviewCommentInput: UpdatePullRequestReviewCommentInput;
    UpdatePullRequestReviewCommentPayload: Omit<UpdatePullRequestReviewCommentPayload, 'pullRequestReviewComment'> & {
        pullRequestReviewComment?: Maybe<ResolversParentTypes['PullRequestReviewComment']>;
    };
    UpdatePullRequestReviewInput: UpdatePullRequestReviewInput;
    UpdatePullRequestReviewPayload: Omit<UpdatePullRequestReviewPayload, 'pullRequestReview'> & {
        pullRequestReview?: Maybe<ResolversParentTypes['PullRequestReview']>;
    };
    UpdateRefInput: UpdateRefInput;
    UpdateRefPayload: Omit<UpdateRefPayload, 'ref'> & {
        ref?: Maybe<ResolversParentTypes['Ref']>;
    };
    UpdateRefsInput: UpdateRefsInput;
    UpdateRefsPayload: UpdateRefsPayload;
    UpdateRepositoryInput: UpdateRepositoryInput;
    UpdateRepositoryPayload: Omit<UpdateRepositoryPayload, 'repository'> & {
        repository?: Maybe<ResolversParentTypes['Repository']>;
    };
    UpdateSubscriptionInput: UpdateSubscriptionInput;
    UpdateSubscriptionPayload: Omit<UpdateSubscriptionPayload, 'subscribable'> & {
        subscribable?: Maybe<ResolversParentTypes['Subscribable']>;
    };
    UpdateTeamDiscussionCommentInput: UpdateTeamDiscussionCommentInput;
    UpdateTeamDiscussionCommentPayload: Omit<UpdateTeamDiscussionCommentPayload, 'teamDiscussionComment'> & {
        teamDiscussionComment?: Maybe<ResolversParentTypes['TeamDiscussionComment']>;
    };
    UpdateTeamDiscussionInput: UpdateTeamDiscussionInput;
    UpdateTeamDiscussionPayload: Omit<UpdateTeamDiscussionPayload, 'teamDiscussion'> & {
        teamDiscussion?: Maybe<ResolversParentTypes['TeamDiscussion']>;
    };
    UpdateTeamReviewAssignmentInput: UpdateTeamReviewAssignmentInput;
    UpdateTeamReviewAssignmentPayload: Omit<UpdateTeamReviewAssignmentPayload, 'team'> & {
        team?: Maybe<ResolversParentTypes['Team']>;
    };
    UpdateTopicsInput: UpdateTopicsInput;
    UpdateTopicsPayload: Omit<UpdateTopicsPayload, 'repository'> & {
        repository?: Maybe<ResolversParentTypes['Repository']>;
    };
    User: Omit<User, 'commitComments' | 'contributionsCollection' | 'followers' | 'following' | 'gist' | 'gistComments' | 'gists' | 'hovercard' | 'issueComments' | 'itemShowcase' | 'organization' | 'organizations' | 'packages' | 'pinnableItems' | 'pinnedItems' | 'project' | 'projects' | 'pullRequests' | 'repositories' | 'repositoriesContributedTo' | 'repository' | 'repositoryDiscussionComments' | 'repositoryDiscussions' | 'savedReplies' | 'sponsorshipsAsMaintainer' | 'sponsorshipsAsSponsor' | 'starredRepositories' | 'status' | 'topRepositories' | 'watching'> & {
        commitComments: ResolversParentTypes['CommitCommentConnection'];
        contributionsCollection: ResolversParentTypes['ContributionsCollection'];
        followers: ResolversParentTypes['FollowerConnection'];
        following: ResolversParentTypes['FollowingConnection'];
        gist?: Maybe<ResolversParentTypes['Gist']>;
        gistComments: ResolversParentTypes['GistCommentConnection'];
        gists: ResolversParentTypes['GistConnection'];
        hovercard: ResolversParentTypes['Hovercard'];
        issueComments: ResolversParentTypes['IssueCommentConnection'];
        itemShowcase: ResolversParentTypes['ProfileItemShowcase'];
        organization?: Maybe<ResolversParentTypes['Organization']>;
        organizations: ResolversParentTypes['OrganizationConnection'];
        packages: ResolversParentTypes['PackageConnection'];
        pinnableItems: ResolversParentTypes['PinnableItemConnection'];
        pinnedItems: ResolversParentTypes['PinnableItemConnection'];
        project?: Maybe<ResolversParentTypes['Project']>;
        projects: ResolversParentTypes['ProjectConnection'];
        pullRequests: ResolversParentTypes['PullRequestConnection'];
        repositories: ResolversParentTypes['RepositoryConnection'];
        repositoriesContributedTo: ResolversParentTypes['RepositoryConnection'];
        repository?: Maybe<ResolversParentTypes['Repository']>;
        repositoryDiscussionComments: ResolversParentTypes['DiscussionCommentConnection'];
        repositoryDiscussions: ResolversParentTypes['DiscussionConnection'];
        savedReplies?: Maybe<ResolversParentTypes['SavedReplyConnection']>;
        sponsorshipsAsMaintainer: ResolversParentTypes['SponsorshipConnection'];
        sponsorshipsAsSponsor: ResolversParentTypes['SponsorshipConnection'];
        starredRepositories: ResolversParentTypes['StarredRepositoryConnection'];
        status?: Maybe<ResolversParentTypes['UserStatus']>;
        topRepositories: ResolversParentTypes['RepositoryConnection'];
        watching: ResolversParentTypes['RepositoryConnection'];
    };
    UserBlockedEvent: Omit<UserBlockedEvent, 'actor' | 'subject'> & {
        actor?: Maybe<ResolversParentTypes['Actor']>;
        subject?: Maybe<ResolversParentTypes['User']>;
    };
    UserConnection: Omit<UserConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['UserEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['User']>>>;
    };
    UserContentEdit: Omit<UserContentEdit, 'deletedBy' | 'editor'> & {
        deletedBy?: Maybe<ResolversParentTypes['Actor']>;
        editor?: Maybe<ResolversParentTypes['Actor']>;
    };
    UserContentEditConnection: Omit<UserContentEditConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['UserContentEditEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['UserContentEdit']>>>;
    };
    UserContentEditEdge: Omit<UserContentEditEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['UserContentEdit']>;
    };
    UserEdge: Omit<UserEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['User']>;
    };
    UserEmailMetadata: UserEmailMetadata;
    UserStatus: Omit<UserStatus, 'organization' | 'user'> & {
        organization?: Maybe<ResolversParentTypes['Organization']>;
        user: ResolversParentTypes['User'];
    };
    UserStatusConnection: Omit<UserStatusConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['UserStatusEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['UserStatus']>>>;
    };
    UserStatusEdge: Omit<UserStatusEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['UserStatus']>;
    };
    UserStatusOrder: UserStatusOrder;
    VerifiableDomain: Omit<VerifiableDomain, 'owner'> & {
        owner: ResolversParentTypes['VerifiableDomainOwner'];
    };
    VerifiableDomainConnection: Omit<VerifiableDomainConnection, 'edges' | 'nodes'> & {
        edges?: Maybe<Array<Maybe<ResolversParentTypes['VerifiableDomainEdge']>>>;
        nodes?: Maybe<Array<Maybe<ResolversParentTypes['VerifiableDomain']>>>;
    };
    VerifiableDomainEdge: Omit<VerifiableDomainEdge, 'node'> & {
        node?: Maybe<ResolversParentTypes['VerifiableDomain']>;
    };
    VerifiableDomainOrder: VerifiableDomainOrder;
    VerifiableDomainOwner: ResolversUnionTypes<ResolversParentTypes>['VerifiableDomainOwner'];
    VerifyVerifiableDomainInput: VerifyVerifiableDomainInput;
    VerifyVerifiableDomainPayload: Omit<VerifyVerifiableDomainPayload, 'domain'> & {
        domain?: Maybe<ResolversParentTypes['VerifiableDomain']>;
    };
    ViewerHovercardContext: Omit<ViewerHovercardContext, 'viewer'> & {
        viewer: ResolversParentTypes['User'];
    };
    Votable: ResolversInterfaceTypes<ResolversParentTypes>['Votable'];
    Workflow: Workflow;
    WorkflowRun: Omit<WorkflowRun, 'checkSuite' | 'deploymentReviews' | 'pendingDeploymentRequests'> & {
        checkSuite: ResolversParentTypes['CheckSuite'];
        deploymentReviews: ResolversParentTypes['DeploymentReviewConnection'];
        pendingDeploymentRequests: ResolversParentTypes['DeploymentRequestConnection'];
    };
    X509Certificate: Scalars['X509Certificate']['output'];
};
export type PossibleTypesDirectiveArgs = {
    abstractType?: Maybe<Scalars['String']['input']>;
    concreteTypes: Array<Scalars['String']['input']>;
};
export type PossibleTypesDirectiveResolver<Result, Parent, ContextType = any, Args = PossibleTypesDirectiveArgs> = DirectiveResolverFn<Result, Parent, ContextType, Args>;
export type PreviewDirectiveArgs = {
    toggledBy: Scalars['String']['input'];
};
export type PreviewDirectiveResolver<Result, Parent, ContextType = any, Args = PreviewDirectiveArgs> = DirectiveResolverFn<Result, Parent, ContextType, Args>;
export type ActorResolvers<ContextType = any, ParentType extends ResolversParentTypes['Actor'] = ResolversParentTypes['Actor']> = {
    __resolveType: TypeResolveFn<'Bot' | 'EnterpriseUserAccount' | 'Mannequin' | 'Organization' | 'User', ParentType, ContextType>;
    avatarUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType, Partial<ActorAvatarUrlArgs>>;
    login?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
};
export type ActorLocationResolvers<ContextType = any, ParentType extends ResolversParentTypes['ActorLocation'] = ResolversParentTypes['ActorLocation']> = {
    city?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    country?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    countryCode?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    region?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    regionCode?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AddAssigneesToAssignablePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['AddAssigneesToAssignablePayload'] = ResolversParentTypes['AddAssigneesToAssignablePayload']> = {
    assignable?: Resolver<Maybe<ResolversTypes['Assignable']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AddCommentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['AddCommentPayload'] = ResolversParentTypes['AddCommentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    commentEdge?: Resolver<Maybe<ResolversTypes['IssueCommentEdge']>, ParentType, ContextType>;
    subject?: Resolver<Maybe<ResolversTypes['Node']>, ParentType, ContextType>;
    timelineEdge?: Resolver<Maybe<ResolversTypes['IssueTimelineItemEdge']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AddDiscussionCommentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['AddDiscussionCommentPayload'] = ResolversParentTypes['AddDiscussionCommentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    comment?: Resolver<Maybe<ResolversTypes['DiscussionComment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AddEnterpriseAdminPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['AddEnterpriseAdminPayload'] = ResolversParentTypes['AddEnterpriseAdminPayload']> = {
    admin?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    role?: Resolver<Maybe<ResolversTypes['EnterpriseAdministratorRole']>, ParentType, ContextType>;
    viewer?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AddLabelsToLabelablePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['AddLabelsToLabelablePayload'] = ResolversParentTypes['AddLabelsToLabelablePayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    labelable?: Resolver<Maybe<ResolversTypes['Labelable']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AddProjectCardPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['AddProjectCardPayload'] = ResolversParentTypes['AddProjectCardPayload']> = {
    cardEdge?: Resolver<Maybe<ResolversTypes['ProjectCardEdge']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    projectColumn?: Resolver<Maybe<ResolversTypes['ProjectColumn']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AddProjectColumnPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['AddProjectColumnPayload'] = ResolversParentTypes['AddProjectColumnPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    columnEdge?: Resolver<Maybe<ResolversTypes['ProjectColumnEdge']>, ParentType, ContextType>;
    project?: Resolver<Maybe<ResolversTypes['Project']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AddPullRequestReviewCommentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['AddPullRequestReviewCommentPayload'] = ResolversParentTypes['AddPullRequestReviewCommentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    comment?: Resolver<Maybe<ResolversTypes['PullRequestReviewComment']>, ParentType, ContextType>;
    commentEdge?: Resolver<Maybe<ResolversTypes['PullRequestReviewCommentEdge']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AddPullRequestReviewPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['AddPullRequestReviewPayload'] = ResolversParentTypes['AddPullRequestReviewPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequestReview?: Resolver<Maybe<ResolversTypes['PullRequestReview']>, ParentType, ContextType>;
    reviewEdge?: Resolver<Maybe<ResolversTypes['PullRequestReviewEdge']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AddPullRequestReviewThreadPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['AddPullRequestReviewThreadPayload'] = ResolversParentTypes['AddPullRequestReviewThreadPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    thread?: Resolver<Maybe<ResolversTypes['PullRequestReviewThread']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AddReactionPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['AddReactionPayload'] = ResolversParentTypes['AddReactionPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    reaction?: Resolver<Maybe<ResolversTypes['Reaction']>, ParentType, ContextType>;
    subject?: Resolver<Maybe<ResolversTypes['Reactable']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AddStarPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['AddStarPayload'] = ResolversParentTypes['AddStarPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    starrable?: Resolver<Maybe<ResolversTypes['Starrable']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AddUpvotePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['AddUpvotePayload'] = ResolversParentTypes['AddUpvotePayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    subject?: Resolver<Maybe<ResolversTypes['Votable']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AddVerifiableDomainPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['AddVerifiableDomainPayload'] = ResolversParentTypes['AddVerifiableDomainPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    domain?: Resolver<Maybe<ResolversTypes['VerifiableDomain']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AddedToProjectEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['AddedToProjectEvent'] = ResolversParentTypes['AddedToProjectEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    project?: Resolver<Maybe<ResolversTypes['Project']>, ParentType, ContextType>;
    projectCard?: Resolver<Maybe<ResolversTypes['ProjectCard']>, ParentType, ContextType>;
    projectColumnName?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AppResolvers<ContextType = any, ParentType extends ResolversParentTypes['App'] = ResolversParentTypes['App']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    description?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    ipAllowListEntries?: Resolver<ResolversTypes['IpAllowListEntryConnection'], ParentType, ContextType, RequireFields<AppIpAllowListEntriesArgs, 'orderBy'>>;
    logoBackgroundColor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    logoUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType, Partial<AppLogoUrlArgs>>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    slug?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ApproveDeploymentsPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['ApproveDeploymentsPayload'] = ResolversParentTypes['ApproveDeploymentsPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    deployments?: Resolver<Maybe<Array<ResolversTypes['Deployment']>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ApproveVerifiableDomainPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['ApproveVerifiableDomainPayload'] = ResolversParentTypes['ApproveVerifiableDomainPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    domain?: Resolver<Maybe<ResolversTypes['VerifiableDomain']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ArchiveRepositoryPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['ArchiveRepositoryPayload'] = ResolversParentTypes['ArchiveRepositoryPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AssignableResolvers<ContextType = any, ParentType extends ResolversParentTypes['Assignable'] = ResolversParentTypes['Assignable']> = {
    __resolveType: TypeResolveFn<'Issue' | 'PullRequest', ParentType, ContextType>;
    assignees?: Resolver<ResolversTypes['UserConnection'], ParentType, ContextType, Partial<AssignableAssigneesArgs>>;
};
export type AssignedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['AssignedEvent'] = ResolversParentTypes['AssignedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    assignable?: Resolver<ResolversTypes['Assignable'], ParentType, ContextType>;
    assignee?: Resolver<Maybe<ResolversTypes['Assignee']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AssigneeResolvers<ContextType = any, ParentType extends ResolversParentTypes['Assignee'] = ResolversParentTypes['Assignee']> = {
    __resolveType: TypeResolveFn<'Bot' | 'Mannequin' | 'Organization' | 'User', ParentType, ContextType>;
};
export type AuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['AuditEntry'] = ResolversParentTypes['AuditEntry']> = {
    __resolveType: TypeResolveFn<'MembersCanDeleteReposClearAuditEntry' | 'MembersCanDeleteReposDisableAuditEntry' | 'MembersCanDeleteReposEnableAuditEntry' | 'OauthApplicationCreateAuditEntry' | 'OrgAddBillingManagerAuditEntry' | 'OrgAddMemberAuditEntry' | 'OrgBlockUserAuditEntry' | 'OrgConfigDisableCollaboratorsOnlyAuditEntry' | 'OrgConfigEnableCollaboratorsOnlyAuditEntry' | 'OrgCreateAuditEntry' | 'OrgDisableOauthAppRestrictionsAuditEntry' | 'OrgDisableSamlAuditEntry' | 'OrgDisableTwoFactorRequirementAuditEntry' | 'OrgEnableOauthAppRestrictionsAuditEntry' | 'OrgEnableSamlAuditEntry' | 'OrgEnableTwoFactorRequirementAuditEntry' | 'OrgInviteMemberAuditEntry' | 'OrgInviteToBusinessAuditEntry' | 'OrgOauthAppAccessApprovedAuditEntry' | 'OrgOauthAppAccessDeniedAuditEntry' | 'OrgOauthAppAccessRequestedAuditEntry' | 'OrgRemoveBillingManagerAuditEntry' | 'OrgRemoveMemberAuditEntry' | 'OrgRemoveOutsideCollaboratorAuditEntry' | 'OrgRestoreMemberAuditEntry' | 'OrgUnblockUserAuditEntry' | 'OrgUpdateDefaultRepositoryPermissionAuditEntry' | 'OrgUpdateMemberAuditEntry' | 'OrgUpdateMemberRepositoryCreationPermissionAuditEntry' | 'OrgUpdateMemberRepositoryInvitationPermissionAuditEntry' | 'PrivateRepositoryForkingDisableAuditEntry' | 'PrivateRepositoryForkingEnableAuditEntry' | 'RepoAccessAuditEntry' | 'RepoAddMemberAuditEntry' | 'RepoAddTopicAuditEntry' | 'RepoArchivedAuditEntry' | 'RepoChangeMergeSettingAuditEntry' | 'RepoConfigDisableAnonymousGitAccessAuditEntry' | 'RepoConfigDisableCollaboratorsOnlyAuditEntry' | 'RepoConfigDisableContributorsOnlyAuditEntry' | 'RepoConfigDisableSockpuppetDisallowedAuditEntry' | 'RepoConfigEnableAnonymousGitAccessAuditEntry' | 'RepoConfigEnableCollaboratorsOnlyAuditEntry' | 'RepoConfigEnableContributorsOnlyAuditEntry' | 'RepoConfigEnableSockpuppetDisallowedAuditEntry' | 'RepoConfigLockAnonymousGitAccessAuditEntry' | 'RepoConfigUnlockAnonymousGitAccessAuditEntry' | 'RepoCreateAuditEntry' | 'RepoDestroyAuditEntry' | 'RepoRemoveMemberAuditEntry' | 'RepoRemoveTopicAuditEntry' | 'RepositoryVisibilityChangeDisableAuditEntry' | 'RepositoryVisibilityChangeEnableAuditEntry' | 'TeamAddMemberAuditEntry' | 'TeamAddRepositoryAuditEntry' | 'TeamChangeParentTeamAuditEntry' | 'TeamRemoveMemberAuditEntry' | 'TeamRemoveRepositoryAuditEntry', ParentType, ContextType>;
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
};
export type AuditEntryActorResolvers<ContextType = any, ParentType extends ResolversParentTypes['AuditEntryActor'] = ResolversParentTypes['AuditEntryActor']> = {
    __resolveType: TypeResolveFn<'Bot' | 'Organization' | 'User', ParentType, ContextType>;
};
export type AutoMergeDisabledEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['AutoMergeDisabledEvent'] = ResolversParentTypes['AutoMergeDisabledEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    disabler?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    reason?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    reasonCode?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AutoMergeEnabledEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['AutoMergeEnabledEvent'] = ResolversParentTypes['AutoMergeEnabledEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    enabler?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AutoMergeRequestResolvers<ContextType = any, ParentType extends ResolversParentTypes['AutoMergeRequest'] = ResolversParentTypes['AutoMergeRequest']> = {
    authorEmail?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    commitBody?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    commitHeadline?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enabledAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    enabledBy?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    mergeMethod?: Resolver<ResolversTypes['PullRequestMergeMethod'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AutoRebaseEnabledEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['AutoRebaseEnabledEvent'] = ResolversParentTypes['AutoRebaseEnabledEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    enabler?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AutoSquashEnabledEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['AutoSquashEnabledEvent'] = ResolversParentTypes['AutoSquashEnabledEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    enabler?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AutomaticBaseChangeFailedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['AutomaticBaseChangeFailedEvent'] = ResolversParentTypes['AutomaticBaseChangeFailedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    newBase?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    oldBase?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type AutomaticBaseChangeSucceededEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['AutomaticBaseChangeSucceededEvent'] = ResolversParentTypes['AutomaticBaseChangeSucceededEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    newBase?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    oldBase?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type BaseRefChangedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['BaseRefChangedEvent'] = ResolversParentTypes['BaseRefChangedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    currentRefName?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    previousRefName?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type BaseRefDeletedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['BaseRefDeletedEvent'] = ResolversParentTypes['BaseRefDeletedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    baseRefName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type BaseRefForcePushedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['BaseRefForcePushedEvent'] = ResolversParentTypes['BaseRefForcePushedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    afterCommit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    beforeCommit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    ref?: Resolver<Maybe<ResolversTypes['Ref']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type BlameResolvers<ContextType = any, ParentType extends ResolversParentTypes['Blame'] = ResolversParentTypes['Blame']> = {
    ranges?: Resolver<Array<ResolversTypes['BlameRange']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type BlameRangeResolvers<ContextType = any, ParentType extends ResolversParentTypes['BlameRange'] = ResolversParentTypes['BlameRange']> = {
    age?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    commit?: Resolver<ResolversTypes['Commit'], ParentType, ContextType>;
    endingLine?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    startingLine?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type BlobResolvers<ContextType = any, ParentType extends ResolversParentTypes['Blob'] = ResolversParentTypes['Blob']> = {
    abbreviatedOid?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    byteSize?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    commitResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    commitUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isBinary?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    isTruncated?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    oid?: Resolver<ResolversTypes['GitObjectID'], ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    text?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type BotResolvers<ContextType = any, ParentType extends ResolversParentTypes['Bot'] = ResolversParentTypes['Bot']> = {
    avatarUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType, Partial<BotAvatarUrlArgs>>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    login?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type BranchProtectionRuleResolvers<ContextType = any, ParentType extends ResolversParentTypes['BranchProtectionRule'] = ResolversParentTypes['BranchProtectionRule']> = {
    allowsDeletions?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    allowsForcePushes?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    branchProtectionRuleConflicts?: Resolver<ResolversTypes['BranchProtectionRuleConflictConnection'], ParentType, ContextType, Partial<BranchProtectionRuleBranchProtectionRuleConflictsArgs>>;
    creator?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    dismissesStaleReviews?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isAdminEnforced?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    matchingRefs?: Resolver<ResolversTypes['RefConnection'], ParentType, ContextType, Partial<BranchProtectionRuleMatchingRefsArgs>>;
    pattern?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    pushAllowances?: Resolver<ResolversTypes['PushAllowanceConnection'], ParentType, ContextType, Partial<BranchProtectionRulePushAllowancesArgs>>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    requiredApprovingReviewCount?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    requiredStatusCheckContexts?: Resolver<Maybe<Array<Maybe<ResolversTypes['String']>>>, ParentType, ContextType>;
    requiresApprovingReviews?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    requiresCodeOwnerReviews?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    requiresCommitSignatures?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    requiresConversationResolution?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    requiresLinearHistory?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    requiresStatusChecks?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    requiresStrictStatusChecks?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    restrictsPushes?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    restrictsReviewDismissals?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    reviewDismissalAllowances?: Resolver<ResolversTypes['ReviewDismissalAllowanceConnection'], ParentType, ContextType, Partial<BranchProtectionRuleReviewDismissalAllowancesArgs>>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type BranchProtectionRuleConflictResolvers<ContextType = any, ParentType extends ResolversParentTypes['BranchProtectionRuleConflict'] = ResolversParentTypes['BranchProtectionRuleConflict']> = {
    branchProtectionRule?: Resolver<Maybe<ResolversTypes['BranchProtectionRule']>, ParentType, ContextType>;
    conflictingBranchProtectionRule?: Resolver<Maybe<ResolversTypes['BranchProtectionRule']>, ParentType, ContextType>;
    ref?: Resolver<Maybe<ResolversTypes['Ref']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type BranchProtectionRuleConflictConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['BranchProtectionRuleConflictConnection'] = ResolversParentTypes['BranchProtectionRuleConflictConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['BranchProtectionRuleConflictEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['BranchProtectionRuleConflict']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type BranchProtectionRuleConflictEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['BranchProtectionRuleConflictEdge'] = ResolversParentTypes['BranchProtectionRuleConflictEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['BranchProtectionRuleConflict']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type BranchProtectionRuleConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['BranchProtectionRuleConnection'] = ResolversParentTypes['BranchProtectionRuleConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['BranchProtectionRuleEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['BranchProtectionRule']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type BranchProtectionRuleEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['BranchProtectionRuleEdge'] = ResolversParentTypes['BranchProtectionRuleEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['BranchProtectionRule']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CvssResolvers<ContextType = any, ParentType extends ResolversParentTypes['CVSS'] = ResolversParentTypes['CVSS']> = {
    score?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    vectorString?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CweResolvers<ContextType = any, ParentType extends ResolversParentTypes['CWE'] = ResolversParentTypes['CWE']> = {
    cweId?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    description?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CweConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CWEConnection'] = ResolversParentTypes['CWEConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['CWEEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['CWE']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CweEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['CWEEdge'] = ResolversParentTypes['CWEEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['CWE']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ChangeUserStatusPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['ChangeUserStatusPayload'] = ResolversParentTypes['ChangeUserStatusPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    status?: Resolver<Maybe<ResolversTypes['UserStatus']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CheckAnnotationResolvers<ContextType = any, ParentType extends ResolversParentTypes['CheckAnnotation'] = ResolversParentTypes['CheckAnnotation']> = {
    annotationLevel?: Resolver<Maybe<ResolversTypes['CheckAnnotationLevel']>, ParentType, ContextType>;
    blobUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    location?: Resolver<ResolversTypes['CheckAnnotationSpan'], ParentType, ContextType>;
    message?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    path?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    rawDetails?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    title?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CheckAnnotationConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CheckAnnotationConnection'] = ResolversParentTypes['CheckAnnotationConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['CheckAnnotationEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['CheckAnnotation']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CheckAnnotationEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['CheckAnnotationEdge'] = ResolversParentTypes['CheckAnnotationEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['CheckAnnotation']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CheckAnnotationPositionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CheckAnnotationPosition'] = ResolversParentTypes['CheckAnnotationPosition']> = {
    column?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    line?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CheckAnnotationSpanResolvers<ContextType = any, ParentType extends ResolversParentTypes['CheckAnnotationSpan'] = ResolversParentTypes['CheckAnnotationSpan']> = {
    end?: Resolver<ResolversTypes['CheckAnnotationPosition'], ParentType, ContextType>;
    start?: Resolver<ResolversTypes['CheckAnnotationPosition'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CheckRunResolvers<ContextType = any, ParentType extends ResolversParentTypes['CheckRun'] = ResolversParentTypes['CheckRun']> = {
    annotations?: Resolver<Maybe<ResolversTypes['CheckAnnotationConnection']>, ParentType, ContextType, Partial<CheckRunAnnotationsArgs>>;
    checkSuite?: Resolver<ResolversTypes['CheckSuite'], ParentType, ContextType>;
    completedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    conclusion?: Resolver<Maybe<ResolversTypes['CheckConclusionState']>, ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    deployment?: Resolver<Maybe<ResolversTypes['Deployment']>, ParentType, ContextType>;
    detailsUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    externalId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isRequired?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType, Partial<CheckRunIsRequiredArgs>>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    pendingDeploymentRequest?: Resolver<Maybe<ResolversTypes['DeploymentRequest']>, ParentType, ContextType>;
    permalink?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    startedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    status?: Resolver<ResolversTypes['CheckStatusState'], ParentType, ContextType>;
    steps?: Resolver<Maybe<ResolversTypes['CheckStepConnection']>, ParentType, ContextType, Partial<CheckRunStepsArgs>>;
    summary?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    text?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    title?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CheckRunConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CheckRunConnection'] = ResolversParentTypes['CheckRunConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['CheckRunEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['CheckRun']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CheckRunEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['CheckRunEdge'] = ResolversParentTypes['CheckRunEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['CheckRun']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CheckStepResolvers<ContextType = any, ParentType extends ResolversParentTypes['CheckStep'] = ResolversParentTypes['CheckStep']> = {
    completedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    conclusion?: Resolver<Maybe<ResolversTypes['CheckConclusionState']>, ParentType, ContextType>;
    externalId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    number?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    secondsToCompletion?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    startedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    status?: Resolver<ResolversTypes['CheckStatusState'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CheckStepConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CheckStepConnection'] = ResolversParentTypes['CheckStepConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['CheckStepEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['CheckStep']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CheckStepEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['CheckStepEdge'] = ResolversParentTypes['CheckStepEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['CheckStep']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CheckSuiteResolvers<ContextType = any, ParentType extends ResolversParentTypes['CheckSuite'] = ResolversParentTypes['CheckSuite']> = {
    app?: Resolver<Maybe<ResolversTypes['App']>, ParentType, ContextType>;
    branch?: Resolver<Maybe<ResolversTypes['Ref']>, ParentType, ContextType>;
    checkRuns?: Resolver<Maybe<ResolversTypes['CheckRunConnection']>, ParentType, ContextType, Partial<CheckSuiteCheckRunsArgs>>;
    commit?: Resolver<ResolversTypes['Commit'], ParentType, ContextType>;
    conclusion?: Resolver<Maybe<ResolversTypes['CheckConclusionState']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    creator?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    matchingPullRequests?: Resolver<Maybe<ResolversTypes['PullRequestConnection']>, ParentType, ContextType, Partial<CheckSuiteMatchingPullRequestsArgs>>;
    push?: Resolver<Maybe<ResolversTypes['Push']>, ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    status?: Resolver<ResolversTypes['CheckStatusState'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    workflowRun?: Resolver<Maybe<ResolversTypes['WorkflowRun']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CheckSuiteConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CheckSuiteConnection'] = ResolversParentTypes['CheckSuiteConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['CheckSuiteEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['CheckSuite']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CheckSuiteEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['CheckSuiteEdge'] = ResolversParentTypes['CheckSuiteEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['CheckSuite']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ClearLabelsFromLabelablePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['ClearLabelsFromLabelablePayload'] = ResolversParentTypes['ClearLabelsFromLabelablePayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    labelable?: Resolver<Maybe<ResolversTypes['Labelable']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CloneProjectPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CloneProjectPayload'] = ResolversParentTypes['CloneProjectPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    jobStatusId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    project?: Resolver<Maybe<ResolversTypes['Project']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CloneTemplateRepositoryPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CloneTemplateRepositoryPayload'] = ResolversParentTypes['CloneTemplateRepositoryPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ClosableResolvers<ContextType = any, ParentType extends ResolversParentTypes['Closable'] = ResolversParentTypes['Closable']> = {
    __resolveType: TypeResolveFn<'Issue' | 'Milestone' | 'Project' | 'PullRequest', ParentType, ContextType>;
    closed?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    closedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
};
export type CloseIssuePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CloseIssuePayload'] = ResolversParentTypes['CloseIssuePayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    issue?: Resolver<Maybe<ResolversTypes['Issue']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ClosePullRequestPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['ClosePullRequestPayload'] = ResolversParentTypes['ClosePullRequestPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ClosedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['ClosedEvent'] = ResolversParentTypes['ClosedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    closable?: Resolver<ResolversTypes['Closable'], ParentType, ContextType>;
    closer?: Resolver<Maybe<ResolversTypes['Closer']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CloserResolvers<ContextType = any, ParentType extends ResolversParentTypes['Closer'] = ResolversParentTypes['Closer']> = {
    __resolveType: TypeResolveFn<'Commit' | 'PullRequest', ParentType, ContextType>;
};
export type CodeOfConductResolvers<ContextType = any, ParentType extends ResolversParentTypes['CodeOfConduct'] = ResolversParentTypes['CodeOfConduct']> = {
    body?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    key?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    resourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    url?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CommentResolvers<ContextType = any, ParentType extends ResolversParentTypes['Comment'] = ResolversParentTypes['Comment']> = {
    __resolveType: TypeResolveFn<'CommitComment' | 'Discussion' | 'DiscussionComment' | 'GistComment' | 'Issue' | 'IssueComment' | 'PullRequest' | 'PullRequestReview' | 'PullRequestReviewComment' | 'TeamDiscussion' | 'TeamDiscussionComment', ParentType, ContextType>;
    author?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    authorAssociation?: Resolver<ResolversTypes['CommentAuthorAssociation'], ParentType, ContextType>;
    body?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    bodyHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    bodyText?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    createdViaEmail?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    editor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    includesCreatedEdit?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    lastEditedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    publishedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    userContentEdits?: Resolver<Maybe<ResolversTypes['UserContentEditConnection']>, ParentType, ContextType, Partial<CommentUserContentEditsArgs>>;
    viewerDidAuthor?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
};
export type CommentDeletedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['CommentDeletedEvent'] = ResolversParentTypes['CommentDeletedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    deletedCommentAuthor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CommitResolvers<ContextType = any, ParentType extends ResolversParentTypes['Commit'] = ResolversParentTypes['Commit']> = {
    abbreviatedOid?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    additions?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    associatedPullRequests?: Resolver<Maybe<ResolversTypes['PullRequestConnection']>, ParentType, ContextType, RequireFields<CommitAssociatedPullRequestsArgs, 'orderBy'>>;
    author?: Resolver<Maybe<ResolversTypes['GitActor']>, ParentType, ContextType>;
    authoredByCommitter?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    authoredDate?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    authors?: Resolver<ResolversTypes['GitActorConnection'], ParentType, ContextType, Partial<CommitAuthorsArgs>>;
    blame?: Resolver<ResolversTypes['Blame'], ParentType, ContextType, RequireFields<CommitBlameArgs, 'path'>>;
    changedFiles?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    checkSuites?: Resolver<Maybe<ResolversTypes['CheckSuiteConnection']>, ParentType, ContextType, Partial<CommitCheckSuitesArgs>>;
    comments?: Resolver<ResolversTypes['CommitCommentConnection'], ParentType, ContextType, Partial<CommitCommentsArgs>>;
    commitResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    commitUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    committedDate?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    committedViaWeb?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    committer?: Resolver<Maybe<ResolversTypes['GitActor']>, ParentType, ContextType>;
    deletions?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    deployments?: Resolver<Maybe<ResolversTypes['DeploymentConnection']>, ParentType, ContextType, RequireFields<CommitDeploymentsArgs, 'orderBy'>>;
    file?: Resolver<Maybe<ResolversTypes['TreeEntry']>, ParentType, ContextType, RequireFields<CommitFileArgs, 'path'>>;
    history?: Resolver<ResolversTypes['CommitHistoryConnection'], ParentType, ContextType, Partial<CommitHistoryArgs>>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    message?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    messageBody?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    messageBodyHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    messageHeadline?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    messageHeadlineHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    oid?: Resolver<ResolversTypes['GitObjectID'], ParentType, ContextType>;
    onBehalfOf?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    parents?: Resolver<ResolversTypes['CommitConnection'], ParentType, ContextType, Partial<CommitParentsArgs>>;
    pushedDate?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    signature?: Resolver<Maybe<ResolversTypes['GitSignature']>, ParentType, ContextType>;
    status?: Resolver<Maybe<ResolversTypes['Status']>, ParentType, ContextType>;
    statusCheckRollup?: Resolver<Maybe<ResolversTypes['StatusCheckRollup']>, ParentType, ContextType>;
    submodules?: Resolver<ResolversTypes['SubmoduleConnection'], ParentType, ContextType, Partial<CommitSubmodulesArgs>>;
    tarballUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    tree?: Resolver<ResolversTypes['Tree'], ParentType, ContextType>;
    treeResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    treeUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    viewerCanSubscribe?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerSubscription?: Resolver<Maybe<ResolversTypes['SubscriptionState']>, ParentType, ContextType>;
    zipballUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CommitCommentResolvers<ContextType = any, ParentType extends ResolversParentTypes['CommitComment'] = ResolversParentTypes['CommitComment']> = {
    author?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    authorAssociation?: Resolver<ResolversTypes['CommentAuthorAssociation'], ParentType, ContextType>;
    body?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    bodyHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    bodyText?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    commit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    createdViaEmail?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    editor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    includesCreatedEdit?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isMinimized?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    lastEditedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    minimizedReason?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    path?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    position?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    publishedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    reactionGroups?: Resolver<Maybe<Array<ResolversTypes['ReactionGroup']>>, ParentType, ContextType>;
    reactions?: Resolver<ResolversTypes['ReactionConnection'], ParentType, ContextType, Partial<CommitCommentReactionsArgs>>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    userContentEdits?: Resolver<Maybe<ResolversTypes['UserContentEditConnection']>, ParentType, ContextType, Partial<CommitCommentUserContentEditsArgs>>;
    viewerCanDelete?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanMinimize?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanReact?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanUpdate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCannotUpdateReasons?: Resolver<Array<ResolversTypes['CommentCannotUpdateReason']>, ParentType, ContextType>;
    viewerDidAuthor?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CommitCommentConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CommitCommentConnection'] = ResolversParentTypes['CommitCommentConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['CommitCommentEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['CommitComment']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CommitCommentEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['CommitCommentEdge'] = ResolversParentTypes['CommitCommentEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['CommitComment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CommitCommentThreadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CommitCommentThread'] = ResolversParentTypes['CommitCommentThread']> = {
    comments?: Resolver<ResolversTypes['CommitCommentConnection'], ParentType, ContextType, Partial<CommitCommentThreadCommentsArgs>>;
    commit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    path?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    position?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CommitConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CommitConnection'] = ResolversParentTypes['CommitConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['CommitEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Commit']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CommitContributionsByRepositoryResolvers<ContextType = any, ParentType extends ResolversParentTypes['CommitContributionsByRepository'] = ResolversParentTypes['CommitContributionsByRepository']> = {
    contributions?: Resolver<ResolversTypes['CreatedCommitContributionConnection'], ParentType, ContextType, RequireFields<CommitContributionsByRepositoryContributionsArgs, 'orderBy'>>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CommitEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['CommitEdge'] = ResolversParentTypes['CommitEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CommitHistoryConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CommitHistoryConnection'] = ResolversParentTypes['CommitHistoryConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['CommitEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Commit']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ConnectedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['ConnectedEvent'] = ResolversParentTypes['ConnectedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isCrossRepository?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    source?: Resolver<ResolversTypes['ReferencedSubject'], ParentType, ContextType>;
    subject?: Resolver<ResolversTypes['ReferencedSubject'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ContentAttachmentResolvers<ContextType = any, ParentType extends ResolversParentTypes['ContentAttachment'] = ResolversParentTypes['ContentAttachment']> = {
    body?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    contentReference?: Resolver<ResolversTypes['ContentReference'], ParentType, ContextType>;
    databaseId?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    title?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ContentReferenceResolvers<ContextType = any, ParentType extends ResolversParentTypes['ContentReference'] = ResolversParentTypes['ContentReference']> = {
    databaseId?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    reference?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ContributionResolvers<ContextType = any, ParentType extends ResolversParentTypes['Contribution'] = ResolversParentTypes['Contribution']> = {
    __resolveType: TypeResolveFn<'CreatedCommitContribution' | 'CreatedIssueContribution' | 'CreatedPullRequestContribution' | 'CreatedPullRequestReviewContribution' | 'CreatedRepositoryContribution' | 'JoinedGitHubContribution' | 'RestrictedContribution', ParentType, ContextType>;
    isRestricted?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    occurredAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    user?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
};
export type ContributionCalendarResolvers<ContextType = any, ParentType extends ResolversParentTypes['ContributionCalendar'] = ResolversParentTypes['ContributionCalendar']> = {
    colors?: Resolver<Array<ResolversTypes['String']>, ParentType, ContextType>;
    isHalloween?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    months?: Resolver<Array<ResolversTypes['ContributionCalendarMonth']>, ParentType, ContextType>;
    totalContributions?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    weeks?: Resolver<Array<ResolversTypes['ContributionCalendarWeek']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ContributionCalendarDayResolvers<ContextType = any, ParentType extends ResolversParentTypes['ContributionCalendarDay'] = ResolversParentTypes['ContributionCalendarDay']> = {
    color?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    contributionCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    contributionLevel?: Resolver<ResolversTypes['ContributionLevel'], ParentType, ContextType>;
    date?: Resolver<ResolversTypes['Date'], ParentType, ContextType>;
    weekday?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ContributionCalendarMonthResolvers<ContextType = any, ParentType extends ResolversParentTypes['ContributionCalendarMonth'] = ResolversParentTypes['ContributionCalendarMonth']> = {
    firstDay?: Resolver<ResolversTypes['Date'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    totalWeeks?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    year?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ContributionCalendarWeekResolvers<ContextType = any, ParentType extends ResolversParentTypes['ContributionCalendarWeek'] = ResolversParentTypes['ContributionCalendarWeek']> = {
    contributionDays?: Resolver<Array<ResolversTypes['ContributionCalendarDay']>, ParentType, ContextType>;
    firstDay?: Resolver<ResolversTypes['Date'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ContributionsCollectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['ContributionsCollection'] = ResolversParentTypes['ContributionsCollection']> = {
    commitContributionsByRepository?: Resolver<Array<ResolversTypes['CommitContributionsByRepository']>, ParentType, ContextType, RequireFields<ContributionsCollectionCommitContributionsByRepositoryArgs, 'maxRepositories'>>;
    contributionCalendar?: Resolver<ResolversTypes['ContributionCalendar'], ParentType, ContextType>;
    contributionYears?: Resolver<Array<ResolversTypes['Int']>, ParentType, ContextType>;
    doesEndInCurrentMonth?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    earliestRestrictedContributionDate?: Resolver<Maybe<ResolversTypes['Date']>, ParentType, ContextType>;
    endedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    firstIssueContribution?: Resolver<Maybe<ResolversTypes['CreatedIssueOrRestrictedContribution']>, ParentType, ContextType>;
    firstPullRequestContribution?: Resolver<Maybe<ResolversTypes['CreatedPullRequestOrRestrictedContribution']>, ParentType, ContextType>;
    firstRepositoryContribution?: Resolver<Maybe<ResolversTypes['CreatedRepositoryOrRestrictedContribution']>, ParentType, ContextType>;
    hasActivityInThePast?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    hasAnyContributions?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    hasAnyRestrictedContributions?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isSingleDay?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    issueContributions?: Resolver<ResolversTypes['CreatedIssueContributionConnection'], ParentType, ContextType, RequireFields<ContributionsCollectionIssueContributionsArgs, 'excludeFirst' | 'excludePopular' | 'orderBy'>>;
    issueContributionsByRepository?: Resolver<Array<ResolversTypes['IssueContributionsByRepository']>, ParentType, ContextType, RequireFields<ContributionsCollectionIssueContributionsByRepositoryArgs, 'excludeFirst' | 'excludePopular' | 'maxRepositories'>>;
    joinedGitHubContribution?: Resolver<Maybe<ResolversTypes['JoinedGitHubContribution']>, ParentType, ContextType>;
    latestRestrictedContributionDate?: Resolver<Maybe<ResolversTypes['Date']>, ParentType, ContextType>;
    mostRecentCollectionWithActivity?: Resolver<Maybe<ResolversTypes['ContributionsCollection']>, ParentType, ContextType>;
    mostRecentCollectionWithoutActivity?: Resolver<Maybe<ResolversTypes['ContributionsCollection']>, ParentType, ContextType>;
    popularIssueContribution?: Resolver<Maybe<ResolversTypes['CreatedIssueContribution']>, ParentType, ContextType>;
    popularPullRequestContribution?: Resolver<Maybe<ResolversTypes['CreatedPullRequestContribution']>, ParentType, ContextType>;
    pullRequestContributions?: Resolver<ResolversTypes['CreatedPullRequestContributionConnection'], ParentType, ContextType, RequireFields<ContributionsCollectionPullRequestContributionsArgs, 'excludeFirst' | 'excludePopular' | 'orderBy'>>;
    pullRequestContributionsByRepository?: Resolver<Array<ResolversTypes['PullRequestContributionsByRepository']>, ParentType, ContextType, RequireFields<ContributionsCollectionPullRequestContributionsByRepositoryArgs, 'excludeFirst' | 'excludePopular' | 'maxRepositories'>>;
    pullRequestReviewContributions?: Resolver<ResolversTypes['CreatedPullRequestReviewContributionConnection'], ParentType, ContextType, RequireFields<ContributionsCollectionPullRequestReviewContributionsArgs, 'orderBy'>>;
    pullRequestReviewContributionsByRepository?: Resolver<Array<ResolversTypes['PullRequestReviewContributionsByRepository']>, ParentType, ContextType, RequireFields<ContributionsCollectionPullRequestReviewContributionsByRepositoryArgs, 'maxRepositories'>>;
    repositoryContributions?: Resolver<ResolversTypes['CreatedRepositoryContributionConnection'], ParentType, ContextType, RequireFields<ContributionsCollectionRepositoryContributionsArgs, 'excludeFirst' | 'orderBy'>>;
    restrictedContributionsCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    startedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    totalCommitContributions?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    totalIssueContributions?: Resolver<ResolversTypes['Int'], ParentType, ContextType, RequireFields<ContributionsCollectionTotalIssueContributionsArgs, 'excludeFirst' | 'excludePopular'>>;
    totalPullRequestContributions?: Resolver<ResolversTypes['Int'], ParentType, ContextType, RequireFields<ContributionsCollectionTotalPullRequestContributionsArgs, 'excludeFirst' | 'excludePopular'>>;
    totalPullRequestReviewContributions?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    totalRepositoriesWithContributedCommits?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    totalRepositoriesWithContributedIssues?: Resolver<ResolversTypes['Int'], ParentType, ContextType, RequireFields<ContributionsCollectionTotalRepositoriesWithContributedIssuesArgs, 'excludeFirst' | 'excludePopular'>>;
    totalRepositoriesWithContributedPullRequestReviews?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    totalRepositoriesWithContributedPullRequests?: Resolver<ResolversTypes['Int'], ParentType, ContextType, RequireFields<ContributionsCollectionTotalRepositoriesWithContributedPullRequestsArgs, 'excludeFirst' | 'excludePopular'>>;
    totalRepositoryContributions?: Resolver<ResolversTypes['Int'], ParentType, ContextType, RequireFields<ContributionsCollectionTotalRepositoryContributionsArgs, 'excludeFirst'>>;
    user?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ConvertProjectCardNoteToIssuePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['ConvertProjectCardNoteToIssuePayload'] = ResolversParentTypes['ConvertProjectCardNoteToIssuePayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    projectCard?: Resolver<Maybe<ResolversTypes['ProjectCard']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ConvertPullRequestToDraftPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['ConvertPullRequestToDraftPayload'] = ResolversParentTypes['ConvertPullRequestToDraftPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ConvertToDraftEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['ConvertToDraftEvent'] = ResolversParentTypes['ConvertToDraftEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ConvertedNoteToIssueEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['ConvertedNoteToIssueEvent'] = ResolversParentTypes['ConvertedNoteToIssueEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    project?: Resolver<Maybe<ResolversTypes['Project']>, ParentType, ContextType>;
    projectCard?: Resolver<Maybe<ResolversTypes['ProjectCard']>, ParentType, ContextType>;
    projectColumnName?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreateBranchProtectionRulePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreateBranchProtectionRulePayload'] = ResolversParentTypes['CreateBranchProtectionRulePayload']> = {
    branchProtectionRule?: Resolver<Maybe<ResolversTypes['BranchProtectionRule']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreateCheckRunPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreateCheckRunPayload'] = ResolversParentTypes['CreateCheckRunPayload']> = {
    checkRun?: Resolver<Maybe<ResolversTypes['CheckRun']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreateCheckSuitePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreateCheckSuitePayload'] = ResolversParentTypes['CreateCheckSuitePayload']> = {
    checkSuite?: Resolver<Maybe<ResolversTypes['CheckSuite']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreateContentAttachmentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreateContentAttachmentPayload'] = ResolversParentTypes['CreateContentAttachmentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    contentAttachment?: Resolver<Maybe<ResolversTypes['ContentAttachment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreateDeploymentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreateDeploymentPayload'] = ResolversParentTypes['CreateDeploymentPayload']> = {
    autoMerged?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    deployment?: Resolver<Maybe<ResolversTypes['Deployment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreateDeploymentStatusPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreateDeploymentStatusPayload'] = ResolversParentTypes['CreateDeploymentStatusPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    deploymentStatus?: Resolver<Maybe<ResolversTypes['DeploymentStatus']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreateDiscussionPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreateDiscussionPayload'] = ResolversParentTypes['CreateDiscussionPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    discussion?: Resolver<Maybe<ResolversTypes['Discussion']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreateEnterpriseOrganizationPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreateEnterpriseOrganizationPayload'] = ResolversParentTypes['CreateEnterpriseOrganizationPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreateEnvironmentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreateEnvironmentPayload'] = ResolversParentTypes['CreateEnvironmentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    environment?: Resolver<Maybe<ResolversTypes['Environment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreateIpAllowListEntryPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreateIpAllowListEntryPayload'] = ResolversParentTypes['CreateIpAllowListEntryPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    ipAllowListEntry?: Resolver<Maybe<ResolversTypes['IpAllowListEntry']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreateIssuePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreateIssuePayload'] = ResolversParentTypes['CreateIssuePayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    issue?: Resolver<Maybe<ResolversTypes['Issue']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreateLabelPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreateLabelPayload'] = ResolversParentTypes['CreateLabelPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    label?: Resolver<Maybe<ResolversTypes['Label']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreateProjectPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreateProjectPayload'] = ResolversParentTypes['CreateProjectPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    project?: Resolver<Maybe<ResolversTypes['Project']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreatePullRequestPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatePullRequestPayload'] = ResolversParentTypes['CreatePullRequestPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreateRefPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreateRefPayload'] = ResolversParentTypes['CreateRefPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    ref?: Resolver<Maybe<ResolversTypes['Ref']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreateRepositoryPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreateRepositoryPayload'] = ResolversParentTypes['CreateRepositoryPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreateTeamDiscussionCommentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreateTeamDiscussionCommentPayload'] = ResolversParentTypes['CreateTeamDiscussionCommentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    teamDiscussionComment?: Resolver<Maybe<ResolversTypes['TeamDiscussionComment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreateTeamDiscussionPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreateTeamDiscussionPayload'] = ResolversParentTypes['CreateTeamDiscussionPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    teamDiscussion?: Resolver<Maybe<ResolversTypes['TeamDiscussion']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreatedCommitContributionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedCommitContribution'] = ResolversParentTypes['CreatedCommitContribution']> = {
    commitCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    isRestricted?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    occurredAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    user?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreatedCommitContributionConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedCommitContributionConnection'] = ResolversParentTypes['CreatedCommitContributionConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['CreatedCommitContributionEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['CreatedCommitContribution']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreatedCommitContributionEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedCommitContributionEdge'] = ResolversParentTypes['CreatedCommitContributionEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['CreatedCommitContribution']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreatedIssueContributionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedIssueContribution'] = ResolversParentTypes['CreatedIssueContribution']> = {
    isRestricted?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    issue?: Resolver<ResolversTypes['Issue'], ParentType, ContextType>;
    occurredAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    user?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreatedIssueContributionConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedIssueContributionConnection'] = ResolversParentTypes['CreatedIssueContributionConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['CreatedIssueContributionEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['CreatedIssueContribution']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreatedIssueContributionEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedIssueContributionEdge'] = ResolversParentTypes['CreatedIssueContributionEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['CreatedIssueContribution']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreatedIssueOrRestrictedContributionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedIssueOrRestrictedContribution'] = ResolversParentTypes['CreatedIssueOrRestrictedContribution']> = {
    __resolveType: TypeResolveFn<'CreatedIssueContribution' | 'RestrictedContribution', ParentType, ContextType>;
};
export type CreatedPullRequestContributionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedPullRequestContribution'] = ResolversParentTypes['CreatedPullRequestContribution']> = {
    isRestricted?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    occurredAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    user?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreatedPullRequestContributionConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedPullRequestContributionConnection'] = ResolversParentTypes['CreatedPullRequestContributionConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['CreatedPullRequestContributionEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['CreatedPullRequestContribution']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreatedPullRequestContributionEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedPullRequestContributionEdge'] = ResolversParentTypes['CreatedPullRequestContributionEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['CreatedPullRequestContribution']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreatedPullRequestOrRestrictedContributionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedPullRequestOrRestrictedContribution'] = ResolversParentTypes['CreatedPullRequestOrRestrictedContribution']> = {
    __resolveType: TypeResolveFn<'CreatedPullRequestContribution' | 'RestrictedContribution', ParentType, ContextType>;
};
export type CreatedPullRequestReviewContributionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedPullRequestReviewContribution'] = ResolversParentTypes['CreatedPullRequestReviewContribution']> = {
    isRestricted?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    occurredAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    pullRequestReview?: Resolver<ResolversTypes['PullRequestReview'], ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    user?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreatedPullRequestReviewContributionConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedPullRequestReviewContributionConnection'] = ResolversParentTypes['CreatedPullRequestReviewContributionConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['CreatedPullRequestReviewContributionEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['CreatedPullRequestReviewContribution']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreatedPullRequestReviewContributionEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedPullRequestReviewContributionEdge'] = ResolversParentTypes['CreatedPullRequestReviewContributionEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['CreatedPullRequestReviewContribution']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreatedRepositoryContributionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedRepositoryContribution'] = ResolversParentTypes['CreatedRepositoryContribution']> = {
    isRestricted?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    occurredAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    user?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreatedRepositoryContributionConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedRepositoryContributionConnection'] = ResolversParentTypes['CreatedRepositoryContributionConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['CreatedRepositoryContributionEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['CreatedRepositoryContribution']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreatedRepositoryContributionEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedRepositoryContributionEdge'] = ResolversParentTypes['CreatedRepositoryContributionEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['CreatedRepositoryContribution']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type CreatedRepositoryOrRestrictedContributionResolvers<ContextType = any, ParentType extends ResolversParentTypes['CreatedRepositoryOrRestrictedContribution'] = ResolversParentTypes['CreatedRepositoryOrRestrictedContribution']> = {
    __resolveType: TypeResolveFn<'CreatedRepositoryContribution' | 'RestrictedContribution', ParentType, ContextType>;
};
export type CrossReferencedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['CrossReferencedEvent'] = ResolversParentTypes['CrossReferencedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isCrossRepository?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    referencedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    source?: Resolver<ResolversTypes['ReferencedSubject'], ParentType, ContextType>;
    target?: Resolver<ResolversTypes['ReferencedSubject'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    willCloseTarget?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export interface DateScalarConfig extends GraphQLScalarTypeConfig<ResolversTypes['Date'], any> {
    name: 'Date';
}
export interface DateTimeScalarConfig extends GraphQLScalarTypeConfig<ResolversTypes['DateTime'], any> {
    name: 'DateTime';
}
export type DeletableResolvers<ContextType = any, ParentType extends ResolversParentTypes['Deletable'] = ResolversParentTypes['Deletable']> = {
    __resolveType: TypeResolveFn<'CommitComment' | 'Discussion' | 'DiscussionComment' | 'GistComment' | 'IssueComment' | 'PullRequestReview' | 'PullRequestReviewComment' | 'TeamDiscussion' | 'TeamDiscussionComment', ParentType, ContextType>;
    viewerCanDelete?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
};
export type DeleteBranchProtectionRulePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeleteBranchProtectionRulePayload'] = ResolversParentTypes['DeleteBranchProtectionRulePayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeleteDeploymentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeleteDeploymentPayload'] = ResolversParentTypes['DeleteDeploymentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeleteDiscussionCommentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeleteDiscussionCommentPayload'] = ResolversParentTypes['DeleteDiscussionCommentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    comment?: Resolver<Maybe<ResolversTypes['DiscussionComment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeleteDiscussionPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeleteDiscussionPayload'] = ResolversParentTypes['DeleteDiscussionPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    discussion?: Resolver<Maybe<ResolversTypes['Discussion']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeleteEnvironmentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeleteEnvironmentPayload'] = ResolversParentTypes['DeleteEnvironmentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeleteIpAllowListEntryPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeleteIpAllowListEntryPayload'] = ResolversParentTypes['DeleteIpAllowListEntryPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    ipAllowListEntry?: Resolver<Maybe<ResolversTypes['IpAllowListEntry']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeleteIssueCommentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeleteIssueCommentPayload'] = ResolversParentTypes['DeleteIssueCommentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeleteIssuePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeleteIssuePayload'] = ResolversParentTypes['DeleteIssuePayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeleteLabelPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeleteLabelPayload'] = ResolversParentTypes['DeleteLabelPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeletePackageVersionPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeletePackageVersionPayload'] = ResolversParentTypes['DeletePackageVersionPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    success?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeleteProjectCardPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeleteProjectCardPayload'] = ResolversParentTypes['DeleteProjectCardPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    column?: Resolver<Maybe<ResolversTypes['ProjectColumn']>, ParentType, ContextType>;
    deletedCardId?: Resolver<Maybe<ResolversTypes['ID']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeleteProjectColumnPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeleteProjectColumnPayload'] = ResolversParentTypes['DeleteProjectColumnPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    deletedColumnId?: Resolver<Maybe<ResolversTypes['ID']>, ParentType, ContextType>;
    project?: Resolver<Maybe<ResolversTypes['Project']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeleteProjectPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeleteProjectPayload'] = ResolversParentTypes['DeleteProjectPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    owner?: Resolver<Maybe<ResolversTypes['ProjectOwner']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeletePullRequestReviewCommentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeletePullRequestReviewCommentPayload'] = ResolversParentTypes['DeletePullRequestReviewCommentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequestReview?: Resolver<Maybe<ResolversTypes['PullRequestReview']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeletePullRequestReviewPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeletePullRequestReviewPayload'] = ResolversParentTypes['DeletePullRequestReviewPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequestReview?: Resolver<Maybe<ResolversTypes['PullRequestReview']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeleteRefPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeleteRefPayload'] = ResolversParentTypes['DeleteRefPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeleteTeamDiscussionCommentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeleteTeamDiscussionCommentPayload'] = ResolversParentTypes['DeleteTeamDiscussionCommentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeleteTeamDiscussionPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeleteTeamDiscussionPayload'] = ResolversParentTypes['DeleteTeamDiscussionPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeleteVerifiableDomainPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeleteVerifiableDomainPayload'] = ResolversParentTypes['DeleteVerifiableDomainPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    owner?: Resolver<Maybe<ResolversTypes['VerifiableDomainOwner']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DemilestonedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['DemilestonedEvent'] = ResolversParentTypes['DemilestonedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    milestoneTitle?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    subject?: Resolver<ResolversTypes['MilestoneItem'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeployKeyResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeployKey'] = ResolversParentTypes['DeployKey']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    key?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    readOnly?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    title?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    verified?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeployKeyConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeployKeyConnection'] = ResolversParentTypes['DeployKeyConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['DeployKeyEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['DeployKey']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeployKeyEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeployKeyEdge'] = ResolversParentTypes['DeployKeyEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['DeployKey']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeployedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeployedEvent'] = ResolversParentTypes['DeployedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    deployment?: Resolver<ResolversTypes['Deployment'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    ref?: Resolver<Maybe<ResolversTypes['Ref']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentResolvers<ContextType = any, ParentType extends ResolversParentTypes['Deployment'] = ResolversParentTypes['Deployment']> = {
    commit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    commitOid?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    creator?: Resolver<ResolversTypes['Actor'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    description?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    environment?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    latestEnvironment?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    latestStatus?: Resolver<Maybe<ResolversTypes['DeploymentStatus']>, ParentType, ContextType>;
    originalEnvironment?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    payload?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    ref?: Resolver<Maybe<ResolversTypes['Ref']>, ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    state?: Resolver<Maybe<ResolversTypes['DeploymentState']>, ParentType, ContextType>;
    statuses?: Resolver<Maybe<ResolversTypes['DeploymentStatusConnection']>, ParentType, ContextType, Partial<DeploymentStatusesArgs>>;
    task?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentConnection'] = ResolversParentTypes['DeploymentConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['DeploymentEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Deployment']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentEdge'] = ResolversParentTypes['DeploymentEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Deployment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentEnvironmentChangedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentEnvironmentChangedEvent'] = ResolversParentTypes['DeploymentEnvironmentChangedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    deploymentStatus?: Resolver<ResolversTypes['DeploymentStatus'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentProtectionRuleResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentProtectionRule'] = ResolversParentTypes['DeploymentProtectionRule']> = {
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    reviewers?: Resolver<ResolversTypes['DeploymentReviewerConnection'], ParentType, ContextType, Partial<DeploymentProtectionRuleReviewersArgs>>;
    timeout?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    type?: Resolver<ResolversTypes['DeploymentProtectionRuleType'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentProtectionRuleConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentProtectionRuleConnection'] = ResolversParentTypes['DeploymentProtectionRuleConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['DeploymentProtectionRuleEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['DeploymentProtectionRule']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentProtectionRuleEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentProtectionRuleEdge'] = ResolversParentTypes['DeploymentProtectionRuleEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['DeploymentProtectionRule']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentRequestResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentRequest'] = ResolversParentTypes['DeploymentRequest']> = {
    currentUserCanApprove?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    environment?: Resolver<ResolversTypes['Environment'], ParentType, ContextType>;
    reviewers?: Resolver<ResolversTypes['DeploymentReviewerConnection'], ParentType, ContextType, Partial<DeploymentRequestReviewersArgs>>;
    waitTimer?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    waitTimerStartedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentRequestConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentRequestConnection'] = ResolversParentTypes['DeploymentRequestConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['DeploymentRequestEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['DeploymentRequest']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentRequestEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentRequestEdge'] = ResolversParentTypes['DeploymentRequestEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['DeploymentRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentReviewResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentReview'] = ResolversParentTypes['DeploymentReview']> = {
    comment?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    environments?: Resolver<ResolversTypes['EnvironmentConnection'], ParentType, ContextType, Partial<DeploymentReviewEnvironmentsArgs>>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    state?: Resolver<ResolversTypes['DeploymentReviewState'], ParentType, ContextType>;
    user?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentReviewConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentReviewConnection'] = ResolversParentTypes['DeploymentReviewConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['DeploymentReviewEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['DeploymentReview']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentReviewEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentReviewEdge'] = ResolversParentTypes['DeploymentReviewEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['DeploymentReview']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentReviewerResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentReviewer'] = ResolversParentTypes['DeploymentReviewer']> = {
    __resolveType: TypeResolveFn<'Team' | 'User', ParentType, ContextType>;
};
export type DeploymentReviewerConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentReviewerConnection'] = ResolversParentTypes['DeploymentReviewerConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['DeploymentReviewerEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['DeploymentReviewer']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentReviewerEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentReviewerEdge'] = ResolversParentTypes['DeploymentReviewerEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['DeploymentReviewer']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentStatusResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentStatus'] = ResolversParentTypes['DeploymentStatus']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    creator?: Resolver<ResolversTypes['Actor'], ParentType, ContextType>;
    deployment?: Resolver<ResolversTypes['Deployment'], ParentType, ContextType>;
    description?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    environment?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    environmentUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    logUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    state?: Resolver<ResolversTypes['DeploymentStatusState'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentStatusConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentStatusConnection'] = ResolversParentTypes['DeploymentStatusConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['DeploymentStatusEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['DeploymentStatus']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DeploymentStatusEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['DeploymentStatusEdge'] = ResolversParentTypes['DeploymentStatusEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['DeploymentStatus']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DisablePullRequestAutoMergePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DisablePullRequestAutoMergePayload'] = ResolversParentTypes['DisablePullRequestAutoMergePayload']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DisconnectedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['DisconnectedEvent'] = ResolversParentTypes['DisconnectedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isCrossRepository?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    source?: Resolver<ResolversTypes['ReferencedSubject'], ParentType, ContextType>;
    subject?: Resolver<ResolversTypes['ReferencedSubject'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DiscussionResolvers<ContextType = any, ParentType extends ResolversParentTypes['Discussion'] = ResolversParentTypes['Discussion']> = {
    activeLockReason?: Resolver<Maybe<ResolversTypes['LockReason']>, ParentType, ContextType>;
    answer?: Resolver<Maybe<ResolversTypes['DiscussionComment']>, ParentType, ContextType>;
    answerChosenAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    answerChosenBy?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    author?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    authorAssociation?: Resolver<ResolversTypes['CommentAuthorAssociation'], ParentType, ContextType>;
    body?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    bodyHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    bodyText?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    category?: Resolver<ResolversTypes['DiscussionCategory'], ParentType, ContextType>;
    comments?: Resolver<ResolversTypes['DiscussionCommentConnection'], ParentType, ContextType, Partial<DiscussionCommentsArgs>>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    createdViaEmail?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    editor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    includesCreatedEdit?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    labels?: Resolver<Maybe<ResolversTypes['LabelConnection']>, ParentType, ContextType, RequireFields<DiscussionLabelsArgs, 'orderBy'>>;
    lastEditedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    locked?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    number?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    publishedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    reactionGroups?: Resolver<Maybe<Array<ResolversTypes['ReactionGroup']>>, ParentType, ContextType>;
    reactions?: Resolver<ResolversTypes['ReactionConnection'], ParentType, ContextType, Partial<DiscussionReactionsArgs>>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    title?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    upvoteCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    userContentEdits?: Resolver<Maybe<ResolversTypes['UserContentEditConnection']>, ParentType, ContextType, Partial<DiscussionUserContentEditsArgs>>;
    viewerCanDelete?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanReact?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanSubscribe?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanUpdate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanUpvote?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerDidAuthor?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerHasUpvoted?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerSubscription?: Resolver<Maybe<ResolversTypes['SubscriptionState']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DiscussionCategoryResolvers<ContextType = any, ParentType extends ResolversParentTypes['DiscussionCategory'] = ResolversParentTypes['DiscussionCategory']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    description?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    emoji?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    emojiHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isAnswerable?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DiscussionCategoryConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['DiscussionCategoryConnection'] = ResolversParentTypes['DiscussionCategoryConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['DiscussionCategoryEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['DiscussionCategory']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DiscussionCategoryEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['DiscussionCategoryEdge'] = ResolversParentTypes['DiscussionCategoryEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['DiscussionCategory']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DiscussionCommentResolvers<ContextType = any, ParentType extends ResolversParentTypes['DiscussionComment'] = ResolversParentTypes['DiscussionComment']> = {
    author?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    authorAssociation?: Resolver<ResolversTypes['CommentAuthorAssociation'], ParentType, ContextType>;
    body?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    bodyHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    bodyText?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    createdViaEmail?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    deletedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    discussion?: Resolver<Maybe<ResolversTypes['Discussion']>, ParentType, ContextType>;
    editor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    includesCreatedEdit?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isAnswer?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isMinimized?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    lastEditedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    minimizedReason?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    publishedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    reactionGroups?: Resolver<Maybe<Array<ResolversTypes['ReactionGroup']>>, ParentType, ContextType>;
    reactions?: Resolver<ResolversTypes['ReactionConnection'], ParentType, ContextType, Partial<DiscussionCommentReactionsArgs>>;
    replies?: Resolver<ResolversTypes['DiscussionCommentConnection'], ParentType, ContextType, Partial<DiscussionCommentRepliesArgs>>;
    replyTo?: Resolver<Maybe<ResolversTypes['DiscussionComment']>, ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    upvoteCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    userContentEdits?: Resolver<Maybe<ResolversTypes['UserContentEditConnection']>, ParentType, ContextType, Partial<DiscussionCommentUserContentEditsArgs>>;
    viewerCanDelete?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanMarkAsAnswer?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanMinimize?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanReact?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanUnmarkAsAnswer?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanUpdate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanUpvote?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCannotUpdateReasons?: Resolver<Array<ResolversTypes['CommentCannotUpdateReason']>, ParentType, ContextType>;
    viewerDidAuthor?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerHasUpvoted?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DiscussionCommentConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['DiscussionCommentConnection'] = ResolversParentTypes['DiscussionCommentConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['DiscussionCommentEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['DiscussionComment']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DiscussionCommentEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['DiscussionCommentEdge'] = ResolversParentTypes['DiscussionCommentEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['DiscussionComment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DiscussionConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['DiscussionConnection'] = ResolversParentTypes['DiscussionConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['DiscussionEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Discussion']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DiscussionEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['DiscussionEdge'] = ResolversParentTypes['DiscussionEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Discussion']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type DismissPullRequestReviewPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['DismissPullRequestReviewPayload'] = ResolversParentTypes['DismissPullRequestReviewPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequestReview?: Resolver<Maybe<ResolversTypes['PullRequestReview']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnablePullRequestAutoMergePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnablePullRequestAutoMergePayload'] = ResolversParentTypes['EnablePullRequestAutoMergePayload']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseResolvers<ContextType = any, ParentType extends ResolversParentTypes['Enterprise'] = ResolversParentTypes['Enterprise']> = {
    avatarUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType, Partial<EnterpriseAvatarUrlArgs>>;
    billingInfo?: Resolver<Maybe<ResolversTypes['EnterpriseBillingInfo']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    description?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    descriptionHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    location?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    members?: Resolver<ResolversTypes['EnterpriseMemberConnection'], ParentType, ContextType, RequireFields<EnterpriseMembersArgs, 'orderBy'>>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    organizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, RequireFields<EnterpriseOrganizationsArgs, 'orderBy'>>;
    ownerInfo?: Resolver<Maybe<ResolversTypes['EnterpriseOwnerInfo']>, ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    slug?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    userAccounts?: Resolver<ResolversTypes['EnterpriseUserAccountConnection'], ParentType, ContextType, Partial<EnterpriseUserAccountsArgs>>;
    viewerIsAdmin?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    websiteUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseAdministratorConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseAdministratorConnection'] = ResolversParentTypes['EnterpriseAdministratorConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterpriseAdministratorEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['User']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseAdministratorEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseAdministratorEdge'] = ResolversParentTypes['EnterpriseAdministratorEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    role?: Resolver<ResolversTypes['EnterpriseAdministratorRole'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseAdministratorInvitationResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseAdministratorInvitation'] = ResolversParentTypes['EnterpriseAdministratorInvitation']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    email?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<ResolversTypes['Enterprise'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    invitee?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    inviter?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    role?: Resolver<ResolversTypes['EnterpriseAdministratorRole'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseAdministratorInvitationConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseAdministratorInvitationConnection'] = ResolversParentTypes['EnterpriseAdministratorInvitationConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterpriseAdministratorInvitationEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterpriseAdministratorInvitation']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseAdministratorInvitationEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseAdministratorInvitationEdge'] = ResolversParentTypes['EnterpriseAdministratorInvitationEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['EnterpriseAdministratorInvitation']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseAuditEntryDataResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseAuditEntryData'] = ResolversParentTypes['EnterpriseAuditEntryData']> = {
    __resolveType: TypeResolveFn<'MembersCanDeleteReposClearAuditEntry' | 'MembersCanDeleteReposDisableAuditEntry' | 'MembersCanDeleteReposEnableAuditEntry' | 'OrgInviteToBusinessAuditEntry' | 'PrivateRepositoryForkingDisableAuditEntry' | 'PrivateRepositoryForkingEnableAuditEntry' | 'RepositoryVisibilityChangeDisableAuditEntry' | 'RepositoryVisibilityChangeEnableAuditEntry', ParentType, ContextType>;
    enterpriseResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    enterpriseSlug?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterpriseUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
};
export type EnterpriseBillingInfoResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseBillingInfo'] = ResolversParentTypes['EnterpriseBillingInfo']> = {
    allLicensableUsersCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    assetPacks?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    availableSeats?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    bandwidthQuota?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    bandwidthUsage?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    bandwidthUsagePercentage?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    seats?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    storageQuota?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    storageUsage?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    storageUsagePercentage?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    totalAvailableLicenses?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    totalLicenses?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseIdentityProviderResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseIdentityProvider'] = ResolversParentTypes['EnterpriseIdentityProvider']> = {
    digestMethod?: Resolver<Maybe<ResolversTypes['SamlDigestAlgorithm']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    externalIdentities?: Resolver<ResolversTypes['ExternalIdentityConnection'], ParentType, ContextType, Partial<EnterpriseIdentityProviderExternalIdentitiesArgs>>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    idpCertificate?: Resolver<Maybe<ResolversTypes['X509Certificate']>, ParentType, ContextType>;
    issuer?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    recoveryCodes?: Resolver<Maybe<Array<ResolversTypes['String']>>, ParentType, ContextType>;
    signatureMethod?: Resolver<Maybe<ResolversTypes['SamlSignatureAlgorithm']>, ParentType, ContextType>;
    ssoUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseMemberResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseMember'] = ResolversParentTypes['EnterpriseMember']> = {
    __resolveType: TypeResolveFn<'EnterpriseUserAccount' | 'User', ParentType, ContextType>;
};
export type EnterpriseMemberConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseMemberConnection'] = ResolversParentTypes['EnterpriseMemberConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterpriseMemberEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterpriseMember']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseMemberEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseMemberEdge'] = ResolversParentTypes['EnterpriseMemberEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    isUnlicensed?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['EnterpriseMember']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseOrganizationMembershipConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseOrganizationMembershipConnection'] = ResolversParentTypes['EnterpriseOrganizationMembershipConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterpriseOrganizationMembershipEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Organization']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseOrganizationMembershipEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseOrganizationMembershipEdge'] = ResolversParentTypes['EnterpriseOrganizationMembershipEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    role?: Resolver<ResolversTypes['EnterpriseUserAccountMembershipRole'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseOutsideCollaboratorConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseOutsideCollaboratorConnection'] = ResolversParentTypes['EnterpriseOutsideCollaboratorConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterpriseOutsideCollaboratorEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['User']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseOutsideCollaboratorEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseOutsideCollaboratorEdge'] = ResolversParentTypes['EnterpriseOutsideCollaboratorEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    isUnlicensed?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    repositories?: Resolver<ResolversTypes['EnterpriseRepositoryInfoConnection'], ParentType, ContextType, RequireFields<EnterpriseOutsideCollaboratorEdgeRepositoriesArgs, 'orderBy'>>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseOwnerInfoResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseOwnerInfo'] = ResolversParentTypes['EnterpriseOwnerInfo']> = {
    admins?: Resolver<ResolversTypes['EnterpriseAdministratorConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoAdminsArgs, 'orderBy'>>;
    affiliatedUsersWithTwoFactorDisabled?: Resolver<ResolversTypes['UserConnection'], ParentType, ContextType, Partial<EnterpriseOwnerInfoAffiliatedUsersWithTwoFactorDisabledArgs>>;
    affiliatedUsersWithTwoFactorDisabledExist?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    allowPrivateRepositoryForkingSetting?: Resolver<ResolversTypes['EnterpriseEnabledDisabledSettingValue'], ParentType, ContextType>;
    allowPrivateRepositoryForkingSettingOrganizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoAllowPrivateRepositoryForkingSettingOrganizationsArgs, 'orderBy' | 'value'>>;
    defaultRepositoryPermissionSetting?: Resolver<ResolversTypes['EnterpriseDefaultRepositoryPermissionSettingValue'], ParentType, ContextType>;
    defaultRepositoryPermissionSettingOrganizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoDefaultRepositoryPermissionSettingOrganizationsArgs, 'orderBy' | 'value'>>;
    domains?: Resolver<ResolversTypes['VerifiableDomainConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoDomainsArgs, 'isApproved' | 'isVerified' | 'orderBy'>>;
    ipAllowListEnabledSetting?: Resolver<ResolversTypes['IpAllowListEnabledSettingValue'], ParentType, ContextType>;
    ipAllowListEntries?: Resolver<ResolversTypes['IpAllowListEntryConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoIpAllowListEntriesArgs, 'orderBy'>>;
    ipAllowListForInstalledAppsEnabledSetting?: Resolver<ResolversTypes['IpAllowListForInstalledAppsEnabledSettingValue'], ParentType, ContextType>;
    isUpdatingDefaultRepositoryPermission?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isUpdatingTwoFactorRequirement?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    membersCanChangeRepositoryVisibilitySetting?: Resolver<ResolversTypes['EnterpriseEnabledDisabledSettingValue'], ParentType, ContextType>;
    membersCanChangeRepositoryVisibilitySettingOrganizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoMembersCanChangeRepositoryVisibilitySettingOrganizationsArgs, 'orderBy' | 'value'>>;
    membersCanCreateInternalRepositoriesSetting?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    membersCanCreatePrivateRepositoriesSetting?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    membersCanCreatePublicRepositoriesSetting?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    membersCanCreateRepositoriesSetting?: Resolver<Maybe<ResolversTypes['EnterpriseMembersCanCreateRepositoriesSettingValue']>, ParentType, ContextType>;
    membersCanCreateRepositoriesSettingOrganizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoMembersCanCreateRepositoriesSettingOrganizationsArgs, 'orderBy' | 'value'>>;
    membersCanDeleteIssuesSetting?: Resolver<ResolversTypes['EnterpriseEnabledDisabledSettingValue'], ParentType, ContextType>;
    membersCanDeleteIssuesSettingOrganizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoMembersCanDeleteIssuesSettingOrganizationsArgs, 'orderBy' | 'value'>>;
    membersCanDeleteRepositoriesSetting?: Resolver<ResolversTypes['EnterpriseEnabledDisabledSettingValue'], ParentType, ContextType>;
    membersCanDeleteRepositoriesSettingOrganizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoMembersCanDeleteRepositoriesSettingOrganizationsArgs, 'orderBy' | 'value'>>;
    membersCanInviteCollaboratorsSetting?: Resolver<ResolversTypes['EnterpriseEnabledDisabledSettingValue'], ParentType, ContextType>;
    membersCanInviteCollaboratorsSettingOrganizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoMembersCanInviteCollaboratorsSettingOrganizationsArgs, 'orderBy' | 'value'>>;
    membersCanMakePurchasesSetting?: Resolver<ResolversTypes['EnterpriseMembersCanMakePurchasesSettingValue'], ParentType, ContextType>;
    membersCanUpdateProtectedBranchesSetting?: Resolver<ResolversTypes['EnterpriseEnabledDisabledSettingValue'], ParentType, ContextType>;
    membersCanUpdateProtectedBranchesSettingOrganizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoMembersCanUpdateProtectedBranchesSettingOrganizationsArgs, 'orderBy' | 'value'>>;
    membersCanViewDependencyInsightsSetting?: Resolver<ResolversTypes['EnterpriseEnabledDisabledSettingValue'], ParentType, ContextType>;
    membersCanViewDependencyInsightsSettingOrganizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoMembersCanViewDependencyInsightsSettingOrganizationsArgs, 'orderBy' | 'value'>>;
    notificationDeliveryRestrictionEnabledSetting?: Resolver<ResolversTypes['NotificationRestrictionSettingValue'], ParentType, ContextType>;
    organizationProjectsSetting?: Resolver<ResolversTypes['EnterpriseEnabledDisabledSettingValue'], ParentType, ContextType>;
    organizationProjectsSettingOrganizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoOrganizationProjectsSettingOrganizationsArgs, 'orderBy' | 'value'>>;
    outsideCollaborators?: Resolver<ResolversTypes['EnterpriseOutsideCollaboratorConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoOutsideCollaboratorsArgs, 'orderBy'>>;
    pendingAdminInvitations?: Resolver<ResolversTypes['EnterpriseAdministratorInvitationConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoPendingAdminInvitationsArgs, 'orderBy'>>;
    pendingCollaboratorInvitations?: Resolver<ResolversTypes['RepositoryInvitationConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoPendingCollaboratorInvitationsArgs, 'orderBy'>>;
    pendingCollaborators?: Resolver<ResolversTypes['EnterprisePendingCollaboratorConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoPendingCollaboratorsArgs, 'orderBy'>>;
    pendingMemberInvitations?: Resolver<ResolversTypes['EnterprisePendingMemberInvitationConnection'], ParentType, ContextType, Partial<EnterpriseOwnerInfoPendingMemberInvitationsArgs>>;
    repositoryProjectsSetting?: Resolver<ResolversTypes['EnterpriseEnabledDisabledSettingValue'], ParentType, ContextType>;
    repositoryProjectsSettingOrganizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoRepositoryProjectsSettingOrganizationsArgs, 'orderBy' | 'value'>>;
    samlIdentityProvider?: Resolver<Maybe<ResolversTypes['EnterpriseIdentityProvider']>, ParentType, ContextType>;
    samlIdentityProviderSettingOrganizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoSamlIdentityProviderSettingOrganizationsArgs, 'orderBy' | 'value'>>;
    teamDiscussionsSetting?: Resolver<ResolversTypes['EnterpriseEnabledDisabledSettingValue'], ParentType, ContextType>;
    teamDiscussionsSettingOrganizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoTeamDiscussionsSettingOrganizationsArgs, 'orderBy' | 'value'>>;
    twoFactorRequiredSetting?: Resolver<ResolversTypes['EnterpriseEnabledSettingValue'], ParentType, ContextType>;
    twoFactorRequiredSettingOrganizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, RequireFields<EnterpriseOwnerInfoTwoFactorRequiredSettingOrganizationsArgs, 'orderBy' | 'value'>>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterprisePendingCollaboratorConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterprisePendingCollaboratorConnection'] = ResolversParentTypes['EnterprisePendingCollaboratorConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterprisePendingCollaboratorEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['User']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterprisePendingCollaboratorEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterprisePendingCollaboratorEdge'] = ResolversParentTypes['EnterprisePendingCollaboratorEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    isUnlicensed?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    repositories?: Resolver<ResolversTypes['EnterpriseRepositoryInfoConnection'], ParentType, ContextType, RequireFields<EnterprisePendingCollaboratorEdgeRepositoriesArgs, 'orderBy'>>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterprisePendingMemberInvitationConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterprisePendingMemberInvitationConnection'] = ResolversParentTypes['EnterprisePendingMemberInvitationConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterprisePendingMemberInvitationEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['OrganizationInvitation']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    totalUniqueUserCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterprisePendingMemberInvitationEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterprisePendingMemberInvitationEdge'] = ResolversParentTypes['EnterprisePendingMemberInvitationEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    isUnlicensed?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['OrganizationInvitation']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseRepositoryInfoResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseRepositoryInfo'] = ResolversParentTypes['EnterpriseRepositoryInfo']> = {
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isPrivate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    nameWithOwner?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseRepositoryInfoConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseRepositoryInfoConnection'] = ResolversParentTypes['EnterpriseRepositoryInfoConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterpriseRepositoryInfoEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterpriseRepositoryInfo']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseRepositoryInfoEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseRepositoryInfoEdge'] = ResolversParentTypes['EnterpriseRepositoryInfoEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['EnterpriseRepositoryInfo']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseServerInstallationResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseServerInstallation'] = ResolversParentTypes['EnterpriseServerInstallation']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    customerName?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    hostName?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isConnected?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    userAccounts?: Resolver<ResolversTypes['EnterpriseServerUserAccountConnection'], ParentType, ContextType, RequireFields<EnterpriseServerInstallationUserAccountsArgs, 'orderBy'>>;
    userAccountsUploads?: Resolver<ResolversTypes['EnterpriseServerUserAccountsUploadConnection'], ParentType, ContextType, RequireFields<EnterpriseServerInstallationUserAccountsUploadsArgs, 'orderBy'>>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseServerUserAccountResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseServerUserAccount'] = ResolversParentTypes['EnterpriseServerUserAccount']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    emails?: Resolver<ResolversTypes['EnterpriseServerUserAccountEmailConnection'], ParentType, ContextType, RequireFields<EnterpriseServerUserAccountEmailsArgs, 'orderBy'>>;
    enterpriseServerInstallation?: Resolver<ResolversTypes['EnterpriseServerInstallation'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isSiteAdmin?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    login?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    profileName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    remoteCreatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    remoteUserId?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseServerUserAccountConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseServerUserAccountConnection'] = ResolversParentTypes['EnterpriseServerUserAccountConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterpriseServerUserAccountEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterpriseServerUserAccount']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseServerUserAccountEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseServerUserAccountEdge'] = ResolversParentTypes['EnterpriseServerUserAccountEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['EnterpriseServerUserAccount']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseServerUserAccountEmailResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseServerUserAccountEmail'] = ResolversParentTypes['EnterpriseServerUserAccountEmail']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    email?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isPrimary?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    userAccount?: Resolver<ResolversTypes['EnterpriseServerUserAccount'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseServerUserAccountEmailConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseServerUserAccountEmailConnection'] = ResolversParentTypes['EnterpriseServerUserAccountEmailConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterpriseServerUserAccountEmailEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterpriseServerUserAccountEmail']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseServerUserAccountEmailEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseServerUserAccountEmailEdge'] = ResolversParentTypes['EnterpriseServerUserAccountEmailEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['EnterpriseServerUserAccountEmail']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseServerUserAccountsUploadResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseServerUserAccountsUpload'] = ResolversParentTypes['EnterpriseServerUserAccountsUpload']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    enterprise?: Resolver<ResolversTypes['Enterprise'], ParentType, ContextType>;
    enterpriseServerInstallation?: Resolver<ResolversTypes['EnterpriseServerInstallation'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    syncState?: Resolver<ResolversTypes['EnterpriseServerUserAccountsUploadSyncState'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseServerUserAccountsUploadConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseServerUserAccountsUploadConnection'] = ResolversParentTypes['EnterpriseServerUserAccountsUploadConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterpriseServerUserAccountsUploadEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterpriseServerUserAccountsUpload']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseServerUserAccountsUploadEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseServerUserAccountsUploadEdge'] = ResolversParentTypes['EnterpriseServerUserAccountsUploadEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['EnterpriseServerUserAccountsUpload']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseUserAccountResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseUserAccount'] = ResolversParentTypes['EnterpriseUserAccount']> = {
    avatarUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType, Partial<EnterpriseUserAccountAvatarUrlArgs>>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    enterprise?: Resolver<ResolversTypes['Enterprise'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    login?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    name?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizations?: Resolver<ResolversTypes['EnterpriseOrganizationMembershipConnection'], ParentType, ContextType, RequireFields<EnterpriseUserAccountOrganizationsArgs, 'orderBy'>>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseUserAccountConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseUserAccountConnection'] = ResolversParentTypes['EnterpriseUserAccountConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterpriseUserAccountEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnterpriseUserAccount']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnterpriseUserAccountEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnterpriseUserAccountEdge'] = ResolversParentTypes['EnterpriseUserAccountEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['EnterpriseUserAccount']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnvironmentResolvers<ContextType = any, ParentType extends ResolversParentTypes['Environment'] = ResolversParentTypes['Environment']> = {
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    protectionRules?: Resolver<ResolversTypes['DeploymentProtectionRuleConnection'], ParentType, ContextType, Partial<EnvironmentProtectionRulesArgs>>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnvironmentConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnvironmentConnection'] = ResolversParentTypes['EnvironmentConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['EnvironmentEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Environment']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type EnvironmentEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['EnvironmentEdge'] = ResolversParentTypes['EnvironmentEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Environment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ExternalIdentityResolvers<ContextType = any, ParentType extends ResolversParentTypes['ExternalIdentity'] = ResolversParentTypes['ExternalIdentity']> = {
    guid?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    organizationInvitation?: Resolver<Maybe<ResolversTypes['OrganizationInvitation']>, ParentType, ContextType>;
    samlIdentity?: Resolver<Maybe<ResolversTypes['ExternalIdentitySamlAttributes']>, ParentType, ContextType>;
    scimIdentity?: Resolver<Maybe<ResolversTypes['ExternalIdentityScimAttributes']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ExternalIdentityConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['ExternalIdentityConnection'] = ResolversParentTypes['ExternalIdentityConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['ExternalIdentityEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['ExternalIdentity']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ExternalIdentityEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['ExternalIdentityEdge'] = ResolversParentTypes['ExternalIdentityEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['ExternalIdentity']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ExternalIdentitySamlAttributesResolvers<ContextType = any, ParentType extends ResolversParentTypes['ExternalIdentitySamlAttributes'] = ResolversParentTypes['ExternalIdentitySamlAttributes']> = {
    emails?: Resolver<Maybe<Array<ResolversTypes['UserEmailMetadata']>>, ParentType, ContextType>;
    familyName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    givenName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    groups?: Resolver<Maybe<Array<ResolversTypes['String']>>, ParentType, ContextType>;
    nameId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    username?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ExternalIdentityScimAttributesResolvers<ContextType = any, ParentType extends ResolversParentTypes['ExternalIdentityScimAttributes'] = ResolversParentTypes['ExternalIdentityScimAttributes']> = {
    emails?: Resolver<Maybe<Array<ResolversTypes['UserEmailMetadata']>>, ParentType, ContextType>;
    familyName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    givenName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    groups?: Resolver<Maybe<Array<ResolversTypes['String']>>, ParentType, ContextType>;
    username?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type FollowUserPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['FollowUserPayload'] = ResolversParentTypes['FollowUserPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type FollowerConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['FollowerConnection'] = ResolversParentTypes['FollowerConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['UserEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['User']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type FollowingConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['FollowingConnection'] = ResolversParentTypes['FollowingConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['UserEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['User']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type GenericHovercardContextResolvers<ContextType = any, ParentType extends ResolversParentTypes['GenericHovercardContext'] = ResolversParentTypes['GenericHovercardContext']> = {
    message?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    octicon?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type GistResolvers<ContextType = any, ParentType extends ResolversParentTypes['Gist'] = ResolversParentTypes['Gist']> = {
    comments?: Resolver<ResolversTypes['GistCommentConnection'], ParentType, ContextType, Partial<GistCommentsArgs>>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    description?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    files?: Resolver<Maybe<Array<Maybe<ResolversTypes['GistFile']>>>, ParentType, ContextType, RequireFields<GistFilesArgs, 'limit'>>;
    forks?: Resolver<ResolversTypes['GistConnection'], ParentType, ContextType, Partial<GistForksArgs>>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isFork?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isPublic?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    owner?: Resolver<Maybe<ResolversTypes['RepositoryOwner']>, ParentType, ContextType>;
    pushedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    stargazerCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    stargazers?: Resolver<ResolversTypes['StargazerConnection'], ParentType, ContextType, Partial<GistStargazersArgs>>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    viewerHasStarred?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type GistCommentResolvers<ContextType = any, ParentType extends ResolversParentTypes['GistComment'] = ResolversParentTypes['GistComment']> = {
    author?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    authorAssociation?: Resolver<ResolversTypes['CommentAuthorAssociation'], ParentType, ContextType>;
    body?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    bodyHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    bodyText?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    createdViaEmail?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    editor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    gist?: Resolver<ResolversTypes['Gist'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    includesCreatedEdit?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isMinimized?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    lastEditedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    minimizedReason?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    publishedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    userContentEdits?: Resolver<Maybe<ResolversTypes['UserContentEditConnection']>, ParentType, ContextType, Partial<GistCommentUserContentEditsArgs>>;
    viewerCanDelete?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanMinimize?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanUpdate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCannotUpdateReasons?: Resolver<Array<ResolversTypes['CommentCannotUpdateReason']>, ParentType, ContextType>;
    viewerDidAuthor?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type GistCommentConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['GistCommentConnection'] = ResolversParentTypes['GistCommentConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['GistCommentEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['GistComment']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type GistCommentEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['GistCommentEdge'] = ResolversParentTypes['GistCommentEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['GistComment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type GistConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['GistConnection'] = ResolversParentTypes['GistConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['GistEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Gist']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type GistEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['GistEdge'] = ResolversParentTypes['GistEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Gist']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type GistFileResolvers<ContextType = any, ParentType extends ResolversParentTypes['GistFile'] = ResolversParentTypes['GistFile']> = {
    encodedName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    encoding?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    extension?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    isImage?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isTruncated?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    language?: Resolver<Maybe<ResolversTypes['Language']>, ParentType, ContextType>;
    name?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    size?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    text?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType, Partial<GistFileTextArgs>>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type GitActorResolvers<ContextType = any, ParentType extends ResolversParentTypes['GitActor'] = ResolversParentTypes['GitActor']> = {
    avatarUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType, Partial<GitActorAvatarUrlArgs>>;
    date?: Resolver<Maybe<ResolversTypes['GitTimestamp']>, ParentType, ContextType>;
    email?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type GitActorConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['GitActorConnection'] = ResolversParentTypes['GitActorConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['GitActorEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['GitActor']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type GitActorEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['GitActorEdge'] = ResolversParentTypes['GitActorEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['GitActor']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type GitHubMetadataResolvers<ContextType = any, ParentType extends ResolversParentTypes['GitHubMetadata'] = ResolversParentTypes['GitHubMetadata']> = {
    gitHubServicesSha?: Resolver<ResolversTypes['GitObjectID'], ParentType, ContextType>;
    isPasswordAuthenticationVerifiable?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type GitObjectResolvers<ContextType = any, ParentType extends ResolversParentTypes['GitObject'] = ResolversParentTypes['GitObject']> = {
    __resolveType: TypeResolveFn<'Blob' | 'Commit' | 'Tag' | 'Tree', ParentType, ContextType>;
    abbreviatedOid?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    commitResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    commitUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    oid?: Resolver<ResolversTypes['GitObjectID'], ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
};
export interface GitObjectIdScalarConfig extends GraphQLScalarTypeConfig<ResolversTypes['GitObjectID'], any> {
    name: 'GitObjectID';
}
export interface GitRefnameScalarConfig extends GraphQLScalarTypeConfig<ResolversTypes['GitRefname'], any> {
    name: 'GitRefname';
}
export interface GitSshRemoteScalarConfig extends GraphQLScalarTypeConfig<ResolversTypes['GitSSHRemote'], any> {
    name: 'GitSSHRemote';
}
export type GitSignatureResolvers<ContextType = any, ParentType extends ResolversParentTypes['GitSignature'] = ResolversParentTypes['GitSignature']> = {
    __resolveType: TypeResolveFn<'GpgSignature' | 'SmimeSignature' | 'UnknownSignature', ParentType, ContextType>;
    email?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    isValid?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    payload?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    signature?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    signer?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    state?: Resolver<ResolversTypes['GitSignatureState'], ParentType, ContextType>;
    wasSignedByGitHub?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
};
export interface GitTimestampScalarConfig extends GraphQLScalarTypeConfig<ResolversTypes['GitTimestamp'], any> {
    name: 'GitTimestamp';
}
export type GpgSignatureResolvers<ContextType = any, ParentType extends ResolversParentTypes['GpgSignature'] = ResolversParentTypes['GpgSignature']> = {
    email?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    isValid?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    keyId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    payload?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    signature?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    signer?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    state?: Resolver<ResolversTypes['GitSignatureState'], ParentType, ContextType>;
    wasSignedByGitHub?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export interface HtmlScalarConfig extends GraphQLScalarTypeConfig<ResolversTypes['HTML'], any> {
    name: 'HTML';
}
export type HeadRefDeletedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['HeadRefDeletedEvent'] = ResolversParentTypes['HeadRefDeletedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    headRef?: Resolver<Maybe<ResolversTypes['Ref']>, ParentType, ContextType>;
    headRefName?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type HeadRefForcePushedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['HeadRefForcePushedEvent'] = ResolversParentTypes['HeadRefForcePushedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    afterCommit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    beforeCommit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    ref?: Resolver<Maybe<ResolversTypes['Ref']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type HeadRefRestoredEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['HeadRefRestoredEvent'] = ResolversParentTypes['HeadRefRestoredEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type HovercardResolvers<ContextType = any, ParentType extends ResolversParentTypes['Hovercard'] = ResolversParentTypes['Hovercard']> = {
    contexts?: Resolver<Array<ResolversTypes['HovercardContext']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type HovercardContextResolvers<ContextType = any, ParentType extends ResolversParentTypes['HovercardContext'] = ResolversParentTypes['HovercardContext']> = {
    __resolveType: TypeResolveFn<'GenericHovercardContext' | 'OrganizationTeamsHovercardContext' | 'OrganizationsHovercardContext' | 'ReviewStatusHovercardContext' | 'ViewerHovercardContext', ParentType, ContextType>;
    message?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    octicon?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
};
export type ImportProjectPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['ImportProjectPayload'] = ResolversParentTypes['ImportProjectPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    project?: Resolver<Maybe<ResolversTypes['Project']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type IpAllowListEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['IpAllowListEntry'] = ResolversParentTypes['IpAllowListEntry']> = {
    allowListValue?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isActive?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    name?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    owner?: Resolver<ResolversTypes['IpAllowListOwner'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type IpAllowListEntryConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['IpAllowListEntryConnection'] = ResolversParentTypes['IpAllowListEntryConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['IpAllowListEntryEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['IpAllowListEntry']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type IpAllowListEntryEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['IpAllowListEntryEdge'] = ResolversParentTypes['IpAllowListEntryEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['IpAllowListEntry']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type IpAllowListOwnerResolvers<ContextType = any, ParentType extends ResolversParentTypes['IpAllowListOwner'] = ResolversParentTypes['IpAllowListOwner']> = {
    __resolveType: TypeResolveFn<'App' | 'Enterprise' | 'Organization', ParentType, ContextType>;
};
export type IssueResolvers<ContextType = any, ParentType extends ResolversParentTypes['Issue'] = ResolversParentTypes['Issue']> = {
    activeLockReason?: Resolver<Maybe<ResolversTypes['LockReason']>, ParentType, ContextType>;
    assignees?: Resolver<ResolversTypes['UserConnection'], ParentType, ContextType, Partial<IssueAssigneesArgs>>;
    author?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    authorAssociation?: Resolver<ResolversTypes['CommentAuthorAssociation'], ParentType, ContextType>;
    body?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    bodyHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    bodyResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    bodyText?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    bodyUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    closed?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    closedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    comments?: Resolver<ResolversTypes['IssueCommentConnection'], ParentType, ContextType, Partial<IssueCommentsArgs>>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    createdViaEmail?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    editor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    hovercard?: Resolver<ResolversTypes['Hovercard'], ParentType, ContextType, RequireFields<IssueHovercardArgs, 'includeNotificationContexts'>>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    includesCreatedEdit?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isPinned?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    isReadByViewer?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    labels?: Resolver<Maybe<ResolversTypes['LabelConnection']>, ParentType, ContextType, RequireFields<IssueLabelsArgs, 'orderBy'>>;
    lastEditedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    locked?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    milestone?: Resolver<Maybe<ResolversTypes['Milestone']>, ParentType, ContextType>;
    number?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    participants?: Resolver<ResolversTypes['UserConnection'], ParentType, ContextType, Partial<IssueParticipantsArgs>>;
    projectCards?: Resolver<ResolversTypes['ProjectCardConnection'], ParentType, ContextType, RequireFields<IssueProjectCardsArgs, 'archivedStates'>>;
    publishedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    reactionGroups?: Resolver<Maybe<Array<ResolversTypes['ReactionGroup']>>, ParentType, ContextType>;
    reactions?: Resolver<ResolversTypes['ReactionConnection'], ParentType, ContextType, Partial<IssueReactionsArgs>>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    state?: Resolver<ResolversTypes['IssueState'], ParentType, ContextType>;
    timeline?: Resolver<ResolversTypes['IssueTimelineConnection'], ParentType, ContextType, Partial<IssueTimelineArgs>>;
    timelineItems?: Resolver<ResolversTypes['IssueTimelineItemsConnection'], ParentType, ContextType, Partial<IssueTimelineItemsArgs>>;
    title?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    titleHTML?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    userContentEdits?: Resolver<Maybe<ResolversTypes['UserContentEditConnection']>, ParentType, ContextType, Partial<IssueUserContentEditsArgs>>;
    viewerCanReact?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanSubscribe?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanUpdate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCannotUpdateReasons?: Resolver<Array<ResolversTypes['CommentCannotUpdateReason']>, ParentType, ContextType>;
    viewerDidAuthor?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerSubscription?: Resolver<Maybe<ResolversTypes['SubscriptionState']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type IssueCommentResolvers<ContextType = any, ParentType extends ResolversParentTypes['IssueComment'] = ResolversParentTypes['IssueComment']> = {
    author?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    authorAssociation?: Resolver<ResolversTypes['CommentAuthorAssociation'], ParentType, ContextType>;
    body?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    bodyHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    bodyText?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    createdViaEmail?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    editor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    includesCreatedEdit?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isMinimized?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    issue?: Resolver<ResolversTypes['Issue'], ParentType, ContextType>;
    lastEditedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    minimizedReason?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    publishedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    reactionGroups?: Resolver<Maybe<Array<ResolversTypes['ReactionGroup']>>, ParentType, ContextType>;
    reactions?: Resolver<ResolversTypes['ReactionConnection'], ParentType, ContextType, Partial<IssueCommentReactionsArgs>>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    userContentEdits?: Resolver<Maybe<ResolversTypes['UserContentEditConnection']>, ParentType, ContextType, Partial<IssueCommentUserContentEditsArgs>>;
    viewerCanDelete?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanMinimize?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanReact?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanUpdate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCannotUpdateReasons?: Resolver<Array<ResolversTypes['CommentCannotUpdateReason']>, ParentType, ContextType>;
    viewerDidAuthor?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type IssueCommentConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['IssueCommentConnection'] = ResolversParentTypes['IssueCommentConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['IssueCommentEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['IssueComment']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type IssueCommentEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['IssueCommentEdge'] = ResolversParentTypes['IssueCommentEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['IssueComment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type IssueConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['IssueConnection'] = ResolversParentTypes['IssueConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['IssueEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Issue']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type IssueContributionsByRepositoryResolvers<ContextType = any, ParentType extends ResolversParentTypes['IssueContributionsByRepository'] = ResolversParentTypes['IssueContributionsByRepository']> = {
    contributions?: Resolver<ResolversTypes['CreatedIssueContributionConnection'], ParentType, ContextType, RequireFields<IssueContributionsByRepositoryContributionsArgs, 'orderBy'>>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type IssueEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['IssueEdge'] = ResolversParentTypes['IssueEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Issue']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type IssueOrPullRequestResolvers<ContextType = any, ParentType extends ResolversParentTypes['IssueOrPullRequest'] = ResolversParentTypes['IssueOrPullRequest']> = {
    __resolveType: TypeResolveFn<'Issue' | 'PullRequest', ParentType, ContextType>;
};
export type IssueTemplateResolvers<ContextType = any, ParentType extends ResolversParentTypes['IssueTemplate'] = ResolversParentTypes['IssueTemplate']> = {
    about?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    body?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    title?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type IssueTimelineConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['IssueTimelineConnection'] = ResolversParentTypes['IssueTimelineConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['IssueTimelineItemEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['IssueTimelineItem']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type IssueTimelineItemResolvers<ContextType = any, ParentType extends ResolversParentTypes['IssueTimelineItem'] = ResolversParentTypes['IssueTimelineItem']> = {
    __resolveType: TypeResolveFn<'AssignedEvent' | 'ClosedEvent' | 'Commit' | 'CrossReferencedEvent' | 'DemilestonedEvent' | 'IssueComment' | 'LabeledEvent' | 'LockedEvent' | 'MilestonedEvent' | 'ReferencedEvent' | 'RenamedTitleEvent' | 'ReopenedEvent' | 'SubscribedEvent' | 'TransferredEvent' | 'UnassignedEvent' | 'UnlabeledEvent' | 'UnlockedEvent' | 'UnsubscribedEvent' | 'UserBlockedEvent', ParentType, ContextType>;
};
export type IssueTimelineItemEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['IssueTimelineItemEdge'] = ResolversParentTypes['IssueTimelineItemEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['IssueTimelineItem']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type IssueTimelineItemsResolvers<ContextType = any, ParentType extends ResolversParentTypes['IssueTimelineItems'] = ResolversParentTypes['IssueTimelineItems']> = {
    __resolveType: TypeResolveFn<'AddedToProjectEvent' | 'AssignedEvent' | 'ClosedEvent' | 'CommentDeletedEvent' | 'ConnectedEvent' | 'ConvertedNoteToIssueEvent' | 'CrossReferencedEvent' | 'DemilestonedEvent' | 'DisconnectedEvent' | 'IssueComment' | 'LabeledEvent' | 'LockedEvent' | 'MarkedAsDuplicateEvent' | 'MentionedEvent' | 'MilestonedEvent' | 'MovedColumnsInProjectEvent' | 'PinnedEvent' | 'ReferencedEvent' | 'RemovedFromProjectEvent' | 'RenamedTitleEvent' | 'ReopenedEvent' | 'SubscribedEvent' | 'TransferredEvent' | 'UnassignedEvent' | 'UnlabeledEvent' | 'UnlockedEvent' | 'UnmarkedAsDuplicateEvent' | 'UnpinnedEvent' | 'UnsubscribedEvent' | 'UserBlockedEvent', ParentType, ContextType>;
};
export type IssueTimelineItemsConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['IssueTimelineItemsConnection'] = ResolversParentTypes['IssueTimelineItemsConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['IssueTimelineItemsEdge']>>>, ParentType, ContextType>;
    filteredCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['IssueTimelineItems']>>>, ParentType, ContextType>;
    pageCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type IssueTimelineItemsEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['IssueTimelineItemsEdge'] = ResolversParentTypes['IssueTimelineItemsEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['IssueTimelineItems']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type JoinedGitHubContributionResolvers<ContextType = any, ParentType extends ResolversParentTypes['JoinedGitHubContribution'] = ResolversParentTypes['JoinedGitHubContribution']> = {
    isRestricted?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    occurredAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    user?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type LabelResolvers<ContextType = any, ParentType extends ResolversParentTypes['Label'] = ResolversParentTypes['Label']> = {
    color?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    createdAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    description?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isDefault?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    issues?: Resolver<ResolversTypes['IssueConnection'], ParentType, ContextType, Partial<LabelIssuesArgs>>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    pullRequests?: Resolver<ResolversTypes['PullRequestConnection'], ParentType, ContextType, Partial<LabelPullRequestsArgs>>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    updatedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type LabelConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['LabelConnection'] = ResolversParentTypes['LabelConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['LabelEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Label']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type LabelEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['LabelEdge'] = ResolversParentTypes['LabelEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Label']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type LabelableResolvers<ContextType = any, ParentType extends ResolversParentTypes['Labelable'] = ResolversParentTypes['Labelable']> = {
    __resolveType: TypeResolveFn<'Discussion' | 'Issue' | 'PullRequest', ParentType, ContextType>;
    labels?: Resolver<Maybe<ResolversTypes['LabelConnection']>, ParentType, ContextType, RequireFields<LabelableLabelsArgs, 'orderBy'>>;
};
export type LabeledEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['LabeledEvent'] = ResolversParentTypes['LabeledEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    label?: Resolver<ResolversTypes['Label'], ParentType, ContextType>;
    labelable?: Resolver<ResolversTypes['Labelable'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type LanguageResolvers<ContextType = any, ParentType extends ResolversParentTypes['Language'] = ResolversParentTypes['Language']> = {
    color?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type LanguageConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['LanguageConnection'] = ResolversParentTypes['LanguageConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['LanguageEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Language']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    totalSize?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type LanguageEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['LanguageEdge'] = ResolversParentTypes['LanguageEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<ResolversTypes['Language'], ParentType, ContextType>;
    size?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type LicenseResolvers<ContextType = any, ParentType extends ResolversParentTypes['License'] = ResolversParentTypes['License']> = {
    body?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    conditions?: Resolver<Array<Maybe<ResolversTypes['LicenseRule']>>, ParentType, ContextType>;
    description?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    featured?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    hidden?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    implementation?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    key?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    limitations?: Resolver<Array<Maybe<ResolversTypes['LicenseRule']>>, ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    nickname?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    permissions?: Resolver<Array<Maybe<ResolversTypes['LicenseRule']>>, ParentType, ContextType>;
    pseudoLicense?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    spdxId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    url?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type LicenseRuleResolvers<ContextType = any, ParentType extends ResolversParentTypes['LicenseRule'] = ResolversParentTypes['LicenseRule']> = {
    description?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    key?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    label?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type LinkRepositoryToProjectPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['LinkRepositoryToProjectPayload'] = ResolversParentTypes['LinkRepositoryToProjectPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    project?: Resolver<Maybe<ResolversTypes['Project']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type LockLockablePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['LockLockablePayload'] = ResolversParentTypes['LockLockablePayload']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    lockedRecord?: Resolver<Maybe<ResolversTypes['Lockable']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type LockableResolvers<ContextType = any, ParentType extends ResolversParentTypes['Lockable'] = ResolversParentTypes['Lockable']> = {
    __resolveType: TypeResolveFn<'Discussion' | 'Issue' | 'PullRequest', ParentType, ContextType>;
    activeLockReason?: Resolver<Maybe<ResolversTypes['LockReason']>, ParentType, ContextType>;
    locked?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
};
export type LockedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['LockedEvent'] = ResolversParentTypes['LockedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    lockReason?: Resolver<Maybe<ResolversTypes['LockReason']>, ParentType, ContextType>;
    lockable?: Resolver<ResolversTypes['Lockable'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MannequinResolvers<ContextType = any, ParentType extends ResolversParentTypes['Mannequin'] = ResolversParentTypes['Mannequin']> = {
    avatarUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType, Partial<MannequinAvatarUrlArgs>>;
    claimant?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    email?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    login?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MarkDiscussionCommentAsAnswerPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['MarkDiscussionCommentAsAnswerPayload'] = ResolversParentTypes['MarkDiscussionCommentAsAnswerPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    discussion?: Resolver<Maybe<ResolversTypes['Discussion']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MarkFileAsViewedPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['MarkFileAsViewedPayload'] = ResolversParentTypes['MarkFileAsViewedPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MarkPullRequestReadyForReviewPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['MarkPullRequestReadyForReviewPayload'] = ResolversParentTypes['MarkPullRequestReadyForReviewPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MarkedAsDuplicateEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['MarkedAsDuplicateEvent'] = ResolversParentTypes['MarkedAsDuplicateEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    canonical?: Resolver<Maybe<ResolversTypes['IssueOrPullRequest']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    duplicate?: Resolver<Maybe<ResolversTypes['IssueOrPullRequest']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isCrossRepository?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MemberStatusableResolvers<ContextType = any, ParentType extends ResolversParentTypes['MemberStatusable'] = ResolversParentTypes['MemberStatusable']> = {
    __resolveType: TypeResolveFn<'Organization' | 'Team', ParentType, ContextType>;
    memberStatuses?: Resolver<ResolversTypes['UserStatusConnection'], ParentType, ContextType, RequireFields<MemberStatusableMemberStatusesArgs, 'orderBy'>>;
};
export type MembersCanDeleteReposClearAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['MembersCanDeleteReposClearAuditEntry'] = ResolversParentTypes['MembersCanDeleteReposClearAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    enterpriseResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    enterpriseSlug?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterpriseUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MembersCanDeleteReposDisableAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['MembersCanDeleteReposDisableAuditEntry'] = ResolversParentTypes['MembersCanDeleteReposDisableAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    enterpriseResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    enterpriseSlug?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterpriseUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MembersCanDeleteReposEnableAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['MembersCanDeleteReposEnableAuditEntry'] = ResolversParentTypes['MembersCanDeleteReposEnableAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    enterpriseResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    enterpriseSlug?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterpriseUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MentionedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['MentionedEvent'] = ResolversParentTypes['MentionedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MergeBranchPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['MergeBranchPayload'] = ResolversParentTypes['MergeBranchPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    mergeCommit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MergePullRequestPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['MergePullRequestPayload'] = ResolversParentTypes['MergePullRequestPayload']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MergedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['MergedEvent'] = ResolversParentTypes['MergedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    commit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    mergeRef?: Resolver<Maybe<ResolversTypes['Ref']>, ParentType, ContextType>;
    mergeRefName?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MilestoneResolvers<ContextType = any, ParentType extends ResolversParentTypes['Milestone'] = ResolversParentTypes['Milestone']> = {
    closed?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    closedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    creator?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    description?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    dueOn?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    issues?: Resolver<ResolversTypes['IssueConnection'], ParentType, ContextType, Partial<MilestoneIssuesArgs>>;
    number?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    progressPercentage?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    pullRequests?: Resolver<ResolversTypes['PullRequestConnection'], ParentType, ContextType, Partial<MilestonePullRequestsArgs>>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    state?: Resolver<ResolversTypes['MilestoneState'], ParentType, ContextType>;
    title?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MilestoneConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['MilestoneConnection'] = ResolversParentTypes['MilestoneConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['MilestoneEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Milestone']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MilestoneEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['MilestoneEdge'] = ResolversParentTypes['MilestoneEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Milestone']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MilestoneItemResolvers<ContextType = any, ParentType extends ResolversParentTypes['MilestoneItem'] = ResolversParentTypes['MilestoneItem']> = {
    __resolveType: TypeResolveFn<'Issue' | 'PullRequest', ParentType, ContextType>;
};
export type MilestonedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['MilestonedEvent'] = ResolversParentTypes['MilestonedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    milestoneTitle?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    subject?: Resolver<ResolversTypes['MilestoneItem'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MinimizableResolvers<ContextType = any, ParentType extends ResolversParentTypes['Minimizable'] = ResolversParentTypes['Minimizable']> = {
    __resolveType: TypeResolveFn<'CommitComment' | 'DiscussionComment' | 'GistComment' | 'IssueComment' | 'PullRequestReviewComment', ParentType, ContextType>;
    isMinimized?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    minimizedReason?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    viewerCanMinimize?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
};
export type MinimizeCommentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['MinimizeCommentPayload'] = ResolversParentTypes['MinimizeCommentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    minimizedComment?: Resolver<Maybe<ResolversTypes['Minimizable']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MoveProjectCardPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['MoveProjectCardPayload'] = ResolversParentTypes['MoveProjectCardPayload']> = {
    cardEdge?: Resolver<Maybe<ResolversTypes['ProjectCardEdge']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MoveProjectColumnPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['MoveProjectColumnPayload'] = ResolversParentTypes['MoveProjectColumnPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    columnEdge?: Resolver<Maybe<ResolversTypes['ProjectColumnEdge']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MovedColumnsInProjectEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['MovedColumnsInProjectEvent'] = ResolversParentTypes['MovedColumnsInProjectEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    previousProjectColumnName?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    project?: Resolver<Maybe<ResolversTypes['Project']>, ParentType, ContextType>;
    projectCard?: Resolver<Maybe<ResolversTypes['ProjectCard']>, ParentType, ContextType>;
    projectColumnName?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type MutationResolvers<ContextType = any, ParentType extends ResolversParentTypes['Mutation'] = ResolversParentTypes['Mutation']> = {
    addAssigneesToAssignable?: Resolver<Maybe<ResolversTypes['AddAssigneesToAssignablePayload']>, ParentType, ContextType, RequireFields<MutationAddAssigneesToAssignableArgs, 'input'>>;
    addComment?: Resolver<Maybe<ResolversTypes['AddCommentPayload']>, ParentType, ContextType, RequireFields<MutationAddCommentArgs, 'input'>>;
    addDiscussionComment?: Resolver<Maybe<ResolversTypes['AddDiscussionCommentPayload']>, ParentType, ContextType, RequireFields<MutationAddDiscussionCommentArgs, 'input'>>;
    addEnterpriseAdmin?: Resolver<Maybe<ResolversTypes['AddEnterpriseAdminPayload']>, ParentType, ContextType, RequireFields<MutationAddEnterpriseAdminArgs, 'input'>>;
    addLabelsToLabelable?: Resolver<Maybe<ResolversTypes['AddLabelsToLabelablePayload']>, ParentType, ContextType, RequireFields<MutationAddLabelsToLabelableArgs, 'input'>>;
    addProjectCard?: Resolver<Maybe<ResolversTypes['AddProjectCardPayload']>, ParentType, ContextType, RequireFields<MutationAddProjectCardArgs, 'input'>>;
    addProjectColumn?: Resolver<Maybe<ResolversTypes['AddProjectColumnPayload']>, ParentType, ContextType, RequireFields<MutationAddProjectColumnArgs, 'input'>>;
    addPullRequestReview?: Resolver<Maybe<ResolversTypes['AddPullRequestReviewPayload']>, ParentType, ContextType, RequireFields<MutationAddPullRequestReviewArgs, 'input'>>;
    addPullRequestReviewComment?: Resolver<Maybe<ResolversTypes['AddPullRequestReviewCommentPayload']>, ParentType, ContextType, RequireFields<MutationAddPullRequestReviewCommentArgs, 'input'>>;
    addPullRequestReviewThread?: Resolver<Maybe<ResolversTypes['AddPullRequestReviewThreadPayload']>, ParentType, ContextType, RequireFields<MutationAddPullRequestReviewThreadArgs, 'input'>>;
    addReaction?: Resolver<Maybe<ResolversTypes['AddReactionPayload']>, ParentType, ContextType, RequireFields<MutationAddReactionArgs, 'input'>>;
    addStar?: Resolver<Maybe<ResolversTypes['AddStarPayload']>, ParentType, ContextType, RequireFields<MutationAddStarArgs, 'input'>>;
    addUpvote?: Resolver<Maybe<ResolversTypes['AddUpvotePayload']>, ParentType, ContextType, RequireFields<MutationAddUpvoteArgs, 'input'>>;
    addVerifiableDomain?: Resolver<Maybe<ResolversTypes['AddVerifiableDomainPayload']>, ParentType, ContextType, RequireFields<MutationAddVerifiableDomainArgs, 'input'>>;
    approveDeployments?: Resolver<Maybe<ResolversTypes['ApproveDeploymentsPayload']>, ParentType, ContextType, RequireFields<MutationApproveDeploymentsArgs, 'input'>>;
    approveVerifiableDomain?: Resolver<Maybe<ResolversTypes['ApproveVerifiableDomainPayload']>, ParentType, ContextType, RequireFields<MutationApproveVerifiableDomainArgs, 'input'>>;
    archiveRepository?: Resolver<Maybe<ResolversTypes['ArchiveRepositoryPayload']>, ParentType, ContextType, RequireFields<MutationArchiveRepositoryArgs, 'input'>>;
    changeUserStatus?: Resolver<Maybe<ResolversTypes['ChangeUserStatusPayload']>, ParentType, ContextType, RequireFields<MutationChangeUserStatusArgs, 'input'>>;
    clearLabelsFromLabelable?: Resolver<Maybe<ResolversTypes['ClearLabelsFromLabelablePayload']>, ParentType, ContextType, RequireFields<MutationClearLabelsFromLabelableArgs, 'input'>>;
    cloneProject?: Resolver<Maybe<ResolversTypes['CloneProjectPayload']>, ParentType, ContextType, RequireFields<MutationCloneProjectArgs, 'input'>>;
    cloneTemplateRepository?: Resolver<Maybe<ResolversTypes['CloneTemplateRepositoryPayload']>, ParentType, ContextType, RequireFields<MutationCloneTemplateRepositoryArgs, 'input'>>;
    closeIssue?: Resolver<Maybe<ResolversTypes['CloseIssuePayload']>, ParentType, ContextType, RequireFields<MutationCloseIssueArgs, 'input'>>;
    closePullRequest?: Resolver<Maybe<ResolversTypes['ClosePullRequestPayload']>, ParentType, ContextType, RequireFields<MutationClosePullRequestArgs, 'input'>>;
    convertProjectCardNoteToIssue?: Resolver<Maybe<ResolversTypes['ConvertProjectCardNoteToIssuePayload']>, ParentType, ContextType, RequireFields<MutationConvertProjectCardNoteToIssueArgs, 'input'>>;
    convertPullRequestToDraft?: Resolver<Maybe<ResolversTypes['ConvertPullRequestToDraftPayload']>, ParentType, ContextType, RequireFields<MutationConvertPullRequestToDraftArgs, 'input'>>;
    createBranchProtectionRule?: Resolver<Maybe<ResolversTypes['CreateBranchProtectionRulePayload']>, ParentType, ContextType, RequireFields<MutationCreateBranchProtectionRuleArgs, 'input'>>;
    createCheckRun?: Resolver<Maybe<ResolversTypes['CreateCheckRunPayload']>, ParentType, ContextType, RequireFields<MutationCreateCheckRunArgs, 'input'>>;
    createCheckSuite?: Resolver<Maybe<ResolversTypes['CreateCheckSuitePayload']>, ParentType, ContextType, RequireFields<MutationCreateCheckSuiteArgs, 'input'>>;
    createContentAttachment?: Resolver<Maybe<ResolversTypes['CreateContentAttachmentPayload']>, ParentType, ContextType, RequireFields<MutationCreateContentAttachmentArgs, 'input'>>;
    createDeployment?: Resolver<Maybe<ResolversTypes['CreateDeploymentPayload']>, ParentType, ContextType, RequireFields<MutationCreateDeploymentArgs, 'input'>>;
    createDeploymentStatus?: Resolver<Maybe<ResolversTypes['CreateDeploymentStatusPayload']>, ParentType, ContextType, RequireFields<MutationCreateDeploymentStatusArgs, 'input'>>;
    createDiscussion?: Resolver<Maybe<ResolversTypes['CreateDiscussionPayload']>, ParentType, ContextType, RequireFields<MutationCreateDiscussionArgs, 'input'>>;
    createEnterpriseOrganization?: Resolver<Maybe<ResolversTypes['CreateEnterpriseOrganizationPayload']>, ParentType, ContextType, RequireFields<MutationCreateEnterpriseOrganizationArgs, 'input'>>;
    createEnvironment?: Resolver<Maybe<ResolversTypes['CreateEnvironmentPayload']>, ParentType, ContextType, RequireFields<MutationCreateEnvironmentArgs, 'input'>>;
    createIpAllowListEntry?: Resolver<Maybe<ResolversTypes['CreateIpAllowListEntryPayload']>, ParentType, ContextType, RequireFields<MutationCreateIpAllowListEntryArgs, 'input'>>;
    createIssue?: Resolver<Maybe<ResolversTypes['CreateIssuePayload']>, ParentType, ContextType, RequireFields<MutationCreateIssueArgs, 'input'>>;
    createLabel?: Resolver<Maybe<ResolversTypes['CreateLabelPayload']>, ParentType, ContextType, RequireFields<MutationCreateLabelArgs, 'input'>>;
    createProject?: Resolver<Maybe<ResolversTypes['CreateProjectPayload']>, ParentType, ContextType, RequireFields<MutationCreateProjectArgs, 'input'>>;
    createPullRequest?: Resolver<Maybe<ResolversTypes['CreatePullRequestPayload']>, ParentType, ContextType, RequireFields<MutationCreatePullRequestArgs, 'input'>>;
    createRef?: Resolver<Maybe<ResolversTypes['CreateRefPayload']>, ParentType, ContextType, RequireFields<MutationCreateRefArgs, 'input'>>;
    createRepository?: Resolver<Maybe<ResolversTypes['CreateRepositoryPayload']>, ParentType, ContextType, RequireFields<MutationCreateRepositoryArgs, 'input'>>;
    createTeamDiscussion?: Resolver<Maybe<ResolversTypes['CreateTeamDiscussionPayload']>, ParentType, ContextType, RequireFields<MutationCreateTeamDiscussionArgs, 'input'>>;
    createTeamDiscussionComment?: Resolver<Maybe<ResolversTypes['CreateTeamDiscussionCommentPayload']>, ParentType, ContextType, RequireFields<MutationCreateTeamDiscussionCommentArgs, 'input'>>;
    deleteBranchProtectionRule?: Resolver<Maybe<ResolversTypes['DeleteBranchProtectionRulePayload']>, ParentType, ContextType, RequireFields<MutationDeleteBranchProtectionRuleArgs, 'input'>>;
    deleteDeployment?: Resolver<Maybe<ResolversTypes['DeleteDeploymentPayload']>, ParentType, ContextType, RequireFields<MutationDeleteDeploymentArgs, 'input'>>;
    deleteDiscussion?: Resolver<Maybe<ResolversTypes['DeleteDiscussionPayload']>, ParentType, ContextType, RequireFields<MutationDeleteDiscussionArgs, 'input'>>;
    deleteDiscussionComment?: Resolver<Maybe<ResolversTypes['DeleteDiscussionCommentPayload']>, ParentType, ContextType, RequireFields<MutationDeleteDiscussionCommentArgs, 'input'>>;
    deleteEnvironment?: Resolver<Maybe<ResolversTypes['DeleteEnvironmentPayload']>, ParentType, ContextType, RequireFields<MutationDeleteEnvironmentArgs, 'input'>>;
    deleteIpAllowListEntry?: Resolver<Maybe<ResolversTypes['DeleteIpAllowListEntryPayload']>, ParentType, ContextType, RequireFields<MutationDeleteIpAllowListEntryArgs, 'input'>>;
    deleteIssue?: Resolver<Maybe<ResolversTypes['DeleteIssuePayload']>, ParentType, ContextType, RequireFields<MutationDeleteIssueArgs, 'input'>>;
    deleteIssueComment?: Resolver<Maybe<ResolversTypes['DeleteIssueCommentPayload']>, ParentType, ContextType, RequireFields<MutationDeleteIssueCommentArgs, 'input'>>;
    deleteLabel?: Resolver<Maybe<ResolversTypes['DeleteLabelPayload']>, ParentType, ContextType, RequireFields<MutationDeleteLabelArgs, 'input'>>;
    deletePackageVersion?: Resolver<Maybe<ResolversTypes['DeletePackageVersionPayload']>, ParentType, ContextType, RequireFields<MutationDeletePackageVersionArgs, 'input'>>;
    deleteProject?: Resolver<Maybe<ResolversTypes['DeleteProjectPayload']>, ParentType, ContextType, RequireFields<MutationDeleteProjectArgs, 'input'>>;
    deleteProjectCard?: Resolver<Maybe<ResolversTypes['DeleteProjectCardPayload']>, ParentType, ContextType, RequireFields<MutationDeleteProjectCardArgs, 'input'>>;
    deleteProjectColumn?: Resolver<Maybe<ResolversTypes['DeleteProjectColumnPayload']>, ParentType, ContextType, RequireFields<MutationDeleteProjectColumnArgs, 'input'>>;
    deletePullRequestReview?: Resolver<Maybe<ResolversTypes['DeletePullRequestReviewPayload']>, ParentType, ContextType, RequireFields<MutationDeletePullRequestReviewArgs, 'input'>>;
    deletePullRequestReviewComment?: Resolver<Maybe<ResolversTypes['DeletePullRequestReviewCommentPayload']>, ParentType, ContextType, RequireFields<MutationDeletePullRequestReviewCommentArgs, 'input'>>;
    deleteRef?: Resolver<Maybe<ResolversTypes['DeleteRefPayload']>, ParentType, ContextType, RequireFields<MutationDeleteRefArgs, 'input'>>;
    deleteTeamDiscussion?: Resolver<Maybe<ResolversTypes['DeleteTeamDiscussionPayload']>, ParentType, ContextType, RequireFields<MutationDeleteTeamDiscussionArgs, 'input'>>;
    deleteTeamDiscussionComment?: Resolver<Maybe<ResolversTypes['DeleteTeamDiscussionCommentPayload']>, ParentType, ContextType, RequireFields<MutationDeleteTeamDiscussionCommentArgs, 'input'>>;
    deleteVerifiableDomain?: Resolver<Maybe<ResolversTypes['DeleteVerifiableDomainPayload']>, ParentType, ContextType, RequireFields<MutationDeleteVerifiableDomainArgs, 'input'>>;
    disablePullRequestAutoMerge?: Resolver<Maybe<ResolversTypes['DisablePullRequestAutoMergePayload']>, ParentType, ContextType, RequireFields<MutationDisablePullRequestAutoMergeArgs, 'input'>>;
    dismissPullRequestReview?: Resolver<Maybe<ResolversTypes['DismissPullRequestReviewPayload']>, ParentType, ContextType, RequireFields<MutationDismissPullRequestReviewArgs, 'input'>>;
    enablePullRequestAutoMerge?: Resolver<Maybe<ResolversTypes['EnablePullRequestAutoMergePayload']>, ParentType, ContextType, RequireFields<MutationEnablePullRequestAutoMergeArgs, 'input'>>;
    followUser?: Resolver<Maybe<ResolversTypes['FollowUserPayload']>, ParentType, ContextType, RequireFields<MutationFollowUserArgs, 'input'>>;
    importProject?: Resolver<Maybe<ResolversTypes['ImportProjectPayload']>, ParentType, ContextType, RequireFields<MutationImportProjectArgs, 'input'>>;
    linkRepositoryToProject?: Resolver<Maybe<ResolversTypes['LinkRepositoryToProjectPayload']>, ParentType, ContextType, RequireFields<MutationLinkRepositoryToProjectArgs, 'input'>>;
    lockLockable?: Resolver<Maybe<ResolversTypes['LockLockablePayload']>, ParentType, ContextType, RequireFields<MutationLockLockableArgs, 'input'>>;
    markDiscussionCommentAsAnswer?: Resolver<Maybe<ResolversTypes['MarkDiscussionCommentAsAnswerPayload']>, ParentType, ContextType, RequireFields<MutationMarkDiscussionCommentAsAnswerArgs, 'input'>>;
    markFileAsViewed?: Resolver<Maybe<ResolversTypes['MarkFileAsViewedPayload']>, ParentType, ContextType, RequireFields<MutationMarkFileAsViewedArgs, 'input'>>;
    markPullRequestReadyForReview?: Resolver<Maybe<ResolversTypes['MarkPullRequestReadyForReviewPayload']>, ParentType, ContextType, RequireFields<MutationMarkPullRequestReadyForReviewArgs, 'input'>>;
    mergeBranch?: Resolver<Maybe<ResolversTypes['MergeBranchPayload']>, ParentType, ContextType, RequireFields<MutationMergeBranchArgs, 'input'>>;
    mergePullRequest?: Resolver<Maybe<ResolversTypes['MergePullRequestPayload']>, ParentType, ContextType, RequireFields<MutationMergePullRequestArgs, 'input'>>;
    minimizeComment?: Resolver<Maybe<ResolversTypes['MinimizeCommentPayload']>, ParentType, ContextType, RequireFields<MutationMinimizeCommentArgs, 'input'>>;
    moveProjectCard?: Resolver<Maybe<ResolversTypes['MoveProjectCardPayload']>, ParentType, ContextType, RequireFields<MutationMoveProjectCardArgs, 'input'>>;
    moveProjectColumn?: Resolver<Maybe<ResolversTypes['MoveProjectColumnPayload']>, ParentType, ContextType, RequireFields<MutationMoveProjectColumnArgs, 'input'>>;
    pinIssue?: Resolver<Maybe<ResolversTypes['PinIssuePayload']>, ParentType, ContextType, RequireFields<MutationPinIssueArgs, 'input'>>;
    regenerateVerifiableDomainToken?: Resolver<Maybe<ResolversTypes['RegenerateVerifiableDomainTokenPayload']>, ParentType, ContextType, RequireFields<MutationRegenerateVerifiableDomainTokenArgs, 'input'>>;
    rejectDeployments?: Resolver<Maybe<ResolversTypes['RejectDeploymentsPayload']>, ParentType, ContextType, RequireFields<MutationRejectDeploymentsArgs, 'input'>>;
    removeAssigneesFromAssignable?: Resolver<Maybe<ResolversTypes['RemoveAssigneesFromAssignablePayload']>, ParentType, ContextType, RequireFields<MutationRemoveAssigneesFromAssignableArgs, 'input'>>;
    removeEnterpriseAdmin?: Resolver<Maybe<ResolversTypes['RemoveEnterpriseAdminPayload']>, ParentType, ContextType, RequireFields<MutationRemoveEnterpriseAdminArgs, 'input'>>;
    removeLabelsFromLabelable?: Resolver<Maybe<ResolversTypes['RemoveLabelsFromLabelablePayload']>, ParentType, ContextType, RequireFields<MutationRemoveLabelsFromLabelableArgs, 'input'>>;
    removeOutsideCollaborator?: Resolver<Maybe<ResolversTypes['RemoveOutsideCollaboratorPayload']>, ParentType, ContextType, RequireFields<MutationRemoveOutsideCollaboratorArgs, 'input'>>;
    removeReaction?: Resolver<Maybe<ResolversTypes['RemoveReactionPayload']>, ParentType, ContextType, RequireFields<MutationRemoveReactionArgs, 'input'>>;
    removeStar?: Resolver<Maybe<ResolversTypes['RemoveStarPayload']>, ParentType, ContextType, RequireFields<MutationRemoveStarArgs, 'input'>>;
    removeUpvote?: Resolver<Maybe<ResolversTypes['RemoveUpvotePayload']>, ParentType, ContextType, RequireFields<MutationRemoveUpvoteArgs, 'input'>>;
    reopenIssue?: Resolver<Maybe<ResolversTypes['ReopenIssuePayload']>, ParentType, ContextType, RequireFields<MutationReopenIssueArgs, 'input'>>;
    reopenPullRequest?: Resolver<Maybe<ResolversTypes['ReopenPullRequestPayload']>, ParentType, ContextType, RequireFields<MutationReopenPullRequestArgs, 'input'>>;
    requestReviews?: Resolver<Maybe<ResolversTypes['RequestReviewsPayload']>, ParentType, ContextType, RequireFields<MutationRequestReviewsArgs, 'input'>>;
    rerequestCheckSuite?: Resolver<Maybe<ResolversTypes['RerequestCheckSuitePayload']>, ParentType, ContextType, RequireFields<MutationRerequestCheckSuiteArgs, 'input'>>;
    resolveReviewThread?: Resolver<Maybe<ResolversTypes['ResolveReviewThreadPayload']>, ParentType, ContextType, RequireFields<MutationResolveReviewThreadArgs, 'input'>>;
    submitPullRequestReview?: Resolver<Maybe<ResolversTypes['SubmitPullRequestReviewPayload']>, ParentType, ContextType, RequireFields<MutationSubmitPullRequestReviewArgs, 'input'>>;
    transferIssue?: Resolver<Maybe<ResolversTypes['TransferIssuePayload']>, ParentType, ContextType, RequireFields<MutationTransferIssueArgs, 'input'>>;
    unarchiveRepository?: Resolver<Maybe<ResolversTypes['UnarchiveRepositoryPayload']>, ParentType, ContextType, RequireFields<MutationUnarchiveRepositoryArgs, 'input'>>;
    unfollowUser?: Resolver<Maybe<ResolversTypes['UnfollowUserPayload']>, ParentType, ContextType, RequireFields<MutationUnfollowUserArgs, 'input'>>;
    unlinkRepositoryFromProject?: Resolver<Maybe<ResolversTypes['UnlinkRepositoryFromProjectPayload']>, ParentType, ContextType, RequireFields<MutationUnlinkRepositoryFromProjectArgs, 'input'>>;
    unlockLockable?: Resolver<Maybe<ResolversTypes['UnlockLockablePayload']>, ParentType, ContextType, RequireFields<MutationUnlockLockableArgs, 'input'>>;
    unmarkDiscussionCommentAsAnswer?: Resolver<Maybe<ResolversTypes['UnmarkDiscussionCommentAsAnswerPayload']>, ParentType, ContextType, RequireFields<MutationUnmarkDiscussionCommentAsAnswerArgs, 'input'>>;
    unmarkFileAsViewed?: Resolver<Maybe<ResolversTypes['UnmarkFileAsViewedPayload']>, ParentType, ContextType, RequireFields<MutationUnmarkFileAsViewedArgs, 'input'>>;
    unmarkIssueAsDuplicate?: Resolver<Maybe<ResolversTypes['UnmarkIssueAsDuplicatePayload']>, ParentType, ContextType, RequireFields<MutationUnmarkIssueAsDuplicateArgs, 'input'>>;
    unminimizeComment?: Resolver<Maybe<ResolversTypes['UnminimizeCommentPayload']>, ParentType, ContextType, RequireFields<MutationUnminimizeCommentArgs, 'input'>>;
    unpinIssue?: Resolver<Maybe<ResolversTypes['UnpinIssuePayload']>, ParentType, ContextType, RequireFields<MutationUnpinIssueArgs, 'input'>>;
    unresolveReviewThread?: Resolver<Maybe<ResolversTypes['UnresolveReviewThreadPayload']>, ParentType, ContextType, RequireFields<MutationUnresolveReviewThreadArgs, 'input'>>;
    updateBranchProtectionRule?: Resolver<Maybe<ResolversTypes['UpdateBranchProtectionRulePayload']>, ParentType, ContextType, RequireFields<MutationUpdateBranchProtectionRuleArgs, 'input'>>;
    updateCheckRun?: Resolver<Maybe<ResolversTypes['UpdateCheckRunPayload']>, ParentType, ContextType, RequireFields<MutationUpdateCheckRunArgs, 'input'>>;
    updateCheckSuitePreferences?: Resolver<Maybe<ResolversTypes['UpdateCheckSuitePreferencesPayload']>, ParentType, ContextType, RequireFields<MutationUpdateCheckSuitePreferencesArgs, 'input'>>;
    updateDiscussion?: Resolver<Maybe<ResolversTypes['UpdateDiscussionPayload']>, ParentType, ContextType, RequireFields<MutationUpdateDiscussionArgs, 'input'>>;
    updateDiscussionComment?: Resolver<Maybe<ResolversTypes['UpdateDiscussionCommentPayload']>, ParentType, ContextType, RequireFields<MutationUpdateDiscussionCommentArgs, 'input'>>;
    updateEnterpriseAllowPrivateRepositoryForkingSetting?: Resolver<Maybe<ResolversTypes['UpdateEnterpriseAllowPrivateRepositoryForkingSettingPayload']>, ParentType, ContextType, RequireFields<MutationUpdateEnterpriseAllowPrivateRepositoryForkingSettingArgs, 'input'>>;
    updateEnterpriseDefaultRepositoryPermissionSetting?: Resolver<Maybe<ResolversTypes['UpdateEnterpriseDefaultRepositoryPermissionSettingPayload']>, ParentType, ContextType, RequireFields<MutationUpdateEnterpriseDefaultRepositoryPermissionSettingArgs, 'input'>>;
    updateEnterpriseMembersCanChangeRepositoryVisibilitySetting?: Resolver<Maybe<ResolversTypes['UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingPayload']>, ParentType, ContextType, RequireFields<MutationUpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingArgs, 'input'>>;
    updateEnterpriseMembersCanCreateRepositoriesSetting?: Resolver<Maybe<ResolversTypes['UpdateEnterpriseMembersCanCreateRepositoriesSettingPayload']>, ParentType, ContextType, RequireFields<MutationUpdateEnterpriseMembersCanCreateRepositoriesSettingArgs, 'input'>>;
    updateEnterpriseMembersCanDeleteIssuesSetting?: Resolver<Maybe<ResolversTypes['UpdateEnterpriseMembersCanDeleteIssuesSettingPayload']>, ParentType, ContextType, RequireFields<MutationUpdateEnterpriseMembersCanDeleteIssuesSettingArgs, 'input'>>;
    updateEnterpriseMembersCanDeleteRepositoriesSetting?: Resolver<Maybe<ResolversTypes['UpdateEnterpriseMembersCanDeleteRepositoriesSettingPayload']>, ParentType, ContextType, RequireFields<MutationUpdateEnterpriseMembersCanDeleteRepositoriesSettingArgs, 'input'>>;
    updateEnterpriseMembersCanInviteCollaboratorsSetting?: Resolver<Maybe<ResolversTypes['UpdateEnterpriseMembersCanInviteCollaboratorsSettingPayload']>, ParentType, ContextType, RequireFields<MutationUpdateEnterpriseMembersCanInviteCollaboratorsSettingArgs, 'input'>>;
    updateEnterpriseMembersCanMakePurchasesSetting?: Resolver<Maybe<ResolversTypes['UpdateEnterpriseMembersCanMakePurchasesSettingPayload']>, ParentType, ContextType, RequireFields<MutationUpdateEnterpriseMembersCanMakePurchasesSettingArgs, 'input'>>;
    updateEnterpriseMembersCanUpdateProtectedBranchesSetting?: Resolver<Maybe<ResolversTypes['UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingPayload']>, ParentType, ContextType, RequireFields<MutationUpdateEnterpriseMembersCanUpdateProtectedBranchesSettingArgs, 'input'>>;
    updateEnterpriseMembersCanViewDependencyInsightsSetting?: Resolver<Maybe<ResolversTypes['UpdateEnterpriseMembersCanViewDependencyInsightsSettingPayload']>, ParentType, ContextType, RequireFields<MutationUpdateEnterpriseMembersCanViewDependencyInsightsSettingArgs, 'input'>>;
    updateEnterpriseOrganizationProjectsSetting?: Resolver<Maybe<ResolversTypes['UpdateEnterpriseOrganizationProjectsSettingPayload']>, ParentType, ContextType, RequireFields<MutationUpdateEnterpriseOrganizationProjectsSettingArgs, 'input'>>;
    updateEnterpriseProfile?: Resolver<Maybe<ResolversTypes['UpdateEnterpriseProfilePayload']>, ParentType, ContextType, RequireFields<MutationUpdateEnterpriseProfileArgs, 'input'>>;
    updateEnterpriseRepositoryProjectsSetting?: Resolver<Maybe<ResolversTypes['UpdateEnterpriseRepositoryProjectsSettingPayload']>, ParentType, ContextType, RequireFields<MutationUpdateEnterpriseRepositoryProjectsSettingArgs, 'input'>>;
    updateEnterpriseTeamDiscussionsSetting?: Resolver<Maybe<ResolversTypes['UpdateEnterpriseTeamDiscussionsSettingPayload']>, ParentType, ContextType, RequireFields<MutationUpdateEnterpriseTeamDiscussionsSettingArgs, 'input'>>;
    updateEnterpriseTwoFactorAuthenticationRequiredSetting?: Resolver<Maybe<ResolversTypes['UpdateEnterpriseTwoFactorAuthenticationRequiredSettingPayload']>, ParentType, ContextType, RequireFields<MutationUpdateEnterpriseTwoFactorAuthenticationRequiredSettingArgs, 'input'>>;
    updateEnvironment?: Resolver<Maybe<ResolversTypes['UpdateEnvironmentPayload']>, ParentType, ContextType, RequireFields<MutationUpdateEnvironmentArgs, 'input'>>;
    updateIpAllowListEnabledSetting?: Resolver<Maybe<ResolversTypes['UpdateIpAllowListEnabledSettingPayload']>, ParentType, ContextType, RequireFields<MutationUpdateIpAllowListEnabledSettingArgs, 'input'>>;
    updateIpAllowListEntry?: Resolver<Maybe<ResolversTypes['UpdateIpAllowListEntryPayload']>, ParentType, ContextType, RequireFields<MutationUpdateIpAllowListEntryArgs, 'input'>>;
    updateIpAllowListForInstalledAppsEnabledSetting?: Resolver<Maybe<ResolversTypes['UpdateIpAllowListForInstalledAppsEnabledSettingPayload']>, ParentType, ContextType, RequireFields<MutationUpdateIpAllowListForInstalledAppsEnabledSettingArgs, 'input'>>;
    updateIssue?: Resolver<Maybe<ResolversTypes['UpdateIssuePayload']>, ParentType, ContextType, RequireFields<MutationUpdateIssueArgs, 'input'>>;
    updateIssueComment?: Resolver<Maybe<ResolversTypes['UpdateIssueCommentPayload']>, ParentType, ContextType, RequireFields<MutationUpdateIssueCommentArgs, 'input'>>;
    updateLabel?: Resolver<Maybe<ResolversTypes['UpdateLabelPayload']>, ParentType, ContextType, RequireFields<MutationUpdateLabelArgs, 'input'>>;
    updateNotificationRestrictionSetting?: Resolver<Maybe<ResolversTypes['UpdateNotificationRestrictionSettingPayload']>, ParentType, ContextType, RequireFields<MutationUpdateNotificationRestrictionSettingArgs, 'input'>>;
    updateProject?: Resolver<Maybe<ResolversTypes['UpdateProjectPayload']>, ParentType, ContextType, RequireFields<MutationUpdateProjectArgs, 'input'>>;
    updateProjectCard?: Resolver<Maybe<ResolversTypes['UpdateProjectCardPayload']>, ParentType, ContextType, RequireFields<MutationUpdateProjectCardArgs, 'input'>>;
    updateProjectColumn?: Resolver<Maybe<ResolversTypes['UpdateProjectColumnPayload']>, ParentType, ContextType, RequireFields<MutationUpdateProjectColumnArgs, 'input'>>;
    updatePullRequest?: Resolver<Maybe<ResolversTypes['UpdatePullRequestPayload']>, ParentType, ContextType, RequireFields<MutationUpdatePullRequestArgs, 'input'>>;
    updatePullRequestReview?: Resolver<Maybe<ResolversTypes['UpdatePullRequestReviewPayload']>, ParentType, ContextType, RequireFields<MutationUpdatePullRequestReviewArgs, 'input'>>;
    updatePullRequestReviewComment?: Resolver<Maybe<ResolversTypes['UpdatePullRequestReviewCommentPayload']>, ParentType, ContextType, RequireFields<MutationUpdatePullRequestReviewCommentArgs, 'input'>>;
    updateRef?: Resolver<Maybe<ResolversTypes['UpdateRefPayload']>, ParentType, ContextType, RequireFields<MutationUpdateRefArgs, 'input'>>;
    updateRefs?: Resolver<Maybe<ResolversTypes['UpdateRefsPayload']>, ParentType, ContextType, RequireFields<MutationUpdateRefsArgs, 'input'>>;
    updateRepository?: Resolver<Maybe<ResolversTypes['UpdateRepositoryPayload']>, ParentType, ContextType, RequireFields<MutationUpdateRepositoryArgs, 'input'>>;
    updateSubscription?: Resolver<Maybe<ResolversTypes['UpdateSubscriptionPayload']>, ParentType, ContextType, RequireFields<MutationUpdateSubscriptionArgs, 'input'>>;
    updateTeamDiscussion?: Resolver<Maybe<ResolversTypes['UpdateTeamDiscussionPayload']>, ParentType, ContextType, RequireFields<MutationUpdateTeamDiscussionArgs, 'input'>>;
    updateTeamDiscussionComment?: Resolver<Maybe<ResolversTypes['UpdateTeamDiscussionCommentPayload']>, ParentType, ContextType, RequireFields<MutationUpdateTeamDiscussionCommentArgs, 'input'>>;
    updateTeamReviewAssignment?: Resolver<Maybe<ResolversTypes['UpdateTeamReviewAssignmentPayload']>, ParentType, ContextType, RequireFields<MutationUpdateTeamReviewAssignmentArgs, 'input'>>;
    updateTopics?: Resolver<Maybe<ResolversTypes['UpdateTopicsPayload']>, ParentType, ContextType, RequireFields<MutationUpdateTopicsArgs, 'input'>>;
    verifyVerifiableDomain?: Resolver<Maybe<ResolversTypes['VerifyVerifiableDomainPayload']>, ParentType, ContextType, RequireFields<MutationVerifyVerifiableDomainArgs, 'input'>>;
};
export type NodeResolvers<ContextType = any, ParentType extends ResolversParentTypes['Node'] = ResolversParentTypes['Node']> = {
    __resolveType: TypeResolveFn<'AddedToProjectEvent' | 'App' | 'AssignedEvent' | 'AutoMergeDisabledEvent' | 'AutoMergeEnabledEvent' | 'AutoRebaseEnabledEvent' | 'AutoSquashEnabledEvent' | 'AutomaticBaseChangeFailedEvent' | 'AutomaticBaseChangeSucceededEvent' | 'BaseRefChangedEvent' | 'BaseRefDeletedEvent' | 'BaseRefForcePushedEvent' | 'Blob' | 'Bot' | 'BranchProtectionRule' | 'CWE' | 'CheckRun' | 'CheckSuite' | 'ClosedEvent' | 'CodeOfConduct' | 'CommentDeletedEvent' | 'Commit' | 'CommitComment' | 'CommitCommentThread' | 'ConnectedEvent' | 'ConvertToDraftEvent' | 'ConvertedNoteToIssueEvent' | 'CrossReferencedEvent' | 'DemilestonedEvent' | 'DeployKey' | 'DeployedEvent' | 'Deployment' | 'DeploymentEnvironmentChangedEvent' | 'DeploymentProtectionRule' | 'DeploymentReview' | 'DeploymentStatus' | 'DisconnectedEvent' | 'Discussion' | 'DiscussionCategory' | 'DiscussionComment' | 'Enterprise' | 'EnterpriseAdministratorInvitation' | 'EnterpriseIdentityProvider' | 'EnterpriseRepositoryInfo' | 'EnterpriseServerInstallation' | 'EnterpriseServerUserAccount' | 'EnterpriseServerUserAccountEmail' | 'EnterpriseServerUserAccountsUpload' | 'EnterpriseUserAccount' | 'Environment' | 'ExternalIdentity' | 'Gist' | 'GistComment' | 'HeadRefDeletedEvent' | 'HeadRefForcePushedEvent' | 'HeadRefRestoredEvent' | 'IpAllowListEntry' | 'Issue' | 'IssueComment' | 'Label' | 'LabeledEvent' | 'Language' | 'License' | 'LockedEvent' | 'Mannequin' | 'MarkedAsDuplicateEvent' | 'MembersCanDeleteReposClearAuditEntry' | 'MembersCanDeleteReposDisableAuditEntry' | 'MembersCanDeleteReposEnableAuditEntry' | 'MentionedEvent' | 'MergedEvent' | 'Milestone' | 'MilestonedEvent' | 'MovedColumnsInProjectEvent' | 'OauthApplicationCreateAuditEntry' | 'OrgAddBillingManagerAuditEntry' | 'OrgAddMemberAuditEntry' | 'OrgBlockUserAuditEntry' | 'OrgConfigDisableCollaboratorsOnlyAuditEntry' | 'OrgConfigEnableCollaboratorsOnlyAuditEntry' | 'OrgCreateAuditEntry' | 'OrgDisableOauthAppRestrictionsAuditEntry' | 'OrgDisableSamlAuditEntry' | 'OrgDisableTwoFactorRequirementAuditEntry' | 'OrgEnableOauthAppRestrictionsAuditEntry' | 'OrgEnableSamlAuditEntry' | 'OrgEnableTwoFactorRequirementAuditEntry' | 'OrgInviteMemberAuditEntry' | 'OrgInviteToBusinessAuditEntry' | 'OrgOauthAppAccessApprovedAuditEntry' | 'OrgOauthAppAccessDeniedAuditEntry' | 'OrgOauthAppAccessRequestedAuditEntry' | 'OrgRemoveBillingManagerAuditEntry' | 'OrgRemoveMemberAuditEntry' | 'OrgRemoveOutsideCollaboratorAuditEntry' | 'OrgRestoreMemberAuditEntry' | 'OrgUnblockUserAuditEntry' | 'OrgUpdateDefaultRepositoryPermissionAuditEntry' | 'OrgUpdateMemberAuditEntry' | 'OrgUpdateMemberRepositoryCreationPermissionAuditEntry' | 'OrgUpdateMemberRepositoryInvitationPermissionAuditEntry' | 'Organization' | 'OrganizationIdentityProvider' | 'OrganizationInvitation' | 'Package' | 'PackageFile' | 'PackageTag' | 'PackageVersion' | 'PinnedDiscussion' | 'PinnedEvent' | 'PinnedIssue' | 'PrivateRepositoryForkingDisableAuditEntry' | 'PrivateRepositoryForkingEnableAuditEntry' | 'Project' | 'ProjectCard' | 'ProjectColumn' | 'PublicKey' | 'PullRequest' | 'PullRequestCommit' | 'PullRequestCommitCommentThread' | 'PullRequestReview' | 'PullRequestReviewComment' | 'PullRequestReviewThread' | 'Push' | 'PushAllowance' | 'Reaction' | 'ReadyForReviewEvent' | 'Ref' | 'ReferencedEvent' | 'Release' | 'ReleaseAsset' | 'RemovedFromProjectEvent' | 'RenamedTitleEvent' | 'ReopenedEvent' | 'RepoAccessAuditEntry' | 'RepoAddMemberAuditEntry' | 'RepoAddTopicAuditEntry' | 'RepoArchivedAuditEntry' | 'RepoChangeMergeSettingAuditEntry' | 'RepoConfigDisableAnonymousGitAccessAuditEntry' | 'RepoConfigDisableCollaboratorsOnlyAuditEntry' | 'RepoConfigDisableContributorsOnlyAuditEntry' | 'RepoConfigDisableSockpuppetDisallowedAuditEntry' | 'RepoConfigEnableAnonymousGitAccessAuditEntry' | 'RepoConfigEnableCollaboratorsOnlyAuditEntry' | 'RepoConfigEnableContributorsOnlyAuditEntry' | 'RepoConfigEnableSockpuppetDisallowedAuditEntry' | 'RepoConfigLockAnonymousGitAccessAuditEntry' | 'RepoConfigUnlockAnonymousGitAccessAuditEntry' | 'RepoCreateAuditEntry' | 'RepoDestroyAuditEntry' | 'RepoRemoveMemberAuditEntry' | 'RepoRemoveTopicAuditEntry' | 'Repository' | 'RepositoryInvitation' | 'RepositoryTopic' | 'RepositoryVisibilityChangeDisableAuditEntry' | 'RepositoryVisibilityChangeEnableAuditEntry' | 'RepositoryVulnerabilityAlert' | 'ReviewDismissalAllowance' | 'ReviewDismissedEvent' | 'ReviewRequest' | 'ReviewRequestRemovedEvent' | 'ReviewRequestedEvent' | 'SavedReply' | 'SecurityAdvisory' | 'Sponsorship' | 'Status' | 'StatusCheckRollup' | 'StatusContext' | 'SubscribedEvent' | 'Tag' | 'Team' | 'TeamAddMemberAuditEntry' | 'TeamAddRepositoryAuditEntry' | 'TeamChangeParentTeamAuditEntry' | 'TeamDiscussion' | 'TeamDiscussionComment' | 'TeamRemoveMemberAuditEntry' | 'TeamRemoveRepositoryAuditEntry' | 'Topic' | 'TransferredEvent' | 'Tree' | 'UnassignedEvent' | 'UnlabeledEvent' | 'UnlockedEvent' | 'UnmarkedAsDuplicateEvent' | 'UnpinnedEvent' | 'UnsubscribedEvent' | 'User' | 'UserBlockedEvent' | 'UserContentEdit' | 'UserStatus' | 'VerifiableDomain' | 'Workflow' | 'WorkflowRun', ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
};
export type OauthApplicationAuditEntryDataResolvers<ContextType = any, ParentType extends ResolversParentTypes['OauthApplicationAuditEntryData'] = ResolversParentTypes['OauthApplicationAuditEntryData']> = {
    __resolveType: TypeResolveFn<'OauthApplicationCreateAuditEntry' | 'OrgOauthAppAccessApprovedAuditEntry' | 'OrgOauthAppAccessDeniedAuditEntry' | 'OrgOauthAppAccessRequestedAuditEntry', ParentType, ContextType>;
    oauthApplicationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    oauthApplicationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    oauthApplicationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
};
export type OauthApplicationCreateAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OauthApplicationCreateAuditEntry'] = ResolversParentTypes['OauthApplicationCreateAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    applicationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    callbackUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    oauthApplicationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    oauthApplicationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    oauthApplicationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    rateLimit?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    state?: Resolver<Maybe<ResolversTypes['OauthApplicationCreateAuditEntryState']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgAddBillingManagerAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgAddBillingManagerAuditEntry'] = ResolversParentTypes['OrgAddBillingManagerAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    invitationEmail?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgAddMemberAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgAddMemberAuditEntry'] = ResolversParentTypes['OrgAddMemberAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    permission?: Resolver<Maybe<ResolversTypes['OrgAddMemberAuditEntryPermission']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgBlockUserAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgBlockUserAuditEntry'] = ResolversParentTypes['OrgBlockUserAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    blockedUser?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    blockedUserName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    blockedUserResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    blockedUserUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgConfigDisableCollaboratorsOnlyAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgConfigDisableCollaboratorsOnlyAuditEntry'] = ResolversParentTypes['OrgConfigDisableCollaboratorsOnlyAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgConfigEnableCollaboratorsOnlyAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgConfigEnableCollaboratorsOnlyAuditEntry'] = ResolversParentTypes['OrgConfigEnableCollaboratorsOnlyAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgCreateAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgCreateAuditEntry'] = ResolversParentTypes['OrgCreateAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    billingPlan?: Resolver<Maybe<ResolversTypes['OrgCreateAuditEntryBillingPlan']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgDisableOauthAppRestrictionsAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgDisableOauthAppRestrictionsAuditEntry'] = ResolversParentTypes['OrgDisableOauthAppRestrictionsAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgDisableSamlAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgDisableSamlAuditEntry'] = ResolversParentTypes['OrgDisableSamlAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    digestMethodUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    issuerUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    signatureMethodUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    singleSignOnUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgDisableTwoFactorRequirementAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgDisableTwoFactorRequirementAuditEntry'] = ResolversParentTypes['OrgDisableTwoFactorRequirementAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgEnableOauthAppRestrictionsAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgEnableOauthAppRestrictionsAuditEntry'] = ResolversParentTypes['OrgEnableOauthAppRestrictionsAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgEnableSamlAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgEnableSamlAuditEntry'] = ResolversParentTypes['OrgEnableSamlAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    digestMethodUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    issuerUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    signatureMethodUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    singleSignOnUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgEnableTwoFactorRequirementAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgEnableTwoFactorRequirementAuditEntry'] = ResolversParentTypes['OrgEnableTwoFactorRequirementAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgInviteMemberAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgInviteMemberAuditEntry'] = ResolversParentTypes['OrgInviteMemberAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    email?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationInvitation?: Resolver<Maybe<ResolversTypes['OrganizationInvitation']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgInviteToBusinessAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgInviteToBusinessAuditEntry'] = ResolversParentTypes['OrgInviteToBusinessAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    enterpriseResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    enterpriseSlug?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterpriseUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgOauthAppAccessApprovedAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgOauthAppAccessApprovedAuditEntry'] = ResolversParentTypes['OrgOauthAppAccessApprovedAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    oauthApplicationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    oauthApplicationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    oauthApplicationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgOauthAppAccessDeniedAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgOauthAppAccessDeniedAuditEntry'] = ResolversParentTypes['OrgOauthAppAccessDeniedAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    oauthApplicationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    oauthApplicationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    oauthApplicationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgOauthAppAccessRequestedAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgOauthAppAccessRequestedAuditEntry'] = ResolversParentTypes['OrgOauthAppAccessRequestedAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    oauthApplicationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    oauthApplicationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    oauthApplicationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgRemoveBillingManagerAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgRemoveBillingManagerAuditEntry'] = ResolversParentTypes['OrgRemoveBillingManagerAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    reason?: Resolver<Maybe<ResolversTypes['OrgRemoveBillingManagerAuditEntryReason']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgRemoveMemberAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgRemoveMemberAuditEntry'] = ResolversParentTypes['OrgRemoveMemberAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    membershipTypes?: Resolver<Maybe<Array<ResolversTypes['OrgRemoveMemberAuditEntryMembershipType']>>, ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    reason?: Resolver<Maybe<ResolversTypes['OrgRemoveMemberAuditEntryReason']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgRemoveOutsideCollaboratorAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgRemoveOutsideCollaboratorAuditEntry'] = ResolversParentTypes['OrgRemoveOutsideCollaboratorAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    membershipTypes?: Resolver<Maybe<Array<ResolversTypes['OrgRemoveOutsideCollaboratorAuditEntryMembershipType']>>, ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    reason?: Resolver<Maybe<ResolversTypes['OrgRemoveOutsideCollaboratorAuditEntryReason']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgRestoreMemberAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgRestoreMemberAuditEntry'] = ResolversParentTypes['OrgRestoreMemberAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    restoredCustomEmailRoutingsCount?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    restoredIssueAssignmentsCount?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    restoredMemberships?: Resolver<Maybe<Array<ResolversTypes['OrgRestoreMemberAuditEntryMembership']>>, ParentType, ContextType>;
    restoredMembershipsCount?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    restoredRepositoriesCount?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    restoredRepositoryStarsCount?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    restoredRepositoryWatchesCount?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgRestoreMemberAuditEntryMembershipResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgRestoreMemberAuditEntryMembership'] = ResolversParentTypes['OrgRestoreMemberAuditEntryMembership']> = {
    __resolveType: TypeResolveFn<'OrgRestoreMemberMembershipOrganizationAuditEntryData' | 'OrgRestoreMemberMembershipRepositoryAuditEntryData' | 'OrgRestoreMemberMembershipTeamAuditEntryData', ParentType, ContextType>;
};
export type OrgRestoreMemberMembershipOrganizationAuditEntryDataResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgRestoreMemberMembershipOrganizationAuditEntryData'] = ResolversParentTypes['OrgRestoreMemberMembershipOrganizationAuditEntryData']> = {
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgRestoreMemberMembershipRepositoryAuditEntryDataResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgRestoreMemberMembershipRepositoryAuditEntryData'] = ResolversParentTypes['OrgRestoreMemberMembershipRepositoryAuditEntryData']> = {
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgRestoreMemberMembershipTeamAuditEntryDataResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgRestoreMemberMembershipTeamAuditEntryData'] = ResolversParentTypes['OrgRestoreMemberMembershipTeamAuditEntryData']> = {
    team?: Resolver<Maybe<ResolversTypes['Team']>, ParentType, ContextType>;
    teamName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    teamResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    teamUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgUnblockUserAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgUnblockUserAuditEntry'] = ResolversParentTypes['OrgUnblockUserAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    blockedUser?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    blockedUserName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    blockedUserResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    blockedUserUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgUpdateDefaultRepositoryPermissionAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgUpdateDefaultRepositoryPermissionAuditEntry'] = ResolversParentTypes['OrgUpdateDefaultRepositoryPermissionAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    permission?: Resolver<Maybe<ResolversTypes['OrgUpdateDefaultRepositoryPermissionAuditEntryPermission']>, ParentType, ContextType>;
    permissionWas?: Resolver<Maybe<ResolversTypes['OrgUpdateDefaultRepositoryPermissionAuditEntryPermission']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgUpdateMemberAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgUpdateMemberAuditEntry'] = ResolversParentTypes['OrgUpdateMemberAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    permission?: Resolver<Maybe<ResolversTypes['OrgUpdateMemberAuditEntryPermission']>, ParentType, ContextType>;
    permissionWas?: Resolver<Maybe<ResolversTypes['OrgUpdateMemberAuditEntryPermission']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgUpdateMemberRepositoryCreationPermissionAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgUpdateMemberRepositoryCreationPermissionAuditEntry'] = ResolversParentTypes['OrgUpdateMemberRepositoryCreationPermissionAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    canCreateRepositories?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    visibility?: Resolver<Maybe<ResolversTypes['OrgUpdateMemberRepositoryCreationPermissionAuditEntryVisibility']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrgUpdateMemberRepositoryInvitationPermissionAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrgUpdateMemberRepositoryInvitationPermissionAuditEntry'] = ResolversParentTypes['OrgUpdateMemberRepositoryInvitationPermissionAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    canInviteOutsideCollaboratorsToRepositories?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrganizationResolvers<ContextType = any, ParentType extends ResolversParentTypes['Organization'] = ResolversParentTypes['Organization']> = {
    anyPinnableItems?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType, Partial<OrganizationAnyPinnableItemsArgs>>;
    auditLog?: Resolver<ResolversTypes['OrganizationAuditEntryConnection'], ParentType, ContextType, RequireFields<OrganizationAuditLogArgs, 'orderBy'>>;
    avatarUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType, Partial<OrganizationAvatarUrlArgs>>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    description?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    descriptionHTML?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    domains?: Resolver<Maybe<ResolversTypes['VerifiableDomainConnection']>, ParentType, ContextType, RequireFields<OrganizationDomainsArgs, 'isApproved' | 'isVerified' | 'orderBy'>>;
    email?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    ipAllowListEnabledSetting?: Resolver<ResolversTypes['IpAllowListEnabledSettingValue'], ParentType, ContextType>;
    ipAllowListEntries?: Resolver<ResolversTypes['IpAllowListEntryConnection'], ParentType, ContextType, RequireFields<OrganizationIpAllowListEntriesArgs, 'orderBy'>>;
    ipAllowListForInstalledAppsEnabledSetting?: Resolver<ResolversTypes['IpAllowListForInstalledAppsEnabledSettingValue'], ParentType, ContextType>;
    isVerified?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    itemShowcase?: Resolver<ResolversTypes['ProfileItemShowcase'], ParentType, ContextType>;
    location?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    login?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    memberStatuses?: Resolver<ResolversTypes['UserStatusConnection'], ParentType, ContextType, RequireFields<OrganizationMemberStatusesArgs, 'orderBy'>>;
    membersWithRole?: Resolver<ResolversTypes['OrganizationMemberConnection'], ParentType, ContextType, Partial<OrganizationMembersWithRoleArgs>>;
    name?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    newTeamResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    newTeamUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    notificationDeliveryRestrictionEnabledSetting?: Resolver<ResolversTypes['NotificationRestrictionSettingValue'], ParentType, ContextType>;
    organizationBillingEmail?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    packages?: Resolver<ResolversTypes['PackageConnection'], ParentType, ContextType, RequireFields<OrganizationPackagesArgs, 'orderBy'>>;
    pendingMembers?: Resolver<ResolversTypes['UserConnection'], ParentType, ContextType, Partial<OrganizationPendingMembersArgs>>;
    pinnableItems?: Resolver<ResolversTypes['PinnableItemConnection'], ParentType, ContextType, Partial<OrganizationPinnableItemsArgs>>;
    pinnedItems?: Resolver<ResolversTypes['PinnableItemConnection'], ParentType, ContextType, Partial<OrganizationPinnedItemsArgs>>;
    pinnedItemsRemaining?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    project?: Resolver<Maybe<ResolversTypes['Project']>, ParentType, ContextType, RequireFields<OrganizationProjectArgs, 'number'>>;
    projects?: Resolver<ResolversTypes['ProjectConnection'], ParentType, ContextType, Partial<OrganizationProjectsArgs>>;
    projectsResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    projectsUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    repositories?: Resolver<ResolversTypes['RepositoryConnection'], ParentType, ContextType, RequireFields<OrganizationRepositoriesArgs, 'ownerAffiliations'>>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType, RequireFields<OrganizationRepositoryArgs, 'name'>>;
    repositoryDiscussionComments?: Resolver<ResolversTypes['DiscussionCommentConnection'], ParentType, ContextType, RequireFields<OrganizationRepositoryDiscussionCommentsArgs, 'onlyAnswers'>>;
    repositoryDiscussions?: Resolver<ResolversTypes['DiscussionConnection'], ParentType, ContextType, RequireFields<OrganizationRepositoryDiscussionsArgs, 'answered' | 'orderBy'>>;
    requiresTwoFactorAuthentication?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    samlIdentityProvider?: Resolver<Maybe<ResolversTypes['OrganizationIdentityProvider']>, ParentType, ContextType>;
    sponsorshipsAsMaintainer?: Resolver<ResolversTypes['SponsorshipConnection'], ParentType, ContextType, RequireFields<OrganizationSponsorshipsAsMaintainerArgs, 'includePrivate'>>;
    sponsorshipsAsSponsor?: Resolver<ResolversTypes['SponsorshipConnection'], ParentType, ContextType, Partial<OrganizationSponsorshipsAsSponsorArgs>>;
    team?: Resolver<Maybe<ResolversTypes['Team']>, ParentType, ContextType, RequireFields<OrganizationTeamArgs, 'slug'>>;
    teams?: Resolver<ResolversTypes['TeamConnection'], ParentType, ContextType, RequireFields<OrganizationTeamsArgs, 'rootTeamsOnly'>>;
    teamsResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    teamsUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    twitterUsername?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    viewerCanAdminister?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanChangePinnedItems?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanCreateProjects?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanCreateRepositories?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanCreateTeams?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerIsAMember?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    websiteUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrganizationAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrganizationAuditEntry'] = ResolversParentTypes['OrganizationAuditEntry']> = {
    __resolveType: TypeResolveFn<'MembersCanDeleteReposClearAuditEntry' | 'MembersCanDeleteReposDisableAuditEntry' | 'MembersCanDeleteReposEnableAuditEntry' | 'OauthApplicationCreateAuditEntry' | 'OrgAddBillingManagerAuditEntry' | 'OrgAddMemberAuditEntry' | 'OrgBlockUserAuditEntry' | 'OrgConfigDisableCollaboratorsOnlyAuditEntry' | 'OrgConfigEnableCollaboratorsOnlyAuditEntry' | 'OrgCreateAuditEntry' | 'OrgDisableOauthAppRestrictionsAuditEntry' | 'OrgDisableSamlAuditEntry' | 'OrgDisableTwoFactorRequirementAuditEntry' | 'OrgEnableOauthAppRestrictionsAuditEntry' | 'OrgEnableSamlAuditEntry' | 'OrgEnableTwoFactorRequirementAuditEntry' | 'OrgInviteMemberAuditEntry' | 'OrgInviteToBusinessAuditEntry' | 'OrgOauthAppAccessApprovedAuditEntry' | 'OrgOauthAppAccessDeniedAuditEntry' | 'OrgOauthAppAccessRequestedAuditEntry' | 'OrgRemoveBillingManagerAuditEntry' | 'OrgRemoveMemberAuditEntry' | 'OrgRemoveOutsideCollaboratorAuditEntry' | 'OrgRestoreMemberAuditEntry' | 'OrgUnblockUserAuditEntry' | 'OrgUpdateDefaultRepositoryPermissionAuditEntry' | 'OrgUpdateMemberAuditEntry' | 'OrgUpdateMemberRepositoryCreationPermissionAuditEntry' | 'OrgUpdateMemberRepositoryInvitationPermissionAuditEntry' | 'PrivateRepositoryForkingDisableAuditEntry' | 'PrivateRepositoryForkingEnableAuditEntry' | 'RepoAccessAuditEntry' | 'RepoAddMemberAuditEntry' | 'RepoAddTopicAuditEntry' | 'RepoArchivedAuditEntry' | 'RepoChangeMergeSettingAuditEntry' | 'RepoConfigDisableAnonymousGitAccessAuditEntry' | 'RepoConfigDisableCollaboratorsOnlyAuditEntry' | 'RepoConfigDisableContributorsOnlyAuditEntry' | 'RepoConfigDisableSockpuppetDisallowedAuditEntry' | 'RepoConfigEnableAnonymousGitAccessAuditEntry' | 'RepoConfigEnableCollaboratorsOnlyAuditEntry' | 'RepoConfigEnableContributorsOnlyAuditEntry' | 'RepoConfigEnableSockpuppetDisallowedAuditEntry' | 'RepoConfigLockAnonymousGitAccessAuditEntry' | 'RepoConfigUnlockAnonymousGitAccessAuditEntry' | 'RepoCreateAuditEntry' | 'RepoDestroyAuditEntry' | 'RepoRemoveMemberAuditEntry' | 'RepoRemoveTopicAuditEntry' | 'RepositoryVisibilityChangeDisableAuditEntry' | 'RepositoryVisibilityChangeEnableAuditEntry' | 'TeamAddMemberAuditEntry' | 'TeamAddRepositoryAuditEntry' | 'TeamChangeParentTeamAuditEntry' | 'TeamRemoveMemberAuditEntry' | 'TeamRemoveRepositoryAuditEntry', ParentType, ContextType>;
};
export type OrganizationAuditEntryConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrganizationAuditEntryConnection'] = ResolversParentTypes['OrganizationAuditEntryConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['OrganizationAuditEntryEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['OrganizationAuditEntry']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrganizationAuditEntryDataResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrganizationAuditEntryData'] = ResolversParentTypes['OrganizationAuditEntryData']> = {
    __resolveType: TypeResolveFn<'MembersCanDeleteReposClearAuditEntry' | 'MembersCanDeleteReposDisableAuditEntry' | 'MembersCanDeleteReposEnableAuditEntry' | 'OauthApplicationCreateAuditEntry' | 'OrgAddBillingManagerAuditEntry' | 'OrgAddMemberAuditEntry' | 'OrgBlockUserAuditEntry' | 'OrgConfigDisableCollaboratorsOnlyAuditEntry' | 'OrgConfigEnableCollaboratorsOnlyAuditEntry' | 'OrgCreateAuditEntry' | 'OrgDisableOauthAppRestrictionsAuditEntry' | 'OrgDisableSamlAuditEntry' | 'OrgDisableTwoFactorRequirementAuditEntry' | 'OrgEnableOauthAppRestrictionsAuditEntry' | 'OrgEnableSamlAuditEntry' | 'OrgEnableTwoFactorRequirementAuditEntry' | 'OrgInviteMemberAuditEntry' | 'OrgInviteToBusinessAuditEntry' | 'OrgOauthAppAccessApprovedAuditEntry' | 'OrgOauthAppAccessDeniedAuditEntry' | 'OrgOauthAppAccessRequestedAuditEntry' | 'OrgRemoveBillingManagerAuditEntry' | 'OrgRemoveMemberAuditEntry' | 'OrgRemoveOutsideCollaboratorAuditEntry' | 'OrgRestoreMemberAuditEntry' | 'OrgRestoreMemberMembershipOrganizationAuditEntryData' | 'OrgUnblockUserAuditEntry' | 'OrgUpdateDefaultRepositoryPermissionAuditEntry' | 'OrgUpdateMemberAuditEntry' | 'OrgUpdateMemberRepositoryCreationPermissionAuditEntry' | 'OrgUpdateMemberRepositoryInvitationPermissionAuditEntry' | 'PrivateRepositoryForkingDisableAuditEntry' | 'PrivateRepositoryForkingEnableAuditEntry' | 'RepoAccessAuditEntry' | 'RepoAddMemberAuditEntry' | 'RepoAddTopicAuditEntry' | 'RepoArchivedAuditEntry' | 'RepoChangeMergeSettingAuditEntry' | 'RepoConfigDisableAnonymousGitAccessAuditEntry' | 'RepoConfigDisableCollaboratorsOnlyAuditEntry' | 'RepoConfigDisableContributorsOnlyAuditEntry' | 'RepoConfigDisableSockpuppetDisallowedAuditEntry' | 'RepoConfigEnableAnonymousGitAccessAuditEntry' | 'RepoConfigEnableCollaboratorsOnlyAuditEntry' | 'RepoConfigEnableContributorsOnlyAuditEntry' | 'RepoConfigEnableSockpuppetDisallowedAuditEntry' | 'RepoConfigLockAnonymousGitAccessAuditEntry' | 'RepoConfigUnlockAnonymousGitAccessAuditEntry' | 'RepoCreateAuditEntry' | 'RepoDestroyAuditEntry' | 'RepoRemoveMemberAuditEntry' | 'RepoRemoveTopicAuditEntry' | 'RepositoryVisibilityChangeDisableAuditEntry' | 'RepositoryVisibilityChangeEnableAuditEntry' | 'TeamAddMemberAuditEntry' | 'TeamAddRepositoryAuditEntry' | 'TeamChangeParentTeamAuditEntry' | 'TeamRemoveMemberAuditEntry' | 'TeamRemoveRepositoryAuditEntry', ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
};
export type OrganizationAuditEntryEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrganizationAuditEntryEdge'] = ResolversParentTypes['OrganizationAuditEntryEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['OrganizationAuditEntry']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrganizationConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrganizationConnection'] = ResolversParentTypes['OrganizationConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['OrganizationEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Organization']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrganizationEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrganizationEdge'] = ResolversParentTypes['OrganizationEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrganizationIdentityProviderResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrganizationIdentityProvider'] = ResolversParentTypes['OrganizationIdentityProvider']> = {
    digestMethod?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    externalIdentities?: Resolver<ResolversTypes['ExternalIdentityConnection'], ParentType, ContextType, Partial<OrganizationIdentityProviderExternalIdentitiesArgs>>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    idpCertificate?: Resolver<Maybe<ResolversTypes['X509Certificate']>, ParentType, ContextType>;
    issuer?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    signatureMethod?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    ssoUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrganizationInvitationResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrganizationInvitation'] = ResolversParentTypes['OrganizationInvitation']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    email?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    invitationType?: Resolver<ResolversTypes['OrganizationInvitationType'], ParentType, ContextType>;
    invitee?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    inviter?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    organization?: Resolver<ResolversTypes['Organization'], ParentType, ContextType>;
    role?: Resolver<ResolversTypes['OrganizationInvitationRole'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrganizationInvitationConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrganizationInvitationConnection'] = ResolversParentTypes['OrganizationInvitationConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['OrganizationInvitationEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['OrganizationInvitation']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrganizationInvitationEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrganizationInvitationEdge'] = ResolversParentTypes['OrganizationInvitationEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['OrganizationInvitation']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrganizationMemberConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrganizationMemberConnection'] = ResolversParentTypes['OrganizationMemberConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['OrganizationMemberEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['User']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrganizationMemberEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrganizationMemberEdge'] = ResolversParentTypes['OrganizationMemberEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    hasTwoFactorEnabled?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    role?: Resolver<Maybe<ResolversTypes['OrganizationMemberRole']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrganizationTeamsHovercardContextResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrganizationTeamsHovercardContext'] = ResolversParentTypes['OrganizationTeamsHovercardContext']> = {
    message?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    octicon?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    relevantTeams?: Resolver<ResolversTypes['TeamConnection'], ParentType, ContextType, Partial<OrganizationTeamsHovercardContextRelevantTeamsArgs>>;
    teamsResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    teamsUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    totalTeamCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type OrganizationsHovercardContextResolvers<ContextType = any, ParentType extends ResolversParentTypes['OrganizationsHovercardContext'] = ResolversParentTypes['OrganizationsHovercardContext']> = {
    message?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    octicon?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    relevantOrganizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, Partial<OrganizationsHovercardContextRelevantOrganizationsArgs>>;
    totalOrganizationCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PackageResolvers<ContextType = any, ParentType extends ResolversParentTypes['Package'] = ResolversParentTypes['Package']> = {
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    latestVersion?: Resolver<Maybe<ResolversTypes['PackageVersion']>, ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    packageType?: Resolver<ResolversTypes['PackageType'], ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    statistics?: Resolver<Maybe<ResolversTypes['PackageStatistics']>, ParentType, ContextType>;
    version?: Resolver<Maybe<ResolversTypes['PackageVersion']>, ParentType, ContextType, RequireFields<PackageVersionArgs, 'version'>>;
    versions?: Resolver<ResolversTypes['PackageVersionConnection'], ParentType, ContextType, RequireFields<PackageVersionsArgs, 'orderBy'>>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PackageConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PackageConnection'] = ResolversParentTypes['PackageConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['PackageEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Package']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PackageEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['PackageEdge'] = ResolversParentTypes['PackageEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Package']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PackageFileResolvers<ContextType = any, ParentType extends ResolversParentTypes['PackageFile'] = ResolversParentTypes['PackageFile']> = {
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    md5?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    packageVersion?: Resolver<Maybe<ResolversTypes['PackageVersion']>, ParentType, ContextType>;
    sha1?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    sha256?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    size?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PackageFileConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PackageFileConnection'] = ResolversParentTypes['PackageFileConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['PackageFileEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['PackageFile']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PackageFileEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['PackageFileEdge'] = ResolversParentTypes['PackageFileEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['PackageFile']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PackageOwnerResolvers<ContextType = any, ParentType extends ResolversParentTypes['PackageOwner'] = ResolversParentTypes['PackageOwner']> = {
    __resolveType: TypeResolveFn<'Organization' | 'Repository' | 'User', ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    packages?: Resolver<ResolversTypes['PackageConnection'], ParentType, ContextType, RequireFields<PackageOwnerPackagesArgs, 'orderBy'>>;
};
export type PackageStatisticsResolvers<ContextType = any, ParentType extends ResolversParentTypes['PackageStatistics'] = ResolversParentTypes['PackageStatistics']> = {
    downloadsTotalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PackageTagResolvers<ContextType = any, ParentType extends ResolversParentTypes['PackageTag'] = ResolversParentTypes['PackageTag']> = {
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    version?: Resolver<Maybe<ResolversTypes['PackageVersion']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PackageVersionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PackageVersion'] = ResolversParentTypes['PackageVersion']> = {
    files?: Resolver<ResolversTypes['PackageFileConnection'], ParentType, ContextType, RequireFields<PackageVersionFilesArgs, 'orderBy'>>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    package?: Resolver<Maybe<ResolversTypes['Package']>, ParentType, ContextType>;
    platform?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    preRelease?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    readme?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    release?: Resolver<Maybe<ResolversTypes['Release']>, ParentType, ContextType>;
    statistics?: Resolver<Maybe<ResolversTypes['PackageVersionStatistics']>, ParentType, ContextType>;
    summary?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    version?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PackageVersionConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PackageVersionConnection'] = ResolversParentTypes['PackageVersionConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['PackageVersionEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['PackageVersion']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PackageVersionEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['PackageVersionEdge'] = ResolversParentTypes['PackageVersionEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['PackageVersion']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PackageVersionStatisticsResolvers<ContextType = any, ParentType extends ResolversParentTypes['PackageVersionStatistics'] = ResolversParentTypes['PackageVersionStatistics']> = {
    downloadsTotalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PageInfoResolvers<ContextType = any, ParentType extends ResolversParentTypes['PageInfo'] = ResolversParentTypes['PageInfo']> = {
    endCursor?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    hasNextPage?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    hasPreviousPage?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    startCursor?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PermissionGranterResolvers<ContextType = any, ParentType extends ResolversParentTypes['PermissionGranter'] = ResolversParentTypes['PermissionGranter']> = {
    __resolveType: TypeResolveFn<'Organization' | 'Repository' | 'Team', ParentType, ContextType>;
};
export type PermissionSourceResolvers<ContextType = any, ParentType extends ResolversParentTypes['PermissionSource'] = ResolversParentTypes['PermissionSource']> = {
    organization?: Resolver<ResolversTypes['Organization'], ParentType, ContextType>;
    permission?: Resolver<ResolversTypes['DefaultRepositoryPermissionField'], ParentType, ContextType>;
    source?: Resolver<ResolversTypes['PermissionGranter'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PinIssuePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['PinIssuePayload'] = ResolversParentTypes['PinIssuePayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    issue?: Resolver<Maybe<ResolversTypes['Issue']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PinnableItemResolvers<ContextType = any, ParentType extends ResolversParentTypes['PinnableItem'] = ResolversParentTypes['PinnableItem']> = {
    __resolveType: TypeResolveFn<'Gist' | 'Repository', ParentType, ContextType>;
};
export type PinnableItemConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PinnableItemConnection'] = ResolversParentTypes['PinnableItemConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['PinnableItemEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['PinnableItem']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PinnableItemEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['PinnableItemEdge'] = ResolversParentTypes['PinnableItemEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['PinnableItem']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PinnedDiscussionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PinnedDiscussion'] = ResolversParentTypes['PinnedDiscussion']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    discussion?: Resolver<ResolversTypes['Discussion'], ParentType, ContextType>;
    gradientStopColors?: Resolver<Array<ResolversTypes['String']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pattern?: Resolver<ResolversTypes['PinnedDiscussionPattern'], ParentType, ContextType>;
    pinnedBy?: Resolver<ResolversTypes['Actor'], ParentType, ContextType>;
    preconfiguredGradient?: Resolver<Maybe<ResolversTypes['PinnedDiscussionGradient']>, ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PinnedDiscussionConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PinnedDiscussionConnection'] = ResolversParentTypes['PinnedDiscussionConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['PinnedDiscussionEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['PinnedDiscussion']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PinnedDiscussionEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['PinnedDiscussionEdge'] = ResolversParentTypes['PinnedDiscussionEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['PinnedDiscussion']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PinnedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['PinnedEvent'] = ResolversParentTypes['PinnedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    issue?: Resolver<ResolversTypes['Issue'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PinnedIssueResolvers<ContextType = any, ParentType extends ResolversParentTypes['PinnedIssue'] = ResolversParentTypes['PinnedIssue']> = {
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    issue?: Resolver<ResolversTypes['Issue'], ParentType, ContextType>;
    pinnedBy?: Resolver<ResolversTypes['Actor'], ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PinnedIssueConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PinnedIssueConnection'] = ResolversParentTypes['PinnedIssueConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['PinnedIssueEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['PinnedIssue']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PinnedIssueEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['PinnedIssueEdge'] = ResolversParentTypes['PinnedIssueEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['PinnedIssue']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export interface PreciseDateTimeScalarConfig extends GraphQLScalarTypeConfig<ResolversTypes['PreciseDateTime'], any> {
    name: 'PreciseDateTime';
}
export type PrivateRepositoryForkingDisableAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['PrivateRepositoryForkingDisableAuditEntry'] = ResolversParentTypes['PrivateRepositoryForkingDisableAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    enterpriseResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    enterpriseSlug?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterpriseUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PrivateRepositoryForkingEnableAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['PrivateRepositoryForkingEnableAuditEntry'] = ResolversParentTypes['PrivateRepositoryForkingEnableAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    enterpriseResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    enterpriseSlug?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterpriseUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ProfileItemShowcaseResolvers<ContextType = any, ParentType extends ResolversParentTypes['ProfileItemShowcase'] = ResolversParentTypes['ProfileItemShowcase']> = {
    hasPinnedItems?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    items?: Resolver<ResolversTypes['PinnableItemConnection'], ParentType, ContextType, Partial<ProfileItemShowcaseItemsArgs>>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ProfileOwnerResolvers<ContextType = any, ParentType extends ResolversParentTypes['ProfileOwner'] = ResolversParentTypes['ProfileOwner']> = {
    __resolveType: TypeResolveFn<'Organization' | 'User', ParentType, ContextType>;
    anyPinnableItems?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType, Partial<ProfileOwnerAnyPinnableItemsArgs>>;
    email?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    itemShowcase?: Resolver<ResolversTypes['ProfileItemShowcase'], ParentType, ContextType>;
    location?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    login?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    name?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pinnableItems?: Resolver<ResolversTypes['PinnableItemConnection'], ParentType, ContextType, Partial<ProfileOwnerPinnableItemsArgs>>;
    pinnedItems?: Resolver<ResolversTypes['PinnableItemConnection'], ParentType, ContextType, Partial<ProfileOwnerPinnedItemsArgs>>;
    pinnedItemsRemaining?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    viewerCanChangePinnedItems?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    websiteUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
};
export type ProjectResolvers<ContextType = any, ParentType extends ResolversParentTypes['Project'] = ResolversParentTypes['Project']> = {
    body?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    bodyHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    closed?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    closedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    columns?: Resolver<ResolversTypes['ProjectColumnConnection'], ParentType, ContextType, Partial<ProjectColumnsArgs>>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    creator?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    number?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    owner?: Resolver<ResolversTypes['ProjectOwner'], ParentType, ContextType>;
    pendingCards?: Resolver<ResolversTypes['ProjectCardConnection'], ParentType, ContextType, RequireFields<ProjectPendingCardsArgs, 'archivedStates'>>;
    progress?: Resolver<ResolversTypes['ProjectProgress'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    state?: Resolver<ResolversTypes['ProjectState'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    viewerCanUpdate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ProjectCardResolvers<ContextType = any, ParentType extends ResolversParentTypes['ProjectCard'] = ResolversParentTypes['ProjectCard']> = {
    column?: Resolver<Maybe<ResolversTypes['ProjectColumn']>, ParentType, ContextType>;
    content?: Resolver<Maybe<ResolversTypes['ProjectCardItem']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    creator?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isArchived?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    note?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    project?: Resolver<ResolversTypes['Project'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    state?: Resolver<Maybe<ResolversTypes['ProjectCardState']>, ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ProjectCardConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['ProjectCardConnection'] = ResolversParentTypes['ProjectCardConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['ProjectCardEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['ProjectCard']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ProjectCardEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['ProjectCardEdge'] = ResolversParentTypes['ProjectCardEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['ProjectCard']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ProjectCardItemResolvers<ContextType = any, ParentType extends ResolversParentTypes['ProjectCardItem'] = ResolversParentTypes['ProjectCardItem']> = {
    __resolveType: TypeResolveFn<'Issue' | 'PullRequest', ParentType, ContextType>;
};
export type ProjectColumnResolvers<ContextType = any, ParentType extends ResolversParentTypes['ProjectColumn'] = ResolversParentTypes['ProjectColumn']> = {
    cards?: Resolver<ResolversTypes['ProjectCardConnection'], ParentType, ContextType, RequireFields<ProjectColumnCardsArgs, 'archivedStates'>>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    project?: Resolver<ResolversTypes['Project'], ParentType, ContextType>;
    purpose?: Resolver<Maybe<ResolversTypes['ProjectColumnPurpose']>, ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ProjectColumnConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['ProjectColumnConnection'] = ResolversParentTypes['ProjectColumnConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['ProjectColumnEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['ProjectColumn']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ProjectColumnEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['ProjectColumnEdge'] = ResolversParentTypes['ProjectColumnEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['ProjectColumn']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ProjectConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['ProjectConnection'] = ResolversParentTypes['ProjectConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['ProjectEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Project']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ProjectEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['ProjectEdge'] = ResolversParentTypes['ProjectEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Project']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ProjectOwnerResolvers<ContextType = any, ParentType extends ResolversParentTypes['ProjectOwner'] = ResolversParentTypes['ProjectOwner']> = {
    __resolveType: TypeResolveFn<'Organization' | 'Repository' | 'User', ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    project?: Resolver<Maybe<ResolversTypes['Project']>, ParentType, ContextType, RequireFields<ProjectOwnerProjectArgs, 'number'>>;
    projects?: Resolver<ResolversTypes['ProjectConnection'], ParentType, ContextType, Partial<ProjectOwnerProjectsArgs>>;
    projectsResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    projectsUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    viewerCanCreateProjects?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
};
export type ProjectProgressResolvers<ContextType = any, ParentType extends ResolversParentTypes['ProjectProgress'] = ResolversParentTypes['ProjectProgress']> = {
    doneCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    donePercentage?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    enabled?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    inProgressCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    inProgressPercentage?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    todoCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    todoPercentage?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PublicKeyResolvers<ContextType = any, ParentType extends ResolversParentTypes['PublicKey'] = ResolversParentTypes['PublicKey']> = {
    accessedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    createdAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    fingerprint?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isReadOnly?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    key?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    updatedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PublicKeyConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PublicKeyConnection'] = ResolversParentTypes['PublicKeyConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['PublicKeyEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['PublicKey']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PublicKeyEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['PublicKeyEdge'] = ResolversParentTypes['PublicKeyEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['PublicKey']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequest'] = ResolversParentTypes['PullRequest']> = {
    activeLockReason?: Resolver<Maybe<ResolversTypes['LockReason']>, ParentType, ContextType>;
    additions?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    assignees?: Resolver<ResolversTypes['UserConnection'], ParentType, ContextType, Partial<PullRequestAssigneesArgs>>;
    author?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    authorAssociation?: Resolver<ResolversTypes['CommentAuthorAssociation'], ParentType, ContextType>;
    autoMergeRequest?: Resolver<Maybe<ResolversTypes['AutoMergeRequest']>, ParentType, ContextType>;
    baseRef?: Resolver<Maybe<ResolversTypes['Ref']>, ParentType, ContextType>;
    baseRefName?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    baseRefOid?: Resolver<ResolversTypes['GitObjectID'], ParentType, ContextType>;
    baseRepository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    body?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    bodyHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    bodyText?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    canBeRebased?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    changedFiles?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    checksResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    checksUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    closed?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    closedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    closingIssuesReferences?: Resolver<Maybe<ResolversTypes['IssueConnection']>, ParentType, ContextType, Partial<PullRequestClosingIssuesReferencesArgs>>;
    comments?: Resolver<ResolversTypes['IssueCommentConnection'], ParentType, ContextType, Partial<PullRequestCommentsArgs>>;
    commits?: Resolver<ResolversTypes['PullRequestCommitConnection'], ParentType, ContextType, Partial<PullRequestCommitsArgs>>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    createdViaEmail?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    deletions?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    editor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    files?: Resolver<Maybe<ResolversTypes['PullRequestChangedFileConnection']>, ParentType, ContextType, Partial<PullRequestFilesArgs>>;
    headRef?: Resolver<Maybe<ResolversTypes['Ref']>, ParentType, ContextType>;
    headRefName?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    headRefOid?: Resolver<ResolversTypes['GitObjectID'], ParentType, ContextType>;
    headRepository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    headRepositoryOwner?: Resolver<Maybe<ResolversTypes['RepositoryOwner']>, ParentType, ContextType>;
    hovercard?: Resolver<ResolversTypes['Hovercard'], ParentType, ContextType, RequireFields<PullRequestHovercardArgs, 'includeNotificationContexts'>>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    includesCreatedEdit?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isCrossRepository?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isDraft?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isReadByViewer?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    labels?: Resolver<Maybe<ResolversTypes['LabelConnection']>, ParentType, ContextType, RequireFields<PullRequestLabelsArgs, 'orderBy'>>;
    lastEditedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    latestOpinionatedReviews?: Resolver<Maybe<ResolversTypes['PullRequestReviewConnection']>, ParentType, ContextType, RequireFields<PullRequestLatestOpinionatedReviewsArgs, 'writersOnly'>>;
    latestReviews?: Resolver<Maybe<ResolversTypes['PullRequestReviewConnection']>, ParentType, ContextType, Partial<PullRequestLatestReviewsArgs>>;
    locked?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    maintainerCanModify?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    mergeCommit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    mergeStateStatus?: Resolver<ResolversTypes['MergeStateStatus'], ParentType, ContextType>;
    mergeable?: Resolver<ResolversTypes['MergeableState'], ParentType, ContextType>;
    merged?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    mergedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    mergedBy?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    milestone?: Resolver<Maybe<ResolversTypes['Milestone']>, ParentType, ContextType>;
    number?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    participants?: Resolver<ResolversTypes['UserConnection'], ParentType, ContextType, Partial<PullRequestParticipantsArgs>>;
    permalink?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    potentialMergeCommit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    projectCards?: Resolver<ResolversTypes['ProjectCardConnection'], ParentType, ContextType, RequireFields<PullRequestProjectCardsArgs, 'archivedStates'>>;
    publishedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    reactionGroups?: Resolver<Maybe<Array<ResolversTypes['ReactionGroup']>>, ParentType, ContextType>;
    reactions?: Resolver<ResolversTypes['ReactionConnection'], ParentType, ContextType, Partial<PullRequestReactionsArgs>>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    revertResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    revertUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    reviewDecision?: Resolver<Maybe<ResolversTypes['PullRequestReviewDecision']>, ParentType, ContextType>;
    reviewRequests?: Resolver<Maybe<ResolversTypes['ReviewRequestConnection']>, ParentType, ContextType, Partial<PullRequestReviewRequestsArgs>>;
    reviewThreads?: Resolver<ResolversTypes['PullRequestReviewThreadConnection'], ParentType, ContextType, Partial<PullRequestReviewThreadsArgs>>;
    reviews?: Resolver<Maybe<ResolversTypes['PullRequestReviewConnection']>, ParentType, ContextType, Partial<PullRequestReviewsArgs>>;
    state?: Resolver<ResolversTypes['PullRequestState'], ParentType, ContextType>;
    suggestedReviewers?: Resolver<Array<Maybe<ResolversTypes['SuggestedReviewer']>>, ParentType, ContextType>;
    timeline?: Resolver<ResolversTypes['PullRequestTimelineConnection'], ParentType, ContextType, Partial<PullRequestTimelineArgs>>;
    timelineItems?: Resolver<ResolversTypes['PullRequestTimelineItemsConnection'], ParentType, ContextType, Partial<PullRequestTimelineItemsArgs>>;
    title?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    titleHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    userContentEdits?: Resolver<Maybe<ResolversTypes['UserContentEditConnection']>, ParentType, ContextType, Partial<PullRequestUserContentEditsArgs>>;
    viewerCanApplySuggestion?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanDeleteHeadRef?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanDisableAutoMerge?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanEnableAutoMerge?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanReact?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanSubscribe?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanUpdate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCannotUpdateReasons?: Resolver<Array<ResolversTypes['CommentCannotUpdateReason']>, ParentType, ContextType>;
    viewerDidAuthor?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerLatestReview?: Resolver<Maybe<ResolversTypes['PullRequestReview']>, ParentType, ContextType>;
    viewerLatestReviewRequest?: Resolver<Maybe<ResolversTypes['ReviewRequest']>, ParentType, ContextType>;
    viewerMergeBodyText?: Resolver<ResolversTypes['String'], ParentType, ContextType, Partial<PullRequestViewerMergeBodyTextArgs>>;
    viewerMergeHeadlineText?: Resolver<ResolversTypes['String'], ParentType, ContextType, Partial<PullRequestViewerMergeHeadlineTextArgs>>;
    viewerSubscription?: Resolver<Maybe<ResolversTypes['SubscriptionState']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestChangedFileResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestChangedFile'] = ResolversParentTypes['PullRequestChangedFile']> = {
    additions?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    deletions?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    path?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    viewerViewedState?: Resolver<ResolversTypes['FileViewedState'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestChangedFileConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestChangedFileConnection'] = ResolversParentTypes['PullRequestChangedFileConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['PullRequestChangedFileEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['PullRequestChangedFile']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestChangedFileEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestChangedFileEdge'] = ResolversParentTypes['PullRequestChangedFileEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['PullRequestChangedFile']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestCommitResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestCommit'] = ResolversParentTypes['PullRequestCommit']> = {
    commit?: Resolver<ResolversTypes['Commit'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestCommitCommentThreadResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestCommitCommentThread'] = ResolversParentTypes['PullRequestCommitCommentThread']> = {
    comments?: Resolver<ResolversTypes['CommitCommentConnection'], ParentType, ContextType, Partial<PullRequestCommitCommentThreadCommentsArgs>>;
    commit?: Resolver<ResolversTypes['Commit'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    path?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    position?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestCommitConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestCommitConnection'] = ResolversParentTypes['PullRequestCommitConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['PullRequestCommitEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['PullRequestCommit']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestCommitEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestCommitEdge'] = ResolversParentTypes['PullRequestCommitEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['PullRequestCommit']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestConnection'] = ResolversParentTypes['PullRequestConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['PullRequestEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['PullRequest']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestContributionsByRepositoryResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestContributionsByRepository'] = ResolversParentTypes['PullRequestContributionsByRepository']> = {
    contributions?: Resolver<ResolversTypes['CreatedPullRequestContributionConnection'], ParentType, ContextType, RequireFields<PullRequestContributionsByRepositoryContributionsArgs, 'orderBy'>>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestEdge'] = ResolversParentTypes['PullRequestEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestReviewResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestReview'] = ResolversParentTypes['PullRequestReview']> = {
    author?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    authorAssociation?: Resolver<ResolversTypes['CommentAuthorAssociation'], ParentType, ContextType>;
    authorCanPushToRepository?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    body?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    bodyHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    bodyText?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    comments?: Resolver<ResolversTypes['PullRequestReviewCommentConnection'], ParentType, ContextType, Partial<PullRequestReviewCommentsArgs>>;
    commit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    createdViaEmail?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    editor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    includesCreatedEdit?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    lastEditedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    onBehalfOf?: Resolver<ResolversTypes['TeamConnection'], ParentType, ContextType, Partial<PullRequestReviewOnBehalfOfArgs>>;
    publishedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    reactionGroups?: Resolver<Maybe<Array<ResolversTypes['ReactionGroup']>>, ParentType, ContextType>;
    reactions?: Resolver<ResolversTypes['ReactionConnection'], ParentType, ContextType, Partial<PullRequestReviewReactionsArgs>>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    state?: Resolver<ResolversTypes['PullRequestReviewState'], ParentType, ContextType>;
    submittedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    userContentEdits?: Resolver<Maybe<ResolversTypes['UserContentEditConnection']>, ParentType, ContextType, Partial<PullRequestReviewUserContentEditsArgs>>;
    viewerCanDelete?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanReact?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanUpdate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCannotUpdateReasons?: Resolver<Array<ResolversTypes['CommentCannotUpdateReason']>, ParentType, ContextType>;
    viewerDidAuthor?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestReviewCommentResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestReviewComment'] = ResolversParentTypes['PullRequestReviewComment']> = {
    author?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    authorAssociation?: Resolver<ResolversTypes['CommentAuthorAssociation'], ParentType, ContextType>;
    body?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    bodyHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    bodyText?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    commit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    createdViaEmail?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    diffHunk?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    draftedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    editor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    includesCreatedEdit?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isMinimized?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    lastEditedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    minimizedReason?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    originalCommit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    originalPosition?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    outdated?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    path?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    position?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    publishedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    pullRequestReview?: Resolver<Maybe<ResolversTypes['PullRequestReview']>, ParentType, ContextType>;
    reactionGroups?: Resolver<Maybe<Array<ResolversTypes['ReactionGroup']>>, ParentType, ContextType>;
    reactions?: Resolver<ResolversTypes['ReactionConnection'], ParentType, ContextType, Partial<PullRequestReviewCommentReactionsArgs>>;
    replyTo?: Resolver<Maybe<ResolversTypes['PullRequestReviewComment']>, ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    state?: Resolver<ResolversTypes['PullRequestReviewCommentState'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    userContentEdits?: Resolver<Maybe<ResolversTypes['UserContentEditConnection']>, ParentType, ContextType, Partial<PullRequestReviewCommentUserContentEditsArgs>>;
    viewerCanDelete?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanMinimize?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanReact?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanUpdate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCannotUpdateReasons?: Resolver<Array<ResolversTypes['CommentCannotUpdateReason']>, ParentType, ContextType>;
    viewerDidAuthor?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestReviewCommentConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestReviewCommentConnection'] = ResolversParentTypes['PullRequestReviewCommentConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['PullRequestReviewCommentEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['PullRequestReviewComment']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestReviewCommentEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestReviewCommentEdge'] = ResolversParentTypes['PullRequestReviewCommentEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['PullRequestReviewComment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestReviewConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestReviewConnection'] = ResolversParentTypes['PullRequestReviewConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['PullRequestReviewEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['PullRequestReview']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestReviewContributionsByRepositoryResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestReviewContributionsByRepository'] = ResolversParentTypes['PullRequestReviewContributionsByRepository']> = {
    contributions?: Resolver<ResolversTypes['CreatedPullRequestReviewContributionConnection'], ParentType, ContextType, RequireFields<PullRequestReviewContributionsByRepositoryContributionsArgs, 'orderBy'>>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestReviewEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestReviewEdge'] = ResolversParentTypes['PullRequestReviewEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['PullRequestReview']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestReviewThreadResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestReviewThread'] = ResolversParentTypes['PullRequestReviewThread']> = {
    comments?: Resolver<ResolversTypes['PullRequestReviewCommentConnection'], ParentType, ContextType, Partial<PullRequestReviewThreadCommentsArgs>>;
    diffSide?: Resolver<ResolversTypes['DiffSide'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isCollapsed?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isOutdated?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isResolved?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    line?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    originalLine?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    originalStartLine?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    path?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resolvedBy?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    startDiffSide?: Resolver<Maybe<ResolversTypes['DiffSide']>, ParentType, ContextType>;
    startLine?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    viewerCanReply?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanResolve?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanUnresolve?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestReviewThreadConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestReviewThreadConnection'] = ResolversParentTypes['PullRequestReviewThreadConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['PullRequestReviewThreadEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['PullRequestReviewThread']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestReviewThreadEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestReviewThreadEdge'] = ResolversParentTypes['PullRequestReviewThreadEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['PullRequestReviewThread']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestRevisionMarkerResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestRevisionMarker'] = ResolversParentTypes['PullRequestRevisionMarker']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    lastSeenCommit?: Resolver<ResolversTypes['Commit'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestTemplateResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestTemplate'] = ResolversParentTypes['PullRequestTemplate']> = {
    body?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    filename?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestTimelineConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestTimelineConnection'] = ResolversParentTypes['PullRequestTimelineConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['PullRequestTimelineItemEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['PullRequestTimelineItem']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestTimelineItemResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestTimelineItem'] = ResolversParentTypes['PullRequestTimelineItem']> = {
    __resolveType: TypeResolveFn<'AssignedEvent' | 'BaseRefDeletedEvent' | 'BaseRefForcePushedEvent' | 'ClosedEvent' | 'Commit' | 'CommitCommentThread' | 'CrossReferencedEvent' | 'DemilestonedEvent' | 'DeployedEvent' | 'DeploymentEnvironmentChangedEvent' | 'HeadRefDeletedEvent' | 'HeadRefForcePushedEvent' | 'HeadRefRestoredEvent' | 'IssueComment' | 'LabeledEvent' | 'LockedEvent' | 'MergedEvent' | 'MilestonedEvent' | 'PullRequestReview' | 'PullRequestReviewComment' | 'PullRequestReviewThread' | 'ReferencedEvent' | 'RenamedTitleEvent' | 'ReopenedEvent' | 'ReviewDismissedEvent' | 'ReviewRequestRemovedEvent' | 'ReviewRequestedEvent' | 'SubscribedEvent' | 'UnassignedEvent' | 'UnlabeledEvent' | 'UnlockedEvent' | 'UnsubscribedEvent' | 'UserBlockedEvent', ParentType, ContextType>;
};
export type PullRequestTimelineItemEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestTimelineItemEdge'] = ResolversParentTypes['PullRequestTimelineItemEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['PullRequestTimelineItem']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestTimelineItemsResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestTimelineItems'] = ResolversParentTypes['PullRequestTimelineItems']> = {
    __resolveType: TypeResolveFn<'AddedToProjectEvent' | 'AssignedEvent' | 'AutoMergeDisabledEvent' | 'AutoMergeEnabledEvent' | 'AutoRebaseEnabledEvent' | 'AutoSquashEnabledEvent' | 'AutomaticBaseChangeFailedEvent' | 'AutomaticBaseChangeSucceededEvent' | 'BaseRefChangedEvent' | 'BaseRefDeletedEvent' | 'BaseRefForcePushedEvent' | 'ClosedEvent' | 'CommentDeletedEvent' | 'ConnectedEvent' | 'ConvertToDraftEvent' | 'ConvertedNoteToIssueEvent' | 'CrossReferencedEvent' | 'DemilestonedEvent' | 'DeployedEvent' | 'DeploymentEnvironmentChangedEvent' | 'DisconnectedEvent' | 'HeadRefDeletedEvent' | 'HeadRefForcePushedEvent' | 'HeadRefRestoredEvent' | 'IssueComment' | 'LabeledEvent' | 'LockedEvent' | 'MarkedAsDuplicateEvent' | 'MentionedEvent' | 'MergedEvent' | 'MilestonedEvent' | 'MovedColumnsInProjectEvent' | 'PinnedEvent' | 'PullRequestCommit' | 'PullRequestCommitCommentThread' | 'PullRequestReview' | 'PullRequestReviewThread' | 'PullRequestRevisionMarker' | 'ReadyForReviewEvent' | 'ReferencedEvent' | 'RemovedFromProjectEvent' | 'RenamedTitleEvent' | 'ReopenedEvent' | 'ReviewDismissedEvent' | 'ReviewRequestRemovedEvent' | 'ReviewRequestedEvent' | 'SubscribedEvent' | 'TransferredEvent' | 'UnassignedEvent' | 'UnlabeledEvent' | 'UnlockedEvent' | 'UnmarkedAsDuplicateEvent' | 'UnpinnedEvent' | 'UnsubscribedEvent' | 'UserBlockedEvent', ParentType, ContextType>;
};
export type PullRequestTimelineItemsConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestTimelineItemsConnection'] = ResolversParentTypes['PullRequestTimelineItemsConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['PullRequestTimelineItemsEdge']>>>, ParentType, ContextType>;
    filteredCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['PullRequestTimelineItems']>>>, ParentType, ContextType>;
    pageCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PullRequestTimelineItemsEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['PullRequestTimelineItemsEdge'] = ResolversParentTypes['PullRequestTimelineItemsEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['PullRequestTimelineItems']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PushResolvers<ContextType = any, ParentType extends ResolversParentTypes['Push'] = ResolversParentTypes['Push']> = {
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    nextSha?: Resolver<Maybe<ResolversTypes['GitObjectID']>, ParentType, ContextType>;
    permalink?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    previousSha?: Resolver<Maybe<ResolversTypes['GitObjectID']>, ParentType, ContextType>;
    pusher?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PushAllowanceResolvers<ContextType = any, ParentType extends ResolversParentTypes['PushAllowance'] = ResolversParentTypes['PushAllowance']> = {
    actor?: Resolver<Maybe<ResolversTypes['PushAllowanceActor']>, ParentType, ContextType>;
    branchProtectionRule?: Resolver<Maybe<ResolversTypes['BranchProtectionRule']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PushAllowanceActorResolvers<ContextType = any, ParentType extends ResolversParentTypes['PushAllowanceActor'] = ResolversParentTypes['PushAllowanceActor']> = {
    __resolveType: TypeResolveFn<'App' | 'Team' | 'User', ParentType, ContextType>;
};
export type PushAllowanceConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['PushAllowanceConnection'] = ResolversParentTypes['PushAllowanceConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['PushAllowanceEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['PushAllowance']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type PushAllowanceEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['PushAllowanceEdge'] = ResolversParentTypes['PushAllowanceEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['PushAllowance']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type QueryResolvers<ContextType = any, ParentType extends ResolversParentTypes['Query'] = ResolversParentTypes['Query']> = {
    codeOfConduct?: Resolver<Maybe<ResolversTypes['CodeOfConduct']>, ParentType, ContextType, RequireFields<QueryCodeOfConductArgs, 'key'>>;
    codesOfConduct?: Resolver<Maybe<Array<Maybe<ResolversTypes['CodeOfConduct']>>>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType, RequireFields<QueryEnterpriseArgs, 'slug'>>;
    license?: Resolver<Maybe<ResolversTypes['License']>, ParentType, ContextType, RequireFields<QueryLicenseArgs, 'key'>>;
    licenses?: Resolver<Array<Maybe<ResolversTypes['License']>>, ParentType, ContextType>;
    meta?: Resolver<ResolversTypes['GitHubMetadata'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Node']>, ParentType, ContextType, RequireFields<QueryNodeArgs, 'id'>>;
    nodes?: Resolver<Array<Maybe<ResolversTypes['Node']>>, ParentType, ContextType, RequireFields<QueryNodesArgs, 'ids'>>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType, RequireFields<QueryOrganizationArgs, 'login'>>;
    organizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, Partial<QueryOrganizationsArgs>>;
    rateLimit?: Resolver<Maybe<ResolversTypes['RateLimit']>, ParentType, ContextType, RequireFields<QueryRateLimitArgs, 'dryRun'>>;
    relay?: Resolver<ResolversTypes['Query'], ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType, RequireFields<QueryRepositoryArgs, 'name' | 'owner'>>;
    repositoryOwner?: Resolver<Maybe<ResolversTypes['RepositoryOwner']>, ParentType, ContextType, RequireFields<QueryRepositoryOwnerArgs, 'login'>>;
    resource?: Resolver<Maybe<ResolversTypes['UniformResourceLocatable']>, ParentType, ContextType, RequireFields<QueryResourceArgs, 'url'>>;
    search?: Resolver<ResolversTypes['SearchResultItemConnection'], ParentType, ContextType, RequireFields<QuerySearchArgs, 'query' | 'type'>>;
    securityAdvisories?: Resolver<ResolversTypes['SecurityAdvisoryConnection'], ParentType, ContextType, Partial<QuerySecurityAdvisoriesArgs>>;
    securityAdvisory?: Resolver<Maybe<ResolversTypes['SecurityAdvisory']>, ParentType, ContextType, RequireFields<QuerySecurityAdvisoryArgs, 'ghsaId'>>;
    securityVulnerabilities?: Resolver<ResolversTypes['SecurityVulnerabilityConnection'], ParentType, ContextType, Partial<QuerySecurityVulnerabilitiesArgs>>;
    topic?: Resolver<Maybe<ResolversTypes['Topic']>, ParentType, ContextType, RequireFields<QueryTopicArgs, 'name'>>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType, RequireFields<QueryUserArgs, 'login'>>;
    users?: Resolver<ResolversTypes['UserConnection'], ParentType, ContextType, Partial<QueryUsersArgs>>;
    viewer?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
};
export type RateLimitResolvers<ContextType = any, ParentType extends ResolversParentTypes['RateLimit'] = ResolversParentTypes['RateLimit']> = {
    cost?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    limit?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    nodeCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    remaining?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    resetAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    used?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReactableResolvers<ContextType = any, ParentType extends ResolversParentTypes['Reactable'] = ResolversParentTypes['Reactable']> = {
    __resolveType: TypeResolveFn<'CommitComment' | 'Discussion' | 'DiscussionComment' | 'Issue' | 'IssueComment' | 'PullRequest' | 'PullRequestReview' | 'PullRequestReviewComment' | 'Release' | 'TeamDiscussion' | 'TeamDiscussionComment', ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    reactionGroups?: Resolver<Maybe<Array<ResolversTypes['ReactionGroup']>>, ParentType, ContextType>;
    reactions?: Resolver<ResolversTypes['ReactionConnection'], ParentType, ContextType, Partial<ReactableReactionsArgs>>;
    viewerCanReact?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
};
export type ReactingUserConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReactingUserConnection'] = ResolversParentTypes['ReactingUserConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['ReactingUserEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['User']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReactingUserEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReactingUserEdge'] = ResolversParentTypes['ReactingUserEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    reactedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReactionResolvers<ContextType = any, ParentType extends ResolversParentTypes['Reaction'] = ResolversParentTypes['Reaction']> = {
    content?: Resolver<ResolversTypes['ReactionContent'], ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    reactable?: Resolver<ResolversTypes['Reactable'], ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReactionConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReactionConnection'] = ResolversParentTypes['ReactionConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['ReactionEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Reaction']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    viewerHasReacted?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReactionEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReactionEdge'] = ResolversParentTypes['ReactionEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Reaction']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReactionGroupResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReactionGroup'] = ResolversParentTypes['ReactionGroup']> = {
    content?: Resolver<ResolversTypes['ReactionContent'], ParentType, ContextType>;
    createdAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    reactors?: Resolver<ResolversTypes['ReactorConnection'], ParentType, ContextType, Partial<ReactionGroupReactorsArgs>>;
    subject?: Resolver<ResolversTypes['Reactable'], ParentType, ContextType>;
    users?: Resolver<ResolversTypes['ReactingUserConnection'], ParentType, ContextType, Partial<ReactionGroupUsersArgs>>;
    viewerHasReacted?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReactorResolvers<ContextType = any, ParentType extends ResolversParentTypes['Reactor'] = ResolversParentTypes['Reactor']> = {
    __resolveType: TypeResolveFn<'Bot' | 'Mannequin' | 'Organization' | 'User', ParentType, ContextType>;
};
export type ReactorConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReactorConnection'] = ResolversParentTypes['ReactorConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['ReactorEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Reactor']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReactorEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReactorEdge'] = ResolversParentTypes['ReactorEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<ResolversTypes['Reactor'], ParentType, ContextType>;
    reactedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReadyForReviewEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReadyForReviewEvent'] = ResolversParentTypes['ReadyForReviewEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RefResolvers<ContextType = any, ParentType extends ResolversParentTypes['Ref'] = ResolversParentTypes['Ref']> = {
    associatedPullRequests?: Resolver<ResolversTypes['PullRequestConnection'], ParentType, ContextType, Partial<RefAssociatedPullRequestsArgs>>;
    branchProtectionRule?: Resolver<Maybe<ResolversTypes['BranchProtectionRule']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    prefix?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    refUpdateRule?: Resolver<Maybe<ResolversTypes['RefUpdateRule']>, ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    target?: Resolver<Maybe<ResolversTypes['GitObject']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RefConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['RefConnection'] = ResolversParentTypes['RefConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['RefEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Ref']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RefEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['RefEdge'] = ResolversParentTypes['RefEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Ref']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RefUpdateRuleResolvers<ContextType = any, ParentType extends ResolversParentTypes['RefUpdateRule'] = ResolversParentTypes['RefUpdateRule']> = {
    allowsDeletions?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    allowsForcePushes?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    pattern?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    requiredApprovingReviewCount?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    requiredStatusCheckContexts?: Resolver<Maybe<Array<Maybe<ResolversTypes['String']>>>, ParentType, ContextType>;
    requiresCodeOwnerReviews?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    requiresConversationResolution?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    requiresLinearHistory?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    requiresSignatures?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerAllowedToDismissReviews?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanPush?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReferencedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReferencedEvent'] = ResolversParentTypes['ReferencedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    commit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    commitRepository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isCrossRepository?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isDirectReference?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    subject?: Resolver<ResolversTypes['ReferencedSubject'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReferencedSubjectResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReferencedSubject'] = ResolversParentTypes['ReferencedSubject']> = {
    __resolveType: TypeResolveFn<'Issue' | 'PullRequest', ParentType, ContextType>;
};
export type RegenerateVerifiableDomainTokenPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['RegenerateVerifiableDomainTokenPayload'] = ResolversParentTypes['RegenerateVerifiableDomainTokenPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    verificationToken?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RejectDeploymentsPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['RejectDeploymentsPayload'] = ResolversParentTypes['RejectDeploymentsPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    deployments?: Resolver<Maybe<Array<ResolversTypes['Deployment']>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReleaseResolvers<ContextType = any, ParentType extends ResolversParentTypes['Release'] = ResolversParentTypes['Release']> = {
    author?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    description?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    descriptionHTML?: Resolver<Maybe<ResolversTypes['HTML']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isDraft?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isLatest?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isPrerelease?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    mentions?: Resolver<Maybe<ResolversTypes['UserConnection']>, ParentType, ContextType, Partial<ReleaseMentionsArgs>>;
    name?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    publishedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    reactionGroups?: Resolver<Maybe<Array<ResolversTypes['ReactionGroup']>>, ParentType, ContextType>;
    reactions?: Resolver<ResolversTypes['ReactionConnection'], ParentType, ContextType, Partial<ReleaseReactionsArgs>>;
    releaseAssets?: Resolver<ResolversTypes['ReleaseAssetConnection'], ParentType, ContextType, Partial<ReleaseReleaseAssetsArgs>>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    shortDescriptionHTML?: Resolver<Maybe<ResolversTypes['HTML']>, ParentType, ContextType, RequireFields<ReleaseShortDescriptionHtmlArgs, 'limit'>>;
    tag?: Resolver<Maybe<ResolversTypes['Ref']>, ParentType, ContextType>;
    tagCommit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    tagName?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    viewerCanReact?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReleaseAssetResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReleaseAsset'] = ResolversParentTypes['ReleaseAsset']> = {
    contentType?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    downloadCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    downloadUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    release?: Resolver<Maybe<ResolversTypes['Release']>, ParentType, ContextType>;
    size?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    uploadedBy?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReleaseAssetConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReleaseAssetConnection'] = ResolversParentTypes['ReleaseAssetConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['ReleaseAssetEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['ReleaseAsset']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReleaseAssetEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReleaseAssetEdge'] = ResolversParentTypes['ReleaseAssetEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['ReleaseAsset']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReleaseConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReleaseConnection'] = ResolversParentTypes['ReleaseConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['ReleaseEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Release']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReleaseEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReleaseEdge'] = ResolversParentTypes['ReleaseEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Release']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RemoveAssigneesFromAssignablePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['RemoveAssigneesFromAssignablePayload'] = ResolversParentTypes['RemoveAssigneesFromAssignablePayload']> = {
    assignable?: Resolver<Maybe<ResolversTypes['Assignable']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RemoveEnterpriseAdminPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['RemoveEnterpriseAdminPayload'] = ResolversParentTypes['RemoveEnterpriseAdminPayload']> = {
    admin?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    message?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    viewer?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RemoveLabelsFromLabelablePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['RemoveLabelsFromLabelablePayload'] = ResolversParentTypes['RemoveLabelsFromLabelablePayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    labelable?: Resolver<Maybe<ResolversTypes['Labelable']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RemoveOutsideCollaboratorPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['RemoveOutsideCollaboratorPayload'] = ResolversParentTypes['RemoveOutsideCollaboratorPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    removedUser?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RemoveReactionPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['RemoveReactionPayload'] = ResolversParentTypes['RemoveReactionPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    reaction?: Resolver<Maybe<ResolversTypes['Reaction']>, ParentType, ContextType>;
    subject?: Resolver<Maybe<ResolversTypes['Reactable']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RemoveStarPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['RemoveStarPayload'] = ResolversParentTypes['RemoveStarPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    starrable?: Resolver<Maybe<ResolversTypes['Starrable']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RemoveUpvotePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['RemoveUpvotePayload'] = ResolversParentTypes['RemoveUpvotePayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    subject?: Resolver<Maybe<ResolversTypes['Votable']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RemovedFromProjectEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['RemovedFromProjectEvent'] = ResolversParentTypes['RemovedFromProjectEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    project?: Resolver<Maybe<ResolversTypes['Project']>, ParentType, ContextType>;
    projectColumnName?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RenamedTitleEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['RenamedTitleEvent'] = ResolversParentTypes['RenamedTitleEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    currentTitle?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    previousTitle?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    subject?: Resolver<ResolversTypes['RenamedTitleSubject'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RenamedTitleSubjectResolvers<ContextType = any, ParentType extends ResolversParentTypes['RenamedTitleSubject'] = ResolversParentTypes['RenamedTitleSubject']> = {
    __resolveType: TypeResolveFn<'Issue' | 'PullRequest', ParentType, ContextType>;
};
export type ReopenIssuePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReopenIssuePayload'] = ResolversParentTypes['ReopenIssuePayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    issue?: Resolver<Maybe<ResolversTypes['Issue']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReopenPullRequestPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReopenPullRequestPayload'] = ResolversParentTypes['ReopenPullRequestPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReopenedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReopenedEvent'] = ResolversParentTypes['ReopenedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    closable?: Resolver<ResolversTypes['Closable'], ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoAccessAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoAccessAuditEntry'] = ResolversParentTypes['RepoAccessAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    visibility?: Resolver<Maybe<ResolversTypes['RepoAccessAuditEntryVisibility']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoAddMemberAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoAddMemberAuditEntry'] = ResolversParentTypes['RepoAddMemberAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    visibility?: Resolver<Maybe<ResolversTypes['RepoAddMemberAuditEntryVisibility']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoAddTopicAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoAddTopicAuditEntry'] = ResolversParentTypes['RepoAddTopicAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    topic?: Resolver<Maybe<ResolversTypes['Topic']>, ParentType, ContextType>;
    topicName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoArchivedAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoArchivedAuditEntry'] = ResolversParentTypes['RepoArchivedAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    visibility?: Resolver<Maybe<ResolversTypes['RepoArchivedAuditEntryVisibility']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoChangeMergeSettingAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoChangeMergeSettingAuditEntry'] = ResolversParentTypes['RepoChangeMergeSettingAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isEnabled?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    mergeType?: Resolver<Maybe<ResolversTypes['RepoChangeMergeSettingAuditEntryMergeType']>, ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoConfigDisableAnonymousGitAccessAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoConfigDisableAnonymousGitAccessAuditEntry'] = ResolversParentTypes['RepoConfigDisableAnonymousGitAccessAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoConfigDisableCollaboratorsOnlyAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoConfigDisableCollaboratorsOnlyAuditEntry'] = ResolversParentTypes['RepoConfigDisableCollaboratorsOnlyAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoConfigDisableContributorsOnlyAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoConfigDisableContributorsOnlyAuditEntry'] = ResolversParentTypes['RepoConfigDisableContributorsOnlyAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoConfigDisableSockpuppetDisallowedAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoConfigDisableSockpuppetDisallowedAuditEntry'] = ResolversParentTypes['RepoConfigDisableSockpuppetDisallowedAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoConfigEnableAnonymousGitAccessAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoConfigEnableAnonymousGitAccessAuditEntry'] = ResolversParentTypes['RepoConfigEnableAnonymousGitAccessAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoConfigEnableCollaboratorsOnlyAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoConfigEnableCollaboratorsOnlyAuditEntry'] = ResolversParentTypes['RepoConfigEnableCollaboratorsOnlyAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoConfigEnableContributorsOnlyAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoConfigEnableContributorsOnlyAuditEntry'] = ResolversParentTypes['RepoConfigEnableContributorsOnlyAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoConfigEnableSockpuppetDisallowedAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoConfigEnableSockpuppetDisallowedAuditEntry'] = ResolversParentTypes['RepoConfigEnableSockpuppetDisallowedAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoConfigLockAnonymousGitAccessAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoConfigLockAnonymousGitAccessAuditEntry'] = ResolversParentTypes['RepoConfigLockAnonymousGitAccessAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoConfigUnlockAnonymousGitAccessAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoConfigUnlockAnonymousGitAccessAuditEntry'] = ResolversParentTypes['RepoConfigUnlockAnonymousGitAccessAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoCreateAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoCreateAuditEntry'] = ResolversParentTypes['RepoCreateAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    forkParentName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    forkSourceName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    visibility?: Resolver<Maybe<ResolversTypes['RepoCreateAuditEntryVisibility']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoDestroyAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoDestroyAuditEntry'] = ResolversParentTypes['RepoDestroyAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    visibility?: Resolver<Maybe<ResolversTypes['RepoDestroyAuditEntryVisibility']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoRemoveMemberAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoRemoveMemberAuditEntry'] = ResolversParentTypes['RepoRemoveMemberAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    visibility?: Resolver<Maybe<ResolversTypes['RepoRemoveMemberAuditEntryVisibility']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepoRemoveTopicAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepoRemoveTopicAuditEntry'] = ResolversParentTypes['RepoRemoveTopicAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    topic?: Resolver<Maybe<ResolversTypes['Topic']>, ParentType, ContextType>;
    topicName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepositoryResolvers<ContextType = any, ParentType extends ResolversParentTypes['Repository'] = ResolversParentTypes['Repository']> = {
    assignableUsers?: Resolver<ResolversTypes['UserConnection'], ParentType, ContextType, Partial<RepositoryAssignableUsersArgs>>;
    branchProtectionRules?: Resolver<ResolversTypes['BranchProtectionRuleConnection'], ParentType, ContextType, Partial<RepositoryBranchProtectionRulesArgs>>;
    codeOfConduct?: Resolver<Maybe<ResolversTypes['CodeOfConduct']>, ParentType, ContextType>;
    collaborators?: Resolver<Maybe<ResolversTypes['RepositoryCollaboratorConnection']>, ParentType, ContextType, Partial<RepositoryCollaboratorsArgs>>;
    commitComments?: Resolver<ResolversTypes['CommitCommentConnection'], ParentType, ContextType, Partial<RepositoryCommitCommentsArgs>>;
    contactLinks?: Resolver<Maybe<Array<ResolversTypes['RepositoryContactLink']>>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    defaultBranchRef?: Resolver<Maybe<ResolversTypes['Ref']>, ParentType, ContextType>;
    deleteBranchOnMerge?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    deployKeys?: Resolver<ResolversTypes['DeployKeyConnection'], ParentType, ContextType, Partial<RepositoryDeployKeysArgs>>;
    deployments?: Resolver<ResolversTypes['DeploymentConnection'], ParentType, ContextType, RequireFields<RepositoryDeploymentsArgs, 'orderBy'>>;
    description?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    descriptionHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    discussion?: Resolver<Maybe<ResolversTypes['Discussion']>, ParentType, ContextType, RequireFields<RepositoryDiscussionArgs, 'number'>>;
    discussionCategories?: Resolver<ResolversTypes['DiscussionCategoryConnection'], ParentType, ContextType, Partial<RepositoryDiscussionCategoriesArgs>>;
    discussions?: Resolver<ResolversTypes['DiscussionConnection'], ParentType, ContextType, RequireFields<RepositoryDiscussionsArgs, 'categoryId' | 'orderBy'>>;
    diskUsage?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    environment?: Resolver<Maybe<ResolversTypes['Environment']>, ParentType, ContextType, RequireFields<RepositoryEnvironmentArgs, 'name'>>;
    environments?: Resolver<ResolversTypes['EnvironmentConnection'], ParentType, ContextType, Partial<RepositoryEnvironmentsArgs>>;
    forkCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    forks?: Resolver<ResolversTypes['RepositoryConnection'], ParentType, ContextType, RequireFields<RepositoryForksArgs, 'ownerAffiliations'>>;
    hasAnonymousAccessEnabled?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    hasIssuesEnabled?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    hasProjectsEnabled?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    hasWikiEnabled?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    homepageUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isArchived?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isBlankIssuesEnabled?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isDisabled?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isEmpty?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isFork?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isInOrganization?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isLocked?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isMirror?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isPrivate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isSecurityPolicyEnabled?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    isTemplate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isUserConfigurationRepository?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    issue?: Resolver<Maybe<ResolversTypes['Issue']>, ParentType, ContextType, RequireFields<RepositoryIssueArgs, 'number'>>;
    issueOrPullRequest?: Resolver<Maybe<ResolversTypes['IssueOrPullRequest']>, ParentType, ContextType, RequireFields<RepositoryIssueOrPullRequestArgs, 'number'>>;
    issueTemplates?: Resolver<Maybe<Array<ResolversTypes['IssueTemplate']>>, ParentType, ContextType>;
    issues?: Resolver<ResolversTypes['IssueConnection'], ParentType, ContextType, Partial<RepositoryIssuesArgs>>;
    label?: Resolver<Maybe<ResolversTypes['Label']>, ParentType, ContextType, RequireFields<RepositoryLabelArgs, 'name'>>;
    labels?: Resolver<Maybe<ResolversTypes['LabelConnection']>, ParentType, ContextType, RequireFields<RepositoryLabelsArgs, 'orderBy'>>;
    languages?: Resolver<Maybe<ResolversTypes['LanguageConnection']>, ParentType, ContextType, Partial<RepositoryLanguagesArgs>>;
    latestRelease?: Resolver<Maybe<ResolversTypes['Release']>, ParentType, ContextType>;
    licenseInfo?: Resolver<Maybe<ResolversTypes['License']>, ParentType, ContextType>;
    lockReason?: Resolver<Maybe<ResolversTypes['RepositoryLockReason']>, ParentType, ContextType>;
    mentionableUsers?: Resolver<ResolversTypes['UserConnection'], ParentType, ContextType, Partial<RepositoryMentionableUsersArgs>>;
    mergeCommitAllowed?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    milestone?: Resolver<Maybe<ResolversTypes['Milestone']>, ParentType, ContextType, RequireFields<RepositoryMilestoneArgs, 'number'>>;
    milestones?: Resolver<Maybe<ResolversTypes['MilestoneConnection']>, ParentType, ContextType, Partial<RepositoryMilestonesArgs>>;
    mirrorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    nameWithOwner?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    object?: Resolver<Maybe<ResolversTypes['GitObject']>, ParentType, ContextType, Partial<RepositoryObjectArgs>>;
    openGraphImageUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    owner?: Resolver<ResolversTypes['RepositoryOwner'], ParentType, ContextType>;
    packages?: Resolver<ResolversTypes['PackageConnection'], ParentType, ContextType, RequireFields<RepositoryPackagesArgs, 'orderBy'>>;
    parent?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    pinnedDiscussions?: Resolver<ResolversTypes['PinnedDiscussionConnection'], ParentType, ContextType, Partial<RepositoryPinnedDiscussionsArgs>>;
    pinnedIssues?: Resolver<Maybe<ResolversTypes['PinnedIssueConnection']>, ParentType, ContextType, Partial<RepositoryPinnedIssuesArgs>>;
    primaryLanguage?: Resolver<Maybe<ResolversTypes['Language']>, ParentType, ContextType>;
    project?: Resolver<Maybe<ResolversTypes['Project']>, ParentType, ContextType, RequireFields<RepositoryProjectArgs, 'number'>>;
    projects?: Resolver<ResolversTypes['ProjectConnection'], ParentType, ContextType, Partial<RepositoryProjectsArgs>>;
    projectsResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    projectsUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType, RequireFields<RepositoryPullRequestArgs, 'number'>>;
    pullRequestTemplates?: Resolver<Maybe<Array<ResolversTypes['PullRequestTemplate']>>, ParentType, ContextType>;
    pullRequests?: Resolver<ResolversTypes['PullRequestConnection'], ParentType, ContextType, Partial<RepositoryPullRequestsArgs>>;
    pushedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    rebaseMergeAllowed?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    ref?: Resolver<Maybe<ResolversTypes['Ref']>, ParentType, ContextType, RequireFields<RepositoryRefArgs, 'qualifiedName'>>;
    refs?: Resolver<Maybe<ResolversTypes['RefConnection']>, ParentType, ContextType, RequireFields<RepositoryRefsArgs, 'refPrefix'>>;
    release?: Resolver<Maybe<ResolversTypes['Release']>, ParentType, ContextType, RequireFields<RepositoryReleaseArgs, 'tagName'>>;
    releases?: Resolver<ResolversTypes['ReleaseConnection'], ParentType, ContextType, Partial<RepositoryReleasesArgs>>;
    repositoryTopics?: Resolver<ResolversTypes['RepositoryTopicConnection'], ParentType, ContextType, Partial<RepositoryRepositoryTopicsArgs>>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    securityPolicyUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    shortDescriptionHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType, RequireFields<RepositoryShortDescriptionHtmlArgs, 'limit'>>;
    squashMergeAllowed?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    sshUrl?: Resolver<ResolversTypes['GitSSHRemote'], ParentType, ContextType>;
    stargazerCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    stargazers?: Resolver<ResolversTypes['StargazerConnection'], ParentType, ContextType, Partial<RepositoryStargazersArgs>>;
    submodules?: Resolver<ResolversTypes['SubmoduleConnection'], ParentType, ContextType, Partial<RepositorySubmodulesArgs>>;
    tempCloneToken?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    templateRepository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    usesCustomOpenGraphImage?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanAdminister?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanCreateProjects?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanSubscribe?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanUpdateTopics?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerDefaultCommitEmail?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    viewerDefaultMergeMethod?: Resolver<ResolversTypes['PullRequestMergeMethod'], ParentType, ContextType>;
    viewerHasStarred?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerPermission?: Resolver<Maybe<ResolversTypes['RepositoryPermission']>, ParentType, ContextType>;
    viewerPossibleCommitEmails?: Resolver<Maybe<Array<ResolversTypes['String']>>, ParentType, ContextType>;
    viewerSubscription?: Resolver<Maybe<ResolversTypes['SubscriptionState']>, ParentType, ContextType>;
    visibility?: Resolver<ResolversTypes['RepositoryVisibility'], ParentType, ContextType>;
    vulnerabilityAlerts?: Resolver<Maybe<ResolversTypes['RepositoryVulnerabilityAlertConnection']>, ParentType, ContextType, Partial<RepositoryVulnerabilityAlertsArgs>>;
    watchers?: Resolver<ResolversTypes['UserConnection'], ParentType, ContextType, Partial<RepositoryWatchersArgs>>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepositoryAuditEntryDataResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryAuditEntryData'] = ResolversParentTypes['RepositoryAuditEntryData']> = {
    __resolveType: TypeResolveFn<'OrgRestoreMemberMembershipRepositoryAuditEntryData' | 'PrivateRepositoryForkingDisableAuditEntry' | 'PrivateRepositoryForkingEnableAuditEntry' | 'RepoAccessAuditEntry' | 'RepoAddMemberAuditEntry' | 'RepoAddTopicAuditEntry' | 'RepoArchivedAuditEntry' | 'RepoChangeMergeSettingAuditEntry' | 'RepoConfigDisableAnonymousGitAccessAuditEntry' | 'RepoConfigDisableCollaboratorsOnlyAuditEntry' | 'RepoConfigDisableContributorsOnlyAuditEntry' | 'RepoConfigDisableSockpuppetDisallowedAuditEntry' | 'RepoConfigEnableAnonymousGitAccessAuditEntry' | 'RepoConfigEnableCollaboratorsOnlyAuditEntry' | 'RepoConfigEnableContributorsOnlyAuditEntry' | 'RepoConfigEnableSockpuppetDisallowedAuditEntry' | 'RepoConfigLockAnonymousGitAccessAuditEntry' | 'RepoConfigUnlockAnonymousGitAccessAuditEntry' | 'RepoCreateAuditEntry' | 'RepoDestroyAuditEntry' | 'RepoRemoveMemberAuditEntry' | 'RepoRemoveTopicAuditEntry' | 'TeamAddRepositoryAuditEntry' | 'TeamRemoveRepositoryAuditEntry', ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
};
export type RepositoryCollaboratorConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryCollaboratorConnection'] = ResolversParentTypes['RepositoryCollaboratorConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['RepositoryCollaboratorEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['User']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepositoryCollaboratorEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryCollaboratorEdge'] = ResolversParentTypes['RepositoryCollaboratorEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    permission?: Resolver<ResolversTypes['RepositoryPermission'], ParentType, ContextType>;
    permissionSources?: Resolver<Maybe<Array<ResolversTypes['PermissionSource']>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepositoryConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryConnection'] = ResolversParentTypes['RepositoryConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['RepositoryEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Repository']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    totalDiskUsage?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepositoryContactLinkResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryContactLink'] = ResolversParentTypes['RepositoryContactLink']> = {
    about?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepositoryDiscussionAuthorResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryDiscussionAuthor'] = ResolversParentTypes['RepositoryDiscussionAuthor']> = {
    __resolveType: TypeResolveFn<'Organization' | 'User', ParentType, ContextType>;
    repositoryDiscussions?: Resolver<ResolversTypes['DiscussionConnection'], ParentType, ContextType, RequireFields<RepositoryDiscussionAuthorRepositoryDiscussionsArgs, 'answered' | 'orderBy'>>;
};
export type RepositoryDiscussionCommentAuthorResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryDiscussionCommentAuthor'] = ResolversParentTypes['RepositoryDiscussionCommentAuthor']> = {
    __resolveType: TypeResolveFn<'Organization' | 'User', ParentType, ContextType>;
    repositoryDiscussionComments?: Resolver<ResolversTypes['DiscussionCommentConnection'], ParentType, ContextType, RequireFields<RepositoryDiscussionCommentAuthorRepositoryDiscussionCommentsArgs, 'onlyAnswers'>>;
};
export type RepositoryEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryEdge'] = ResolversParentTypes['RepositoryEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepositoryInfoResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryInfo'] = ResolversParentTypes['RepositoryInfo']> = {
    __resolveType: TypeResolveFn<'Repository', ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    description?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    descriptionHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    forkCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    hasAnonymousAccessEnabled?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    hasIssuesEnabled?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    hasProjectsEnabled?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    hasWikiEnabled?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    homepageUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    isArchived?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isFork?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isInOrganization?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isLocked?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isMirror?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isPrivate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isTemplate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    licenseInfo?: Resolver<Maybe<ResolversTypes['License']>, ParentType, ContextType>;
    lockReason?: Resolver<Maybe<ResolversTypes['RepositoryLockReason']>, ParentType, ContextType>;
    mirrorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    nameWithOwner?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    openGraphImageUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    owner?: Resolver<ResolversTypes['RepositoryOwner'], ParentType, ContextType>;
    pushedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    shortDescriptionHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType, RequireFields<RepositoryInfoShortDescriptionHtmlArgs, 'limit'>>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    usesCustomOpenGraphImage?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    visibility?: Resolver<ResolversTypes['RepositoryVisibility'], ParentType, ContextType>;
};
export type RepositoryInvitationResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryInvitation'] = ResolversParentTypes['RepositoryInvitation']> = {
    email?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    invitee?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    inviter?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    permalink?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    permission?: Resolver<ResolversTypes['RepositoryPermission'], ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['RepositoryInfo']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepositoryInvitationConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryInvitationConnection'] = ResolversParentTypes['RepositoryInvitationConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['RepositoryInvitationEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['RepositoryInvitation']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepositoryInvitationEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryInvitationEdge'] = ResolversParentTypes['RepositoryInvitationEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['RepositoryInvitation']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepositoryNodeResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryNode'] = ResolversParentTypes['RepositoryNode']> = {
    __resolveType: TypeResolveFn<'CommitComment' | 'CommitCommentThread' | 'Discussion' | 'DiscussionCategory' | 'Issue' | 'IssueComment' | 'PinnedDiscussion' | 'PullRequest' | 'PullRequestCommitCommentThread' | 'PullRequestReview' | 'PullRequestReviewComment' | 'RepositoryVulnerabilityAlert', ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
};
export type RepositoryOwnerResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryOwner'] = ResolversParentTypes['RepositoryOwner']> = {
    __resolveType: TypeResolveFn<'Organization' | 'User', ParentType, ContextType>;
    avatarUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType, Partial<RepositoryOwnerAvatarUrlArgs>>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    login?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    repositories?: Resolver<ResolversTypes['RepositoryConnection'], ParentType, ContextType, RequireFields<RepositoryOwnerRepositoriesArgs, 'ownerAffiliations'>>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType, RequireFields<RepositoryOwnerRepositoryArgs, 'name'>>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
};
export type RepositoryTopicResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryTopic'] = ResolversParentTypes['RepositoryTopic']> = {
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    topic?: Resolver<ResolversTypes['Topic'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepositoryTopicConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryTopicConnection'] = ResolversParentTypes['RepositoryTopicConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['RepositoryTopicEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['RepositoryTopic']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepositoryTopicEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryTopicEdge'] = ResolversParentTypes['RepositoryTopicEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['RepositoryTopic']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepositoryVisibilityChangeDisableAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryVisibilityChangeDisableAuditEntry'] = ResolversParentTypes['RepositoryVisibilityChangeDisableAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    enterpriseResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    enterpriseSlug?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterpriseUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepositoryVisibilityChangeEnableAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryVisibilityChangeEnableAuditEntry'] = ResolversParentTypes['RepositoryVisibilityChangeEnableAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    enterpriseResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    enterpriseSlug?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterpriseUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepositoryVulnerabilityAlertResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryVulnerabilityAlert'] = ResolversParentTypes['RepositoryVulnerabilityAlert']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    dismissReason?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    dismissedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    dismisser?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    securityAdvisory?: Resolver<Maybe<ResolversTypes['SecurityAdvisory']>, ParentType, ContextType>;
    securityVulnerability?: Resolver<Maybe<ResolversTypes['SecurityVulnerability']>, ParentType, ContextType>;
    vulnerableManifestFilename?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    vulnerableManifestPath?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    vulnerableRequirements?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepositoryVulnerabilityAlertConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryVulnerabilityAlertConnection'] = ResolversParentTypes['RepositoryVulnerabilityAlertConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['RepositoryVulnerabilityAlertEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['RepositoryVulnerabilityAlert']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RepositoryVulnerabilityAlertEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['RepositoryVulnerabilityAlertEdge'] = ResolversParentTypes['RepositoryVulnerabilityAlertEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['RepositoryVulnerabilityAlert']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RequestReviewsPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['RequestReviewsPayload'] = ResolversParentTypes['RequestReviewsPayload']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    requestedReviewersEdge?: Resolver<Maybe<ResolversTypes['UserEdge']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RequestedReviewerResolvers<ContextType = any, ParentType extends ResolversParentTypes['RequestedReviewer'] = ResolversParentTypes['RequestedReviewer']> = {
    __resolveType: TypeResolveFn<'Mannequin' | 'Team' | 'User', ParentType, ContextType>;
};
export type RequirableByPullRequestResolvers<ContextType = any, ParentType extends ResolversParentTypes['RequirableByPullRequest'] = ResolversParentTypes['RequirableByPullRequest']> = {
    __resolveType: TypeResolveFn<'CheckRun' | 'StatusContext', ParentType, ContextType>;
    isRequired?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType, Partial<RequirableByPullRequestIsRequiredArgs>>;
};
export type RerequestCheckSuitePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['RerequestCheckSuitePayload'] = ResolversParentTypes['RerequestCheckSuitePayload']> = {
    checkSuite?: Resolver<Maybe<ResolversTypes['CheckSuite']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ResolveReviewThreadPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['ResolveReviewThreadPayload'] = ResolversParentTypes['ResolveReviewThreadPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    thread?: Resolver<Maybe<ResolversTypes['PullRequestReviewThread']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type RestrictedContributionResolvers<ContextType = any, ParentType extends ResolversParentTypes['RestrictedContribution'] = ResolversParentTypes['RestrictedContribution']> = {
    isRestricted?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    occurredAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    user?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReviewDismissalAllowanceResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReviewDismissalAllowance'] = ResolversParentTypes['ReviewDismissalAllowance']> = {
    actor?: Resolver<Maybe<ResolversTypes['ReviewDismissalAllowanceActor']>, ParentType, ContextType>;
    branchProtectionRule?: Resolver<Maybe<ResolversTypes['BranchProtectionRule']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReviewDismissalAllowanceActorResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReviewDismissalAllowanceActor'] = ResolversParentTypes['ReviewDismissalAllowanceActor']> = {
    __resolveType: TypeResolveFn<'Team' | 'User', ParentType, ContextType>;
};
export type ReviewDismissalAllowanceConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReviewDismissalAllowanceConnection'] = ResolversParentTypes['ReviewDismissalAllowanceConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['ReviewDismissalAllowanceEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['ReviewDismissalAllowance']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReviewDismissalAllowanceEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReviewDismissalAllowanceEdge'] = ResolversParentTypes['ReviewDismissalAllowanceEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['ReviewDismissalAllowance']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReviewDismissedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReviewDismissedEvent'] = ResolversParentTypes['ReviewDismissedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    dismissalMessage?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    dismissalMessageHTML?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    previousReviewState?: Resolver<ResolversTypes['PullRequestReviewState'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    pullRequestCommit?: Resolver<Maybe<ResolversTypes['PullRequestCommit']>, ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    review?: Resolver<Maybe<ResolversTypes['PullRequestReview']>, ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReviewRequestResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReviewRequest'] = ResolversParentTypes['ReviewRequest']> = {
    asCodeOwner?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    requestedReviewer?: Resolver<Maybe<ResolversTypes['RequestedReviewer']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReviewRequestConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReviewRequestConnection'] = ResolversParentTypes['ReviewRequestConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['ReviewRequestEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['ReviewRequest']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReviewRequestEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReviewRequestEdge'] = ResolversParentTypes['ReviewRequestEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['ReviewRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReviewRequestRemovedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReviewRequestRemovedEvent'] = ResolversParentTypes['ReviewRequestRemovedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    requestedReviewer?: Resolver<Maybe<ResolversTypes['RequestedReviewer']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReviewRequestedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReviewRequestedEvent'] = ResolversParentTypes['ReviewRequestedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pullRequest?: Resolver<ResolversTypes['PullRequest'], ParentType, ContextType>;
    requestedReviewer?: Resolver<Maybe<ResolversTypes['RequestedReviewer']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ReviewStatusHovercardContextResolvers<ContextType = any, ParentType extends ResolversParentTypes['ReviewStatusHovercardContext'] = ResolversParentTypes['ReviewStatusHovercardContext']> = {
    message?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    octicon?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    reviewDecision?: Resolver<Maybe<ResolversTypes['PullRequestReviewDecision']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SavedReplyResolvers<ContextType = any, ParentType extends ResolversParentTypes['SavedReply'] = ResolversParentTypes['SavedReply']> = {
    body?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    bodyHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    title?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SavedReplyConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['SavedReplyConnection'] = ResolversParentTypes['SavedReplyConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['SavedReplyEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['SavedReply']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SavedReplyEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['SavedReplyEdge'] = ResolversParentTypes['SavedReplyEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['SavedReply']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SearchResultItemResolvers<ContextType = any, ParentType extends ResolversParentTypes['SearchResultItem'] = ResolversParentTypes['SearchResultItem']> = {
    __resolveType: TypeResolveFn<'App' | 'Discussion' | 'Issue' | 'Organization' | 'PullRequest' | 'Repository' | 'User', ParentType, ContextType>;
};
export type SearchResultItemConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['SearchResultItemConnection'] = ResolversParentTypes['SearchResultItemConnection']> = {
    codeCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    discussionCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['SearchResultItemEdge']>>>, ParentType, ContextType>;
    issueCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['SearchResultItem']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    repositoryCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    userCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    wikiCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SearchResultItemEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['SearchResultItemEdge'] = ResolversParentTypes['SearchResultItemEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['SearchResultItem']>, ParentType, ContextType>;
    textMatches?: Resolver<Maybe<Array<Maybe<ResolversTypes['TextMatch']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SecurityAdvisoryResolvers<ContextType = any, ParentType extends ResolversParentTypes['SecurityAdvisory'] = ResolversParentTypes['SecurityAdvisory']> = {
    cvss?: Resolver<ResolversTypes['CVSS'], ParentType, ContextType>;
    cwes?: Resolver<ResolversTypes['CWEConnection'], ParentType, ContextType, Partial<SecurityAdvisoryCwesArgs>>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    description?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    ghsaId?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    identifiers?: Resolver<Array<ResolversTypes['SecurityAdvisoryIdentifier']>, ParentType, ContextType>;
    notificationsPermalink?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    origin?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    permalink?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    publishedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    references?: Resolver<Array<ResolversTypes['SecurityAdvisoryReference']>, ParentType, ContextType>;
    severity?: Resolver<ResolversTypes['SecurityAdvisorySeverity'], ParentType, ContextType>;
    summary?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    vulnerabilities?: Resolver<ResolversTypes['SecurityVulnerabilityConnection'], ParentType, ContextType, Partial<SecurityAdvisoryVulnerabilitiesArgs>>;
    withdrawnAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SecurityAdvisoryConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['SecurityAdvisoryConnection'] = ResolversParentTypes['SecurityAdvisoryConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['SecurityAdvisoryEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['SecurityAdvisory']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SecurityAdvisoryEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['SecurityAdvisoryEdge'] = ResolversParentTypes['SecurityAdvisoryEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['SecurityAdvisory']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SecurityAdvisoryIdentifierResolvers<ContextType = any, ParentType extends ResolversParentTypes['SecurityAdvisoryIdentifier'] = ResolversParentTypes['SecurityAdvisoryIdentifier']> = {
    type?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    value?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SecurityAdvisoryPackageResolvers<ContextType = any, ParentType extends ResolversParentTypes['SecurityAdvisoryPackage'] = ResolversParentTypes['SecurityAdvisoryPackage']> = {
    ecosystem?: Resolver<ResolversTypes['SecurityAdvisoryEcosystem'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SecurityAdvisoryPackageVersionResolvers<ContextType = any, ParentType extends ResolversParentTypes['SecurityAdvisoryPackageVersion'] = ResolversParentTypes['SecurityAdvisoryPackageVersion']> = {
    identifier?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SecurityAdvisoryReferenceResolvers<ContextType = any, ParentType extends ResolversParentTypes['SecurityAdvisoryReference'] = ResolversParentTypes['SecurityAdvisoryReference']> = {
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SecurityVulnerabilityResolvers<ContextType = any, ParentType extends ResolversParentTypes['SecurityVulnerability'] = ResolversParentTypes['SecurityVulnerability']> = {
    advisory?: Resolver<ResolversTypes['SecurityAdvisory'], ParentType, ContextType>;
    firstPatchedVersion?: Resolver<Maybe<ResolversTypes['SecurityAdvisoryPackageVersion']>, ParentType, ContextType>;
    package?: Resolver<ResolversTypes['SecurityAdvisoryPackage'], ParentType, ContextType>;
    severity?: Resolver<ResolversTypes['SecurityAdvisorySeverity'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    vulnerableVersionRange?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SecurityVulnerabilityConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['SecurityVulnerabilityConnection'] = ResolversParentTypes['SecurityVulnerabilityConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['SecurityVulnerabilityEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['SecurityVulnerability']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SecurityVulnerabilityEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['SecurityVulnerabilityEdge'] = ResolversParentTypes['SecurityVulnerabilityEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['SecurityVulnerability']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SmimeSignatureResolvers<ContextType = any, ParentType extends ResolversParentTypes['SmimeSignature'] = ResolversParentTypes['SmimeSignature']> = {
    email?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    isValid?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    payload?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    signature?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    signer?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    state?: Resolver<ResolversTypes['GitSignatureState'], ParentType, ContextType>;
    wasSignedByGitHub?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SponsorResolvers<ContextType = any, ParentType extends ResolversParentTypes['Sponsor'] = ResolversParentTypes['Sponsor']> = {
    __resolveType: TypeResolveFn<'Organization' | 'User', ParentType, ContextType>;
};
export type SponsorableResolvers<ContextType = any, ParentType extends ResolversParentTypes['Sponsorable'] = ResolversParentTypes['Sponsorable']> = {
    __resolveType: TypeResolveFn<'Organization' | 'User', ParentType, ContextType>;
    sponsorshipsAsMaintainer?: Resolver<ResolversTypes['SponsorshipConnection'], ParentType, ContextType, RequireFields<SponsorableSponsorshipsAsMaintainerArgs, 'includePrivate'>>;
    sponsorshipsAsSponsor?: Resolver<ResolversTypes['SponsorshipConnection'], ParentType, ContextType, Partial<SponsorableSponsorshipsAsSponsorArgs>>;
};
export type SponsorshipResolvers<ContextType = any, ParentType extends ResolversParentTypes['Sponsorship'] = ResolversParentTypes['Sponsorship']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isOneTimePayment?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    maintainer?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    privacyLevel?: Resolver<ResolversTypes['SponsorshipPrivacy'], ParentType, ContextType>;
    sponsor?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    sponsorEntity?: Resolver<Maybe<ResolversTypes['Sponsor']>, ParentType, ContextType>;
    sponsorable?: Resolver<ResolversTypes['Sponsorable'], ParentType, ContextType>;
    tierSelectedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SponsorshipConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['SponsorshipConnection'] = ResolversParentTypes['SponsorshipConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['SponsorshipEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Sponsorship']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SponsorshipEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['SponsorshipEdge'] = ResolversParentTypes['SponsorshipEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Sponsorship']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type StargazerConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['StargazerConnection'] = ResolversParentTypes['StargazerConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['StargazerEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['User']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type StargazerEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['StargazerEdge'] = ResolversParentTypes['StargazerEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    starredAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type StarrableResolvers<ContextType = any, ParentType extends ResolversParentTypes['Starrable'] = ResolversParentTypes['Starrable']> = {
    __resolveType: TypeResolveFn<'Gist' | 'Repository' | 'Topic', ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    stargazerCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    stargazers?: Resolver<ResolversTypes['StargazerConnection'], ParentType, ContextType, Partial<StarrableStargazersArgs>>;
    viewerHasStarred?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
};
export type StarredRepositoryConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['StarredRepositoryConnection'] = ResolversParentTypes['StarredRepositoryConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['StarredRepositoryEdge']>>>, ParentType, ContextType>;
    isOverLimit?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Repository']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type StarredRepositoryEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['StarredRepositoryEdge'] = ResolversParentTypes['StarredRepositoryEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    starredAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type StatusResolvers<ContextType = any, ParentType extends ResolversParentTypes['Status'] = ResolversParentTypes['Status']> = {
    combinedContexts?: Resolver<ResolversTypes['StatusCheckRollupContextConnection'], ParentType, ContextType, Partial<StatusCombinedContextsArgs>>;
    commit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    context?: Resolver<Maybe<ResolversTypes['StatusContext']>, ParentType, ContextType, RequireFields<StatusContextArgs, 'name'>>;
    contexts?: Resolver<Array<ResolversTypes['StatusContext']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    state?: Resolver<ResolversTypes['StatusState'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type StatusCheckRollupResolvers<ContextType = any, ParentType extends ResolversParentTypes['StatusCheckRollup'] = ResolversParentTypes['StatusCheckRollup']> = {
    commit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    contexts?: Resolver<ResolversTypes['StatusCheckRollupContextConnection'], ParentType, ContextType, Partial<StatusCheckRollupContextsArgs>>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    state?: Resolver<ResolversTypes['StatusState'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type StatusCheckRollupContextResolvers<ContextType = any, ParentType extends ResolversParentTypes['StatusCheckRollupContext'] = ResolversParentTypes['StatusCheckRollupContext']> = {
    __resolveType: TypeResolveFn<'CheckRun' | 'StatusContext', ParentType, ContextType>;
};
export type StatusCheckRollupContextConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['StatusCheckRollupContextConnection'] = ResolversParentTypes['StatusCheckRollupContextConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['StatusCheckRollupContextEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['StatusCheckRollupContext']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type StatusCheckRollupContextEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['StatusCheckRollupContextEdge'] = ResolversParentTypes['StatusCheckRollupContextEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['StatusCheckRollupContext']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type StatusContextResolvers<ContextType = any, ParentType extends ResolversParentTypes['StatusContext'] = ResolversParentTypes['StatusContext']> = {
    avatarUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType, RequireFields<StatusContextAvatarUrlArgs, 'size'>>;
    commit?: Resolver<Maybe<ResolversTypes['Commit']>, ParentType, ContextType>;
    context?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    creator?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    description?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isRequired?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType, Partial<StatusContextIsRequiredArgs>>;
    state?: Resolver<ResolversTypes['StatusState'], ParentType, ContextType>;
    targetUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SubmitPullRequestReviewPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['SubmitPullRequestReviewPayload'] = ResolversParentTypes['SubmitPullRequestReviewPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequestReview?: Resolver<Maybe<ResolversTypes['PullRequestReview']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SubmoduleResolvers<ContextType = any, ParentType extends ResolversParentTypes['Submodule'] = ResolversParentTypes['Submodule']> = {
    branch?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    gitUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    path?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    subprojectCommitOid?: Resolver<Maybe<ResolversTypes['GitObjectID']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SubmoduleConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['SubmoduleConnection'] = ResolversParentTypes['SubmoduleConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['SubmoduleEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Submodule']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SubmoduleEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['SubmoduleEdge'] = ResolversParentTypes['SubmoduleEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Submodule']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SubscribableResolvers<ContextType = any, ParentType extends ResolversParentTypes['Subscribable'] = ResolversParentTypes['Subscribable']> = {
    __resolveType: TypeResolveFn<'Commit' | 'Discussion' | 'Issue' | 'PullRequest' | 'Repository' | 'Team' | 'TeamDiscussion', ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    viewerCanSubscribe?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerSubscription?: Resolver<Maybe<ResolversTypes['SubscriptionState']>, ParentType, ContextType>;
};
export type SubscribedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['SubscribedEvent'] = ResolversParentTypes['SubscribedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    subscribable?: Resolver<ResolversTypes['Subscribable'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type SuggestedReviewerResolvers<ContextType = any, ParentType extends ResolversParentTypes['SuggestedReviewer'] = ResolversParentTypes['SuggestedReviewer']> = {
    isAuthor?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isCommenter?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    reviewer?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TagResolvers<ContextType = any, ParentType extends ResolversParentTypes['Tag'] = ResolversParentTypes['Tag']> = {
    abbreviatedOid?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    commitResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    commitUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    message?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    oid?: Resolver<ResolversTypes['GitObjectID'], ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    tagger?: Resolver<Maybe<ResolversTypes['GitActor']>, ParentType, ContextType>;
    target?: Resolver<ResolversTypes['GitObject'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamResolvers<ContextType = any, ParentType extends ResolversParentTypes['Team'] = ResolversParentTypes['Team']> = {
    ancestors?: Resolver<ResolversTypes['TeamConnection'], ParentType, ContextType, Partial<TeamAncestorsArgs>>;
    avatarUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType, RequireFields<TeamAvatarUrlArgs, 'size'>>;
    childTeams?: Resolver<ResolversTypes['TeamConnection'], ParentType, ContextType, RequireFields<TeamChildTeamsArgs, 'immediateOnly'>>;
    combinedSlug?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    description?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    discussion?: Resolver<Maybe<ResolversTypes['TeamDiscussion']>, ParentType, ContextType, RequireFields<TeamDiscussionArgs, 'number'>>;
    discussions?: Resolver<ResolversTypes['TeamDiscussionConnection'], ParentType, ContextType, Partial<TeamDiscussionsArgs>>;
    discussionsResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    discussionsUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    editTeamResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    editTeamUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    invitations?: Resolver<Maybe<ResolversTypes['OrganizationInvitationConnection']>, ParentType, ContextType, Partial<TeamInvitationsArgs>>;
    memberStatuses?: Resolver<ResolversTypes['UserStatusConnection'], ParentType, ContextType, RequireFields<TeamMemberStatusesArgs, 'orderBy'>>;
    members?: Resolver<ResolversTypes['TeamMemberConnection'], ParentType, ContextType, RequireFields<TeamMembersArgs, 'membership'>>;
    membersResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    membersUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    newTeamResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    newTeamUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    organization?: Resolver<ResolversTypes['Organization'], ParentType, ContextType>;
    parentTeam?: Resolver<Maybe<ResolversTypes['Team']>, ParentType, ContextType>;
    privacy?: Resolver<ResolversTypes['TeamPrivacy'], ParentType, ContextType>;
    repositories?: Resolver<ResolversTypes['TeamRepositoryConnection'], ParentType, ContextType, Partial<TeamRepositoriesArgs>>;
    repositoriesResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    repositoriesUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    reviewRequestDelegationAlgorithm?: Resolver<Maybe<ResolversTypes['TeamReviewAssignmentAlgorithm']>, ParentType, ContextType>;
    reviewRequestDelegationEnabled?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    reviewRequestDelegationMemberCount?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    reviewRequestDelegationNotifyTeam?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    slug?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    teamsResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    teamsUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    viewerCanAdminister?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanSubscribe?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerSubscription?: Resolver<Maybe<ResolversTypes['SubscriptionState']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamAddMemberAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamAddMemberAuditEntry'] = ResolversParentTypes['TeamAddMemberAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isLdapMapped?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    team?: Resolver<Maybe<ResolversTypes['Team']>, ParentType, ContextType>;
    teamName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    teamResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    teamUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamAddRepositoryAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamAddRepositoryAuditEntry'] = ResolversParentTypes['TeamAddRepositoryAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isLdapMapped?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    team?: Resolver<Maybe<ResolversTypes['Team']>, ParentType, ContextType>;
    teamName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    teamResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    teamUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamAuditEntryDataResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamAuditEntryData'] = ResolversParentTypes['TeamAuditEntryData']> = {
    __resolveType: TypeResolveFn<'OrgRestoreMemberMembershipTeamAuditEntryData' | 'TeamAddMemberAuditEntry' | 'TeamAddRepositoryAuditEntry' | 'TeamChangeParentTeamAuditEntry' | 'TeamRemoveMemberAuditEntry' | 'TeamRemoveRepositoryAuditEntry', ParentType, ContextType>;
    team?: Resolver<Maybe<ResolversTypes['Team']>, ParentType, ContextType>;
    teamName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    teamResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    teamUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
};
export type TeamChangeParentTeamAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamChangeParentTeamAuditEntry'] = ResolversParentTypes['TeamChangeParentTeamAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isLdapMapped?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    parentTeam?: Resolver<Maybe<ResolversTypes['Team']>, ParentType, ContextType>;
    parentTeamName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    parentTeamNameWas?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    parentTeamResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    parentTeamUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    parentTeamWas?: Resolver<Maybe<ResolversTypes['Team']>, ParentType, ContextType>;
    parentTeamWasResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    parentTeamWasUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    team?: Resolver<Maybe<ResolversTypes['Team']>, ParentType, ContextType>;
    teamName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    teamResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    teamUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamConnection'] = ResolversParentTypes['TeamConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['TeamEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Team']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamDiscussionResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamDiscussion'] = ResolversParentTypes['TeamDiscussion']> = {
    author?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    authorAssociation?: Resolver<ResolversTypes['CommentAuthorAssociation'], ParentType, ContextType>;
    body?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    bodyHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    bodyText?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    bodyVersion?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    comments?: Resolver<ResolversTypes['TeamDiscussionCommentConnection'], ParentType, ContextType, Partial<TeamDiscussionCommentsArgs>>;
    commentsResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    commentsUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    createdViaEmail?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    editor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    includesCreatedEdit?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isPinned?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isPrivate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    lastEditedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    number?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    publishedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    reactionGroups?: Resolver<Maybe<Array<ResolversTypes['ReactionGroup']>>, ParentType, ContextType>;
    reactions?: Resolver<ResolversTypes['ReactionConnection'], ParentType, ContextType, Partial<TeamDiscussionReactionsArgs>>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    team?: Resolver<ResolversTypes['Team'], ParentType, ContextType>;
    title?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    userContentEdits?: Resolver<Maybe<ResolversTypes['UserContentEditConnection']>, ParentType, ContextType, Partial<TeamDiscussionUserContentEditsArgs>>;
    viewerCanDelete?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanPin?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanReact?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanSubscribe?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanUpdate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCannotUpdateReasons?: Resolver<Array<ResolversTypes['CommentCannotUpdateReason']>, ParentType, ContextType>;
    viewerDidAuthor?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerSubscription?: Resolver<Maybe<ResolversTypes['SubscriptionState']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamDiscussionCommentResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamDiscussionComment'] = ResolversParentTypes['TeamDiscussionComment']> = {
    author?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    authorAssociation?: Resolver<ResolversTypes['CommentAuthorAssociation'], ParentType, ContextType>;
    body?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    bodyHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    bodyText?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    bodyVersion?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    createdViaEmail?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    discussion?: Resolver<ResolversTypes['TeamDiscussion'], ParentType, ContextType>;
    editor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    includesCreatedEdit?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    lastEditedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    number?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    publishedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    reactionGroups?: Resolver<Maybe<Array<ResolversTypes['ReactionGroup']>>, ParentType, ContextType>;
    reactions?: Resolver<ResolversTypes['ReactionConnection'], ParentType, ContextType, Partial<TeamDiscussionCommentReactionsArgs>>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    userContentEdits?: Resolver<Maybe<ResolversTypes['UserContentEditConnection']>, ParentType, ContextType, Partial<TeamDiscussionCommentUserContentEditsArgs>>;
    viewerCanDelete?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanReact?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanUpdate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCannotUpdateReasons?: Resolver<Array<ResolversTypes['CommentCannotUpdateReason']>, ParentType, ContextType>;
    viewerDidAuthor?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamDiscussionCommentConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamDiscussionCommentConnection'] = ResolversParentTypes['TeamDiscussionCommentConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['TeamDiscussionCommentEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['TeamDiscussionComment']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamDiscussionCommentEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamDiscussionCommentEdge'] = ResolversParentTypes['TeamDiscussionCommentEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['TeamDiscussionComment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamDiscussionConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamDiscussionConnection'] = ResolversParentTypes['TeamDiscussionConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['TeamDiscussionEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['TeamDiscussion']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamDiscussionEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamDiscussionEdge'] = ResolversParentTypes['TeamDiscussionEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['TeamDiscussion']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamEdge'] = ResolversParentTypes['TeamEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['Team']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamMemberConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamMemberConnection'] = ResolversParentTypes['TeamMemberConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['TeamMemberEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['User']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamMemberEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamMemberEdge'] = ResolversParentTypes['TeamMemberEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    memberAccessResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    memberAccessUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    node?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    role?: Resolver<ResolversTypes['TeamMemberRole'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamRemoveMemberAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamRemoveMemberAuditEntry'] = ResolversParentTypes['TeamRemoveMemberAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isLdapMapped?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    team?: Resolver<Maybe<ResolversTypes['Team']>, ParentType, ContextType>;
    teamName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    teamResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    teamUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamRemoveRepositoryAuditEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamRemoveRepositoryAuditEntry'] = ResolversParentTypes['TeamRemoveRepositoryAuditEntry']> = {
    action?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    actor?: Resolver<Maybe<ResolversTypes['AuditEntryActor']>, ParentType, ContextType>;
    actorIp?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorLocation?: Resolver<Maybe<ResolversTypes['ActorLocation']>, ParentType, ContextType>;
    actorLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    actorResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    actorUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['PreciseDateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isLdapMapped?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    operationType?: Resolver<Maybe<ResolversTypes['OperationType']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    organizationName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organizationResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    organizationUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    repositoryName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repositoryResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    repositoryUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    team?: Resolver<Maybe<ResolversTypes['Team']>, ParentType, ContextType>;
    teamName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    teamResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    teamUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    userLogin?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    userResourcePath?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    userUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamRepositoryConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamRepositoryConnection'] = ResolversParentTypes['TeamRepositoryConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['TeamRepositoryEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['Repository']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TeamRepositoryEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['TeamRepositoryEdge'] = ResolversParentTypes['TeamRepositoryEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    permission?: Resolver<ResolversTypes['RepositoryPermission'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TextMatchResolvers<ContextType = any, ParentType extends ResolversParentTypes['TextMatch'] = ResolversParentTypes['TextMatch']> = {
    fragment?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    highlights?: Resolver<Array<ResolversTypes['TextMatchHighlight']>, ParentType, ContextType>;
    property?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TextMatchHighlightResolvers<ContextType = any, ParentType extends ResolversParentTypes['TextMatchHighlight'] = ResolversParentTypes['TextMatchHighlight']> = {
    beginIndice?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    endIndice?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    text?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TopicResolvers<ContextType = any, ParentType extends ResolversParentTypes['Topic'] = ResolversParentTypes['Topic']> = {
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    relatedTopics?: Resolver<Array<ResolversTypes['Topic']>, ParentType, ContextType, RequireFields<TopicRelatedTopicsArgs, 'first'>>;
    stargazerCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    stargazers?: Resolver<ResolversTypes['StargazerConnection'], ParentType, ContextType, Partial<TopicStargazersArgs>>;
    viewerHasStarred?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TopicAuditEntryDataResolvers<ContextType = any, ParentType extends ResolversParentTypes['TopicAuditEntryData'] = ResolversParentTypes['TopicAuditEntryData']> = {
    __resolveType: TypeResolveFn<'RepoAddTopicAuditEntry' | 'RepoRemoveTopicAuditEntry', ParentType, ContextType>;
    topic?: Resolver<Maybe<ResolversTypes['Topic']>, ParentType, ContextType>;
    topicName?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
};
export type TransferIssuePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['TransferIssuePayload'] = ResolversParentTypes['TransferIssuePayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    issue?: Resolver<Maybe<ResolversTypes['Issue']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TransferredEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['TransferredEvent'] = ResolversParentTypes['TransferredEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    fromRepository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    issue?: Resolver<ResolversTypes['Issue'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TreeResolvers<ContextType = any, ParentType extends ResolversParentTypes['Tree'] = ResolversParentTypes['Tree']> = {
    abbreviatedOid?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    commitResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    commitUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    entries?: Resolver<Maybe<Array<ResolversTypes['TreeEntry']>>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    oid?: Resolver<ResolversTypes['GitObjectID'], ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type TreeEntryResolvers<ContextType = any, ParentType extends ResolversParentTypes['TreeEntry'] = ResolversParentTypes['TreeEntry']> = {
    extension?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    isGenerated?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    mode?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    object?: Resolver<Maybe<ResolversTypes['GitObject']>, ParentType, ContextType>;
    oid?: Resolver<ResolversTypes['GitObjectID'], ParentType, ContextType>;
    path?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repository?: Resolver<ResolversTypes['Repository'], ParentType, ContextType>;
    submodule?: Resolver<Maybe<ResolversTypes['Submodule']>, ParentType, ContextType>;
    type?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export interface UriScalarConfig extends GraphQLScalarTypeConfig<ResolversTypes['URI'], any> {
    name: 'URI';
}
export type UnarchiveRepositoryPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UnarchiveRepositoryPayload'] = ResolversParentTypes['UnarchiveRepositoryPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UnassignedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['UnassignedEvent'] = ResolversParentTypes['UnassignedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    assignable?: Resolver<ResolversTypes['Assignable'], ParentType, ContextType>;
    assignee?: Resolver<Maybe<ResolversTypes['Assignee']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UnfollowUserPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UnfollowUserPayload'] = ResolversParentTypes['UnfollowUserPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    user?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UniformResourceLocatableResolvers<ContextType = any, ParentType extends ResolversParentTypes['UniformResourceLocatable'] = ResolversParentTypes['UniformResourceLocatable']> = {
    __resolveType: TypeResolveFn<'Bot' | 'CheckRun' | 'ClosedEvent' | 'Commit' | 'ConvertToDraftEvent' | 'CrossReferencedEvent' | 'Gist' | 'Issue' | 'Mannequin' | 'MergedEvent' | 'Milestone' | 'Organization' | 'PullRequest' | 'PullRequestCommit' | 'ReadyForReviewEvent' | 'Release' | 'Repository' | 'RepositoryTopic' | 'ReviewDismissedEvent' | 'TeamDiscussion' | 'TeamDiscussionComment' | 'User', ParentType, ContextType>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
};
export type UnknownSignatureResolvers<ContextType = any, ParentType extends ResolversParentTypes['UnknownSignature'] = ResolversParentTypes['UnknownSignature']> = {
    email?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    isValid?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    payload?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    signature?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    signer?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    state?: Resolver<ResolversTypes['GitSignatureState'], ParentType, ContextType>;
    wasSignedByGitHub?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UnlabeledEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['UnlabeledEvent'] = ResolversParentTypes['UnlabeledEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    label?: Resolver<ResolversTypes['Label'], ParentType, ContextType>;
    labelable?: Resolver<ResolversTypes['Labelable'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UnlinkRepositoryFromProjectPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UnlinkRepositoryFromProjectPayload'] = ResolversParentTypes['UnlinkRepositoryFromProjectPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    project?: Resolver<Maybe<ResolversTypes['Project']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UnlockLockablePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UnlockLockablePayload'] = ResolversParentTypes['UnlockLockablePayload']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    unlockedRecord?: Resolver<Maybe<ResolversTypes['Lockable']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UnlockedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['UnlockedEvent'] = ResolversParentTypes['UnlockedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    lockable?: Resolver<ResolversTypes['Lockable'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UnmarkDiscussionCommentAsAnswerPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UnmarkDiscussionCommentAsAnswerPayload'] = ResolversParentTypes['UnmarkDiscussionCommentAsAnswerPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    discussion?: Resolver<Maybe<ResolversTypes['Discussion']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UnmarkFileAsViewedPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UnmarkFileAsViewedPayload'] = ResolversParentTypes['UnmarkFileAsViewedPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UnmarkIssueAsDuplicatePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UnmarkIssueAsDuplicatePayload'] = ResolversParentTypes['UnmarkIssueAsDuplicatePayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    duplicate?: Resolver<Maybe<ResolversTypes['IssueOrPullRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UnmarkedAsDuplicateEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['UnmarkedAsDuplicateEvent'] = ResolversParentTypes['UnmarkedAsDuplicateEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    canonical?: Resolver<Maybe<ResolversTypes['IssueOrPullRequest']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    duplicate?: Resolver<Maybe<ResolversTypes['IssueOrPullRequest']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isCrossRepository?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UnminimizeCommentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UnminimizeCommentPayload'] = ResolversParentTypes['UnminimizeCommentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    unminimizedComment?: Resolver<Maybe<ResolversTypes['Minimizable']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UnpinIssuePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UnpinIssuePayload'] = ResolversParentTypes['UnpinIssuePayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    issue?: Resolver<Maybe<ResolversTypes['Issue']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UnpinnedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['UnpinnedEvent'] = ResolversParentTypes['UnpinnedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    issue?: Resolver<ResolversTypes['Issue'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UnresolveReviewThreadPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UnresolveReviewThreadPayload'] = ResolversParentTypes['UnresolveReviewThreadPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    thread?: Resolver<Maybe<ResolversTypes['PullRequestReviewThread']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UnsubscribedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['UnsubscribedEvent'] = ResolversParentTypes['UnsubscribedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    subscribable?: Resolver<ResolversTypes['Subscribable'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdatableResolvers<ContextType = any, ParentType extends ResolversParentTypes['Updatable'] = ResolversParentTypes['Updatable']> = {
    __resolveType: TypeResolveFn<'CommitComment' | 'Discussion' | 'DiscussionComment' | 'GistComment' | 'Issue' | 'IssueComment' | 'Project' | 'PullRequest' | 'PullRequestReview' | 'PullRequestReviewComment' | 'TeamDiscussion' | 'TeamDiscussionComment', ParentType, ContextType>;
    viewerCanUpdate?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
};
export type UpdatableCommentResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdatableComment'] = ResolversParentTypes['UpdatableComment']> = {
    __resolveType: TypeResolveFn<'CommitComment' | 'DiscussionComment' | 'GistComment' | 'Issue' | 'IssueComment' | 'PullRequest' | 'PullRequestReview' | 'PullRequestReviewComment' | 'TeamDiscussion' | 'TeamDiscussionComment', ParentType, ContextType>;
    viewerCannotUpdateReasons?: Resolver<Array<ResolversTypes['CommentCannotUpdateReason']>, ParentType, ContextType>;
};
export type UpdateBranchProtectionRulePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateBranchProtectionRulePayload'] = ResolversParentTypes['UpdateBranchProtectionRulePayload']> = {
    branchProtectionRule?: Resolver<Maybe<ResolversTypes['BranchProtectionRule']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateCheckRunPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateCheckRunPayload'] = ResolversParentTypes['UpdateCheckRunPayload']> = {
    checkRun?: Resolver<Maybe<ResolversTypes['CheckRun']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateCheckSuitePreferencesPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateCheckSuitePreferencesPayload'] = ResolversParentTypes['UpdateCheckSuitePreferencesPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateDiscussionCommentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateDiscussionCommentPayload'] = ResolversParentTypes['UpdateDiscussionCommentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    comment?: Resolver<Maybe<ResolversTypes['DiscussionComment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateDiscussionPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateDiscussionPayload'] = ResolversParentTypes['UpdateDiscussionPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    discussion?: Resolver<Maybe<ResolversTypes['Discussion']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateEnterpriseAllowPrivateRepositoryForkingSettingPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateEnterpriseAllowPrivateRepositoryForkingSettingPayload'] = ResolversParentTypes['UpdateEnterpriseAllowPrivateRepositoryForkingSettingPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    message?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateEnterpriseDefaultRepositoryPermissionSettingPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateEnterpriseDefaultRepositoryPermissionSettingPayload'] = ResolversParentTypes['UpdateEnterpriseDefaultRepositoryPermissionSettingPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    message?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingPayload'] = ResolversParentTypes['UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    message?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateEnterpriseMembersCanCreateRepositoriesSettingPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateEnterpriseMembersCanCreateRepositoriesSettingPayload'] = ResolversParentTypes['UpdateEnterpriseMembersCanCreateRepositoriesSettingPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    message?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateEnterpriseMembersCanDeleteIssuesSettingPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateEnterpriseMembersCanDeleteIssuesSettingPayload'] = ResolversParentTypes['UpdateEnterpriseMembersCanDeleteIssuesSettingPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    message?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateEnterpriseMembersCanDeleteRepositoriesSettingPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateEnterpriseMembersCanDeleteRepositoriesSettingPayload'] = ResolversParentTypes['UpdateEnterpriseMembersCanDeleteRepositoriesSettingPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    message?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateEnterpriseMembersCanInviteCollaboratorsSettingPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateEnterpriseMembersCanInviteCollaboratorsSettingPayload'] = ResolversParentTypes['UpdateEnterpriseMembersCanInviteCollaboratorsSettingPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    message?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateEnterpriseMembersCanMakePurchasesSettingPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateEnterpriseMembersCanMakePurchasesSettingPayload'] = ResolversParentTypes['UpdateEnterpriseMembersCanMakePurchasesSettingPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    message?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingPayload'] = ResolversParentTypes['UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    message?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateEnterpriseMembersCanViewDependencyInsightsSettingPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateEnterpriseMembersCanViewDependencyInsightsSettingPayload'] = ResolversParentTypes['UpdateEnterpriseMembersCanViewDependencyInsightsSettingPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    message?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateEnterpriseOrganizationProjectsSettingPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateEnterpriseOrganizationProjectsSettingPayload'] = ResolversParentTypes['UpdateEnterpriseOrganizationProjectsSettingPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    message?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateEnterpriseProfilePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateEnterpriseProfilePayload'] = ResolversParentTypes['UpdateEnterpriseProfilePayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateEnterpriseRepositoryProjectsSettingPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateEnterpriseRepositoryProjectsSettingPayload'] = ResolversParentTypes['UpdateEnterpriseRepositoryProjectsSettingPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    message?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateEnterpriseTeamDiscussionsSettingPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateEnterpriseTeamDiscussionsSettingPayload'] = ResolversParentTypes['UpdateEnterpriseTeamDiscussionsSettingPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    message?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateEnterpriseTwoFactorAuthenticationRequiredSettingPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateEnterpriseTwoFactorAuthenticationRequiredSettingPayload'] = ResolversParentTypes['UpdateEnterpriseTwoFactorAuthenticationRequiredSettingPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    enterprise?: Resolver<Maybe<ResolversTypes['Enterprise']>, ParentType, ContextType>;
    message?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateEnvironmentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateEnvironmentPayload'] = ResolversParentTypes['UpdateEnvironmentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    environment?: Resolver<Maybe<ResolversTypes['Environment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateIpAllowListEnabledSettingPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateIpAllowListEnabledSettingPayload'] = ResolversParentTypes['UpdateIpAllowListEnabledSettingPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    owner?: Resolver<Maybe<ResolversTypes['IpAllowListOwner']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateIpAllowListEntryPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateIpAllowListEntryPayload'] = ResolversParentTypes['UpdateIpAllowListEntryPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    ipAllowListEntry?: Resolver<Maybe<ResolversTypes['IpAllowListEntry']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateIpAllowListForInstalledAppsEnabledSettingPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateIpAllowListForInstalledAppsEnabledSettingPayload'] = ResolversParentTypes['UpdateIpAllowListForInstalledAppsEnabledSettingPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    owner?: Resolver<Maybe<ResolversTypes['IpAllowListOwner']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateIssueCommentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateIssueCommentPayload'] = ResolversParentTypes['UpdateIssueCommentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    issueComment?: Resolver<Maybe<ResolversTypes['IssueComment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateIssuePayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateIssuePayload'] = ResolversParentTypes['UpdateIssuePayload']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    issue?: Resolver<Maybe<ResolversTypes['Issue']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateLabelPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateLabelPayload'] = ResolversParentTypes['UpdateLabelPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    label?: Resolver<Maybe<ResolversTypes['Label']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateNotificationRestrictionSettingPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateNotificationRestrictionSettingPayload'] = ResolversParentTypes['UpdateNotificationRestrictionSettingPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    owner?: Resolver<Maybe<ResolversTypes['VerifiableDomainOwner']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateProjectCardPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateProjectCardPayload'] = ResolversParentTypes['UpdateProjectCardPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    projectCard?: Resolver<Maybe<ResolversTypes['ProjectCard']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateProjectColumnPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateProjectColumnPayload'] = ResolversParentTypes['UpdateProjectColumnPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    projectColumn?: Resolver<Maybe<ResolversTypes['ProjectColumn']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateProjectPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateProjectPayload'] = ResolversParentTypes['UpdateProjectPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    project?: Resolver<Maybe<ResolversTypes['Project']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdatePullRequestPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdatePullRequestPayload'] = ResolversParentTypes['UpdatePullRequestPayload']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequest?: Resolver<Maybe<ResolversTypes['PullRequest']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdatePullRequestReviewCommentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdatePullRequestReviewCommentPayload'] = ResolversParentTypes['UpdatePullRequestReviewCommentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequestReviewComment?: Resolver<Maybe<ResolversTypes['PullRequestReviewComment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdatePullRequestReviewPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdatePullRequestReviewPayload'] = ResolversParentTypes['UpdatePullRequestReviewPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    pullRequestReview?: Resolver<Maybe<ResolversTypes['PullRequestReview']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateRefPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateRefPayload'] = ResolversParentTypes['UpdateRefPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    ref?: Resolver<Maybe<ResolversTypes['Ref']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateRefsPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateRefsPayload'] = ResolversParentTypes['UpdateRefsPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateRepositoryPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateRepositoryPayload'] = ResolversParentTypes['UpdateRepositoryPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateSubscriptionPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateSubscriptionPayload'] = ResolversParentTypes['UpdateSubscriptionPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    subscribable?: Resolver<Maybe<ResolversTypes['Subscribable']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateTeamDiscussionCommentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateTeamDiscussionCommentPayload'] = ResolversParentTypes['UpdateTeamDiscussionCommentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    teamDiscussionComment?: Resolver<Maybe<ResolversTypes['TeamDiscussionComment']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateTeamDiscussionPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateTeamDiscussionPayload'] = ResolversParentTypes['UpdateTeamDiscussionPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    teamDiscussion?: Resolver<Maybe<ResolversTypes['TeamDiscussion']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateTeamReviewAssignmentPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateTeamReviewAssignmentPayload'] = ResolversParentTypes['UpdateTeamReviewAssignmentPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    team?: Resolver<Maybe<ResolversTypes['Team']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UpdateTopicsPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['UpdateTopicsPayload'] = ResolversParentTypes['UpdateTopicsPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    invalidTopicNames?: Resolver<Maybe<Array<ResolversTypes['String']>>, ParentType, ContextType>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UserResolvers<ContextType = any, ParentType extends ResolversParentTypes['User'] = ResolversParentTypes['User']> = {
    anyPinnableItems?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType, Partial<UserAnyPinnableItemsArgs>>;
    avatarUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType, Partial<UserAvatarUrlArgs>>;
    bio?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    bioHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    canReceiveOrganizationEmailsWhenNotificationsRestricted?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType, RequireFields<UserCanReceiveOrganizationEmailsWhenNotificationsRestrictedArgs, 'login'>>;
    commitComments?: Resolver<ResolversTypes['CommitCommentConnection'], ParentType, ContextType, Partial<UserCommitCommentsArgs>>;
    company?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    companyHTML?: Resolver<ResolversTypes['HTML'], ParentType, ContextType>;
    contributionsCollection?: Resolver<ResolversTypes['ContributionsCollection'], ParentType, ContextType, Partial<UserContributionsCollectionArgs>>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    email?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    followers?: Resolver<ResolversTypes['FollowerConnection'], ParentType, ContextType, Partial<UserFollowersArgs>>;
    following?: Resolver<ResolversTypes['FollowingConnection'], ParentType, ContextType, Partial<UserFollowingArgs>>;
    gist?: Resolver<Maybe<ResolversTypes['Gist']>, ParentType, ContextType, RequireFields<UserGistArgs, 'name'>>;
    gistComments?: Resolver<ResolversTypes['GistCommentConnection'], ParentType, ContextType, Partial<UserGistCommentsArgs>>;
    gists?: Resolver<ResolversTypes['GistConnection'], ParentType, ContextType, Partial<UserGistsArgs>>;
    hovercard?: Resolver<ResolversTypes['Hovercard'], ParentType, ContextType, Partial<UserHovercardArgs>>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isBountyHunter?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isCampusExpert?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isDeveloperProgramMember?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isEmployee?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isGitHubStar?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isHireable?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isSiteAdmin?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isViewer?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    issueComments?: Resolver<ResolversTypes['IssueCommentConnection'], ParentType, ContextType, Partial<UserIssueCommentsArgs>>;
    issues?: Resolver<ResolversTypes['IssueConnection'], ParentType, ContextType, Partial<UserIssuesArgs>>;
    itemShowcase?: Resolver<ResolversTypes['ProfileItemShowcase'], ParentType, ContextType>;
    location?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    login?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    name?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType, RequireFields<UserOrganizationArgs, 'login'>>;
    organizationVerifiedDomainEmails?: Resolver<Array<ResolversTypes['String']>, ParentType, ContextType, RequireFields<UserOrganizationVerifiedDomainEmailsArgs, 'login'>>;
    organizations?: Resolver<ResolversTypes['OrganizationConnection'], ParentType, ContextType, Partial<UserOrganizationsArgs>>;
    packages?: Resolver<ResolversTypes['PackageConnection'], ParentType, ContextType, RequireFields<UserPackagesArgs, 'orderBy'>>;
    pinnableItems?: Resolver<ResolversTypes['PinnableItemConnection'], ParentType, ContextType, Partial<UserPinnableItemsArgs>>;
    pinnedItems?: Resolver<ResolversTypes['PinnableItemConnection'], ParentType, ContextType, Partial<UserPinnedItemsArgs>>;
    pinnedItemsRemaining?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    project?: Resolver<Maybe<ResolversTypes['Project']>, ParentType, ContextType, RequireFields<UserProjectArgs, 'number'>>;
    projects?: Resolver<ResolversTypes['ProjectConnection'], ParentType, ContextType, Partial<UserProjectsArgs>>;
    projectsResourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    projectsUrl?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    publicKeys?: Resolver<ResolversTypes['PublicKeyConnection'], ParentType, ContextType, Partial<UserPublicKeysArgs>>;
    pullRequests?: Resolver<ResolversTypes['PullRequestConnection'], ParentType, ContextType, Partial<UserPullRequestsArgs>>;
    repositories?: Resolver<ResolversTypes['RepositoryConnection'], ParentType, ContextType, RequireFields<UserRepositoriesArgs, 'ownerAffiliations'>>;
    repositoriesContributedTo?: Resolver<ResolversTypes['RepositoryConnection'], ParentType, ContextType, Partial<UserRepositoriesContributedToArgs>>;
    repository?: Resolver<Maybe<ResolversTypes['Repository']>, ParentType, ContextType, RequireFields<UserRepositoryArgs, 'name'>>;
    repositoryDiscussionComments?: Resolver<ResolversTypes['DiscussionCommentConnection'], ParentType, ContextType, RequireFields<UserRepositoryDiscussionCommentsArgs, 'onlyAnswers'>>;
    repositoryDiscussions?: Resolver<ResolversTypes['DiscussionConnection'], ParentType, ContextType, RequireFields<UserRepositoryDiscussionsArgs, 'answered' | 'orderBy'>>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    savedReplies?: Resolver<Maybe<ResolversTypes['SavedReplyConnection']>, ParentType, ContextType, RequireFields<UserSavedRepliesArgs, 'orderBy'>>;
    sponsorshipsAsMaintainer?: Resolver<ResolversTypes['SponsorshipConnection'], ParentType, ContextType, RequireFields<UserSponsorshipsAsMaintainerArgs, 'includePrivate'>>;
    sponsorshipsAsSponsor?: Resolver<ResolversTypes['SponsorshipConnection'], ParentType, ContextType, Partial<UserSponsorshipsAsSponsorArgs>>;
    starredRepositories?: Resolver<ResolversTypes['StarredRepositoryConnection'], ParentType, ContextType, Partial<UserStarredRepositoriesArgs>>;
    status?: Resolver<Maybe<ResolversTypes['UserStatus']>, ParentType, ContextType>;
    suspendedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    topRepositories?: Resolver<ResolversTypes['RepositoryConnection'], ParentType, ContextType, RequireFields<UserTopRepositoriesArgs, 'orderBy'>>;
    twitterUsername?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    viewerCanChangePinnedItems?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanCreateProjects?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerCanFollow?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerIsFollowing?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    watching?: Resolver<ResolversTypes['RepositoryConnection'], ParentType, ContextType, RequireFields<UserWatchingArgs, 'ownerAffiliations'>>;
    websiteUrl?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UserBlockedEventResolvers<ContextType = any, ParentType extends ResolversParentTypes['UserBlockedEvent'] = ResolversParentTypes['UserBlockedEvent']> = {
    actor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    blockDuration?: Resolver<ResolversTypes['UserBlockDuration'], ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    subject?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UserConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['UserConnection'] = ResolversParentTypes['UserConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['UserEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['User']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UserContentEditResolvers<ContextType = any, ParentType extends ResolversParentTypes['UserContentEdit'] = ResolversParentTypes['UserContentEdit']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    deletedAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    deletedBy?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    diff?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    editedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    editor?: Resolver<Maybe<ResolversTypes['Actor']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UserContentEditConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['UserContentEditConnection'] = ResolversParentTypes['UserContentEditConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['UserContentEditEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['UserContentEdit']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UserContentEditEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['UserContentEditEdge'] = ResolversParentTypes['UserContentEditEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['UserContentEdit']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UserEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['UserEdge'] = ResolversParentTypes['UserEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['User']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UserEmailMetadataResolvers<ContextType = any, ParentType extends ResolversParentTypes['UserEmailMetadata'] = ResolversParentTypes['UserEmailMetadata']> = {
    primary?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    type?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    value?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UserStatusResolvers<ContextType = any, ParentType extends ResolversParentTypes['UserStatus'] = ResolversParentTypes['UserStatus']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    emoji?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    emojiHTML?: Resolver<Maybe<ResolversTypes['HTML']>, ParentType, ContextType>;
    expiresAt?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    indicatesLimitedAvailability?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    message?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<ResolversTypes['Organization']>, ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    user?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UserStatusConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['UserStatusConnection'] = ResolversParentTypes['UserStatusConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['UserStatusEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['UserStatus']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type UserStatusEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['UserStatusEdge'] = ResolversParentTypes['UserStatusEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['UserStatus']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type VerifiableDomainResolvers<ContextType = any, ParentType extends ResolversParentTypes['VerifiableDomain'] = ResolversParentTypes['VerifiableDomain']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    dnsHostName?: Resolver<Maybe<ResolversTypes['URI']>, ParentType, ContextType>;
    domain?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    hasFoundHostName?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    hasFoundVerificationToken?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    isApproved?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isRequiredForPolicyEnforcement?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    isVerified?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    owner?: Resolver<ResolversTypes['VerifiableDomainOwner'], ParentType, ContextType>;
    punycodeEncodedDomain?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    tokenExpirationTime?: Resolver<Maybe<ResolversTypes['DateTime']>, ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    verificationToken?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type VerifiableDomainConnectionResolvers<ContextType = any, ParentType extends ResolversParentTypes['VerifiableDomainConnection'] = ResolversParentTypes['VerifiableDomainConnection']> = {
    edges?: Resolver<Maybe<Array<Maybe<ResolversTypes['VerifiableDomainEdge']>>>, ParentType, ContextType>;
    nodes?: Resolver<Maybe<Array<Maybe<ResolversTypes['VerifiableDomain']>>>, ParentType, ContextType>;
    pageInfo?: Resolver<ResolversTypes['PageInfo'], ParentType, ContextType>;
    totalCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type VerifiableDomainEdgeResolvers<ContextType = any, ParentType extends ResolversParentTypes['VerifiableDomainEdge'] = ResolversParentTypes['VerifiableDomainEdge']> = {
    cursor?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    node?: Resolver<Maybe<ResolversTypes['VerifiableDomain']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type VerifiableDomainOwnerResolvers<ContextType = any, ParentType extends ResolversParentTypes['VerifiableDomainOwner'] = ResolversParentTypes['VerifiableDomainOwner']> = {
    __resolveType: TypeResolveFn<'Enterprise' | 'Organization', ParentType, ContextType>;
};
export type VerifyVerifiableDomainPayloadResolvers<ContextType = any, ParentType extends ResolversParentTypes['VerifyVerifiableDomainPayload'] = ResolversParentTypes['VerifyVerifiableDomainPayload']> = {
    clientMutationId?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    domain?: Resolver<Maybe<ResolversTypes['VerifiableDomain']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type ViewerHovercardContextResolvers<ContextType = any, ParentType extends ResolversParentTypes['ViewerHovercardContext'] = ResolversParentTypes['ViewerHovercardContext']> = {
    message?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    octicon?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    viewer?: Resolver<ResolversTypes['User'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type VotableResolvers<ContextType = any, ParentType extends ResolversParentTypes['Votable'] = ResolversParentTypes['Votable']> = {
    __resolveType: TypeResolveFn<'Discussion' | 'DiscussionComment', ParentType, ContextType>;
    upvoteCount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    viewerCanUpvote?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
    viewerHasUpvoted?: Resolver<ResolversTypes['Boolean'], ParentType, ContextType>;
};
export type WorkflowResolvers<ContextType = any, ParentType extends ResolversParentTypes['Workflow'] = ResolversParentTypes['Workflow']> = {
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export type WorkflowRunResolvers<ContextType = any, ParentType extends ResolversParentTypes['WorkflowRun'] = ResolversParentTypes['WorkflowRun']> = {
    checkSuite?: Resolver<ResolversTypes['CheckSuite'], ParentType, ContextType>;
    createdAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    databaseId?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    deploymentReviews?: Resolver<ResolversTypes['DeploymentReviewConnection'], ParentType, ContextType, Partial<WorkflowRunDeploymentReviewsArgs>>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
    pendingDeploymentRequests?: Resolver<ResolversTypes['DeploymentRequestConnection'], ParentType, ContextType, Partial<WorkflowRunPendingDeploymentRequestsArgs>>;
    resourcePath?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    runNumber?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    updatedAt?: Resolver<ResolversTypes['DateTime'], ParentType, ContextType>;
    url?: Resolver<ResolversTypes['URI'], ParentType, ContextType>;
    workflow?: Resolver<ResolversTypes['Workflow'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export interface X509CertificateScalarConfig extends GraphQLScalarTypeConfig<ResolversTypes['X509Certificate'], any> {
    name: 'X509Certificate';
}
export type Resolvers<ContextType = any> = {
    Actor?: ActorResolvers<ContextType>;
    ActorLocation?: ActorLocationResolvers<ContextType>;
    AddAssigneesToAssignablePayload?: AddAssigneesToAssignablePayloadResolvers<ContextType>;
    AddCommentPayload?: AddCommentPayloadResolvers<ContextType>;
    AddDiscussionCommentPayload?: AddDiscussionCommentPayloadResolvers<ContextType>;
    AddEnterpriseAdminPayload?: AddEnterpriseAdminPayloadResolvers<ContextType>;
    AddLabelsToLabelablePayload?: AddLabelsToLabelablePayloadResolvers<ContextType>;
    AddProjectCardPayload?: AddProjectCardPayloadResolvers<ContextType>;
    AddProjectColumnPayload?: AddProjectColumnPayloadResolvers<ContextType>;
    AddPullRequestReviewCommentPayload?: AddPullRequestReviewCommentPayloadResolvers<ContextType>;
    AddPullRequestReviewPayload?: AddPullRequestReviewPayloadResolvers<ContextType>;
    AddPullRequestReviewThreadPayload?: AddPullRequestReviewThreadPayloadResolvers<ContextType>;
    AddReactionPayload?: AddReactionPayloadResolvers<ContextType>;
    AddStarPayload?: AddStarPayloadResolvers<ContextType>;
    AddUpvotePayload?: AddUpvotePayloadResolvers<ContextType>;
    AddVerifiableDomainPayload?: AddVerifiableDomainPayloadResolvers<ContextType>;
    AddedToProjectEvent?: AddedToProjectEventResolvers<ContextType>;
    App?: AppResolvers<ContextType>;
    ApproveDeploymentsPayload?: ApproveDeploymentsPayloadResolvers<ContextType>;
    ApproveVerifiableDomainPayload?: ApproveVerifiableDomainPayloadResolvers<ContextType>;
    ArchiveRepositoryPayload?: ArchiveRepositoryPayloadResolvers<ContextType>;
    Assignable?: AssignableResolvers<ContextType>;
    AssignedEvent?: AssignedEventResolvers<ContextType>;
    Assignee?: AssigneeResolvers<ContextType>;
    AuditEntry?: AuditEntryResolvers<ContextType>;
    AuditEntryActor?: AuditEntryActorResolvers<ContextType>;
    AutoMergeDisabledEvent?: AutoMergeDisabledEventResolvers<ContextType>;
    AutoMergeEnabledEvent?: AutoMergeEnabledEventResolvers<ContextType>;
    AutoMergeRequest?: AutoMergeRequestResolvers<ContextType>;
    AutoRebaseEnabledEvent?: AutoRebaseEnabledEventResolvers<ContextType>;
    AutoSquashEnabledEvent?: AutoSquashEnabledEventResolvers<ContextType>;
    AutomaticBaseChangeFailedEvent?: AutomaticBaseChangeFailedEventResolvers<ContextType>;
    AutomaticBaseChangeSucceededEvent?: AutomaticBaseChangeSucceededEventResolvers<ContextType>;
    BaseRefChangedEvent?: BaseRefChangedEventResolvers<ContextType>;
    BaseRefDeletedEvent?: BaseRefDeletedEventResolvers<ContextType>;
    BaseRefForcePushedEvent?: BaseRefForcePushedEventResolvers<ContextType>;
    Blame?: BlameResolvers<ContextType>;
    BlameRange?: BlameRangeResolvers<ContextType>;
    Blob?: BlobResolvers<ContextType>;
    Bot?: BotResolvers<ContextType>;
    BranchProtectionRule?: BranchProtectionRuleResolvers<ContextType>;
    BranchProtectionRuleConflict?: BranchProtectionRuleConflictResolvers<ContextType>;
    BranchProtectionRuleConflictConnection?: BranchProtectionRuleConflictConnectionResolvers<ContextType>;
    BranchProtectionRuleConflictEdge?: BranchProtectionRuleConflictEdgeResolvers<ContextType>;
    BranchProtectionRuleConnection?: BranchProtectionRuleConnectionResolvers<ContextType>;
    BranchProtectionRuleEdge?: BranchProtectionRuleEdgeResolvers<ContextType>;
    CVSS?: CvssResolvers<ContextType>;
    CWE?: CweResolvers<ContextType>;
    CWEConnection?: CweConnectionResolvers<ContextType>;
    CWEEdge?: CweEdgeResolvers<ContextType>;
    ChangeUserStatusPayload?: ChangeUserStatusPayloadResolvers<ContextType>;
    CheckAnnotation?: CheckAnnotationResolvers<ContextType>;
    CheckAnnotationConnection?: CheckAnnotationConnectionResolvers<ContextType>;
    CheckAnnotationEdge?: CheckAnnotationEdgeResolvers<ContextType>;
    CheckAnnotationPosition?: CheckAnnotationPositionResolvers<ContextType>;
    CheckAnnotationSpan?: CheckAnnotationSpanResolvers<ContextType>;
    CheckRun?: CheckRunResolvers<ContextType>;
    CheckRunConnection?: CheckRunConnectionResolvers<ContextType>;
    CheckRunEdge?: CheckRunEdgeResolvers<ContextType>;
    CheckStep?: CheckStepResolvers<ContextType>;
    CheckStepConnection?: CheckStepConnectionResolvers<ContextType>;
    CheckStepEdge?: CheckStepEdgeResolvers<ContextType>;
    CheckSuite?: CheckSuiteResolvers<ContextType>;
    CheckSuiteConnection?: CheckSuiteConnectionResolvers<ContextType>;
    CheckSuiteEdge?: CheckSuiteEdgeResolvers<ContextType>;
    ClearLabelsFromLabelablePayload?: ClearLabelsFromLabelablePayloadResolvers<ContextType>;
    CloneProjectPayload?: CloneProjectPayloadResolvers<ContextType>;
    CloneTemplateRepositoryPayload?: CloneTemplateRepositoryPayloadResolvers<ContextType>;
    Closable?: ClosableResolvers<ContextType>;
    CloseIssuePayload?: CloseIssuePayloadResolvers<ContextType>;
    ClosePullRequestPayload?: ClosePullRequestPayloadResolvers<ContextType>;
    ClosedEvent?: ClosedEventResolvers<ContextType>;
    Closer?: CloserResolvers<ContextType>;
    CodeOfConduct?: CodeOfConductResolvers<ContextType>;
    Comment?: CommentResolvers<ContextType>;
    CommentDeletedEvent?: CommentDeletedEventResolvers<ContextType>;
    Commit?: CommitResolvers<ContextType>;
    CommitComment?: CommitCommentResolvers<ContextType>;
    CommitCommentConnection?: CommitCommentConnectionResolvers<ContextType>;
    CommitCommentEdge?: CommitCommentEdgeResolvers<ContextType>;
    CommitCommentThread?: CommitCommentThreadResolvers<ContextType>;
    CommitConnection?: CommitConnectionResolvers<ContextType>;
    CommitContributionsByRepository?: CommitContributionsByRepositoryResolvers<ContextType>;
    CommitEdge?: CommitEdgeResolvers<ContextType>;
    CommitHistoryConnection?: CommitHistoryConnectionResolvers<ContextType>;
    ConnectedEvent?: ConnectedEventResolvers<ContextType>;
    ContentAttachment?: ContentAttachmentResolvers<ContextType>;
    ContentReference?: ContentReferenceResolvers<ContextType>;
    Contribution?: ContributionResolvers<ContextType>;
    ContributionCalendar?: ContributionCalendarResolvers<ContextType>;
    ContributionCalendarDay?: ContributionCalendarDayResolvers<ContextType>;
    ContributionCalendarMonth?: ContributionCalendarMonthResolvers<ContextType>;
    ContributionCalendarWeek?: ContributionCalendarWeekResolvers<ContextType>;
    ContributionsCollection?: ContributionsCollectionResolvers<ContextType>;
    ConvertProjectCardNoteToIssuePayload?: ConvertProjectCardNoteToIssuePayloadResolvers<ContextType>;
    ConvertPullRequestToDraftPayload?: ConvertPullRequestToDraftPayloadResolvers<ContextType>;
    ConvertToDraftEvent?: ConvertToDraftEventResolvers<ContextType>;
    ConvertedNoteToIssueEvent?: ConvertedNoteToIssueEventResolvers<ContextType>;
    CreateBranchProtectionRulePayload?: CreateBranchProtectionRulePayloadResolvers<ContextType>;
    CreateCheckRunPayload?: CreateCheckRunPayloadResolvers<ContextType>;
    CreateCheckSuitePayload?: CreateCheckSuitePayloadResolvers<ContextType>;
    CreateContentAttachmentPayload?: CreateContentAttachmentPayloadResolvers<ContextType>;
    CreateDeploymentPayload?: CreateDeploymentPayloadResolvers<ContextType>;
    CreateDeploymentStatusPayload?: CreateDeploymentStatusPayloadResolvers<ContextType>;
    CreateDiscussionPayload?: CreateDiscussionPayloadResolvers<ContextType>;
    CreateEnterpriseOrganizationPayload?: CreateEnterpriseOrganizationPayloadResolvers<ContextType>;
    CreateEnvironmentPayload?: CreateEnvironmentPayloadResolvers<ContextType>;
    CreateIpAllowListEntryPayload?: CreateIpAllowListEntryPayloadResolvers<ContextType>;
    CreateIssuePayload?: CreateIssuePayloadResolvers<ContextType>;
    CreateLabelPayload?: CreateLabelPayloadResolvers<ContextType>;
    CreateProjectPayload?: CreateProjectPayloadResolvers<ContextType>;
    CreatePullRequestPayload?: CreatePullRequestPayloadResolvers<ContextType>;
    CreateRefPayload?: CreateRefPayloadResolvers<ContextType>;
    CreateRepositoryPayload?: CreateRepositoryPayloadResolvers<ContextType>;
    CreateTeamDiscussionCommentPayload?: CreateTeamDiscussionCommentPayloadResolvers<ContextType>;
    CreateTeamDiscussionPayload?: CreateTeamDiscussionPayloadResolvers<ContextType>;
    CreatedCommitContribution?: CreatedCommitContributionResolvers<ContextType>;
    CreatedCommitContributionConnection?: CreatedCommitContributionConnectionResolvers<ContextType>;
    CreatedCommitContributionEdge?: CreatedCommitContributionEdgeResolvers<ContextType>;
    CreatedIssueContribution?: CreatedIssueContributionResolvers<ContextType>;
    CreatedIssueContributionConnection?: CreatedIssueContributionConnectionResolvers<ContextType>;
    CreatedIssueContributionEdge?: CreatedIssueContributionEdgeResolvers<ContextType>;
    CreatedIssueOrRestrictedContribution?: CreatedIssueOrRestrictedContributionResolvers<ContextType>;
    CreatedPullRequestContribution?: CreatedPullRequestContributionResolvers<ContextType>;
    CreatedPullRequestContributionConnection?: CreatedPullRequestContributionConnectionResolvers<ContextType>;
    CreatedPullRequestContributionEdge?: CreatedPullRequestContributionEdgeResolvers<ContextType>;
    CreatedPullRequestOrRestrictedContribution?: CreatedPullRequestOrRestrictedContributionResolvers<ContextType>;
    CreatedPullRequestReviewContribution?: CreatedPullRequestReviewContributionResolvers<ContextType>;
    CreatedPullRequestReviewContributionConnection?: CreatedPullRequestReviewContributionConnectionResolvers<ContextType>;
    CreatedPullRequestReviewContributionEdge?: CreatedPullRequestReviewContributionEdgeResolvers<ContextType>;
    CreatedRepositoryContribution?: CreatedRepositoryContributionResolvers<ContextType>;
    CreatedRepositoryContributionConnection?: CreatedRepositoryContributionConnectionResolvers<ContextType>;
    CreatedRepositoryContributionEdge?: CreatedRepositoryContributionEdgeResolvers<ContextType>;
    CreatedRepositoryOrRestrictedContribution?: CreatedRepositoryOrRestrictedContributionResolvers<ContextType>;
    CrossReferencedEvent?: CrossReferencedEventResolvers<ContextType>;
    Date?: GraphQLScalarType;
    DateTime?: GraphQLScalarType;
    Deletable?: DeletableResolvers<ContextType>;
    DeleteBranchProtectionRulePayload?: DeleteBranchProtectionRulePayloadResolvers<ContextType>;
    DeleteDeploymentPayload?: DeleteDeploymentPayloadResolvers<ContextType>;
    DeleteDiscussionCommentPayload?: DeleteDiscussionCommentPayloadResolvers<ContextType>;
    DeleteDiscussionPayload?: DeleteDiscussionPayloadResolvers<ContextType>;
    DeleteEnvironmentPayload?: DeleteEnvironmentPayloadResolvers<ContextType>;
    DeleteIpAllowListEntryPayload?: DeleteIpAllowListEntryPayloadResolvers<ContextType>;
    DeleteIssueCommentPayload?: DeleteIssueCommentPayloadResolvers<ContextType>;
    DeleteIssuePayload?: DeleteIssuePayloadResolvers<ContextType>;
    DeleteLabelPayload?: DeleteLabelPayloadResolvers<ContextType>;
    DeletePackageVersionPayload?: DeletePackageVersionPayloadResolvers<ContextType>;
    DeleteProjectCardPayload?: DeleteProjectCardPayloadResolvers<ContextType>;
    DeleteProjectColumnPayload?: DeleteProjectColumnPayloadResolvers<ContextType>;
    DeleteProjectPayload?: DeleteProjectPayloadResolvers<ContextType>;
    DeletePullRequestReviewCommentPayload?: DeletePullRequestReviewCommentPayloadResolvers<ContextType>;
    DeletePullRequestReviewPayload?: DeletePullRequestReviewPayloadResolvers<ContextType>;
    DeleteRefPayload?: DeleteRefPayloadResolvers<ContextType>;
    DeleteTeamDiscussionCommentPayload?: DeleteTeamDiscussionCommentPayloadResolvers<ContextType>;
    DeleteTeamDiscussionPayload?: DeleteTeamDiscussionPayloadResolvers<ContextType>;
    DeleteVerifiableDomainPayload?: DeleteVerifiableDomainPayloadResolvers<ContextType>;
    DemilestonedEvent?: DemilestonedEventResolvers<ContextType>;
    DeployKey?: DeployKeyResolvers<ContextType>;
    DeployKeyConnection?: DeployKeyConnectionResolvers<ContextType>;
    DeployKeyEdge?: DeployKeyEdgeResolvers<ContextType>;
    DeployedEvent?: DeployedEventResolvers<ContextType>;
    Deployment?: DeploymentResolvers<ContextType>;
    DeploymentConnection?: DeploymentConnectionResolvers<ContextType>;
    DeploymentEdge?: DeploymentEdgeResolvers<ContextType>;
    DeploymentEnvironmentChangedEvent?: DeploymentEnvironmentChangedEventResolvers<ContextType>;
    DeploymentProtectionRule?: DeploymentProtectionRuleResolvers<ContextType>;
    DeploymentProtectionRuleConnection?: DeploymentProtectionRuleConnectionResolvers<ContextType>;
    DeploymentProtectionRuleEdge?: DeploymentProtectionRuleEdgeResolvers<ContextType>;
    DeploymentRequest?: DeploymentRequestResolvers<ContextType>;
    DeploymentRequestConnection?: DeploymentRequestConnectionResolvers<ContextType>;
    DeploymentRequestEdge?: DeploymentRequestEdgeResolvers<ContextType>;
    DeploymentReview?: DeploymentReviewResolvers<ContextType>;
    DeploymentReviewConnection?: DeploymentReviewConnectionResolvers<ContextType>;
    DeploymentReviewEdge?: DeploymentReviewEdgeResolvers<ContextType>;
    DeploymentReviewer?: DeploymentReviewerResolvers<ContextType>;
    DeploymentReviewerConnection?: DeploymentReviewerConnectionResolvers<ContextType>;
    DeploymentReviewerEdge?: DeploymentReviewerEdgeResolvers<ContextType>;
    DeploymentStatus?: DeploymentStatusResolvers<ContextType>;
    DeploymentStatusConnection?: DeploymentStatusConnectionResolvers<ContextType>;
    DeploymentStatusEdge?: DeploymentStatusEdgeResolvers<ContextType>;
    DisablePullRequestAutoMergePayload?: DisablePullRequestAutoMergePayloadResolvers<ContextType>;
    DisconnectedEvent?: DisconnectedEventResolvers<ContextType>;
    Discussion?: DiscussionResolvers<ContextType>;
    DiscussionCategory?: DiscussionCategoryResolvers<ContextType>;
    DiscussionCategoryConnection?: DiscussionCategoryConnectionResolvers<ContextType>;
    DiscussionCategoryEdge?: DiscussionCategoryEdgeResolvers<ContextType>;
    DiscussionComment?: DiscussionCommentResolvers<ContextType>;
    DiscussionCommentConnection?: DiscussionCommentConnectionResolvers<ContextType>;
    DiscussionCommentEdge?: DiscussionCommentEdgeResolvers<ContextType>;
    DiscussionConnection?: DiscussionConnectionResolvers<ContextType>;
    DiscussionEdge?: DiscussionEdgeResolvers<ContextType>;
    DismissPullRequestReviewPayload?: DismissPullRequestReviewPayloadResolvers<ContextType>;
    EnablePullRequestAutoMergePayload?: EnablePullRequestAutoMergePayloadResolvers<ContextType>;
    Enterprise?: EnterpriseResolvers<ContextType>;
    EnterpriseAdministratorConnection?: EnterpriseAdministratorConnectionResolvers<ContextType>;
    EnterpriseAdministratorEdge?: EnterpriseAdministratorEdgeResolvers<ContextType>;
    EnterpriseAdministratorInvitation?: EnterpriseAdministratorInvitationResolvers<ContextType>;
    EnterpriseAdministratorInvitationConnection?: EnterpriseAdministratorInvitationConnectionResolvers<ContextType>;
    EnterpriseAdministratorInvitationEdge?: EnterpriseAdministratorInvitationEdgeResolvers<ContextType>;
    EnterpriseAuditEntryData?: EnterpriseAuditEntryDataResolvers<ContextType>;
    EnterpriseBillingInfo?: EnterpriseBillingInfoResolvers<ContextType>;
    EnterpriseIdentityProvider?: EnterpriseIdentityProviderResolvers<ContextType>;
    EnterpriseMember?: EnterpriseMemberResolvers<ContextType>;
    EnterpriseMemberConnection?: EnterpriseMemberConnectionResolvers<ContextType>;
    EnterpriseMemberEdge?: EnterpriseMemberEdgeResolvers<ContextType>;
    EnterpriseOrganizationMembershipConnection?: EnterpriseOrganizationMembershipConnectionResolvers<ContextType>;
    EnterpriseOrganizationMembershipEdge?: EnterpriseOrganizationMembershipEdgeResolvers<ContextType>;
    EnterpriseOutsideCollaboratorConnection?: EnterpriseOutsideCollaboratorConnectionResolvers<ContextType>;
    EnterpriseOutsideCollaboratorEdge?: EnterpriseOutsideCollaboratorEdgeResolvers<ContextType>;
    EnterpriseOwnerInfo?: EnterpriseOwnerInfoResolvers<ContextType>;
    EnterprisePendingCollaboratorConnection?: EnterprisePendingCollaboratorConnectionResolvers<ContextType>;
    EnterprisePendingCollaboratorEdge?: EnterprisePendingCollaboratorEdgeResolvers<ContextType>;
    EnterprisePendingMemberInvitationConnection?: EnterprisePendingMemberInvitationConnectionResolvers<ContextType>;
    EnterprisePendingMemberInvitationEdge?: EnterprisePendingMemberInvitationEdgeResolvers<ContextType>;
    EnterpriseRepositoryInfo?: EnterpriseRepositoryInfoResolvers<ContextType>;
    EnterpriseRepositoryInfoConnection?: EnterpriseRepositoryInfoConnectionResolvers<ContextType>;
    EnterpriseRepositoryInfoEdge?: EnterpriseRepositoryInfoEdgeResolvers<ContextType>;
    EnterpriseServerInstallation?: EnterpriseServerInstallationResolvers<ContextType>;
    EnterpriseServerUserAccount?: EnterpriseServerUserAccountResolvers<ContextType>;
    EnterpriseServerUserAccountConnection?: EnterpriseServerUserAccountConnectionResolvers<ContextType>;
    EnterpriseServerUserAccountEdge?: EnterpriseServerUserAccountEdgeResolvers<ContextType>;
    EnterpriseServerUserAccountEmail?: EnterpriseServerUserAccountEmailResolvers<ContextType>;
    EnterpriseServerUserAccountEmailConnection?: EnterpriseServerUserAccountEmailConnectionResolvers<ContextType>;
    EnterpriseServerUserAccountEmailEdge?: EnterpriseServerUserAccountEmailEdgeResolvers<ContextType>;
    EnterpriseServerUserAccountsUpload?: EnterpriseServerUserAccountsUploadResolvers<ContextType>;
    EnterpriseServerUserAccountsUploadConnection?: EnterpriseServerUserAccountsUploadConnectionResolvers<ContextType>;
    EnterpriseServerUserAccountsUploadEdge?: EnterpriseServerUserAccountsUploadEdgeResolvers<ContextType>;
    EnterpriseUserAccount?: EnterpriseUserAccountResolvers<ContextType>;
    EnterpriseUserAccountConnection?: EnterpriseUserAccountConnectionResolvers<ContextType>;
    EnterpriseUserAccountEdge?: EnterpriseUserAccountEdgeResolvers<ContextType>;
    Environment?: EnvironmentResolvers<ContextType>;
    EnvironmentConnection?: EnvironmentConnectionResolvers<ContextType>;
    EnvironmentEdge?: EnvironmentEdgeResolvers<ContextType>;
    ExternalIdentity?: ExternalIdentityResolvers<ContextType>;
    ExternalIdentityConnection?: ExternalIdentityConnectionResolvers<ContextType>;
    ExternalIdentityEdge?: ExternalIdentityEdgeResolvers<ContextType>;
    ExternalIdentitySamlAttributes?: ExternalIdentitySamlAttributesResolvers<ContextType>;
    ExternalIdentityScimAttributes?: ExternalIdentityScimAttributesResolvers<ContextType>;
    FollowUserPayload?: FollowUserPayloadResolvers<ContextType>;
    FollowerConnection?: FollowerConnectionResolvers<ContextType>;
    FollowingConnection?: FollowingConnectionResolvers<ContextType>;
    GenericHovercardContext?: GenericHovercardContextResolvers<ContextType>;
    Gist?: GistResolvers<ContextType>;
    GistComment?: GistCommentResolvers<ContextType>;
    GistCommentConnection?: GistCommentConnectionResolvers<ContextType>;
    GistCommentEdge?: GistCommentEdgeResolvers<ContextType>;
    GistConnection?: GistConnectionResolvers<ContextType>;
    GistEdge?: GistEdgeResolvers<ContextType>;
    GistFile?: GistFileResolvers<ContextType>;
    GitActor?: GitActorResolvers<ContextType>;
    GitActorConnection?: GitActorConnectionResolvers<ContextType>;
    GitActorEdge?: GitActorEdgeResolvers<ContextType>;
    GitHubMetadata?: GitHubMetadataResolvers<ContextType>;
    GitObject?: GitObjectResolvers<ContextType>;
    GitObjectID?: GraphQLScalarType;
    GitRefname?: GraphQLScalarType;
    GitSSHRemote?: GraphQLScalarType;
    GitSignature?: GitSignatureResolvers<ContextType>;
    GitTimestamp?: GraphQLScalarType;
    GpgSignature?: GpgSignatureResolvers<ContextType>;
    HTML?: GraphQLScalarType;
    HeadRefDeletedEvent?: HeadRefDeletedEventResolvers<ContextType>;
    HeadRefForcePushedEvent?: HeadRefForcePushedEventResolvers<ContextType>;
    HeadRefRestoredEvent?: HeadRefRestoredEventResolvers<ContextType>;
    Hovercard?: HovercardResolvers<ContextType>;
    HovercardContext?: HovercardContextResolvers<ContextType>;
    ImportProjectPayload?: ImportProjectPayloadResolvers<ContextType>;
    IpAllowListEntry?: IpAllowListEntryResolvers<ContextType>;
    IpAllowListEntryConnection?: IpAllowListEntryConnectionResolvers<ContextType>;
    IpAllowListEntryEdge?: IpAllowListEntryEdgeResolvers<ContextType>;
    IpAllowListOwner?: IpAllowListOwnerResolvers<ContextType>;
    Issue?: IssueResolvers<ContextType>;
    IssueComment?: IssueCommentResolvers<ContextType>;
    IssueCommentConnection?: IssueCommentConnectionResolvers<ContextType>;
    IssueCommentEdge?: IssueCommentEdgeResolvers<ContextType>;
    IssueConnection?: IssueConnectionResolvers<ContextType>;
    IssueContributionsByRepository?: IssueContributionsByRepositoryResolvers<ContextType>;
    IssueEdge?: IssueEdgeResolvers<ContextType>;
    IssueOrPullRequest?: IssueOrPullRequestResolvers<ContextType>;
    IssueTemplate?: IssueTemplateResolvers<ContextType>;
    IssueTimelineConnection?: IssueTimelineConnectionResolvers<ContextType>;
    IssueTimelineItem?: IssueTimelineItemResolvers<ContextType>;
    IssueTimelineItemEdge?: IssueTimelineItemEdgeResolvers<ContextType>;
    IssueTimelineItems?: IssueTimelineItemsResolvers<ContextType>;
    IssueTimelineItemsConnection?: IssueTimelineItemsConnectionResolvers<ContextType>;
    IssueTimelineItemsEdge?: IssueTimelineItemsEdgeResolvers<ContextType>;
    JoinedGitHubContribution?: JoinedGitHubContributionResolvers<ContextType>;
    Label?: LabelResolvers<ContextType>;
    LabelConnection?: LabelConnectionResolvers<ContextType>;
    LabelEdge?: LabelEdgeResolvers<ContextType>;
    Labelable?: LabelableResolvers<ContextType>;
    LabeledEvent?: LabeledEventResolvers<ContextType>;
    Language?: LanguageResolvers<ContextType>;
    LanguageConnection?: LanguageConnectionResolvers<ContextType>;
    LanguageEdge?: LanguageEdgeResolvers<ContextType>;
    License?: LicenseResolvers<ContextType>;
    LicenseRule?: LicenseRuleResolvers<ContextType>;
    LinkRepositoryToProjectPayload?: LinkRepositoryToProjectPayloadResolvers<ContextType>;
    LockLockablePayload?: LockLockablePayloadResolvers<ContextType>;
    Lockable?: LockableResolvers<ContextType>;
    LockedEvent?: LockedEventResolvers<ContextType>;
    Mannequin?: MannequinResolvers<ContextType>;
    MarkDiscussionCommentAsAnswerPayload?: MarkDiscussionCommentAsAnswerPayloadResolvers<ContextType>;
    MarkFileAsViewedPayload?: MarkFileAsViewedPayloadResolvers<ContextType>;
    MarkPullRequestReadyForReviewPayload?: MarkPullRequestReadyForReviewPayloadResolvers<ContextType>;
    MarkedAsDuplicateEvent?: MarkedAsDuplicateEventResolvers<ContextType>;
    MemberStatusable?: MemberStatusableResolvers<ContextType>;
    MembersCanDeleteReposClearAuditEntry?: MembersCanDeleteReposClearAuditEntryResolvers<ContextType>;
    MembersCanDeleteReposDisableAuditEntry?: MembersCanDeleteReposDisableAuditEntryResolvers<ContextType>;
    MembersCanDeleteReposEnableAuditEntry?: MembersCanDeleteReposEnableAuditEntryResolvers<ContextType>;
    MentionedEvent?: MentionedEventResolvers<ContextType>;
    MergeBranchPayload?: MergeBranchPayloadResolvers<ContextType>;
    MergePullRequestPayload?: MergePullRequestPayloadResolvers<ContextType>;
    MergedEvent?: MergedEventResolvers<ContextType>;
    Milestone?: MilestoneResolvers<ContextType>;
    MilestoneConnection?: MilestoneConnectionResolvers<ContextType>;
    MilestoneEdge?: MilestoneEdgeResolvers<ContextType>;
    MilestoneItem?: MilestoneItemResolvers<ContextType>;
    MilestonedEvent?: MilestonedEventResolvers<ContextType>;
    Minimizable?: MinimizableResolvers<ContextType>;
    MinimizeCommentPayload?: MinimizeCommentPayloadResolvers<ContextType>;
    MoveProjectCardPayload?: MoveProjectCardPayloadResolvers<ContextType>;
    MoveProjectColumnPayload?: MoveProjectColumnPayloadResolvers<ContextType>;
    MovedColumnsInProjectEvent?: MovedColumnsInProjectEventResolvers<ContextType>;
    Mutation?: MutationResolvers<ContextType>;
    Node?: NodeResolvers<ContextType>;
    OauthApplicationAuditEntryData?: OauthApplicationAuditEntryDataResolvers<ContextType>;
    OauthApplicationCreateAuditEntry?: OauthApplicationCreateAuditEntryResolvers<ContextType>;
    OrgAddBillingManagerAuditEntry?: OrgAddBillingManagerAuditEntryResolvers<ContextType>;
    OrgAddMemberAuditEntry?: OrgAddMemberAuditEntryResolvers<ContextType>;
    OrgBlockUserAuditEntry?: OrgBlockUserAuditEntryResolvers<ContextType>;
    OrgConfigDisableCollaboratorsOnlyAuditEntry?: OrgConfigDisableCollaboratorsOnlyAuditEntryResolvers<ContextType>;
    OrgConfigEnableCollaboratorsOnlyAuditEntry?: OrgConfigEnableCollaboratorsOnlyAuditEntryResolvers<ContextType>;
    OrgCreateAuditEntry?: OrgCreateAuditEntryResolvers<ContextType>;
    OrgDisableOauthAppRestrictionsAuditEntry?: OrgDisableOauthAppRestrictionsAuditEntryResolvers<ContextType>;
    OrgDisableSamlAuditEntry?: OrgDisableSamlAuditEntryResolvers<ContextType>;
    OrgDisableTwoFactorRequirementAuditEntry?: OrgDisableTwoFactorRequirementAuditEntryResolvers<ContextType>;
    OrgEnableOauthAppRestrictionsAuditEntry?: OrgEnableOauthAppRestrictionsAuditEntryResolvers<ContextType>;
    OrgEnableSamlAuditEntry?: OrgEnableSamlAuditEntryResolvers<ContextType>;
    OrgEnableTwoFactorRequirementAuditEntry?: OrgEnableTwoFactorRequirementAuditEntryResolvers<ContextType>;
    OrgInviteMemberAuditEntry?: OrgInviteMemberAuditEntryResolvers<ContextType>;
    OrgInviteToBusinessAuditEntry?: OrgInviteToBusinessAuditEntryResolvers<ContextType>;
    OrgOauthAppAccessApprovedAuditEntry?: OrgOauthAppAccessApprovedAuditEntryResolvers<ContextType>;
    OrgOauthAppAccessDeniedAuditEntry?: OrgOauthAppAccessDeniedAuditEntryResolvers<ContextType>;
    OrgOauthAppAccessRequestedAuditEntry?: OrgOauthAppAccessRequestedAuditEntryResolvers<ContextType>;
    OrgRemoveBillingManagerAuditEntry?: OrgRemoveBillingManagerAuditEntryResolvers<ContextType>;
    OrgRemoveMemberAuditEntry?: OrgRemoveMemberAuditEntryResolvers<ContextType>;
    OrgRemoveOutsideCollaboratorAuditEntry?: OrgRemoveOutsideCollaboratorAuditEntryResolvers<ContextType>;
    OrgRestoreMemberAuditEntry?: OrgRestoreMemberAuditEntryResolvers<ContextType>;
    OrgRestoreMemberAuditEntryMembership?: OrgRestoreMemberAuditEntryMembershipResolvers<ContextType>;
    OrgRestoreMemberMembershipOrganizationAuditEntryData?: OrgRestoreMemberMembershipOrganizationAuditEntryDataResolvers<ContextType>;
    OrgRestoreMemberMembershipRepositoryAuditEntryData?: OrgRestoreMemberMembershipRepositoryAuditEntryDataResolvers<ContextType>;
    OrgRestoreMemberMembershipTeamAuditEntryData?: OrgRestoreMemberMembershipTeamAuditEntryDataResolvers<ContextType>;
    OrgUnblockUserAuditEntry?: OrgUnblockUserAuditEntryResolvers<ContextType>;
    OrgUpdateDefaultRepositoryPermissionAuditEntry?: OrgUpdateDefaultRepositoryPermissionAuditEntryResolvers<ContextType>;
    OrgUpdateMemberAuditEntry?: OrgUpdateMemberAuditEntryResolvers<ContextType>;
    OrgUpdateMemberRepositoryCreationPermissionAuditEntry?: OrgUpdateMemberRepositoryCreationPermissionAuditEntryResolvers<ContextType>;
    OrgUpdateMemberRepositoryInvitationPermissionAuditEntry?: OrgUpdateMemberRepositoryInvitationPermissionAuditEntryResolvers<ContextType>;
    Organization?: OrganizationResolvers<ContextType>;
    OrganizationAuditEntry?: OrganizationAuditEntryResolvers<ContextType>;
    OrganizationAuditEntryConnection?: OrganizationAuditEntryConnectionResolvers<ContextType>;
    OrganizationAuditEntryData?: OrganizationAuditEntryDataResolvers<ContextType>;
    OrganizationAuditEntryEdge?: OrganizationAuditEntryEdgeResolvers<ContextType>;
    OrganizationConnection?: OrganizationConnectionResolvers<ContextType>;
    OrganizationEdge?: OrganizationEdgeResolvers<ContextType>;
    OrganizationIdentityProvider?: OrganizationIdentityProviderResolvers<ContextType>;
    OrganizationInvitation?: OrganizationInvitationResolvers<ContextType>;
    OrganizationInvitationConnection?: OrganizationInvitationConnectionResolvers<ContextType>;
    OrganizationInvitationEdge?: OrganizationInvitationEdgeResolvers<ContextType>;
    OrganizationMemberConnection?: OrganizationMemberConnectionResolvers<ContextType>;
    OrganizationMemberEdge?: OrganizationMemberEdgeResolvers<ContextType>;
    OrganizationTeamsHovercardContext?: OrganizationTeamsHovercardContextResolvers<ContextType>;
    OrganizationsHovercardContext?: OrganizationsHovercardContextResolvers<ContextType>;
    Package?: PackageResolvers<ContextType>;
    PackageConnection?: PackageConnectionResolvers<ContextType>;
    PackageEdge?: PackageEdgeResolvers<ContextType>;
    PackageFile?: PackageFileResolvers<ContextType>;
    PackageFileConnection?: PackageFileConnectionResolvers<ContextType>;
    PackageFileEdge?: PackageFileEdgeResolvers<ContextType>;
    PackageOwner?: PackageOwnerResolvers<ContextType>;
    PackageStatistics?: PackageStatisticsResolvers<ContextType>;
    PackageTag?: PackageTagResolvers<ContextType>;
    PackageVersion?: PackageVersionResolvers<ContextType>;
    PackageVersionConnection?: PackageVersionConnectionResolvers<ContextType>;
    PackageVersionEdge?: PackageVersionEdgeResolvers<ContextType>;
    PackageVersionStatistics?: PackageVersionStatisticsResolvers<ContextType>;
    PageInfo?: PageInfoResolvers<ContextType>;
    PermissionGranter?: PermissionGranterResolvers<ContextType>;
    PermissionSource?: PermissionSourceResolvers<ContextType>;
    PinIssuePayload?: PinIssuePayloadResolvers<ContextType>;
    PinnableItem?: PinnableItemResolvers<ContextType>;
    PinnableItemConnection?: PinnableItemConnectionResolvers<ContextType>;
    PinnableItemEdge?: PinnableItemEdgeResolvers<ContextType>;
    PinnedDiscussion?: PinnedDiscussionResolvers<ContextType>;
    PinnedDiscussionConnection?: PinnedDiscussionConnectionResolvers<ContextType>;
    PinnedDiscussionEdge?: PinnedDiscussionEdgeResolvers<ContextType>;
    PinnedEvent?: PinnedEventResolvers<ContextType>;
    PinnedIssue?: PinnedIssueResolvers<ContextType>;
    PinnedIssueConnection?: PinnedIssueConnectionResolvers<ContextType>;
    PinnedIssueEdge?: PinnedIssueEdgeResolvers<ContextType>;
    PreciseDateTime?: GraphQLScalarType;
    PrivateRepositoryForkingDisableAuditEntry?: PrivateRepositoryForkingDisableAuditEntryResolvers<ContextType>;
    PrivateRepositoryForkingEnableAuditEntry?: PrivateRepositoryForkingEnableAuditEntryResolvers<ContextType>;
    ProfileItemShowcase?: ProfileItemShowcaseResolvers<ContextType>;
    ProfileOwner?: ProfileOwnerResolvers<ContextType>;
    Project?: ProjectResolvers<ContextType>;
    ProjectCard?: ProjectCardResolvers<ContextType>;
    ProjectCardConnection?: ProjectCardConnectionResolvers<ContextType>;
    ProjectCardEdge?: ProjectCardEdgeResolvers<ContextType>;
    ProjectCardItem?: ProjectCardItemResolvers<ContextType>;
    ProjectColumn?: ProjectColumnResolvers<ContextType>;
    ProjectColumnConnection?: ProjectColumnConnectionResolvers<ContextType>;
    ProjectColumnEdge?: ProjectColumnEdgeResolvers<ContextType>;
    ProjectConnection?: ProjectConnectionResolvers<ContextType>;
    ProjectEdge?: ProjectEdgeResolvers<ContextType>;
    ProjectOwner?: ProjectOwnerResolvers<ContextType>;
    ProjectProgress?: ProjectProgressResolvers<ContextType>;
    PublicKey?: PublicKeyResolvers<ContextType>;
    PublicKeyConnection?: PublicKeyConnectionResolvers<ContextType>;
    PublicKeyEdge?: PublicKeyEdgeResolvers<ContextType>;
    PullRequest?: PullRequestResolvers<ContextType>;
    PullRequestChangedFile?: PullRequestChangedFileResolvers<ContextType>;
    PullRequestChangedFileConnection?: PullRequestChangedFileConnectionResolvers<ContextType>;
    PullRequestChangedFileEdge?: PullRequestChangedFileEdgeResolvers<ContextType>;
    PullRequestCommit?: PullRequestCommitResolvers<ContextType>;
    PullRequestCommitCommentThread?: PullRequestCommitCommentThreadResolvers<ContextType>;
    PullRequestCommitConnection?: PullRequestCommitConnectionResolvers<ContextType>;
    PullRequestCommitEdge?: PullRequestCommitEdgeResolvers<ContextType>;
    PullRequestConnection?: PullRequestConnectionResolvers<ContextType>;
    PullRequestContributionsByRepository?: PullRequestContributionsByRepositoryResolvers<ContextType>;
    PullRequestEdge?: PullRequestEdgeResolvers<ContextType>;
    PullRequestReview?: PullRequestReviewResolvers<ContextType>;
    PullRequestReviewComment?: PullRequestReviewCommentResolvers<ContextType>;
    PullRequestReviewCommentConnection?: PullRequestReviewCommentConnectionResolvers<ContextType>;
    PullRequestReviewCommentEdge?: PullRequestReviewCommentEdgeResolvers<ContextType>;
    PullRequestReviewConnection?: PullRequestReviewConnectionResolvers<ContextType>;
    PullRequestReviewContributionsByRepository?: PullRequestReviewContributionsByRepositoryResolvers<ContextType>;
    PullRequestReviewEdge?: PullRequestReviewEdgeResolvers<ContextType>;
    PullRequestReviewThread?: PullRequestReviewThreadResolvers<ContextType>;
    PullRequestReviewThreadConnection?: PullRequestReviewThreadConnectionResolvers<ContextType>;
    PullRequestReviewThreadEdge?: PullRequestReviewThreadEdgeResolvers<ContextType>;
    PullRequestRevisionMarker?: PullRequestRevisionMarkerResolvers<ContextType>;
    PullRequestTemplate?: PullRequestTemplateResolvers<ContextType>;
    PullRequestTimelineConnection?: PullRequestTimelineConnectionResolvers<ContextType>;
    PullRequestTimelineItem?: PullRequestTimelineItemResolvers<ContextType>;
    PullRequestTimelineItemEdge?: PullRequestTimelineItemEdgeResolvers<ContextType>;
    PullRequestTimelineItems?: PullRequestTimelineItemsResolvers<ContextType>;
    PullRequestTimelineItemsConnection?: PullRequestTimelineItemsConnectionResolvers<ContextType>;
    PullRequestTimelineItemsEdge?: PullRequestTimelineItemsEdgeResolvers<ContextType>;
    Push?: PushResolvers<ContextType>;
    PushAllowance?: PushAllowanceResolvers<ContextType>;
    PushAllowanceActor?: PushAllowanceActorResolvers<ContextType>;
    PushAllowanceConnection?: PushAllowanceConnectionResolvers<ContextType>;
    PushAllowanceEdge?: PushAllowanceEdgeResolvers<ContextType>;
    Query?: QueryResolvers<ContextType>;
    RateLimit?: RateLimitResolvers<ContextType>;
    Reactable?: ReactableResolvers<ContextType>;
    ReactingUserConnection?: ReactingUserConnectionResolvers<ContextType>;
    ReactingUserEdge?: ReactingUserEdgeResolvers<ContextType>;
    Reaction?: ReactionResolvers<ContextType>;
    ReactionConnection?: ReactionConnectionResolvers<ContextType>;
    ReactionEdge?: ReactionEdgeResolvers<ContextType>;
    ReactionGroup?: ReactionGroupResolvers<ContextType>;
    Reactor?: ReactorResolvers<ContextType>;
    ReactorConnection?: ReactorConnectionResolvers<ContextType>;
    ReactorEdge?: ReactorEdgeResolvers<ContextType>;
    ReadyForReviewEvent?: ReadyForReviewEventResolvers<ContextType>;
    Ref?: RefResolvers<ContextType>;
    RefConnection?: RefConnectionResolvers<ContextType>;
    RefEdge?: RefEdgeResolvers<ContextType>;
    RefUpdateRule?: RefUpdateRuleResolvers<ContextType>;
    ReferencedEvent?: ReferencedEventResolvers<ContextType>;
    ReferencedSubject?: ReferencedSubjectResolvers<ContextType>;
    RegenerateVerifiableDomainTokenPayload?: RegenerateVerifiableDomainTokenPayloadResolvers<ContextType>;
    RejectDeploymentsPayload?: RejectDeploymentsPayloadResolvers<ContextType>;
    Release?: ReleaseResolvers<ContextType>;
    ReleaseAsset?: ReleaseAssetResolvers<ContextType>;
    ReleaseAssetConnection?: ReleaseAssetConnectionResolvers<ContextType>;
    ReleaseAssetEdge?: ReleaseAssetEdgeResolvers<ContextType>;
    ReleaseConnection?: ReleaseConnectionResolvers<ContextType>;
    ReleaseEdge?: ReleaseEdgeResolvers<ContextType>;
    RemoveAssigneesFromAssignablePayload?: RemoveAssigneesFromAssignablePayloadResolvers<ContextType>;
    RemoveEnterpriseAdminPayload?: RemoveEnterpriseAdminPayloadResolvers<ContextType>;
    RemoveLabelsFromLabelablePayload?: RemoveLabelsFromLabelablePayloadResolvers<ContextType>;
    RemoveOutsideCollaboratorPayload?: RemoveOutsideCollaboratorPayloadResolvers<ContextType>;
    RemoveReactionPayload?: RemoveReactionPayloadResolvers<ContextType>;
    RemoveStarPayload?: RemoveStarPayloadResolvers<ContextType>;
    RemoveUpvotePayload?: RemoveUpvotePayloadResolvers<ContextType>;
    RemovedFromProjectEvent?: RemovedFromProjectEventResolvers<ContextType>;
    RenamedTitleEvent?: RenamedTitleEventResolvers<ContextType>;
    RenamedTitleSubject?: RenamedTitleSubjectResolvers<ContextType>;
    ReopenIssuePayload?: ReopenIssuePayloadResolvers<ContextType>;
    ReopenPullRequestPayload?: ReopenPullRequestPayloadResolvers<ContextType>;
    ReopenedEvent?: ReopenedEventResolvers<ContextType>;
    RepoAccessAuditEntry?: RepoAccessAuditEntryResolvers<ContextType>;
    RepoAddMemberAuditEntry?: RepoAddMemberAuditEntryResolvers<ContextType>;
    RepoAddTopicAuditEntry?: RepoAddTopicAuditEntryResolvers<ContextType>;
    RepoArchivedAuditEntry?: RepoArchivedAuditEntryResolvers<ContextType>;
    RepoChangeMergeSettingAuditEntry?: RepoChangeMergeSettingAuditEntryResolvers<ContextType>;
    RepoConfigDisableAnonymousGitAccessAuditEntry?: RepoConfigDisableAnonymousGitAccessAuditEntryResolvers<ContextType>;
    RepoConfigDisableCollaboratorsOnlyAuditEntry?: RepoConfigDisableCollaboratorsOnlyAuditEntryResolvers<ContextType>;
    RepoConfigDisableContributorsOnlyAuditEntry?: RepoConfigDisableContributorsOnlyAuditEntryResolvers<ContextType>;
    RepoConfigDisableSockpuppetDisallowedAuditEntry?: RepoConfigDisableSockpuppetDisallowedAuditEntryResolvers<ContextType>;
    RepoConfigEnableAnonymousGitAccessAuditEntry?: RepoConfigEnableAnonymousGitAccessAuditEntryResolvers<ContextType>;
    RepoConfigEnableCollaboratorsOnlyAuditEntry?: RepoConfigEnableCollaboratorsOnlyAuditEntryResolvers<ContextType>;
    RepoConfigEnableContributorsOnlyAuditEntry?: RepoConfigEnableContributorsOnlyAuditEntryResolvers<ContextType>;
    RepoConfigEnableSockpuppetDisallowedAuditEntry?: RepoConfigEnableSockpuppetDisallowedAuditEntryResolvers<ContextType>;
    RepoConfigLockAnonymousGitAccessAuditEntry?: RepoConfigLockAnonymousGitAccessAuditEntryResolvers<ContextType>;
    RepoConfigUnlockAnonymousGitAccessAuditEntry?: RepoConfigUnlockAnonymousGitAccessAuditEntryResolvers<ContextType>;
    RepoCreateAuditEntry?: RepoCreateAuditEntryResolvers<ContextType>;
    RepoDestroyAuditEntry?: RepoDestroyAuditEntryResolvers<ContextType>;
    RepoRemoveMemberAuditEntry?: RepoRemoveMemberAuditEntryResolvers<ContextType>;
    RepoRemoveTopicAuditEntry?: RepoRemoveTopicAuditEntryResolvers<ContextType>;
    Repository?: RepositoryResolvers<ContextType>;
    RepositoryAuditEntryData?: RepositoryAuditEntryDataResolvers<ContextType>;
    RepositoryCollaboratorConnection?: RepositoryCollaboratorConnectionResolvers<ContextType>;
    RepositoryCollaboratorEdge?: RepositoryCollaboratorEdgeResolvers<ContextType>;
    RepositoryConnection?: RepositoryConnectionResolvers<ContextType>;
    RepositoryContactLink?: RepositoryContactLinkResolvers<ContextType>;
    RepositoryDiscussionAuthor?: RepositoryDiscussionAuthorResolvers<ContextType>;
    RepositoryDiscussionCommentAuthor?: RepositoryDiscussionCommentAuthorResolvers<ContextType>;
    RepositoryEdge?: RepositoryEdgeResolvers<ContextType>;
    RepositoryInfo?: RepositoryInfoResolvers<ContextType>;
    RepositoryInvitation?: RepositoryInvitationResolvers<ContextType>;
    RepositoryInvitationConnection?: RepositoryInvitationConnectionResolvers<ContextType>;
    RepositoryInvitationEdge?: RepositoryInvitationEdgeResolvers<ContextType>;
    RepositoryNode?: RepositoryNodeResolvers<ContextType>;
    RepositoryOwner?: RepositoryOwnerResolvers<ContextType>;
    RepositoryTopic?: RepositoryTopicResolvers<ContextType>;
    RepositoryTopicConnection?: RepositoryTopicConnectionResolvers<ContextType>;
    RepositoryTopicEdge?: RepositoryTopicEdgeResolvers<ContextType>;
    RepositoryVisibilityChangeDisableAuditEntry?: RepositoryVisibilityChangeDisableAuditEntryResolvers<ContextType>;
    RepositoryVisibilityChangeEnableAuditEntry?: RepositoryVisibilityChangeEnableAuditEntryResolvers<ContextType>;
    RepositoryVulnerabilityAlert?: RepositoryVulnerabilityAlertResolvers<ContextType>;
    RepositoryVulnerabilityAlertConnection?: RepositoryVulnerabilityAlertConnectionResolvers<ContextType>;
    RepositoryVulnerabilityAlertEdge?: RepositoryVulnerabilityAlertEdgeResolvers<ContextType>;
    RequestReviewsPayload?: RequestReviewsPayloadResolvers<ContextType>;
    RequestedReviewer?: RequestedReviewerResolvers<ContextType>;
    RequirableByPullRequest?: RequirableByPullRequestResolvers<ContextType>;
    RerequestCheckSuitePayload?: RerequestCheckSuitePayloadResolvers<ContextType>;
    ResolveReviewThreadPayload?: ResolveReviewThreadPayloadResolvers<ContextType>;
    RestrictedContribution?: RestrictedContributionResolvers<ContextType>;
    ReviewDismissalAllowance?: ReviewDismissalAllowanceResolvers<ContextType>;
    ReviewDismissalAllowanceActor?: ReviewDismissalAllowanceActorResolvers<ContextType>;
    ReviewDismissalAllowanceConnection?: ReviewDismissalAllowanceConnectionResolvers<ContextType>;
    ReviewDismissalAllowanceEdge?: ReviewDismissalAllowanceEdgeResolvers<ContextType>;
    ReviewDismissedEvent?: ReviewDismissedEventResolvers<ContextType>;
    ReviewRequest?: ReviewRequestResolvers<ContextType>;
    ReviewRequestConnection?: ReviewRequestConnectionResolvers<ContextType>;
    ReviewRequestEdge?: ReviewRequestEdgeResolvers<ContextType>;
    ReviewRequestRemovedEvent?: ReviewRequestRemovedEventResolvers<ContextType>;
    ReviewRequestedEvent?: ReviewRequestedEventResolvers<ContextType>;
    ReviewStatusHovercardContext?: ReviewStatusHovercardContextResolvers<ContextType>;
    SavedReply?: SavedReplyResolvers<ContextType>;
    SavedReplyConnection?: SavedReplyConnectionResolvers<ContextType>;
    SavedReplyEdge?: SavedReplyEdgeResolvers<ContextType>;
    SearchResultItem?: SearchResultItemResolvers<ContextType>;
    SearchResultItemConnection?: SearchResultItemConnectionResolvers<ContextType>;
    SearchResultItemEdge?: SearchResultItemEdgeResolvers<ContextType>;
    SecurityAdvisory?: SecurityAdvisoryResolvers<ContextType>;
    SecurityAdvisoryConnection?: SecurityAdvisoryConnectionResolvers<ContextType>;
    SecurityAdvisoryEdge?: SecurityAdvisoryEdgeResolvers<ContextType>;
    SecurityAdvisoryIdentifier?: SecurityAdvisoryIdentifierResolvers<ContextType>;
    SecurityAdvisoryPackage?: SecurityAdvisoryPackageResolvers<ContextType>;
    SecurityAdvisoryPackageVersion?: SecurityAdvisoryPackageVersionResolvers<ContextType>;
    SecurityAdvisoryReference?: SecurityAdvisoryReferenceResolvers<ContextType>;
    SecurityVulnerability?: SecurityVulnerabilityResolvers<ContextType>;
    SecurityVulnerabilityConnection?: SecurityVulnerabilityConnectionResolvers<ContextType>;
    SecurityVulnerabilityEdge?: SecurityVulnerabilityEdgeResolvers<ContextType>;
    SmimeSignature?: SmimeSignatureResolvers<ContextType>;
    Sponsor?: SponsorResolvers<ContextType>;
    Sponsorable?: SponsorableResolvers<ContextType>;
    Sponsorship?: SponsorshipResolvers<ContextType>;
    SponsorshipConnection?: SponsorshipConnectionResolvers<ContextType>;
    SponsorshipEdge?: SponsorshipEdgeResolvers<ContextType>;
    StargazerConnection?: StargazerConnectionResolvers<ContextType>;
    StargazerEdge?: StargazerEdgeResolvers<ContextType>;
    Starrable?: StarrableResolvers<ContextType>;
    StarredRepositoryConnection?: StarredRepositoryConnectionResolvers<ContextType>;
    StarredRepositoryEdge?: StarredRepositoryEdgeResolvers<ContextType>;
    Status?: StatusResolvers<ContextType>;
    StatusCheckRollup?: StatusCheckRollupResolvers<ContextType>;
    StatusCheckRollupContext?: StatusCheckRollupContextResolvers<ContextType>;
    StatusCheckRollupContextConnection?: StatusCheckRollupContextConnectionResolvers<ContextType>;
    StatusCheckRollupContextEdge?: StatusCheckRollupContextEdgeResolvers<ContextType>;
    StatusContext?: StatusContextResolvers<ContextType>;
    SubmitPullRequestReviewPayload?: SubmitPullRequestReviewPayloadResolvers<ContextType>;
    Submodule?: SubmoduleResolvers<ContextType>;
    SubmoduleConnection?: SubmoduleConnectionResolvers<ContextType>;
    SubmoduleEdge?: SubmoduleEdgeResolvers<ContextType>;
    Subscribable?: SubscribableResolvers<ContextType>;
    SubscribedEvent?: SubscribedEventResolvers<ContextType>;
    SuggestedReviewer?: SuggestedReviewerResolvers<ContextType>;
    Tag?: TagResolvers<ContextType>;
    Team?: TeamResolvers<ContextType>;
    TeamAddMemberAuditEntry?: TeamAddMemberAuditEntryResolvers<ContextType>;
    TeamAddRepositoryAuditEntry?: TeamAddRepositoryAuditEntryResolvers<ContextType>;
    TeamAuditEntryData?: TeamAuditEntryDataResolvers<ContextType>;
    TeamChangeParentTeamAuditEntry?: TeamChangeParentTeamAuditEntryResolvers<ContextType>;
    TeamConnection?: TeamConnectionResolvers<ContextType>;
    TeamDiscussion?: TeamDiscussionResolvers<ContextType>;
    TeamDiscussionComment?: TeamDiscussionCommentResolvers<ContextType>;
    TeamDiscussionCommentConnection?: TeamDiscussionCommentConnectionResolvers<ContextType>;
    TeamDiscussionCommentEdge?: TeamDiscussionCommentEdgeResolvers<ContextType>;
    TeamDiscussionConnection?: TeamDiscussionConnectionResolvers<ContextType>;
    TeamDiscussionEdge?: TeamDiscussionEdgeResolvers<ContextType>;
    TeamEdge?: TeamEdgeResolvers<ContextType>;
    TeamMemberConnection?: TeamMemberConnectionResolvers<ContextType>;
    TeamMemberEdge?: TeamMemberEdgeResolvers<ContextType>;
    TeamRemoveMemberAuditEntry?: TeamRemoveMemberAuditEntryResolvers<ContextType>;
    TeamRemoveRepositoryAuditEntry?: TeamRemoveRepositoryAuditEntryResolvers<ContextType>;
    TeamRepositoryConnection?: TeamRepositoryConnectionResolvers<ContextType>;
    TeamRepositoryEdge?: TeamRepositoryEdgeResolvers<ContextType>;
    TextMatch?: TextMatchResolvers<ContextType>;
    TextMatchHighlight?: TextMatchHighlightResolvers<ContextType>;
    Topic?: TopicResolvers<ContextType>;
    TopicAuditEntryData?: TopicAuditEntryDataResolvers<ContextType>;
    TransferIssuePayload?: TransferIssuePayloadResolvers<ContextType>;
    TransferredEvent?: TransferredEventResolvers<ContextType>;
    Tree?: TreeResolvers<ContextType>;
    TreeEntry?: TreeEntryResolvers<ContextType>;
    URI?: GraphQLScalarType;
    UnarchiveRepositoryPayload?: UnarchiveRepositoryPayloadResolvers<ContextType>;
    UnassignedEvent?: UnassignedEventResolvers<ContextType>;
    UnfollowUserPayload?: UnfollowUserPayloadResolvers<ContextType>;
    UniformResourceLocatable?: UniformResourceLocatableResolvers<ContextType>;
    UnknownSignature?: UnknownSignatureResolvers<ContextType>;
    UnlabeledEvent?: UnlabeledEventResolvers<ContextType>;
    UnlinkRepositoryFromProjectPayload?: UnlinkRepositoryFromProjectPayloadResolvers<ContextType>;
    UnlockLockablePayload?: UnlockLockablePayloadResolvers<ContextType>;
    UnlockedEvent?: UnlockedEventResolvers<ContextType>;
    UnmarkDiscussionCommentAsAnswerPayload?: UnmarkDiscussionCommentAsAnswerPayloadResolvers<ContextType>;
    UnmarkFileAsViewedPayload?: UnmarkFileAsViewedPayloadResolvers<ContextType>;
    UnmarkIssueAsDuplicatePayload?: UnmarkIssueAsDuplicatePayloadResolvers<ContextType>;
    UnmarkedAsDuplicateEvent?: UnmarkedAsDuplicateEventResolvers<ContextType>;
    UnminimizeCommentPayload?: UnminimizeCommentPayloadResolvers<ContextType>;
    UnpinIssuePayload?: UnpinIssuePayloadResolvers<ContextType>;
    UnpinnedEvent?: UnpinnedEventResolvers<ContextType>;
    UnresolveReviewThreadPayload?: UnresolveReviewThreadPayloadResolvers<ContextType>;
    UnsubscribedEvent?: UnsubscribedEventResolvers<ContextType>;
    Updatable?: UpdatableResolvers<ContextType>;
    UpdatableComment?: UpdatableCommentResolvers<ContextType>;
    UpdateBranchProtectionRulePayload?: UpdateBranchProtectionRulePayloadResolvers<ContextType>;
    UpdateCheckRunPayload?: UpdateCheckRunPayloadResolvers<ContextType>;
    UpdateCheckSuitePreferencesPayload?: UpdateCheckSuitePreferencesPayloadResolvers<ContextType>;
    UpdateDiscussionCommentPayload?: UpdateDiscussionCommentPayloadResolvers<ContextType>;
    UpdateDiscussionPayload?: UpdateDiscussionPayloadResolvers<ContextType>;
    UpdateEnterpriseAllowPrivateRepositoryForkingSettingPayload?: UpdateEnterpriseAllowPrivateRepositoryForkingSettingPayloadResolvers<ContextType>;
    UpdateEnterpriseDefaultRepositoryPermissionSettingPayload?: UpdateEnterpriseDefaultRepositoryPermissionSettingPayloadResolvers<ContextType>;
    UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingPayload?: UpdateEnterpriseMembersCanChangeRepositoryVisibilitySettingPayloadResolvers<ContextType>;
    UpdateEnterpriseMembersCanCreateRepositoriesSettingPayload?: UpdateEnterpriseMembersCanCreateRepositoriesSettingPayloadResolvers<ContextType>;
    UpdateEnterpriseMembersCanDeleteIssuesSettingPayload?: UpdateEnterpriseMembersCanDeleteIssuesSettingPayloadResolvers<ContextType>;
    UpdateEnterpriseMembersCanDeleteRepositoriesSettingPayload?: UpdateEnterpriseMembersCanDeleteRepositoriesSettingPayloadResolvers<ContextType>;
    UpdateEnterpriseMembersCanInviteCollaboratorsSettingPayload?: UpdateEnterpriseMembersCanInviteCollaboratorsSettingPayloadResolvers<ContextType>;
    UpdateEnterpriseMembersCanMakePurchasesSettingPayload?: UpdateEnterpriseMembersCanMakePurchasesSettingPayloadResolvers<ContextType>;
    UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingPayload?: UpdateEnterpriseMembersCanUpdateProtectedBranchesSettingPayloadResolvers<ContextType>;
    UpdateEnterpriseMembersCanViewDependencyInsightsSettingPayload?: UpdateEnterpriseMembersCanViewDependencyInsightsSettingPayloadResolvers<ContextType>;
    UpdateEnterpriseOrganizationProjectsSettingPayload?: UpdateEnterpriseOrganizationProjectsSettingPayloadResolvers<ContextType>;
    UpdateEnterpriseProfilePayload?: UpdateEnterpriseProfilePayloadResolvers<ContextType>;
    UpdateEnterpriseRepositoryProjectsSettingPayload?: UpdateEnterpriseRepositoryProjectsSettingPayloadResolvers<ContextType>;
    UpdateEnterpriseTeamDiscussionsSettingPayload?: UpdateEnterpriseTeamDiscussionsSettingPayloadResolvers<ContextType>;
    UpdateEnterpriseTwoFactorAuthenticationRequiredSettingPayload?: UpdateEnterpriseTwoFactorAuthenticationRequiredSettingPayloadResolvers<ContextType>;
    UpdateEnvironmentPayload?: UpdateEnvironmentPayloadResolvers<ContextType>;
    UpdateIpAllowListEnabledSettingPayload?: UpdateIpAllowListEnabledSettingPayloadResolvers<ContextType>;
    UpdateIpAllowListEntryPayload?: UpdateIpAllowListEntryPayloadResolvers<ContextType>;
    UpdateIpAllowListForInstalledAppsEnabledSettingPayload?: UpdateIpAllowListForInstalledAppsEnabledSettingPayloadResolvers<ContextType>;
    UpdateIssueCommentPayload?: UpdateIssueCommentPayloadResolvers<ContextType>;
    UpdateIssuePayload?: UpdateIssuePayloadResolvers<ContextType>;
    UpdateLabelPayload?: UpdateLabelPayloadResolvers<ContextType>;
    UpdateNotificationRestrictionSettingPayload?: UpdateNotificationRestrictionSettingPayloadResolvers<ContextType>;
    UpdateProjectCardPayload?: UpdateProjectCardPayloadResolvers<ContextType>;
    UpdateProjectColumnPayload?: UpdateProjectColumnPayloadResolvers<ContextType>;
    UpdateProjectPayload?: UpdateProjectPayloadResolvers<ContextType>;
    UpdatePullRequestPayload?: UpdatePullRequestPayloadResolvers<ContextType>;
    UpdatePullRequestReviewCommentPayload?: UpdatePullRequestReviewCommentPayloadResolvers<ContextType>;
    UpdatePullRequestReviewPayload?: UpdatePullRequestReviewPayloadResolvers<ContextType>;
    UpdateRefPayload?: UpdateRefPayloadResolvers<ContextType>;
    UpdateRefsPayload?: UpdateRefsPayloadResolvers<ContextType>;
    UpdateRepositoryPayload?: UpdateRepositoryPayloadResolvers<ContextType>;
    UpdateSubscriptionPayload?: UpdateSubscriptionPayloadResolvers<ContextType>;
    UpdateTeamDiscussionCommentPayload?: UpdateTeamDiscussionCommentPayloadResolvers<ContextType>;
    UpdateTeamDiscussionPayload?: UpdateTeamDiscussionPayloadResolvers<ContextType>;
    UpdateTeamReviewAssignmentPayload?: UpdateTeamReviewAssignmentPayloadResolvers<ContextType>;
    UpdateTopicsPayload?: UpdateTopicsPayloadResolvers<ContextType>;
    User?: UserResolvers<ContextType>;
    UserBlockedEvent?: UserBlockedEventResolvers<ContextType>;
    UserConnection?: UserConnectionResolvers<ContextType>;
    UserContentEdit?: UserContentEditResolvers<ContextType>;
    UserContentEditConnection?: UserContentEditConnectionResolvers<ContextType>;
    UserContentEditEdge?: UserContentEditEdgeResolvers<ContextType>;
    UserEdge?: UserEdgeResolvers<ContextType>;
    UserEmailMetadata?: UserEmailMetadataResolvers<ContextType>;
    UserStatus?: UserStatusResolvers<ContextType>;
    UserStatusConnection?: UserStatusConnectionResolvers<ContextType>;
    UserStatusEdge?: UserStatusEdgeResolvers<ContextType>;
    VerifiableDomain?: VerifiableDomainResolvers<ContextType>;
    VerifiableDomainConnection?: VerifiableDomainConnectionResolvers<ContextType>;
    VerifiableDomainEdge?: VerifiableDomainEdgeResolvers<ContextType>;
    VerifiableDomainOwner?: VerifiableDomainOwnerResolvers<ContextType>;
    VerifyVerifiableDomainPayload?: VerifyVerifiableDomainPayloadResolvers<ContextType>;
    ViewerHovercardContext?: ViewerHovercardContextResolvers<ContextType>;
    Votable?: VotableResolvers<ContextType>;
    Workflow?: WorkflowResolvers<ContextType>;
    WorkflowRun?: WorkflowRunResolvers<ContextType>;
    X509Certificate?: GraphQLScalarType;
};
export type DirectiveResolvers<ContextType = any> = {
    possibleTypes?: PossibleTypesDirectiveResolver<any, any, ContextType>;
    preview?: PreviewDirectiveResolver<any, any, ContextType>;
};
//# sourceMappingURL=resolvers-types.d.ts.map